/***
 * @auth topoadmin
 * @description 中国省市信息联动插件
 * @time 2016-09-25 20:42:54
 * options 参数说明
 * ------------------
 * @param title				String		头部提示
 * @param prov				String 		默认省份
 * @param city				String 		默认城市
 * @param district			String 		默认区/县
 * @param selectNumber		Int			设置省市县可选择个数 1-2,默认为3个都可选
 * @param scrollToCenter	Boolean 	true:已选位置滚动到中央 ,默认为顶部
 * @param autoOpen			Boolean 	自动打开
 * @param customOutput		Function	自定义选择完毕输出，不执行内部填充函数
 * @param selectEnd			Function 	选择完毕回调事件 return {prov,city,district},address
 * ------------------
 * @version 1.0.0
 */
(function(factory) {
	'use strict';
	if(typeof define === 'function' && define.amd) {
		define(['jquery', 'amazeui'], factory);
	} else if(typeof exports !== 'undefined') {
		module.exports = factory(require('jquery'), require('amazeui'));
	} else {
		factory(jQuery, jQuery.AMUI);
	}

}(function($) {
	"use strict";
	var addressJson = [{
		"id": 210000,
		"name": "辽宁省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 210200,
			"name": "大连市",
			"parent_id": 210000,
			"type": 3,
			"zip": "116000",
			"district": [{
				"id": 210203,
				"name": "西岗区",
				"parent_id": 210200,
				"type": 4,
				"zip": "116011"
			}, {
				"id": 210202,
				"name": "中山区",
				"parent_id": 210200,
				"type": 4,
				"zip": "116001"
			}, {
				"id": 210204,
				"name": "沙河口区",
				"parent_id": 210200,
				"type": 4,
				"zip": "116021"
			}, {
				"id": 210211,
				"name": "甘井子区",
				"parent_id": 210200,
				"type": 4,
				"zip": "116033"
			}, {
				"id": 210212,
				"name": "旅顺口区",
				"parent_id": 210200,
				"type": 4,
				"zip": "116041"
			}, {
				"id": 210213,
				"name": "金州区",
				"parent_id": 210200,
				"type": 4,
				"zip": "116100"
			}, {
				"id": 210224,
				"name": "长海县",
				"parent_id": 210200,
				"type": 4,
				"zip": "116500"
			}, {
				"id": 210251,
				"name": "开发区",
				"parent_id": 210200,
				"type": 4,
				"zip": ""
			}, {
				"id": 210281,
				"name": "瓦房店市",
				"parent_id": 210200,
				"type": 4,
				"zip": "116300"
			}, {
				"id": 210282,
				"name": "普兰店市",
				"parent_id": 210200,
				"type": 4,
				"zip": "116200"
			}, {
				"id": 210283,
				"name": "庄河市",
				"parent_id": 210200,
				"type": 4,
				"zip": "116400"
			}, {
				"id": 210297,
				"name": "岭前区",
				"parent_id": 210200,
				"type": 4,
				"zip": ""
			}, {
				"id": 210298,
				"name": "其它区",
				"parent_id": 210200,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 210300,
			"name": "鞍山市",
			"parent_id": 210000,
			"type": 3,
			"zip": "114000",
			"district": [{
				"id": 210303,
				"name": "铁西区",
				"parent_id": 210300,
				"type": 4,
				"zip": "110023"
			}, {
				"id": 210302,
				"name": "铁东区",
				"parent_id": 210300,
				"type": 4,
				"zip": "114001"
			}, {
				"id": 210304,
				"name": "立山区",
				"parent_id": 210300,
				"type": 4,
				"zip": "114031"
			}, {
				"id": 210311,
				"name": "千山区",
				"parent_id": 210300,
				"type": 4,
				"zip": "114041"
			}, {
				"id": 210323,
				"name": "岫岩满族自治县",
				"parent_id": 210300,
				"type": 4,
				"zip": "114300"
			}, {
				"id": 210321,
				"name": "台安县",
				"parent_id": 210300,
				"type": 4,
				"zip": "114100"
			}, {
				"id": 210351,
				"name": "高新区",
				"parent_id": 210300,
				"type": 4,
				"zip": ""
			}, {
				"id": 210382,
				"name": "其它区",
				"parent_id": 210300,
				"type": 4,
				"zip": ""
			}, {
				"id": 210381,
				"name": "海城市",
				"parent_id": 210300,
				"type": 4,
				"zip": "114200"
			}]
		}, {
			"id": 210400,
			"name": "抚顺市",
			"parent_id": 210000,
			"type": 3,
			"zip": "113000",
			"district": [{
				"id": 210404,
				"name": "望花区",
				"parent_id": 210400,
				"type": 4,
				"zip": "113001"
			}, {
				"id": 210403,
				"name": "东洲区",
				"parent_id": 210400,
				"type": 4,
				"zip": "113003"
			}, {
				"id": 210402,
				"name": "新抚区",
				"parent_id": 210400,
				"type": 4,
				"zip": "113006"
			}, {
				"id": 210411,
				"name": "顺城区",
				"parent_id": 210400,
				"type": 4,
				"zip": "113006"
			}, {
				"id": 210421,
				"name": "抚顺县",
				"parent_id": 210400,
				"type": 4,
				"zip": "113100"
			}, {
				"id": 210422,
				"name": "新宾满族自治县",
				"parent_id": 210400,
				"type": 4,
				"zip": "113200"
			}, {
				"id": 210423,
				"name": "清原满族自治县",
				"parent_id": 210400,
				"type": 4,
				"zip": "113300"
			}, {
				"id": 210424,
				"name": "其它区",
				"parent_id": 210400,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 210100,
			"name": "沈阳市",
			"parent_id": 210000,
			"type": 3,
			"zip": "110000",
			"district": [{
				"id": 210184,
				"name": "沈北新区",
				"parent_id": 210100,
				"type": 4,
				"zip": ""
			}, {
				"id": 210185,
				"name": "其它区",
				"parent_id": 210100,
				"type": 4,
				"zip": ""
			}, {
				"id": 210182,
				"name": "浑南新区",
				"parent_id": 210100,
				"type": 4,
				"zip": ""
			}, {
				"id": 210183,
				"name": "张士开发区",
				"parent_id": 210100,
				"type": 4,
				"zip": ""
			}, {
				"id": 210181,
				"name": "新民市",
				"parent_id": 210100,
				"type": 4,
				"zip": "110300"
			}, {
				"id": 210102,
				"name": "和平区",
				"parent_id": 210100,
				"type": 4,
				"zip": "110002"
			}, {
				"id": 210103,
				"name": "沈河区",
				"parent_id": 210100,
				"type": 4,
				"zip": "110013"
			}, {
				"id": 210106,
				"name": "铁西区",
				"parent_id": 210100,
				"type": 4,
				"zip": "110023"
			}, {
				"id": 210104,
				"name": "大东区",
				"parent_id": 210100,
				"type": 4,
				"zip": "110044"
			}, {
				"id": 210105,
				"name": "皇姑区",
				"parent_id": 210100,
				"type": 4,
				"zip": "110031"
			}, {
				"id": 210111,
				"name": "苏家屯区",
				"parent_id": 210100,
				"type": 4,
				"zip": "110102"
			}, {
				"id": 210113,
				"name": "新城子区",
				"parent_id": 210100,
				"type": 4,
				"zip": "110121"
			}, {
				"id": 210112,
				"name": "东陵区",
				"parent_id": 210100,
				"type": 4,
				"zip": "110015"
			}, {
				"id": 210114,
				"name": "于洪区",
				"parent_id": 210100,
				"type": 4,
				"zip": "110024"
			}, {
				"id": 210124,
				"name": "法库县",
				"parent_id": 210100,
				"type": 4,
				"zip": "110400"
			}, {
				"id": 210123,
				"name": "康平县",
				"parent_id": 210100,
				"type": 4,
				"zip": "110500"
			}, {
				"id": 210122,
				"name": "辽中县",
				"parent_id": 210100,
				"type": 4,
				"zip": "110200"
			}]
		}, {
			"id": 210700,
			"name": "锦州市",
			"parent_id": 210000,
			"type": 3,
			"zip": "121000",
			"district": [{
				"id": 210726,
				"name": "黑山县",
				"parent_id": 210700,
				"type": 4,
				"zip": "121400"
			}, {
				"id": 210727,
				"name": "义县",
				"parent_id": 210700,
				"type": 4,
				"zip": "121100"
			}, {
				"id": 210702,
				"name": "古塔区",
				"parent_id": 210700,
				"type": 4,
				"zip": "121001"
			}, {
				"id": 210703,
				"name": "凌河区",
				"parent_id": 210700,
				"type": 4,
				"zip": "121000"
			}, {
				"id": 210711,
				"name": "太和区",
				"parent_id": 210700,
				"type": 4,
				"zip": "121011"
			}, {
				"id": 210783,
				"name": "其它区",
				"parent_id": 210700,
				"type": 4,
				"zip": ""
			}, {
				"id": 210782,
				"name": "北镇市",
				"parent_id": 210700,
				"type": 4,
				"zip": "121300"
			}, {
				"id": 210781,
				"name": "凌海市",
				"parent_id": 210700,
				"type": 4,
				"zip": "121200"
			}]
		}, {
			"id": 210800,
			"name": "营口市",
			"parent_id": 210000,
			"type": 3,
			"zip": "115000",
			"district": [{
				"id": 210811,
				"name": "老边区",
				"parent_id": 210800,
				"type": 4,
				"zip": "115005"
			}, {
				"id": 210803,
				"name": "西市区",
				"parent_id": 210800,
				"type": 4,
				"zip": "115004"
			}, {
				"id": 210802,
				"name": "站前区",
				"parent_id": 210800,
				"type": 4,
				"zip": "115002"
			}, {
				"id": 210804,
				"name": "鲅鱼圈区",
				"parent_id": 210800,
				"type": 4,
				"zip": "115007"
			}, {
				"id": 210883,
				"name": "其它区",
				"parent_id": 210800,
				"type": 4,
				"zip": ""
			}, {
				"id": 210882,
				"name": "大石桥市",
				"parent_id": 210800,
				"type": 4,
				"zip": "115100"
			}, {
				"id": 210881,
				"name": "盖州市",
				"parent_id": 210800,
				"type": 4,
				"zip": "115200"
			}]
		}, {
			"id": 210900,
			"name": "阜新市",
			"parent_id": 210000,
			"type": 3,
			"zip": "123000",
			"district": [{
				"id": 210921,
				"name": "阜新蒙古族自治县",
				"parent_id": 210900,
				"type": 4,
				"zip": "123100"
			}, {
				"id": 210923,
				"name": "其它区",
				"parent_id": 210900,
				"type": 4,
				"zip": ""
			}, {
				"id": 210922,
				"name": "彰武县",
				"parent_id": 210900,
				"type": 4,
				"zip": "123200"
			}, {
				"id": 210902,
				"name": "海州区",
				"parent_id": 210900,
				"type": 4,
				"zip": "123000"
			}, {
				"id": 210903,
				"name": "新邱区",
				"parent_id": 210900,
				"type": 4,
				"zip": "123005"
			}, {
				"id": 210904,
				"name": "太平区",
				"parent_id": 210900,
				"type": 4,
				"zip": "123003"
			}, {
				"id": 210905,
				"name": "清河门区",
				"parent_id": 210900,
				"type": 4,
				"zip": "123006"
			}, {
				"id": 210911,
				"name": "细河区",
				"parent_id": 210900,
				"type": 4,
				"zip": "123000"
			}]
		}, {
			"id": 210500,
			"name": "本溪市",
			"parent_id": 210000,
			"type": 3,
			"zip": "117000",
			"district": [{
				"id": 210521,
				"name": "本溪满族自治县",
				"parent_id": 210500,
				"type": 4,
				"zip": "117100"
			}, {
				"id": 210523,
				"name": "其它区",
				"parent_id": 210500,
				"type": 4,
				"zip": ""
			}, {
				"id": 210522,
				"name": "桓仁满族自治县",
				"parent_id": 210500,
				"type": 4,
				"zip": "117200"
			}, {
				"id": 210504,
				"name": "明山区",
				"parent_id": 210500,
				"type": 4,
				"zip": "117021"
			}, {
				"id": 210505,
				"name": "南芬区",
				"parent_id": 210500,
				"type": 4,
				"zip": "117014"
			}, {
				"id": 210502,
				"name": "平山区",
				"parent_id": 210500,
				"type": 4,
				"zip": "117000"
			}, {
				"id": 210503,
				"name": "溪湖区",
				"parent_id": 210500,
				"type": 4,
				"zip": "117002"
			}]
		}, {
			"id": 210600,
			"name": "丹东市",
			"parent_id": 210000,
			"type": 3,
			"zip": "118000",
			"district": [{
				"id": 210604,
				"name": "振安区",
				"parent_id": 210600,
				"type": 4,
				"zip": "118001"
			}, {
				"id": 210603,
				"name": "振兴区",
				"parent_id": 210600,
				"type": 4,
				"zip": "118002"
			}, {
				"id": 210602,
				"name": "元宝区",
				"parent_id": 210600,
				"type": 4,
				"zip": "118000"
			}, {
				"id": 210682,
				"name": "凤城市",
				"parent_id": 210600,
				"type": 4,
				"zip": "118100"
			}, {
				"id": 210683,
				"name": "其它区",
				"parent_id": 210600,
				"type": 4,
				"zip": ""
			}, {
				"id": 210681,
				"name": "东港市",
				"parent_id": 210600,
				"type": 4,
				"zip": "118300"
			}, {
				"id": 210624,
				"name": "宽甸满族自治县",
				"parent_id": 210600,
				"type": 4,
				"zip": "118200"
			}]
		}, {
			"id": 211400,
			"name": "葫芦岛市",
			"parent_id": 210000,
			"type": 3,
			"zip": "125000",
			"district": [{
				"id": 211422,
				"name": "建昌县",
				"parent_id": 211400,
				"type": 4,
				"zip": "125300"
			}, {
				"id": 211421,
				"name": "绥中县",
				"parent_id": 211400,
				"type": 4,
				"zip": "125200"
			}, {
				"id": 211404,
				"name": "南票区",
				"parent_id": 211400,
				"type": 4,
				"zip": "125027"
			}, {
				"id": 211403,
				"name": "龙港区",
				"parent_id": 211400,
				"type": 4,
				"zip": "125004"
			}, {
				"id": 211402,
				"name": "连山区",
				"parent_id": 211400,
				"type": 4,
				"zip": "125001"
			}, {
				"id": 211481,
				"name": "兴城市",
				"parent_id": 211400,
				"type": 4,
				"zip": "125100"
			}, {
				"id": 211482,
				"name": "其它区",
				"parent_id": 211400,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 211300,
			"name": "朝阳市",
			"parent_id": 210000,
			"type": 3,
			"zip": "122000",
			"district": [{
				"id": 211381,
				"name": "北票市",
				"parent_id": 211300,
				"type": 4,
				"zip": "122100"
			}, {
				"id": 211382,
				"name": "凌源市",
				"parent_id": 211300,
				"type": 4,
				"zip": "122500"
			}, {
				"id": 211383,
				"name": "其它区",
				"parent_id": 211300,
				"type": 4,
				"zip": ""
			}, {
				"id": 211324,
				"name": "喀喇沁左翼蒙古族自治县",
				"parent_id": 211300,
				"type": 4,
				"zip": "122300"
			}, {
				"id": 211321,
				"name": "朝阳县",
				"parent_id": 211300,
				"type": 4,
				"zip": "122000"
			}, {
				"id": 211322,
				"name": "建平县",
				"parent_id": 211300,
				"type": 4,
				"zip": "122400"
			}, {
				"id": 211302,
				"name": "双塔区",
				"parent_id": 211300,
				"type": 4,
				"zip": "122000"
			}, {
				"id": 211303,
				"name": "龙城区",
				"parent_id": 211300,
				"type": 4,
				"zip": "122000"
			}]
		}, {
			"id": 211200,
			"name": "铁岭市",
			"parent_id": 210000,
			"type": 3,
			"zip": "112000",
			"district": [{
				"id": 211283,
				"name": "其它区",
				"parent_id": 211200,
				"type": 4,
				"zip": ""
			}, {
				"id": 211282,
				"name": "开原市",
				"parent_id": 211200,
				"type": 4,
				"zip": "112300"
			}, {
				"id": 211281,
				"name": "调兵山市",
				"parent_id": 211200,
				"type": 4,
				"zip": "112700"
			}, {
				"id": 211223,
				"name": "西丰县",
				"parent_id": 211200,
				"type": 4,
				"zip": "112400"
			}, {
				"id": 211221,
				"name": "铁岭县",
				"parent_id": 211200,
				"type": 4,
				"zip": "112600"
			}, {
				"id": 211224,
				"name": "昌图县",
				"parent_id": 211200,
				"type": 4,
				"zip": "112500"
			}, {
				"id": 211202,
				"name": "银州区",
				"parent_id": 211200,
				"type": 4,
				"zip": "112000"
			}, {
				"id": 211204,
				"name": "清河区",
				"parent_id": 211200,
				"type": 4,
				"zip": "112003"
			}]
		}, {
			"id": 211100,
			"name": "盘锦市",
			"parent_id": 210000,
			"type": 3,
			"zip": "124000",
			"district": [{
				"id": 211102,
				"name": "双台子区",
				"parent_id": 211100,
				"type": 4,
				"zip": "124000"
			}, {
				"id": 211103,
				"name": "兴隆台区",
				"parent_id": 211100,
				"type": 4,
				"zip": "124010"
			}, {
				"id": 211122,
				"name": "盘山县",
				"parent_id": 211100,
				"type": 4,
				"zip": "124100"
			}, {
				"id": 211123,
				"name": "其它区",
				"parent_id": 211100,
				"type": 4,
				"zip": ""
			}, {
				"id": 211121,
				"name": "大洼县",
				"parent_id": 211100,
				"type": 4,
				"zip": "124000"
			}]
		}, {
			"id": 211000,
			"name": "辽阳市",
			"parent_id": 210000,
			"type": 3,
			"zip": "111000",
			"district": [{
				"id": 211081,
				"name": "灯塔市",
				"parent_id": 211000,
				"type": 4,
				"zip": "111300"
			}, {
				"id": 211082,
				"name": "其它区",
				"parent_id": 211000,
				"type": 4,
				"zip": ""
			}, {
				"id": 211011,
				"name": "太子河区",
				"parent_id": 211000,
				"type": 4,
				"zip": "111000"
			}, {
				"id": 211021,
				"name": "辽阳县",
				"parent_id": 211000,
				"type": 4,
				"zip": "111200"
			}, {
				"id": 211003,
				"name": "文圣区",
				"parent_id": 211000,
				"type": 4,
				"zip": "111000"
			}, {
				"id": 211002,
				"name": "白塔区",
				"parent_id": 211000,
				"type": 4,
				"zip": "111000"
			}, {
				"id": 211005,
				"name": "弓长岭区",
				"parent_id": 211000,
				"type": 4,
				"zip": "111008"
			}, {
				"id": 211004,
				"name": "宏伟区",
				"parent_id": 211000,
				"type": 4,
				"zip": "111003"
			}]
		}]
	}, {
		"id": 420000,
		"name": "湖北省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 420500,
			"name": "宜昌市",
			"parent_id": 420000,
			"type": 3,
			"zip": "443000",
			"district": [{
				"id": 420504,
				"name": "点军区",
				"parent_id": 420500,
				"type": 4,
				"zip": "443006"
			}, {
				"id": 420505,
				"name": "猇亭区",
				"parent_id": 420500,
				"type": 4,
				"zip": "443007"
			}, {
				"id": 420506,
				"name": "夷陵区",
				"parent_id": 420500,
				"type": 4,
				"zip": "443100"
			}, {
				"id": 420502,
				"name": "西陵区",
				"parent_id": 420500,
				"type": 4,
				"zip": "443000"
			}, {
				"id": 420503,
				"name": "伍家岗区",
				"parent_id": 420500,
				"type": 4,
				"zip": "443001"
			}, {
				"id": 420528,
				"name": "长阳土家族自治县",
				"parent_id": 420500,
				"type": 4,
				"zip": "443500"
			}, {
				"id": 420529,
				"name": "五峰土家族自治县",
				"parent_id": 420500,
				"type": 4,
				"zip": "443400"
			}, {
				"id": 420527,
				"name": "秭归县",
				"parent_id": 420500,
				"type": 4,
				"zip": "443600"
			}, {
				"id": 420526,
				"name": "兴山县",
				"parent_id": 420500,
				"type": 4,
				"zip": "443700"
			}, {
				"id": 420525,
				"name": "远安县",
				"parent_id": 420500,
				"type": 4,
				"zip": "444200"
			}, {
				"id": 420552,
				"name": "开发区",
				"parent_id": 420500,
				"type": 4,
				"zip": ""
			}, {
				"id": 420551,
				"name": "葛洲坝区",
				"parent_id": 420500,
				"type": 4,
				"zip": ""
			}, {
				"id": 420584,
				"name": "其它区",
				"parent_id": 420500,
				"type": 4,
				"zip": ""
			}, {
				"id": 420583,
				"name": "枝江市",
				"parent_id": 420500,
				"type": 4,
				"zip": "443200"
			}, {
				"id": 420582,
				"name": "当阳市",
				"parent_id": 420500,
				"type": 4,
				"zip": "444100"
			}, {
				"id": 420581,
				"name": "宜都市",
				"parent_id": 420500,
				"type": 4,
				"zip": "443300"
			}]
		}, {
			"id": 420600,
			"name": "襄阳市",
			"parent_id": 420000,
			"type": 3,
			"zip": "441000",
			"district": [{
				"id": 420602,
				"name": "襄城区",
				"parent_id": 420600,
				"type": 4,
				"zip": "441021"
			}, {
				"id": 420606,
				"name": "樊城区",
				"parent_id": 420600,
				"type": 4,
				"zip": "441001"
			}, {
				"id": 420607,
				"name": "襄州区",
				"parent_id": 420600,
				"type": 4,
				"zip": "441100"
			}, {
				"id": 420626,
				"name": "保康县",
				"parent_id": 420600,
				"type": 4,
				"zip": "441600"
			}, {
				"id": 420625,
				"name": "谷城县",
				"parent_id": 420600,
				"type": 4,
				"zip": "441700"
			}, {
				"id": 420624,
				"name": "南漳县",
				"parent_id": 420600,
				"type": 4,
				"zip": "441500"
			}, {
				"id": 420682,
				"name": "老河口市",
				"parent_id": 420600,
				"type": 4,
				"zip": "441800"
			}, {
				"id": 420683,
				"name": "枣阳市",
				"parent_id": 420600,
				"type": 4,
				"zip": "441200"
			}, {
				"id": 420684,
				"name": "宜城市",
				"parent_id": 420600,
				"type": 4,
				"zip": "441400"
			}, {
				"id": 420685,
				"name": "其它区",
				"parent_id": 420600,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 420700,
			"name": "鄂州市",
			"parent_id": 420000,
			"type": 3,
			"zip": "436000",
			"district": [{
				"id": 420703,
				"name": "华容区",
				"parent_id": 420700,
				"type": 4,
				"zip": "436030"
			}, {
				"id": 420702,
				"name": "梁子湖区",
				"parent_id": 420700,
				"type": 4,
				"zip": "436064"
			}, {
				"id": 420704,
				"name": "鄂城区",
				"parent_id": 420700,
				"type": 4,
				"zip": "436000"
			}, {
				"id": 420705,
				"name": "其它区",
				"parent_id": 420700,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 420800,
			"name": "荆门市",
			"parent_id": 420000,
			"type": 3,
			"zip": "448000",
			"district": [{
				"id": 420802,
				"name": "东宝区",
				"parent_id": 420800,
				"type": 4,
				"zip": "448004"
			}, {
				"id": 420804,
				"name": "掇刀区",
				"parent_id": 420800,
				"type": 4,
				"zip": "448124"
			}, {
				"id": 420822,
				"name": "沙洋县",
				"parent_id": 420800,
				"type": 4,
				"zip": "448200"
			}, {
				"id": 420821,
				"name": "京山县",
				"parent_id": 420800,
				"type": 4,
				"zip": "431800"
			}, {
				"id": 420881,
				"name": "钟祥市",
				"parent_id": 420800,
				"type": 4,
				"zip": "431900"
			}, {
				"id": 420882,
				"name": "其它区",
				"parent_id": 420800,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 420100,
			"name": "武汉市",
			"parent_id": 420000,
			"type": 3,
			"zip": "430000",
			"district": [{
				"id": 420102,
				"name": "江岸区",
				"parent_id": 420100,
				"type": 4,
				"zip": "430014"
			}, {
				"id": 420103,
				"name": "江汉区",
				"parent_id": 420100,
				"type": 4,
				"zip": "430015"
			}, {
				"id": 420106,
				"name": "武昌区",
				"parent_id": 420100,
				"type": 4,
				"zip": "430061"
			}, {
				"id": 420107,
				"name": "青山区",
				"parent_id": 420100,
				"type": 4,
				"zip": "430080"
			}, {
				"id": 420104,
				"name": "硚口区",
				"parent_id": 420100,
				"type": 4,
				"zip": "430033"
			}, {
				"id": 420105,
				"name": "汉阳区",
				"parent_id": 420100,
				"type": 4,
				"zip": "430050"
			}, {
				"id": 420111,
				"name": "洪山区",
				"parent_id": 420100,
				"type": 4,
				"zip": "430070"
			}, {
				"id": 420115,
				"name": "江夏区",
				"parent_id": 420100,
				"type": 4,
				"zip": "430200"
			}, {
				"id": 420114,
				"name": "蔡甸区",
				"parent_id": 420100,
				"type": 4,
				"zip": "430100"
			}, {
				"id": 420113,
				"name": "汉南区",
				"parent_id": 420100,
				"type": 4,
				"zip": "430090"
			}, {
				"id": 420112,
				"name": "东西湖区",
				"parent_id": 420100,
				"type": 4,
				"zip": "430040"
			}, {
				"id": 420118,
				"name": "其它区",
				"parent_id": 420100,
				"type": 4,
				"zip": ""
			}, {
				"id": 420117,
				"name": "新洲区",
				"parent_id": 420100,
				"type": 4,
				"zip": "431400"
			}, {
				"id": 420116,
				"name": "黄陂区",
				"parent_id": 420100,
				"type": 4,
				"zip": "430300"
			}]
		}, {
			"id": 420200,
			"name": "黄石市",
			"parent_id": 420000,
			"type": 3,
			"zip": "435000",
			"district": [{
				"id": 420204,
				"name": "下陆区",
				"parent_id": 420200,
				"type": 4,
				"zip": "435004"
			}, {
				"id": 420205,
				"name": "铁山区",
				"parent_id": 420200,
				"type": 4,
				"zip": "435006"
			}, {
				"id": 420202,
				"name": "黄石港区",
				"parent_id": 420200,
				"type": 4,
				"zip": "435002"
			}, {
				"id": 420203,
				"name": "西塞山区",
				"parent_id": 420200,
				"type": 4,
				"zip": "435001"
			}, {
				"id": 420222,
				"name": "阳新县",
				"parent_id": 420200,
				"type": 4,
				"zip": "435200"
			}, {
				"id": 420281,
				"name": "大冶市",
				"parent_id": 420200,
				"type": 4,
				"zip": "435100"
			}, {
				"id": 420282,
				"name": "其它区",
				"parent_id": 420200,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 420300,
			"name": "十堰市",
			"parent_id": 420000,
			"type": 3,
			"zip": "442000",
			"district": [{
				"id": 420381,
				"name": "丹江口市",
				"parent_id": 420300,
				"type": 4,
				"zip": "441900"
			}, {
				"id": 420383,
				"name": "其它区",
				"parent_id": 420300,
				"type": 4,
				"zip": ""
			}, {
				"id": 420382,
				"name": "城区",
				"parent_id": 420300,
				"type": 4,
				"zip": ""
			}, {
				"id": 420325,
				"name": "房县",
				"parent_id": 420300,
				"type": 4,
				"zip": "442100"
			}, {
				"id": 420324,
				"name": "竹溪县",
				"parent_id": 420300,
				"type": 4,
				"zip": "442300"
			}, {
				"id": 420321,
				"name": "郧县",
				"parent_id": 420300,
				"type": 4,
				"zip": "442500"
			}, {
				"id": 420323,
				"name": "竹山县",
				"parent_id": 420300,
				"type": 4,
				"zip": "442200"
			}, {
				"id": 420322,
				"name": "郧西县",
				"parent_id": 420300,
				"type": 4,
				"zip": "442600"
			}, {
				"id": 420303,
				"name": "张湾区",
				"parent_id": 420300,
				"type": 4,
				"zip": "442001"
			}, {
				"id": 420302,
				"name": "茅箭区",
				"parent_id": 420300,
				"type": 4,
				"zip": "442012"
			}]
		}, {
			"id": 420900,
			"name": "孝感市",
			"parent_id": 420000,
			"type": 3,
			"zip": "432000",
			"district": [{
				"id": 420985,
				"name": "其它区",
				"parent_id": 420900,
				"type": 4,
				"zip": ""
			}, {
				"id": 420984,
				"name": "汉川市",
				"parent_id": 420900,
				"type": 4,
				"zip": "431600"
			}, {
				"id": 420982,
				"name": "安陆市",
				"parent_id": 420900,
				"type": 4,
				"zip": "432600"
			}, {
				"id": 420981,
				"name": "应城市",
				"parent_id": 420900,
				"type": 4,
				"zip": "432400"
			}, {
				"id": 420923,
				"name": "云梦县",
				"parent_id": 420900,
				"type": 4,
				"zip": "432500"
			}, {
				"id": 420922,
				"name": "大悟县",
				"parent_id": 420900,
				"type": 4,
				"zip": "432800"
			}, {
				"id": 420921,
				"name": "孝昌县",
				"parent_id": 420900,
				"type": 4,
				"zip": "432900"
			}, {
				"id": 420902,
				"name": "孝南区",
				"parent_id": 420900,
				"type": 4,
				"zip": "432100"
			}]
		}, {
			"id": 421100,
			"name": "黄冈市",
			"parent_id": 420000,
			"type": 3,
			"zip": "438000",
			"district": [{
				"id": 421102,
				"name": "黄州区",
				"parent_id": 421100,
				"type": 4,
				"zip": "438000"
			}, {
				"id": 421181,
				"name": "麻城市",
				"parent_id": 421100,
				"type": 4,
				"zip": "438300"
			}, {
				"id": 421183,
				"name": "其它区",
				"parent_id": 421100,
				"type": 4,
				"zip": ""
			}, {
				"id": 421182,
				"name": "武穴市",
				"parent_id": 421100,
				"type": 4,
				"zip": "435400"
			}, {
				"id": 421122,
				"name": "红安县",
				"parent_id": 421100,
				"type": 4,
				"zip": "431500"
			}, {
				"id": 421123,
				"name": "罗田县",
				"parent_id": 421100,
				"type": 4,
				"zip": "438600"
			}, {
				"id": 421121,
				"name": "团风县",
				"parent_id": 421100,
				"type": 4,
				"zip": "438000"
			}, {
				"id": 421126,
				"name": "蕲春县",
				"parent_id": 421100,
				"type": 4,
				"zip": "436300"
			}, {
				"id": 421127,
				"name": "黄梅县",
				"parent_id": 421100,
				"type": 4,
				"zip": "435500"
			}, {
				"id": 421124,
				"name": "英山县",
				"parent_id": 421100,
				"type": 4,
				"zip": "438700"
			}, {
				"id": 421125,
				"name": "浠水县",
				"parent_id": 421100,
				"type": 4,
				"zip": "438200"
			}]
		}, {
			"id": 421000,
			"name": "荆州市",
			"parent_id": 420000,
			"type": 3,
			"zip": "434000",
			"district": [{
				"id": 421088,
				"name": "其它区",
				"parent_id": 421000,
				"type": 4,
				"zip": ""
			}, {
				"id": 421087,
				"name": "松滋市",
				"parent_id": 421000,
				"type": 4,
				"zip": "434200"
			}, {
				"id": 421081,
				"name": "石首市",
				"parent_id": 421000,
				"type": 4,
				"zip": "434400"
			}, {
				"id": 421083,
				"name": "洪湖市",
				"parent_id": 421000,
				"type": 4,
				"zip": "433200"
			}, {
				"id": 421024,
				"name": "江陵县",
				"parent_id": 421000,
				"type": 4,
				"zip": "434100"
			}, {
				"id": 421022,
				"name": "公安县",
				"parent_id": 421000,
				"type": 4,
				"zip": "434300"
			}, {
				"id": 421023,
				"name": "监利县",
				"parent_id": 421000,
				"type": 4,
				"zip": "433300"
			}, {
				"id": 421003,
				"name": "荆州区",
				"parent_id": 421000,
				"type": 4,
				"zip": "434020"
			}, {
				"id": 421002,
				"name": "沙市区",
				"parent_id": 421000,
				"type": 4,
				"zip": "434000"
			}]
		}, {
			"id": 421200,
			"name": "咸宁市",
			"parent_id": 420000,
			"type": 3,
			"zip": "437100",
			"district": [{
				"id": 421224,
				"name": "通山县",
				"parent_id": 421200,
				"type": 4,
				"zip": "437600"
			}, {
				"id": 421221,
				"name": "嘉鱼县",
				"parent_id": 421200,
				"type": 4,
				"zip": "437200"
			}, {
				"id": 421222,
				"name": "通城县",
				"parent_id": 421200,
				"type": 4,
				"zip": "437400"
			}, {
				"id": 421223,
				"name": "崇阳县",
				"parent_id": 421200,
				"type": 4,
				"zip": "437500"
			}, {
				"id": 421202,
				"name": "咸安区",
				"parent_id": 421200,
				"type": 4,
				"zip": "437000"
			}, {
				"id": 421281,
				"name": "赤壁市",
				"parent_id": 421200,
				"type": 4,
				"zip": "437300"
			}, {
				"id": 421283,
				"name": "其它区",
				"parent_id": 421200,
				"type": 4,
				"zip": ""
			}, {
				"id": 421282,
				"name": "温泉城区",
				"parent_id": 421200,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 421300,
			"name": "随州市",
			"parent_id": 420000,
			"type": 3,
			"zip": "441300",
			"district": [{
				"id": 421381,
				"name": "广水市",
				"parent_id": 421300,
				"type": 4,
				"zip": "432700"
			}, {
				"id": 421382,
				"name": "其它区",
				"parent_id": 421300,
				"type": 4,
				"zip": ""
			}, {
				"id": 421321,
				"name": "随县",
				"parent_id": 421300,
				"type": 4,
				"zip": "441300"
			}, {
				"id": 421302,
				"name": "曾都区",
				"parent_id": 421300,
				"type": 4,
				"zip": "441300"
			}]
		}, {
			"id": 422800,
			"name": "恩施土家族苗族自治州",
			"parent_id": 420000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 422828,
				"name": "鹤峰县",
				"parent_id": 422800,
				"type": 4,
				"zip": "445800"
			}, {
				"id": 422829,
				"name": "其它区",
				"parent_id": 422800,
				"type": 4,
				"zip": ""
			}, {
				"id": 422825,
				"name": "宣恩县",
				"parent_id": 422800,
				"type": 4,
				"zip": "445500"
			}, {
				"id": 422826,
				"name": "咸丰县",
				"parent_id": 422800,
				"type": 4,
				"zip": "445600"
			}, {
				"id": 422827,
				"name": "来凤县",
				"parent_id": 422800,
				"type": 4,
				"zip": "445700"
			}, {
				"id": 422822,
				"name": "建始县",
				"parent_id": 422800,
				"type": 4,
				"zip": "445300"
			}, {
				"id": 422823,
				"name": "巴东县",
				"parent_id": 422800,
				"type": 4,
				"zip": "444300"
			}, {
				"id": 422802,
				"name": "利川市",
				"parent_id": 422800,
				"type": 4,
				"zip": "445400"
			}, {
				"id": 422801,
				"name": "恩施市",
				"parent_id": 422800,
				"type": 4,
				"zip": "445000"
			}]
		}, {
			"id": 429005,
			"name": "潜江市",
			"parent_id": 420000,
			"type": 4,
			"zip": "433100",
			"district": [{
				"id": 429105,
				"name": "园林办事处",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429115,
				"name": "杨市办事处",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429135,
				"name": "周矶办事处",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429145,
				"name": "广华办事处",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429155,
				"name": "泰丰办事处",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429165,
				"name": "高场办事处",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429175,
				"name": "竹根滩镇",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429185,
				"name": "渔洋镇",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429195,
				"name": "王场镇",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429205,
				"name": "高石碑镇",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429215,
				"name": "熊口镇",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429225,
				"name": "老新镇",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429235,
				"name": "浩口镇",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429245,
				"name": "积玉口镇",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429255,
				"name": "张金镇",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429265,
				"name": "龙湾镇",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429275,
				"name": "江汉石油管理局",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429285,
				"name": "潜江经济开发区",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429295,
				"name": "周矶管理区",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429305,
				"name": "后湖管理区",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429315,
				"name": "熊口管理区",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429325,
				"name": "总口管理区",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429335,
				"name": "白鹭湖管理区",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429345,
				"name": "运粮湖管理区",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}, {
				"id": 429355,
				"name": "浩口原种场",
				"parent_id": 429005,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 429004,
			"name": "仙桃市",
			"parent_id": 420000,
			"type": 4,
			"zip": "433000",
			"district": [{
				"id": 429104,
				"name": "沙嘴街道办事处",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429114,
				"name": "干河街道办事处",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429124,
				"name": "龙华山办事处",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429134,
				"name": "郑场镇",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429144,
				"name": "毛嘴镇",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429154,
				"name": "豆河镇",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429164,
				"name": "三伏潭镇",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429174,
				"name": "胡场镇",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429184,
				"name": "长倘口镇",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429194,
				"name": "西流河镇",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429204,
				"name": "沙湖镇",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429214,
				"name": "杨林尾镇",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429224,
				"name": "彭场镇",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429234,
				"name": "张沟镇",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429244,
				"name": "郭河镇",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429254,
				"name": "沔城回族镇",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429264,
				"name": "通海口镇",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429274,
				"name": "陈场镇",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429284,
				"name": "工业园区",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429294,
				"name": "九合垸原种场",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429304,
				"name": "沙湖原种场",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429314,
				"name": "五湖渔场",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429324,
				"name": "赵西垸林场",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429334,
				"name": "畜禽良种场",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}, {
				"id": 429344,
				"name": "排湖风景区",
				"parent_id": 429004,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 429006,
			"name": "天门市",
			"parent_id": 420000,
			"type": 4,
			"zip": "431700",
			"district": [{
				"id": 429106,
				"name": "竟陵街道办事处",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429116,
				"name": "侨乡街道开发区",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429126,
				"name": "杨林街道办事处",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429136,
				"name": "多宝镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429146,
				"name": "拖市镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429156,
				"name": "张港镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429166,
				"name": "蒋场镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429176,
				"name": "汪场镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429186,
				"name": "渔薪镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429196,
				"name": "黄潭镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429206,
				"name": "岳口镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429216,
				"name": "横林镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429226,
				"name": "彭市镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429236,
				"name": "麻洋镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429246,
				"name": "多祥镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429256,
				"name": "干驿镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429266,
				"name": "马湾镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429276,
				"name": "卢市镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429286,
				"name": "小板镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429296,
				"name": "九真镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429306,
				"name": "皂市镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429316,
				"name": "胡市镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429326,
				"name": "石河镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429336,
				"name": "佛子山镇",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429346,
				"name": "净潭乡",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429356,
				"name": "蒋湖农场",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429366,
				"name": "白茅湖农场",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}, {
				"id": 429376,
				"name": "沉湖管委会",
				"parent_id": 429006,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 429021,
			"name": "神农架林区",
			"parent_id": 420000,
			"type": 4,
			"zip": "442400",
			"district": [{
				"id": 42902110,
				"name": "松柏镇",
				"parent_id": 429021,
				"type": 4,
				"zip": ""
			}, {
				"id": 42902111,
				"name": "阳日镇",
				"parent_id": 429021,
				"type": 4,
				"zip": ""
			}, {
				"id": 42902112,
				"name": "木鱼镇",
				"parent_id": 429021,
				"type": 4,
				"zip": ""
			}, {
				"id": 42902113,
				"name": "红坪镇",
				"parent_id": 429021,
				"type": 4,
				"zip": ""
			}, {
				"id": 42902114,
				"name": "新华镇",
				"parent_id": 429021,
				"type": 4,
				"zip": ""
			}, {
				"id": 42902115,
				"name": "九湖镇",
				"parent_id": 429021,
				"type": 4,
				"zip": ""
			}, {
				"id": 42902116,
				"name": "宋洛乡",
				"parent_id": 429021,
				"type": 4,
				"zip": ""
			}, {
				"id": 42902117,
				"name": "下谷坪土家族乡",
				"parent_id": 429021,
				"type": 4,
				"zip": ""
			}]
		}]
	}, {
		"id": 140000,
		"name": "山西省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 140800,
			"name": "运城市",
			"parent_id": 140000,
			"type": 3,
			"zip": "044000",
			"district": [{
				"id": 140802,
				"name": "盐湖区",
				"parent_id": 140800,
				"type": 4,
				"zip": "044300"
			}, {
				"id": 140829,
				"name": "平陆县",
				"parent_id": 140800,
				"type": 4,
				"zip": "044300"
			}, {
				"id": 140828,
				"name": "夏县",
				"parent_id": 140800,
				"type": 4,
				"zip": "044400"
			}, {
				"id": 140830,
				"name": "芮城县",
				"parent_id": 140800,
				"type": 4,
				"zip": "044600"
			}, {
				"id": 140825,
				"name": "新绛县",
				"parent_id": 140800,
				"type": 4,
				"zip": "043100"
			}, {
				"id": 140824,
				"name": "稷山县",
				"parent_id": 140800,
				"type": 4,
				"zip": "043200"
			}, {
				"id": 140827,
				"name": "垣曲县",
				"parent_id": 140800,
				"type": 4,
				"zip": "043700"
			}, {
				"id": 140826,
				"name": "绛县",
				"parent_id": 140800,
				"type": 4,
				"zip": "043600"
			}, {
				"id": 140821,
				"name": "临猗县",
				"parent_id": 140800,
				"type": 4,
				"zip": "044100"
			}, {
				"id": 140823,
				"name": "闻喜县",
				"parent_id": 140800,
				"type": 4,
				"zip": "043800"
			}, {
				"id": 140822,
				"name": "万荣县",
				"parent_id": 140800,
				"type": 4,
				"zip": "044200"
			}, {
				"id": 140881,
				"name": "永济市",
				"parent_id": 140800,
				"type": 4,
				"zip": "044500"
			}, {
				"id": 140883,
				"name": "其它区",
				"parent_id": 140800,
				"type": 4,
				"zip": ""
			}, {
				"id": 140882,
				"name": "河津市",
				"parent_id": 140800,
				"type": 4,
				"zip": "043300"
			}]
		}, {
			"id": 140900,
			"name": "忻州市",
			"parent_id": 140000,
			"type": 3,
			"zip": "034000",
			"district": [{
				"id": 140902,
				"name": "忻府区",
				"parent_id": 140900,
				"type": 4,
				"zip": "034000"
			}, {
				"id": 140923,
				"name": "代县",
				"parent_id": 140900,
				"type": 4,
				"zip": "034200"
			}, {
				"id": 140922,
				"name": "五台县",
				"parent_id": 140900,
				"type": 4,
				"zip": "035500"
			}, {
				"id": 140921,
				"name": "定襄县",
				"parent_id": 140900,
				"type": 4,
				"zip": "035400"
			}, {
				"id": 140927,
				"name": "神池县",
				"parent_id": 140900,
				"type": 4,
				"zip": "036100"
			}, {
				"id": 140926,
				"name": "静乐县",
				"parent_id": 140900,
				"type": 4,
				"zip": "035100"
			}, {
				"id": 140925,
				"name": "宁武县",
				"parent_id": 140900,
				"type": 4,
				"zip": "036700"
			}, {
				"id": 140924,
				"name": "繁峙县",
				"parent_id": 140900,
				"type": 4,
				"zip": "034300"
			}, {
				"id": 140932,
				"name": "偏关县",
				"parent_id": 140900,
				"type": 4,
				"zip": "036400"
			}, {
				"id": 140929,
				"name": "岢岚县",
				"parent_id": 140900,
				"type": 4,
				"zip": "036300"
			}, {
				"id": 140928,
				"name": "五寨县",
				"parent_id": 140900,
				"type": 4,
				"zip": "036100"
			}, {
				"id": 140931,
				"name": "保德县",
				"parent_id": 140900,
				"type": 4,
				"zip": "036600"
			}, {
				"id": 140930,
				"name": "河曲县",
				"parent_id": 140900,
				"type": 4,
				"zip": "036500"
			}, {
				"id": 140982,
				"name": "其它区",
				"parent_id": 140900,
				"type": 4,
				"zip": ""
			}, {
				"id": 140981,
				"name": "原平市",
				"parent_id": 140900,
				"type": 4,
				"zip": "034100"
			}]
		}, {
			"id": 141000,
			"name": "临汾市",
			"parent_id": 140000,
			"type": 3,
			"zip": "041000",
			"district": [{
				"id": 141002,
				"name": "尧都区",
				"parent_id": 141000,
				"type": 4,
				"zip": "041000"
			}, {
				"id": 141021,
				"name": "曲沃县",
				"parent_id": 141000,
				"type": 4,
				"zip": "043400"
			}, {
				"id": 141022,
				"name": "翼城县",
				"parent_id": 141000,
				"type": 4,
				"zip": "043500"
			}, {
				"id": 141023,
				"name": "襄汾县",
				"parent_id": 141000,
				"type": 4,
				"zip": "041500"
			}, {
				"id": 141027,
				"name": "浮山县",
				"parent_id": 141000,
				"type": 4,
				"zip": "042600"
			}, {
				"id": 141026,
				"name": "安泽县",
				"parent_id": 141000,
				"type": 4,
				"zip": "042500"
			}, {
				"id": 141025,
				"name": "古县",
				"parent_id": 141000,
				"type": 4,
				"zip": "042400"
			}, {
				"id": 141024,
				"name": "洪洞县",
				"parent_id": 141000,
				"type": 4,
				"zip": "041600"
			}, {
				"id": 141031,
				"name": "隰县",
				"parent_id": 141000,
				"type": 4,
				"zip": "041300"
			}, {
				"id": 141030,
				"name": "大宁县",
				"parent_id": 141000,
				"type": 4,
				"zip": "042300"
			}, {
				"id": 141029,
				"name": "乡宁县",
				"parent_id": 141000,
				"type": 4,
				"zip": "042100"
			}, {
				"id": 141028,
				"name": "吉县",
				"parent_id": 141000,
				"type": 4,
				"zip": "042200"
			}, {
				"id": 141034,
				"name": "汾西县",
				"parent_id": 141000,
				"type": 4,
				"zip": "031500"
			}, {
				"id": 141033,
				"name": "蒲县",
				"parent_id": 141000,
				"type": 4,
				"zip": "041200"
			}, {
				"id": 141032,
				"name": "永和县",
				"parent_id": 141000,
				"type": 4,
				"zip": "041400"
			}, {
				"id": 141083,
				"name": "其它区",
				"parent_id": 141000,
				"type": 4,
				"zip": ""
			}, {
				"id": 141082,
				"name": "霍州市",
				"parent_id": 141000,
				"type": 4,
				"zip": "031400"
			}, {
				"id": 141081,
				"name": "侯马市",
				"parent_id": 141000,
				"type": 4,
				"zip": "043000"
			}]
		}, {
			"id": 141100,
			"name": "吕梁市",
			"parent_id": 140000,
			"type": 3,
			"zip": "033000",
			"district": [{
				"id": 141102,
				"name": "离石区",
				"parent_id": 141100,
				"type": 4,
				"zip": "033000"
			}, {
				"id": 141130,
				"name": "交口县",
				"parent_id": 141100,
				"type": 4,
				"zip": "032400"
			}, {
				"id": 141128,
				"name": "方山县",
				"parent_id": 141100,
				"type": 4,
				"zip": "033100"
			}, {
				"id": 141129,
				"name": "中阳县",
				"parent_id": 141100,
				"type": 4,
				"zip": "033400"
			}, {
				"id": 141122,
				"name": "交城县",
				"parent_id": 141100,
				"type": 4,
				"zip": "030500"
			}, {
				"id": 141123,
				"name": "兴县",
				"parent_id": 141100,
				"type": 4,
				"zip": "033601"
			}, {
				"id": 141121,
				"name": "文水县",
				"parent_id": 141100,
				"type": 4,
				"zip": "032100"
			}, {
				"id": 141126,
				"name": "石楼县",
				"parent_id": 141100,
				"type": 4,
				"zip": "032500"
			}, {
				"id": 141127,
				"name": "岚县",
				"parent_id": 141100,
				"type": 4,
				"zip": "033500"
			}, {
				"id": 141124,
				"name": "临县",
				"parent_id": 141100,
				"type": 4,
				"zip": "033200"
			}, {
				"id": 141125,
				"name": "柳林县",
				"parent_id": 141100,
				"type": 4,
				"zip": "033300"
			}, {
				"id": 141181,
				"name": "孝义市",
				"parent_id": 141100,
				"type": 4,
				"zip": "032208"
			}, {
				"id": 141183,
				"name": "其它区",
				"parent_id": 141100,
				"type": 4,
				"zip": ""
			}, {
				"id": 141182,
				"name": "汾阳市",
				"parent_id": 141100,
				"type": 4,
				"zip": "032200"
			}]
		}, {
			"id": 140300,
			"name": "阳泉市",
			"parent_id": 140000,
			"type": 3,
			"zip": "045000",
			"district": [{
				"id": 140322,
				"name": "盂县",
				"parent_id": 140300,
				"type": 4,
				"zip": "045100"
			}, {
				"id": 140323,
				"name": "其它区",
				"parent_id": 140300,
				"type": 4,
				"zip": ""
			}, {
				"id": 140321,
				"name": "平定县",
				"parent_id": 140300,
				"type": 4,
				"zip": "045200"
			}, {
				"id": 140302,
				"name": "城区",
				"parent_id": 140300,
				"type": 4,
				"zip": "045000"
			}, {
				"id": 140303,
				"name": "矿区",
				"parent_id": 140300,
				"type": 4,
				"zip": "045000"
			}, {
				"id": 140311,
				"name": "郊区",
				"parent_id": 140300,
				"type": 4,
				"zip": "045011"
			}]
		}, {
			"id": 140400,
			"name": "长治市",
			"parent_id": 140000,
			"type": 3,
			"zip": "046000",
			"district": [{
				"id": 140421,
				"name": "长治县",
				"parent_id": 140400,
				"type": 4,
				"zip": "047100"
			}, {
				"id": 140423,
				"name": "襄垣县",
				"parent_id": 140400,
				"type": 4,
				"zip": "046200"
			}, {
				"id": 140425,
				"name": "平顺县",
				"parent_id": 140400,
				"type": 4,
				"zip": "047400"
			}, {
				"id": 140424,
				"name": "屯留县",
				"parent_id": 140400,
				"type": 4,
				"zip": "046100"
			}, {
				"id": 140427,
				"name": "壶关县",
				"parent_id": 140400,
				"type": 4,
				"zip": "047300"
			}, {
				"id": 140426,
				"name": "黎城县",
				"parent_id": 140400,
				"type": 4,
				"zip": "047600"
			}, {
				"id": 140429,
				"name": "武乡县",
				"parent_id": 140400,
				"type": 4,
				"zip": "046300"
			}, {
				"id": 140428,
				"name": "长子县",
				"parent_id": 140400,
				"type": 4,
				"zip": "046600"
			}, {
				"id": 140431,
				"name": "沁源县",
				"parent_id": 140400,
				"type": 4,
				"zip": "046500"
			}, {
				"id": 140430,
				"name": "沁县",
				"parent_id": 140400,
				"type": 4,
				"zip": "046400"
			}, {
				"id": 140485,
				"name": "其它区",
				"parent_id": 140400,
				"type": 4,
				"zip": ""
			}, {
				"id": 140484,
				"name": "高新区",
				"parent_id": 140400,
				"type": 4,
				"zip": ""
			}, {
				"id": 140481,
				"name": "潞城市",
				"parent_id": 140400,
				"type": 4,
				"zip": "047500"
			}, {
				"id": 140483,
				"name": "郊区",
				"parent_id": 140400,
				"type": 4,
				"zip": "046011"
			}, {
				"id": 140482,
				"name": "城区",
				"parent_id": 140400,
				"type": 4,
				"zip": "046011"
			}]
		}, {
			"id": 140500,
			"name": "晋城市",
			"parent_id": 140000,
			"type": 3,
			"zip": "048000",
			"district": [{
				"id": 140525,
				"name": "泽州县",
				"parent_id": 140500,
				"type": 4,
				"zip": "048012"
			}, {
				"id": 140524,
				"name": "陵川县",
				"parent_id": 140500,
				"type": 4,
				"zip": "048300"
			}, {
				"id": 140522,
				"name": "阳城县",
				"parent_id": 140500,
				"type": 4,
				"zip": "048100"
			}, {
				"id": 140521,
				"name": "沁水县",
				"parent_id": 140500,
				"type": 4,
				"zip": "048200"
			}, {
				"id": 140502,
				"name": "城区",
				"parent_id": 140500,
				"type": 4,
				"zip": "048000"
			}, {
				"id": 140581,
				"name": "高平市",
				"parent_id": 140500,
				"type": 4,
				"zip": "048400"
			}, {
				"id": 140582,
				"name": "其它区",
				"parent_id": 140500,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 140600,
			"name": "朔州市",
			"parent_id": 140000,
			"type": 3,
			"zip": "036000",
			"district": [{
				"id": 140603,
				"name": "平鲁区",
				"parent_id": 140600,
				"type": 4,
				"zip": "038600"
			}, {
				"id": 140602,
				"name": "朔城区",
				"parent_id": 140600,
				"type": 4,
				"zip": "038500"
			}, {
				"id": 140625,
				"name": "其它区",
				"parent_id": 140600,
				"type": 4,
				"zip": ""
			}, {
				"id": 140624,
				"name": "怀仁县",
				"parent_id": 140600,
				"type": 4,
				"zip": "038300"
			}, {
				"id": 140622,
				"name": "应县",
				"parent_id": 140600,
				"type": 4,
				"zip": "037600"
			}, {
				"id": 140623,
				"name": "右玉县",
				"parent_id": 140600,
				"type": 4,
				"zip": "037200"
			}, {
				"id": 140621,
				"name": "山阴县",
				"parent_id": 140600,
				"type": 4,
				"zip": "036900"
			}]
		}, {
			"id": 140700,
			"name": "晋中市",
			"parent_id": 140000,
			"type": 3,
			"zip": "030600",
			"district": [{
				"id": 140721,
				"name": "榆社县",
				"parent_id": 140700,
				"type": 4,
				"zip": "031800"
			}, {
				"id": 140722,
				"name": "左权县",
				"parent_id": 140700,
				"type": 4,
				"zip": "032600"
			}, {
				"id": 140723,
				"name": "和顺县",
				"parent_id": 140700,
				"type": 4,
				"zip": "032700"
			}, {
				"id": 140724,
				"name": "昔阳县",
				"parent_id": 140700,
				"type": 4,
				"zip": "045300"
			}, {
				"id": 140725,
				"name": "寿阳县",
				"parent_id": 140700,
				"type": 4,
				"zip": "045400"
			}, {
				"id": 140726,
				"name": "太谷县",
				"parent_id": 140700,
				"type": 4,
				"zip": "030800"
			}, {
				"id": 140727,
				"name": "祁县",
				"parent_id": 140700,
				"type": 4,
				"zip": "030900"
			}, {
				"id": 140728,
				"name": "平遥县",
				"parent_id": 140700,
				"type": 4,
				"zip": "031100"
			}, {
				"id": 140729,
				"name": "灵石县",
				"parent_id": 140700,
				"type": 4,
				"zip": "031300"
			}, {
				"id": 140702,
				"name": "榆次区",
				"parent_id": 140700,
				"type": 4,
				"zip": "030600"
			}, {
				"id": 140781,
				"name": "介休市",
				"parent_id": 140700,
				"type": 4,
				"zip": "032000"
			}, {
				"id": 140782,
				"name": "其它区",
				"parent_id": 140700,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 140100,
			"name": "太原市",
			"parent_id": 140000,
			"type": 3,
			"zip": "030000",
			"district": [{
				"id": 140123,
				"name": "娄烦县",
				"parent_id": 140100,
				"type": 4,
				"zip": "030300"
			}, {
				"id": 140122,
				"name": "阳曲县",
				"parent_id": 140100,
				"type": 4,
				"zip": "030100"
			}, {
				"id": 140121,
				"name": "清徐县",
				"parent_id": 140100,
				"type": 4,
				"zip": "030400"
			}, {
				"id": 140106,
				"name": "迎泽区",
				"parent_id": 140100,
				"type": 4,
				"zip": "030024"
			}, {
				"id": 140107,
				"name": "杏花岭区",
				"parent_id": 140100,
				"type": 4,
				"zip": "030001"
			}, {
				"id": 140105,
				"name": "小店区",
				"parent_id": 140100,
				"type": 4,
				"zip": "030032"
			}, {
				"id": 140110,
				"name": "晋源区",
				"parent_id": 140100,
				"type": 4,
				"zip": "030025"
			}, {
				"id": 140108,
				"name": "尖草坪区",
				"parent_id": 140100,
				"type": 4,
				"zip": "030003"
			}, {
				"id": 140109,
				"name": "万柏林区",
				"parent_id": 140100,
				"type": 4,
				"zip": "030027"
			}, {
				"id": 140182,
				"name": "其它区",
				"parent_id": 140100,
				"type": 4,
				"zip": ""
			}, {
				"id": 140181,
				"name": "古交市",
				"parent_id": 140100,
				"type": 4,
				"zip": "030200"
			}]
		}, {
			"id": 140200,
			"name": "大同市",
			"parent_id": 140000,
			"type": 3,
			"zip": "037000",
			"district": [{
				"id": 140227,
				"name": "大同县",
				"parent_id": 140200,
				"type": 4,
				"zip": "037300"
			}, {
				"id": 140226,
				"name": "左云县",
				"parent_id": 140200,
				"type": 4,
				"zip": "037100"
			}, {
				"id": 140225,
				"name": "浑源县",
				"parent_id": 140200,
				"type": 4,
				"zip": "037400"
			}, {
				"id": 140224,
				"name": "灵丘县",
				"parent_id": 140200,
				"type": 4,
				"zip": "034400"
			}, {
				"id": 140228,
				"name": "其它区",
				"parent_id": 140200,
				"type": 4,
				"zip": ""
			}, {
				"id": 140221,
				"name": "阳高县",
				"parent_id": 140200,
				"type": 4,
				"zip": "038100"
			}, {
				"id": 140222,
				"name": "天镇县",
				"parent_id": 140200,
				"type": 4,
				"zip": "038200"
			}, {
				"id": 140223,
				"name": "广灵县",
				"parent_id": 140200,
				"type": 4,
				"zip": "037500"
			}, {
				"id": 140212,
				"name": "新荣区",
				"parent_id": 140200,
				"type": 4,
				"zip": "037002"
			}, {
				"id": 140211,
				"name": "南郊区",
				"parent_id": 140200,
				"type": 4,
				"zip": "037001"
			}, {
				"id": 140203,
				"name": "矿区",
				"parent_id": 140200,
				"type": 4,
				"zip": "037001"
			}, {
				"id": 140202,
				"name": "城区",
				"parent_id": 140200,
				"type": 4,
				"zip": "037008"
			}]
		}]
	}, {
		"id": 350000,
		"name": "福建省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 350800,
			"name": "龙岩市",
			"parent_id": 350000,
			"type": 3,
			"zip": "364000",
			"district": [{
				"id": 350802,
				"name": "新罗区",
				"parent_id": 350800,
				"type": 4,
				"zip": "364000"
			}, {
				"id": 350822,
				"name": "永定县",
				"parent_id": 350800,
				"type": 4,
				"zip": "364100"
			}, {
				"id": 350823,
				"name": "上杭县",
				"parent_id": 350800,
				"type": 4,
				"zip": "364200"
			}, {
				"id": 350821,
				"name": "长汀县",
				"parent_id": 350800,
				"type": 4,
				"zip": "366300"
			}, {
				"id": 350824,
				"name": "武平县",
				"parent_id": 350800,
				"type": 4,
				"zip": "364300"
			}, {
				"id": 350825,
				"name": "连城县",
				"parent_id": 350800,
				"type": 4,
				"zip": "366200"
			}, {
				"id": 350882,
				"name": "其它区",
				"parent_id": 350800,
				"type": 4,
				"zip": ""
			}, {
				"id": 350881,
				"name": "漳平市",
				"parent_id": 350800,
				"type": 4,
				"zip": "364400"
			}]
		}, {
			"id": 350900,
			"name": "宁德市",
			"parent_id": 350000,
			"type": 3,
			"zip": "352100",
			"district": [{
				"id": 350982,
				"name": "福鼎市",
				"parent_id": 350900,
				"type": 4,
				"zip": "355200"
			}, {
				"id": 350983,
				"name": "其它区",
				"parent_id": 350900,
				"type": 4,
				"zip": ""
			}, {
				"id": 350981,
				"name": "福安市",
				"parent_id": 350900,
				"type": 4,
				"zip": "355000"
			}, {
				"id": 350921,
				"name": "霞浦县",
				"parent_id": 350900,
				"type": 4,
				"zip": "355100"
			}, {
				"id": 350923,
				"name": "屏南县",
				"parent_id": 350900,
				"type": 4,
				"zip": "352300"
			}, {
				"id": 350922,
				"name": "古田县",
				"parent_id": 350900,
				"type": 4,
				"zip": "352200"
			}, {
				"id": 350925,
				"name": "周宁县",
				"parent_id": 350900,
				"type": 4,
				"zip": "355400"
			}, {
				"id": 350924,
				"name": "寿宁县",
				"parent_id": 350900,
				"type": 4,
				"zip": "355500"
			}, {
				"id": 350926,
				"name": "柘荣县",
				"parent_id": 350900,
				"type": 4,
				"zip": "355300"
			}, {
				"id": 350902,
				"name": "蕉城区",
				"parent_id": 350900,
				"type": 4,
				"zip": "352100"
			}]
		}, {
			"id": 350500,
			"name": "泉州市",
			"parent_id": 350000,
			"type": 3,
			"zip": "362000",
			"district": [{
				"id": 350581,
				"name": "石狮市",
				"parent_id": 350500,
				"type": 4,
				"zip": "362700"
			}, {
				"id": 350583,
				"name": "南安市",
				"parent_id": 350500,
				"type": 4,
				"zip": "362300"
			}, {
				"id": 350582,
				"name": "晋江市",
				"parent_id": 350500,
				"type": 4,
				"zip": "362200"
			}, {
				"id": 350584,
				"name": "其它区",
				"parent_id": 350500,
				"type": 4,
				"zip": ""
			}, {
				"id": 350521,
				"name": "惠安县",
				"parent_id": 350500,
				"type": 4,
				"zip": "362100"
			}, {
				"id": 350525,
				"name": "永春县",
				"parent_id": 350500,
				"type": 4,
				"zip": "362600"
			}, {
				"id": 350524,
				"name": "安溪县",
				"parent_id": 350500,
				"type": 4,
				"zip": "362400"
			}, {
				"id": 350527,
				"name": "金门县",
				"parent_id": 350500,
				"type": 4,
				"zip": "362000"
			}, {
				"id": 350526,
				"name": "德化县",
				"parent_id": 350500,
				"type": 4,
				"zip": "362500"
			}, {
				"id": 350502,
				"name": "鲤城区",
				"parent_id": 350500,
				"type": 4,
				"zip": "362000"
			}, {
				"id": 350503,
				"name": "丰泽区",
				"parent_id": 350500,
				"type": 4,
				"zip": "362000"
			}, {
				"id": 350504,
				"name": "洛江区",
				"parent_id": 350500,
				"type": 4,
				"zip": "362011"
			}, {
				"id": 350505,
				"name": "泉港区",
				"parent_id": 350500,
				"type": 4,
				"zip": "362801"
			}]
		}, {
			"id": 350700,
			"name": "南平市",
			"parent_id": 350000,
			"type": 3,
			"zip": "353000",
			"district": [{
				"id": 350784,
				"name": "建阳市",
				"parent_id": 350700,
				"type": 4,
				"zip": "354200"
			}, {
				"id": 350785,
				"name": "其它区",
				"parent_id": 350700,
				"type": 4,
				"zip": ""
			}, {
				"id": 350724,
				"name": "松溪县",
				"parent_id": 350700,
				"type": 4,
				"zip": "353500"
			}, {
				"id": 350725,
				"name": "政和县",
				"parent_id": 350700,
				"type": 4,
				"zip": "353600"
			}, {
				"id": 350721,
				"name": "顺昌县",
				"parent_id": 350700,
				"type": 4,
				"zip": "353200"
			}, {
				"id": 350722,
				"name": "浦城县",
				"parent_id": 350700,
				"type": 4,
				"zip": "353400"
			}, {
				"id": 350723,
				"name": "光泽县",
				"parent_id": 350700,
				"type": 4,
				"zip": "354100"
			}, {
				"id": 350783,
				"name": "建瓯市",
				"parent_id": 350700,
				"type": 4,
				"zip": "353100"
			}, {
				"id": 350782,
				"name": "武夷山市",
				"parent_id": 350700,
				"type": 4,
				"zip": "354300"
			}, {
				"id": 350781,
				"name": "邵武市",
				"parent_id": 350700,
				"type": 4,
				"zip": "354000"
			}, {
				"id": 350702,
				"name": "延平区",
				"parent_id": 350700,
				"type": 4,
				"zip": "353000"
			}]
		}, {
			"id": 350600,
			"name": "漳州市",
			"parent_id": 350000,
			"type": 3,
			"zip": "363000",
			"district": [{
				"id": 350682,
				"name": "其它区",
				"parent_id": 350600,
				"type": 4,
				"zip": ""
			}, {
				"id": 350681,
				"name": "龙海市",
				"parent_id": 350600,
				"type": 4,
				"zip": "363100"
			}, {
				"id": 350625,
				"name": "长泰县",
				"parent_id": 350600,
				"type": 4,
				"zip": "363900"
			}, {
				"id": 350624,
				"name": "诏安县",
				"parent_id": 350600,
				"type": 4,
				"zip": "363500"
			}, {
				"id": 350627,
				"name": "南靖县",
				"parent_id": 350600,
				"type": 4,
				"zip": "363600"
			}, {
				"id": 350626,
				"name": "东山县",
				"parent_id": 350600,
				"type": 4,
				"zip": "363400"
			}, {
				"id": 350629,
				"name": "华安县",
				"parent_id": 350600,
				"type": 4,
				"zip": "363800"
			}, {
				"id": 350628,
				"name": "平和县",
				"parent_id": 350600,
				"type": 4,
				"zip": "363700"
			}, {
				"id": 350622,
				"name": "云霄县",
				"parent_id": 350600,
				"type": 4,
				"zip": "363300"
			}, {
				"id": 350623,
				"name": "漳浦县",
				"parent_id": 350600,
				"type": 4,
				"zip": "363200"
			}, {
				"id": 350603,
				"name": "龙文区",
				"parent_id": 350600,
				"type": 4,
				"zip": "363005"
			}, {
				"id": 350602,
				"name": "芗城区",
				"parent_id": 350600,
				"type": 4,
				"zip": "363000"
			}]
		}, {
			"id": 350300,
			"name": "莆田市",
			"parent_id": 350000,
			"type": 3,
			"zip": "351100",
			"district": [{
				"id": 350304,
				"name": "荔城区",
				"parent_id": 350300,
				"type": 4,
				"zip": "351100"
			}, {
				"id": 350305,
				"name": "秀屿区",
				"parent_id": 350300,
				"type": 4,
				"zip": "351152"
			}, {
				"id": 350323,
				"name": "其它区",
				"parent_id": 350300,
				"type": 4,
				"zip": ""
			}, {
				"id": 350322,
				"name": "仙游县",
				"parent_id": 350300,
				"type": 4,
				"zip": "351200"
			}, {
				"id": 350303,
				"name": "涵江区",
				"parent_id": 350300,
				"type": 4,
				"zip": "351111"
			}, {
				"id": 350302,
				"name": "城厢区",
				"parent_id": 350300,
				"type": 4,
				"zip": "351100"
			}]
		}, {
			"id": 350400,
			"name": "三明市",
			"parent_id": 350000,
			"type": 3,
			"zip": "365000",
			"district": [{
				"id": 350482,
				"name": "其它区",
				"parent_id": 350400,
				"type": 4,
				"zip": ""
			}, {
				"id": 350481,
				"name": "永安市",
				"parent_id": 350400,
				"type": 4,
				"zip": "366000"
			}, {
				"id": 350403,
				"name": "三元区",
				"parent_id": 350400,
				"type": 4,
				"zip": "365001"
			}, {
				"id": 350402,
				"name": "梅列区",
				"parent_id": 350400,
				"type": 4,
				"zip": "365000"
			}, {
				"id": 350428,
				"name": "将乐县",
				"parent_id": 350400,
				"type": 4,
				"zip": "353300"
			}, {
				"id": 350429,
				"name": "泰宁县",
				"parent_id": 350400,
				"type": 4,
				"zip": "354400"
			}, {
				"id": 350430,
				"name": "建宁县",
				"parent_id": 350400,
				"type": 4,
				"zip": "354500"
			}, {
				"id": 350424,
				"name": "宁化县",
				"parent_id": 350400,
				"type": 4,
				"zip": "365400"
			}, {
				"id": 350425,
				"name": "大田县",
				"parent_id": 350400,
				"type": 4,
				"zip": "366100"
			}, {
				"id": 350426,
				"name": "尤溪县",
				"parent_id": 350400,
				"type": 4,
				"zip": "365100"
			}, {
				"id": 350427,
				"name": "沙县",
				"parent_id": 350400,
				"type": 4,
				"zip": "365500"
			}, {
				"id": 350421,
				"name": "明溪县",
				"parent_id": 350400,
				"type": 4,
				"zip": "365200"
			}, {
				"id": 350423,
				"name": "清流县",
				"parent_id": 350400,
				"type": 4,
				"zip": "365300"
			}]
		}, {
			"id": 350100,
			"name": "福州市",
			"parent_id": 350000,
			"type": 3,
			"zip": "350000",
			"district": [{
				"id": 350102,
				"name": "鼓楼区",
				"parent_id": 350100,
				"type": 4,
				"zip": "350001"
			}, {
				"id": 350103,
				"name": "台江区",
				"parent_id": 350100,
				"type": 4,
				"zip": "350004"
			}, {
				"id": 350111,
				"name": "晋安区",
				"parent_id": 350100,
				"type": 4,
				"zip": "350011"
			}, {
				"id": 350104,
				"name": "仓山区",
				"parent_id": 350100,
				"type": 4,
				"zip": "350007"
			}, {
				"id": 350105,
				"name": "马尾区",
				"parent_id": 350100,
				"type": 4,
				"zip": "350015"
			}, {
				"id": 350125,
				"name": "永泰县",
				"parent_id": 350100,
				"type": 4,
				"zip": "350700"
			}, {
				"id": 350124,
				"name": "闽清县",
				"parent_id": 350100,
				"type": 4,
				"zip": "350800"
			}, {
				"id": 350121,
				"name": "闽侯县",
				"parent_id": 350100,
				"type": 4,
				"zip": "350100"
			}, {
				"id": 350123,
				"name": "罗源县",
				"parent_id": 350100,
				"type": 4,
				"zip": "350600"
			}, {
				"id": 350122,
				"name": "连江县",
				"parent_id": 350100,
				"type": 4,
				"zip": "350500"
			}, {
				"id": 350128,
				"name": "平潭县",
				"parent_id": 350100,
				"type": 4,
				"zip": "350400"
			}, {
				"id": 350181,
				"name": "福清市",
				"parent_id": 350100,
				"type": 4,
				"zip": "350300"
			}, {
				"id": 350183,
				"name": "其它区",
				"parent_id": 350100,
				"type": 4,
				"zip": ""
			}, {
				"id": 350182,
				"name": "长乐市",
				"parent_id": 350100,
				"type": 4,
				"zip": "350200"
			}]
		}, {
			"id": 350200,
			"name": "厦门市",
			"parent_id": 350000,
			"type": 3,
			"zip": "361000",
			"district": [{
				"id": 350211,
				"name": "集美区",
				"parent_id": 350200,
				"type": 4,
				"zip": "361021"
			}, {
				"id": 350212,
				"name": "同安区",
				"parent_id": 350200,
				"type": 4,
				"zip": "361100"
			}, {
				"id": 350213,
				"name": "翔安区",
				"parent_id": 350200,
				"type": 4,
				"zip": "361101"
			}, {
				"id": 350214,
				"name": "其它区",
				"parent_id": 350200,
				"type": 4,
				"zip": ""
			}, {
				"id": 350203,
				"name": "思明区",
				"parent_id": 350200,
				"type": 4,
				"zip": "361001"
			}, {
				"id": 350205,
				"name": "海沧区",
				"parent_id": 350200,
				"type": 4,
				"zip": "361026"
			}, {
				"id": 350206,
				"name": "湖里区",
				"parent_id": 350200,
				"type": 4,
				"zip": "361006"
			}]
		}]
	}, {
		"id": 630000,
		"name": "青海省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 630100,
			"name": "西宁市",
			"parent_id": 630000,
			"type": 3,
			"zip": "810000",
			"district": [{
				"id": 630124,
				"name": "其它区",
				"parent_id": 630100,
				"type": 4,
				"zip": ""
			}, {
				"id": 630121,
				"name": "大通回族土族自治县",
				"parent_id": 630100,
				"type": 4,
				"zip": "810100"
			}, {
				"id": 630123,
				"name": "湟源县",
				"parent_id": 630100,
				"type": 4,
				"zip": "812100"
			}, {
				"id": 630122,
				"name": "湟中县",
				"parent_id": 630100,
				"type": 4,
				"zip": "811600"
			}, {
				"id": 630104,
				"name": "城西区",
				"parent_id": 630100,
				"type": 4,
				"zip": "810001"
			}, {
				"id": 630105,
				"name": "城北区",
				"parent_id": 630100,
				"type": 4,
				"zip": "810001"
			}, {
				"id": 630102,
				"name": "城东区",
				"parent_id": 630100,
				"type": 4,
				"zip": "810000"
			}, {
				"id": 630103,
				"name": "城中区",
				"parent_id": 630100,
				"type": 4,
				"zip": "810000"
			}]
		}, {
			"id": 632200,
			"name": "海北藏族自治州",
			"parent_id": 630000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 632221,
				"name": "门源回族自治县",
				"parent_id": 632200,
				"type": 4,
				"zip": "810300"
			}, {
				"id": 632222,
				"name": "祁连县",
				"parent_id": 632200,
				"type": 4,
				"zip": "810400"
			}, {
				"id": 632223,
				"name": "海晏县",
				"parent_id": 632200,
				"type": 4,
				"zip": "812200"
			}, {
				"id": 632225,
				"name": "其它区",
				"parent_id": 632200,
				"type": 4,
				"zip": ""
			}, {
				"id": 632224,
				"name": "刚察县",
				"parent_id": 632200,
				"type": 4,
				"zip": "812300"
			}]
		}, {
			"id": 632300,
			"name": "黄南藏族自治州",
			"parent_id": 630000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 632324,
				"name": "河南蒙古族自治县",
				"parent_id": 632300,
				"type": 4,
				"zip": "811500"
			}, {
				"id": 632325,
				"name": "其它区",
				"parent_id": 632300,
				"type": 4,
				"zip": ""
			}, {
				"id": 632322,
				"name": "尖扎县",
				"parent_id": 632300,
				"type": 4,
				"zip": "811200"
			}, {
				"id": 632323,
				"name": "泽库县",
				"parent_id": 632300,
				"type": 4,
				"zip": "811400"
			}, {
				"id": 632321,
				"name": "同仁县",
				"parent_id": 632300,
				"type": 4,
				"zip": "811300"
			}]
		}, {
			"id": 632100,
			"name": "海东市",
			"parent_id": 630000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 632123,
				"name": "乐都区",
				"parent_id": 632100,
				"type": 4,
				"zip": "810700"
			}, {
				"id": 632122,
				"name": "民和回族土族自治县",
				"parent_id": 632100,
				"type": 4,
				"zip": "810800"
			}, {
				"id": 632121,
				"name": "平安县",
				"parent_id": 632100,
				"type": 4,
				"zip": "810600"
			}, {
				"id": 632127,
				"name": "化隆回族自治县",
				"parent_id": 632100,
				"type": 4,
				"zip": "810900"
			}, {
				"id": 632126,
				"name": "互助土族自治县",
				"parent_id": 632100,
				"type": 4,
				"zip": "810500"
			}, {
				"id": 632128,
				"name": "循化撒拉族自治县",
				"parent_id": 632100,
				"type": 4,
				"zip": "811100"
			}, {
				"id": 632129,
				"name": "其它区",
				"parent_id": 632100,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 632800,
			"name": "海西蒙古族藏族自治州",
			"parent_id": 630000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 632802,
				"name": "德令哈市",
				"parent_id": 632800,
				"type": 4,
				"zip": "817000"
			}, {
				"id": 632801,
				"name": "格尔木市",
				"parent_id": 632800,
				"type": 4,
				"zip": "816000"
			}, {
				"id": 632822,
				"name": "都兰县",
				"parent_id": 632800,
				"type": 4,
				"zip": "816100"
			}, {
				"id": 632823,
				"name": "天峻县",
				"parent_id": 632800,
				"type": 4,
				"zip": "817200"
			}, {
				"id": 632821,
				"name": "乌兰县",
				"parent_id": 632800,
				"type": 4,
				"zip": "817100"
			}, {
				"id": 632824,
				"name": "其它区",
				"parent_id": 632800,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 632600,
			"name": "果洛藏族自治州",
			"parent_id": 630000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 632622,
				"name": "班玛县",
				"parent_id": 632600,
				"type": 4,
				"zip": "814300"
			}, {
				"id": 632623,
				"name": "甘德县",
				"parent_id": 632600,
				"type": 4,
				"zip": "814100"
			}, {
				"id": 632621,
				"name": "玛沁县",
				"parent_id": 632600,
				"type": 4,
				"zip": "814000"
			}, {
				"id": 632627,
				"name": "其它区",
				"parent_id": 632600,
				"type": 4,
				"zip": ""
			}, {
				"id": 632626,
				"name": "玛多县",
				"parent_id": 632600,
				"type": 4,
				"zip": "813500"
			}, {
				"id": 632625,
				"name": "久治县",
				"parent_id": 632600,
				"type": 4,
				"zip": "624700"
			}, {
				"id": 632624,
				"name": "达日县",
				"parent_id": 632600,
				"type": 4,
				"zip": "814200"
			}]
		}, {
			"id": 632700,
			"name": "玉树藏族自治州",
			"parent_id": 630000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 632724,
				"name": "治多县",
				"parent_id": 632700,
				"type": 4,
				"zip": "815400"
			}, {
				"id": 632725,
				"name": "囊谦县",
				"parent_id": 632700,
				"type": 4,
				"zip": "815200"
			}, {
				"id": 632726,
				"name": "曲麻莱县",
				"parent_id": 632700,
				"type": 4,
				"zip": "815500"
			}, {
				"id": 632727,
				"name": "其它区",
				"parent_id": 632700,
				"type": 4,
				"zip": ""
			}, {
				"id": 632721,
				"name": "玉树市",
				"parent_id": 632700,
				"type": 4,
				"zip": "815000"
			}, {
				"id": 632722,
				"name": "杂多县",
				"parent_id": 632700,
				"type": 4,
				"zip": "815300"
			}, {
				"id": 632723,
				"name": "称多县",
				"parent_id": 632700,
				"type": 4,
				"zip": "815100"
			}]
		}, {
			"id": 632500,
			"name": "海南藏族自治州",
			"parent_id": 630000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 632523,
				"name": "贵德县",
				"parent_id": 632500,
				"type": 4,
				"zip": "811700"
			}, {
				"id": 632522,
				"name": "同德县",
				"parent_id": 632500,
				"type": 4,
				"zip": "813200"
			}, {
				"id": 632521,
				"name": "共和县",
				"parent_id": 632500,
				"type": 4,
				"zip": "813000"
			}, {
				"id": 632526,
				"name": "其它区",
				"parent_id": 632500,
				"type": 4,
				"zip": ""
			}, {
				"id": 632525,
				"name": "贵南县",
				"parent_id": 632500,
				"type": 4,
				"zip": "813100"
			}, {
				"id": 632524,
				"name": "兴海县",
				"parent_id": 632500,
				"type": 4,
				"zip": "813300"
			}]
		}]
	}, {
		"id": 360000,
		"name": "江西省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 360300,
			"name": "萍乡市",
			"parent_id": 360000,
			"type": 3,
			"zip": "337000",
			"district": [{
				"id": 360313,
				"name": "湘东区",
				"parent_id": 360300,
				"type": 4,
				"zip": "337032"
			}, {
				"id": 360302,
				"name": "安源区",
				"parent_id": 360300,
				"type": 4,
				"zip": "337000"
			}, {
				"id": 360324,
				"name": "其它区",
				"parent_id": 360300,
				"type": 4,
				"zip": ""
			}, {
				"id": 360321,
				"name": "莲花县",
				"parent_id": 360300,
				"type": 4,
				"zip": "337100"
			}, {
				"id": 360323,
				"name": "芦溪县",
				"parent_id": 360300,
				"type": 4,
				"zip": "337200"
			}, {
				"id": 360322,
				"name": "上栗县",
				"parent_id": 360300,
				"type": 4,
				"zip": "337009"
			}]
		}, {
			"id": 360200,
			"name": "景德镇市",
			"parent_id": 360000,
			"type": 3,
			"zip": "333000",
			"district": [{
				"id": 360281,
				"name": "乐平市",
				"parent_id": 360200,
				"type": 4,
				"zip": "333300"
			}, {
				"id": 360282,
				"name": "其它区",
				"parent_id": 360200,
				"type": 4,
				"zip": ""
			}, {
				"id": 360222,
				"name": "浮梁县",
				"parent_id": 360200,
				"type": 4,
				"zip": "333400"
			}, {
				"id": 360202,
				"name": "昌江区",
				"parent_id": 360200,
				"type": 4,
				"zip": "333000"
			}, {
				"id": 360203,
				"name": "珠山区",
				"parent_id": 360200,
				"type": 4,
				"zip": "333000"
			}]
		}, {
			"id": 360400,
			"name": "九江市",
			"parent_id": 360000,
			"type": 3,
			"zip": "332000",
			"district": [{
				"id": 360402,
				"name": "庐山区",
				"parent_id": 360400,
				"type": 4,
				"zip": "332005"
			}, {
				"id": 360403,
				"name": "浔阳区",
				"parent_id": 360400,
				"type": 4,
				"zip": "332000"
			}, {
				"id": 360423,
				"name": "武宁县",
				"parent_id": 360400,
				"type": 4,
				"zip": "332300"
			}, {
				"id": 360421,
				"name": "九江县",
				"parent_id": 360400,
				"type": 4,
				"zip": "332100"
			}, {
				"id": 360427,
				"name": "星子县",
				"parent_id": 360400,
				"type": 4,
				"zip": "332800"
			}, {
				"id": 360426,
				"name": "德安县",
				"parent_id": 360400,
				"type": 4,
				"zip": "330400"
			}, {
				"id": 360425,
				"name": "永修县",
				"parent_id": 360400,
				"type": 4,
				"zip": "330300"
			}, {
				"id": 360424,
				"name": "修水县",
				"parent_id": 360400,
				"type": 4,
				"zip": "332400"
			}, {
				"id": 360430,
				"name": "彭泽县",
				"parent_id": 360400,
				"type": 4,
				"zip": "332700"
			}, {
				"id": 360429,
				"name": "湖口县",
				"parent_id": 360400,
				"type": 4,
				"zip": "332500"
			}, {
				"id": 360428,
				"name": "都昌县",
				"parent_id": 360400,
				"type": 4,
				"zip": "332600"
			}, {
				"id": 360483,
				"name": "共青城市",
				"parent_id": 360400,
				"type": 4,
				"zip": ""
			}, {
				"id": 360482,
				"name": "其它区",
				"parent_id": 360400,
				"type": 4,
				"zip": ""
			}, {
				"id": 360481,
				"name": "瑞昌市",
				"parent_id": 360400,
				"type": 4,
				"zip": "332200"
			}]
		}, {
			"id": 360100,
			"name": "南昌市",
			"parent_id": 360000,
			"type": 3,
			"zip": "330000",
			"district": [{
				"id": 360128,
				"name": "其它区",
				"parent_id": 360100,
				"type": 4,
				"zip": ""
			}, {
				"id": 360103,
				"name": "西湖区",
				"parent_id": 360100,
				"type": 4,
				"zip": "330009"
			}, {
				"id": 360102,
				"name": "东湖区",
				"parent_id": 360100,
				"type": 4,
				"zip": "330006"
			}, {
				"id": 360111,
				"name": "青山湖区",
				"parent_id": 360100,
				"type": 4,
				"zip": "330006"
			}, {
				"id": 360105,
				"name": "湾里区",
				"parent_id": 360100,
				"type": 4,
				"zip": "330004"
			}, {
				"id": 360104,
				"name": "青云谱区",
				"parent_id": 360100,
				"type": 4,
				"zip": "330001"
			}, {
				"id": 360124,
				"name": "进贤县",
				"parent_id": 360100,
				"type": 4,
				"zip": "331700"
			}, {
				"id": 360125,
				"name": "红谷滩新区",
				"parent_id": 360100,
				"type": 4,
				"zip": ""
			}, {
				"id": 360126,
				"name": "经济技术开发区",
				"parent_id": 360100,
				"type": 4,
				"zip": ""
			}, {
				"id": 360127,
				"name": "昌北区",
				"parent_id": 360100,
				"type": 4,
				"zip": ""
			}, {
				"id": 360121,
				"name": "南昌县",
				"parent_id": 360100,
				"type": 4,
				"zip": "330200"
			}, {
				"id": 360122,
				"name": "新建县",
				"parent_id": 360100,
				"type": 4,
				"zip": "330100"
			}, {
				"id": 360123,
				"name": "安义县",
				"parent_id": 360100,
				"type": 4,
				"zip": "330500"
			}]
		}, {
			"id": 361000,
			"name": "抚州市",
			"parent_id": 360000,
			"type": 3,
			"zip": "344000",
			"district": [{
				"id": 361029,
				"name": "东乡县",
				"parent_id": 361000,
				"type": 4,
				"zip": "331800"
			}, {
				"id": 361028,
				"name": "资溪县",
				"parent_id": 361000,
				"type": 4,
				"zip": "335300"
			}, {
				"id": 361031,
				"name": "其它区",
				"parent_id": 361000,
				"type": 4,
				"zip": ""
			}, {
				"id": 361030,
				"name": "广昌县",
				"parent_id": 361000,
				"type": 4,
				"zip": "344900"
			}, {
				"id": 361025,
				"name": "乐安县",
				"parent_id": 361000,
				"type": 4,
				"zip": "344300"
			}, {
				"id": 361024,
				"name": "崇仁县",
				"parent_id": 361000,
				"type": 4,
				"zip": "344200"
			}, {
				"id": 361027,
				"name": "金溪县",
				"parent_id": 361000,
				"type": 4,
				"zip": "344800"
			}, {
				"id": 361026,
				"name": "宜黄县",
				"parent_id": 361000,
				"type": 4,
				"zip": "344400"
			}, {
				"id": 361022,
				"name": "黎川县",
				"parent_id": 361000,
				"type": 4,
				"zip": "344600"
			}, {
				"id": 361023,
				"name": "南丰县",
				"parent_id": 361000,
				"type": 4,
				"zip": "344500"
			}, {
				"id": 361021,
				"name": "南城县",
				"parent_id": 361000,
				"type": 4,
				"zip": "344700"
			}, {
				"id": 361002,
				"name": "临川区",
				"parent_id": 361000,
				"type": 4,
				"zip": "344100"
			}]
		}, {
			"id": 361100,
			"name": "上饶市",
			"parent_id": 360000,
			"type": 3,
			"zip": "334000",
			"district": [{
				"id": 361181,
				"name": "德兴市",
				"parent_id": 361100,
				"type": 4,
				"zip": "334200"
			}, {
				"id": 361182,
				"name": "其它区",
				"parent_id": 361100,
				"type": 4,
				"zip": ""
			}, {
				"id": 361122,
				"name": "广丰县",
				"parent_id": 361100,
				"type": 4,
				"zip": "334600"
			}, {
				"id": 361123,
				"name": "玉山县",
				"parent_id": 361100,
				"type": 4,
				"zip": "334700"
			}, {
				"id": 361121,
				"name": "上饶县",
				"parent_id": 361100,
				"type": 4,
				"zip": "334100"
			}, {
				"id": 361126,
				"name": "弋阳县",
				"parent_id": 361100,
				"type": 4,
				"zip": "334400"
			}, {
				"id": 361127,
				"name": "余干县",
				"parent_id": 361100,
				"type": 4,
				"zip": "335100"
			}, {
				"id": 361124,
				"name": "铅山县",
				"parent_id": 361100,
				"type": 4,
				"zip": "334500"
			}, {
				"id": 361125,
				"name": "横峰县",
				"parent_id": 361100,
				"type": 4,
				"zip": "334300"
			}, {
				"id": 361130,
				"name": "婺源县",
				"parent_id": 361100,
				"type": 4,
				"zip": "333200"
			}, {
				"id": 361128,
				"name": "鄱阳县",
				"parent_id": 361100,
				"type": 4,
				"zip": "333100"
			}, {
				"id": 361129,
				"name": "万年县",
				"parent_id": 361100,
				"type": 4,
				"zip": "335500"
			}, {
				"id": 361102,
				"name": "信州区",
				"parent_id": 361100,
				"type": 4,
				"zip": "334000"
			}]
		}, {
			"id": 360800,
			"name": "吉安市",
			"parent_id": 360000,
			"type": 3,
			"zip": "343000",
			"district": [{
				"id": 360803,
				"name": "青原区",
				"parent_id": 360800,
				"type": 4,
				"zip": "343009"
			}, {
				"id": 360802,
				"name": "吉州区",
				"parent_id": 360800,
				"type": 4,
				"zip": "343000"
			}, {
				"id": 360824,
				"name": "新干县",
				"parent_id": 360800,
				"type": 4,
				"zip": "331300"
			}, {
				"id": 360825,
				"name": "永丰县",
				"parent_id": 360800,
				"type": 4,
				"zip": "331500"
			}, {
				"id": 360826,
				"name": "泰和县",
				"parent_id": 360800,
				"type": 4,
				"zip": "343700"
			}, {
				"id": 360827,
				"name": "遂川县",
				"parent_id": 360800,
				"type": 4,
				"zip": "343900"
			}, {
				"id": 360828,
				"name": "万安县",
				"parent_id": 360800,
				"type": 4,
				"zip": "343800"
			}, {
				"id": 360829,
				"name": "安福县",
				"parent_id": 360800,
				"type": 4,
				"zip": "343200"
			}, {
				"id": 360830,
				"name": "永新县",
				"parent_id": 360800,
				"type": 4,
				"zip": "343400"
			}, {
				"id": 360821,
				"name": "吉安县",
				"parent_id": 360800,
				"type": 4,
				"zip": "343100"
			}, {
				"id": 360822,
				"name": "吉水县",
				"parent_id": 360800,
				"type": 4,
				"zip": "331600"
			}, {
				"id": 360823,
				"name": "峡江县",
				"parent_id": 360800,
				"type": 4,
				"zip": "331400"
			}, {
				"id": 360881,
				"name": "井冈山市",
				"parent_id": 360800,
				"type": 4,
				"zip": "343600"
			}, {
				"id": 360882,
				"name": "其它区",
				"parent_id": 360800,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 360900,
			"name": "宜春市",
			"parent_id": 360000,
			"type": 3,
			"zip": "336000",
			"district": [{
				"id": 360984,
				"name": "其它区",
				"parent_id": 360900,
				"type": 4,
				"zip": ""
			}, {
				"id": 360981,
				"name": "丰城市",
				"parent_id": 360900,
				"type": 4,
				"zip": "331100"
			}, {
				"id": 360982,
				"name": "樟树市",
				"parent_id": 360900,
				"type": 4,
				"zip": "331200"
			}, {
				"id": 360983,
				"name": "高安市",
				"parent_id": 360900,
				"type": 4,
				"zip": "330800"
			}, {
				"id": 360902,
				"name": "袁州区",
				"parent_id": 360900,
				"type": 4,
				"zip": "336000"
			}, {
				"id": 360923,
				"name": "上高县",
				"parent_id": 360900,
				"type": 4,
				"zip": "336400"
			}, {
				"id": 360922,
				"name": "万载县",
				"parent_id": 360900,
				"type": 4,
				"zip": "336100"
			}, {
				"id": 360921,
				"name": "奉新县",
				"parent_id": 360900,
				"type": 4,
				"zip": "330700"
			}, {
				"id": 360926,
				"name": "铜鼓县",
				"parent_id": 360900,
				"type": 4,
				"zip": "336200"
			}, {
				"id": 360925,
				"name": "靖安县",
				"parent_id": 360900,
				"type": 4,
				"zip": "330600"
			}, {
				"id": 360924,
				"name": "宜丰县",
				"parent_id": 360900,
				"type": 4,
				"zip": "336300"
			}]
		}, {
			"id": 360500,
			"name": "新余市",
			"parent_id": 360000,
			"type": 3,
			"zip": "338000",
			"district": [{
				"id": 360521,
				"name": "分宜县",
				"parent_id": 360500,
				"type": 4,
				"zip": "336600"
			}, {
				"id": 360522,
				"name": "其它区",
				"parent_id": 360500,
				"type": 4,
				"zip": ""
			}, {
				"id": 360502,
				"name": "渝水区",
				"parent_id": 360500,
				"type": 4,
				"zip": "338025"
			}]
		}, {
			"id": 360700,
			"name": "赣州市",
			"parent_id": 360000,
			"type": 3,
			"zip": "341000",
			"district": [{
				"id": 360783,
				"name": "其它区",
				"parent_id": 360700,
				"type": 4,
				"zip": ""
			}, {
				"id": 360782,
				"name": "南康市",
				"parent_id": 360700,
				"type": 4,
				"zip": "341400"
			}, {
				"id": 360781,
				"name": "瑞金市",
				"parent_id": 360700,
				"type": 4,
				"zip": "342500"
			}, {
				"id": 360734,
				"name": "寻乌县",
				"parent_id": 360700,
				"type": 4,
				"zip": "342200"
			}, {
				"id": 360735,
				"name": "石城县",
				"parent_id": 360700,
				"type": 4,
				"zip": "342700"
			}, {
				"id": 360732,
				"name": "兴国县",
				"parent_id": 360700,
				"type": 4,
				"zip": "342400"
			}, {
				"id": 360733,
				"name": "会昌县",
				"parent_id": 360700,
				"type": 4,
				"zip": "342600"
			}, {
				"id": 360730,
				"name": "宁都县",
				"parent_id": 360700,
				"type": 4,
				"zip": "342800"
			}, {
				"id": 360731,
				"name": "于都县",
				"parent_id": 360700,
				"type": 4,
				"zip": "342300"
			}, {
				"id": 360728,
				"name": "定南县",
				"parent_id": 360700,
				"type": 4,
				"zip": "341900"
			}, {
				"id": 360729,
				"name": "全南县",
				"parent_id": 360700,
				"type": 4,
				"zip": "341800"
			}, {
				"id": 360726,
				"name": "安远县",
				"parent_id": 360700,
				"type": 4,
				"zip": "342100"
			}, {
				"id": 360727,
				"name": "龙南县",
				"parent_id": 360700,
				"type": 4,
				"zip": "341700"
			}, {
				"id": 360724,
				"name": "上犹县",
				"parent_id": 360700,
				"type": 4,
				"zip": "341200"
			}, {
				"id": 360725,
				"name": "崇义县",
				"parent_id": 360700,
				"type": 4,
				"zip": "341300"
			}, {
				"id": 360722,
				"name": "信丰县",
				"parent_id": 360700,
				"type": 4,
				"zip": "341600"
			}, {
				"id": 360723,
				"name": "大余县",
				"parent_id": 360700,
				"type": 4,
				"zip": "341500"
			}, {
				"id": 360721,
				"name": "赣县",
				"parent_id": 360700,
				"type": 4,
				"zip": "341100"
			}, {
				"id": 360751,
				"name": "黄金区",
				"parent_id": 360700,
				"type": 4,
				"zip": ""
			}, {
				"id": 360702,
				"name": "章贡区",
				"parent_id": 360700,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 360600,
			"name": "鹰潭市",
			"parent_id": 360000,
			"type": 3,
			"zip": "335000",
			"district": [{
				"id": 360682,
				"name": "其它区",
				"parent_id": 360600,
				"type": 4,
				"zip": ""
			}, {
				"id": 360681,
				"name": "贵溪市",
				"parent_id": 360600,
				"type": 4,
				"zip": "335400"
			}, {
				"id": 360602,
				"name": "月湖区",
				"parent_id": 360600,
				"type": 4,
				"zip": "335000"
			}, {
				"id": 360622,
				"name": "余江县",
				"parent_id": 360600,
				"type": 4,
				"zip": "335200"
			}]
		}]
	}, {
		"id": 410000,
		"name": "河南省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 411700,
			"name": "驻马店市",
			"parent_id": 410000,
			"type": 3,
			"zip": "463000",
			"district": [{
				"id": 411730,
				"name": "其它区",
				"parent_id": 411700,
				"type": 4,
				"zip": ""
			}, {
				"id": 411729,
				"name": "新蔡县",
				"parent_id": 411700,
				"type": 4,
				"zip": "463500"
			}, {
				"id": 411728,
				"name": "遂平县",
				"parent_id": 411700,
				"type": 4,
				"zip": "463100"
			}, {
				"id": 411726,
				"name": "泌阳县",
				"parent_id": 411700,
				"type": 4,
				"zip": "463700"
			}, {
				"id": 411727,
				"name": "汝南县",
				"parent_id": 411700,
				"type": 4,
				"zip": "463300"
			}, {
				"id": 411724,
				"name": "正阳县",
				"parent_id": 411700,
				"type": 4,
				"zip": "463600"
			}, {
				"id": 411725,
				"name": "确山县",
				"parent_id": 411700,
				"type": 4,
				"zip": "463200"
			}, {
				"id": 411722,
				"name": "上蔡县",
				"parent_id": 411700,
				"type": 4,
				"zip": "463800"
			}, {
				"id": 411723,
				"name": "平舆县",
				"parent_id": 411700,
				"type": 4,
				"zip": "463400"
			}, {
				"id": 411721,
				"name": "西平县",
				"parent_id": 411700,
				"type": 4,
				"zip": "463900"
			}, {
				"id": 411702,
				"name": "驿城区",
				"parent_id": 411700,
				"type": 4,
				"zip": "463000"
			}]
		}, {
			"id": 410100,
			"name": "郑州市",
			"parent_id": 410000,
			"type": 3,
			"zip": "450000",
			"district": [{
				"id": 410108,
				"name": "惠济区",
				"parent_id": 410100,
				"type": 4,
				"zip": "450053"
			}, {
				"id": 410106,
				"name": "上街区",
				"parent_id": 410100,
				"type": 4,
				"zip": "450041"
			}, {
				"id": 410104,
				"name": "管城回族区",
				"parent_id": 410100,
				"type": 4,
				"zip": "450000"
			}, {
				"id": 410105,
				"name": "金水区",
				"parent_id": 410100,
				"type": 4,
				"zip": "450003"
			}, {
				"id": 410102,
				"name": "中原区",
				"parent_id": 410100,
				"type": 4,
				"zip": "450007"
			}, {
				"id": 410103,
				"name": "二七区",
				"parent_id": 410100,
				"type": 4,
				"zip": "450000"
			}, {
				"id": 410182,
				"name": "荥阳市",
				"parent_id": 410100,
				"type": 4,
				"zip": "450100"
			}, {
				"id": 410183,
				"name": "新密市",
				"parent_id": 410100,
				"type": 4,
				"zip": "452300"
			}, {
				"id": 410181,
				"name": "巩义市",
				"parent_id": 410100,
				"type": 4,
				"zip": "451200"
			}, {
				"id": 410186,
				"name": "郑东新区",
				"parent_id": 410100,
				"type": 4,
				"zip": ""
			}, {
				"id": 410187,
				"name": "高新区",
				"parent_id": 410100,
				"type": 4,
				"zip": ""
			}, {
				"id": 410184,
				"name": "新郑市",
				"parent_id": 410100,
				"type": 4,
				"zip": "451150"
			}, {
				"id": 410185,
				"name": "登封市",
				"parent_id": 410100,
				"type": 4,
				"zip": "452470"
			}, {
				"id": 410188,
				"name": "其它区",
				"parent_id": 410100,
				"type": 4,
				"zip": ""
			}, {
				"id": 410122,
				"name": "中牟县",
				"parent_id": 410100,
				"type": 4,
				"zip": "451450"
			}]
		}, {
			"id": 410300,
			"name": "洛阳市",
			"parent_id": 410000,
			"type": 3,
			"zip": "471000",
			"district": [{
				"id": 410307,
				"name": "洛龙区",
				"parent_id": 410300,
				"type": 4,
				"zip": "471000"
			}, {
				"id": 410306,
				"name": "吉利区",
				"parent_id": 410300,
				"type": 4,
				"zip": "471012"
			}, {
				"id": 410305,
				"name": "涧西区",
				"parent_id": 410300,
				"type": 4,
				"zip": "471003"
			}, {
				"id": 410304,
				"name": "瀍河回族区",
				"parent_id": 410300,
				"type": 4,
				"zip": "471002"
			}, {
				"id": 410328,
				"name": "洛宁县",
				"parent_id": 410300,
				"type": 4,
				"zip": "471700"
			}, {
				"id": 410329,
				"name": "伊川县",
				"parent_id": 410300,
				"type": 4,
				"zip": "471300"
			}, {
				"id": 410322,
				"name": "孟津县",
				"parent_id": 410300,
				"type": 4,
				"zip": "471100"
			}, {
				"id": 410323,
				"name": "新安县",
				"parent_id": 410300,
				"type": 4,
				"zip": "471800"
			}, {
				"id": 410326,
				"name": "汝阳县",
				"parent_id": 410300,
				"type": 4,
				"zip": "471200"
			}, {
				"id": 410327,
				"name": "宜阳县",
				"parent_id": 410300,
				"type": 4,
				"zip": "471600"
			}, {
				"id": 410324,
				"name": "栾川县",
				"parent_id": 410300,
				"type": 4,
				"zip": "471500"
			}, {
				"id": 410325,
				"name": "嵩县",
				"parent_id": 410300,
				"type": 4,
				"zip": "471400"
			}, {
				"id": 410302,
				"name": "老城区",
				"parent_id": 410300,
				"type": 4,
				"zip": "471002"
			}, {
				"id": 410303,
				"name": "西工区",
				"parent_id": 410300,
				"type": 4,
				"zip": "471000"
			}, {
				"id": 410381,
				"name": "偃师市",
				"parent_id": 410300,
				"type": 4,
				"zip": "471900"
			}, {
				"id": 471005,
				"name": "其它区",
				"parent_id": 410300,
				"type": 4,
				"zip": ""
			}, {
				"id": 471004,
				"name": "高新区",
				"parent_id": 410300,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 410200,
			"name": "开封市",
			"parent_id": 410000,
			"type": 3,
			"zip": "475000",
			"district": [{
				"id": 410203,
				"name": "顺河回族区",
				"parent_id": 410200,
				"type": 4,
				"zip": "475000"
			}, {
				"id": 410202,
				"name": "龙亭区",
				"parent_id": 410200,
				"type": 4,
				"zip": "475100"
			}, {
				"id": 410205,
				"name": "禹王台区",
				"parent_id": 410200,
				"type": 4,
				"zip": "475003"
			}, {
				"id": 410204,
				"name": "鼓楼区",
				"parent_id": 410200,
				"type": 4,
				"zip": "475000"
			}, {
				"id": 410211,
				"name": "金明区",
				"parent_id": 410200,
				"type": 4,
				"zip": "475002"
			}, {
				"id": 410221,
				"name": "杞县",
				"parent_id": 410200,
				"type": 4,
				"zip": "475200"
			}, {
				"id": 410222,
				"name": "通许县",
				"parent_id": 410200,
				"type": 4,
				"zip": "475400"
			}, {
				"id": 410223,
				"name": "尉氏县",
				"parent_id": 410200,
				"type": 4,
				"zip": "475500"
			}, {
				"id": 410225,
				"name": "兰考县",
				"parent_id": 410200,
				"type": 4,
				"zip": "475300"
			}, {
				"id": 410224,
				"name": "开封县",
				"parent_id": 410200,
				"type": 4,
				"zip": "475100"
			}, {
				"id": 410226,
				"name": "其它区",
				"parent_id": 410200,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 410600,
			"name": "鹤壁市",
			"parent_id": 410000,
			"type": 3,
			"zip": "458000",
			"district": [{
				"id": 410622,
				"name": "淇县",
				"parent_id": 410600,
				"type": 4,
				"zip": "456750"
			}, {
				"id": 410623,
				"name": "其它区",
				"parent_id": 410600,
				"type": 4,
				"zip": ""
			}, {
				"id": 410621,
				"name": "浚县",
				"parent_id": 410600,
				"type": 4,
				"zip": "456250"
			}, {
				"id": 410611,
				"name": "淇滨区",
				"parent_id": 410600,
				"type": 4,
				"zip": "458030"
			}, {
				"id": 410603,
				"name": "山城区",
				"parent_id": 410600,
				"type": 4,
				"zip": "458000"
			}, {
				"id": 410602,
				"name": "鹤山区",
				"parent_id": 410600,
				"type": 4,
				"zip": "458010"
			}]
		}, {
			"id": 410500,
			"name": "安阳市",
			"parent_id": 410000,
			"type": 3,
			"zip": "455000",
			"district": [{
				"id": 410581,
				"name": "林州市",
				"parent_id": 410500,
				"type": 4,
				"zip": "456500"
			}, {
				"id": 410582,
				"name": "其它区",
				"parent_id": 410500,
				"type": 4,
				"zip": ""
			}, {
				"id": 410526,
				"name": "滑县",
				"parent_id": 410500,
				"type": 4,
				"zip": "456400"
			}, {
				"id": 410527,
				"name": "内黄县",
				"parent_id": 410500,
				"type": 4,
				"zip": "456300"
			}, {
				"id": 410522,
				"name": "安阳县",
				"parent_id": 410500,
				"type": 4,
				"zip": "455100"
			}, {
				"id": 410523,
				"name": "汤阴县",
				"parent_id": 410500,
				"type": 4,
				"zip": "456150"
			}, {
				"id": 410505,
				"name": "殷都区",
				"parent_id": 410500,
				"type": 4,
				"zip": "455004"
			}, {
				"id": 410506,
				"name": "龙安区",
				"parent_id": 410500,
				"type": 4,
				"zip": "455001"
			}, {
				"id": 410503,
				"name": "北关区",
				"parent_id": 410500,
				"type": 4,
				"zip": "455001"
			}, {
				"id": 410502,
				"name": "文峰区",
				"parent_id": 410500,
				"type": 4,
				"zip": "455000"
			}]
		}, {
			"id": 410400,
			"name": "平顶山市",
			"parent_id": 410000,
			"type": 3,
			"zip": "467000",
			"district": [{
				"id": 410483,
				"name": "其它区",
				"parent_id": 410400,
				"type": 4,
				"zip": ""
			}, {
				"id": 410482,
				"name": "汝州市",
				"parent_id": 410400,
				"type": 4,
				"zip": "467500"
			}, {
				"id": 410481,
				"name": "舞钢市",
				"parent_id": 410400,
				"type": 4,
				"zip": "462500"
			}, {
				"id": 410423,
				"name": "鲁山县",
				"parent_id": 410400,
				"type": 4,
				"zip": "467300"
			}, {
				"id": 410422,
				"name": "叶县",
				"parent_id": 410400,
				"type": 4,
				"zip": "467200"
			}, {
				"id": 410421,
				"name": "宝丰县",
				"parent_id": 410400,
				"type": 4,
				"zip": "467400"
			}, {
				"id": 410425,
				"name": "郏县",
				"parent_id": 410400,
				"type": 4,
				"zip": "467100"
			}, {
				"id": 410404,
				"name": "石龙区",
				"parent_id": 410400,
				"type": 4,
				"zip": "467045"
			}, {
				"id": 410402,
				"name": "新华区",
				"parent_id": 410400,
				"type": 4,
				"zip": "467002"
			}, {
				"id": 410403,
				"name": "卫东区",
				"parent_id": 410400,
				"type": 4,
				"zip": "467021"
			}, {
				"id": 410411,
				"name": "湛河区",
				"parent_id": 410400,
				"type": 4,
				"zip": "467000"
			}]
		}, {
			"id": 410800,
			"name": "焦作市",
			"parent_id": 410000,
			"type": 3,
			"zip": "454000",
			"district": [{
				"id": 410802,
				"name": "解放区",
				"parent_id": 410800,
				"type": 4,
				"zip": "454000"
			}, {
				"id": 410803,
				"name": "中站区",
				"parent_id": 410800,
				"type": 4,
				"zip": "454191"
			}, {
				"id": 410804,
				"name": "马村区",
				"parent_id": 410800,
				"type": 4,
				"zip": "454171"
			}, {
				"id": 410811,
				"name": "山阳区",
				"parent_id": 410800,
				"type": 4,
				"zip": "454002"
			}, {
				"id": 410823,
				"name": "武陟县",
				"parent_id": 410800,
				"type": 4,
				"zip": "454950"
			}, {
				"id": 410822,
				"name": "博爱县",
				"parent_id": 410800,
				"type": 4,
				"zip": "454450"
			}, {
				"id": 410821,
				"name": "修武县",
				"parent_id": 410800,
				"type": 4,
				"zip": "454350"
			}, {
				"id": 410825,
				"name": "温县",
				"parent_id": 410800,
				"type": 4,
				"zip": "454850"
			}, {
				"id": 410882,
				"name": "沁阳市",
				"parent_id": 410800,
				"type": 4,
				"zip": "454550"
			}, {
				"id": 410883,
				"name": "孟州市",
				"parent_id": 410800,
				"type": 4,
				"zip": "454750"
			}, {
				"id": 410884,
				"name": "其它区",
				"parent_id": 410800,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 410700,
			"name": "新乡市",
			"parent_id": 410000,
			"type": 3,
			"zip": "453000",
			"district": [{
				"id": 410782,
				"name": "辉县市",
				"parent_id": 410700,
				"type": 4,
				"zip": "453600"
			}, {
				"id": 410783,
				"name": "其它区",
				"parent_id": 410700,
				"type": 4,
				"zip": ""
			}, {
				"id": 410781,
				"name": "卫辉市",
				"parent_id": 410700,
				"type": 4,
				"zip": "453100"
			}, {
				"id": 410728,
				"name": "长垣县",
				"parent_id": 410700,
				"type": 4,
				"zip": "453400"
			}, {
				"id": 410724,
				"name": "获嘉县",
				"parent_id": 410700,
				"type": 4,
				"zip": "453800"
			}, {
				"id": 410725,
				"name": "原阳县",
				"parent_id": 410700,
				"type": 4,
				"zip": "453500"
			}, {
				"id": 410726,
				"name": "延津县",
				"parent_id": 410700,
				"type": 4,
				"zip": "453200"
			}, {
				"id": 410727,
				"name": "封丘县",
				"parent_id": 410700,
				"type": 4,
				"zip": "453300"
			}, {
				"id": 410721,
				"name": "新乡县",
				"parent_id": 410700,
				"type": 4,
				"zip": "453700"
			}, {
				"id": 410702,
				"name": "红旗区",
				"parent_id": 410700,
				"type": 4,
				"zip": "453000"
			}, {
				"id": 410703,
				"name": "卫滨区",
				"parent_id": 410700,
				"type": 4,
				"zip": "453000"
			}, {
				"id": 410711,
				"name": "牧野区",
				"parent_id": 410700,
				"type": 4,
				"zip": "453002"
			}, {
				"id": 410704,
				"name": "凤泉区",
				"parent_id": 410700,
				"type": 4,
				"zip": "453011"
			}]
		}, {
			"id": 411100,
			"name": "漯河市",
			"parent_id": 410000,
			"type": 3,
			"zip": "462000",
			"district": [{
				"id": 411122,
				"name": "临颍县",
				"parent_id": 411100,
				"type": 4,
				"zip": "462600"
			}, {
				"id": 411123,
				"name": "其它区",
				"parent_id": 411100,
				"type": 4,
				"zip": ""
			}, {
				"id": 411121,
				"name": "舞阳县",
				"parent_id": 411100,
				"type": 4,
				"zip": "462400"
			}, {
				"id": 411104,
				"name": "召陵区",
				"parent_id": 411100,
				"type": 4,
				"zip": "462300"
			}, {
				"id": 411102,
				"name": "源汇区",
				"parent_id": 411100,
				"type": 4,
				"zip": "462000"
			}, {
				"id": 411103,
				"name": "郾城区",
				"parent_id": 411100,
				"type": 4,
				"zip": "462300"
			}]
		}, {
			"id": 410900,
			"name": "濮阳市",
			"parent_id": 410000,
			"type": 3,
			"zip": "457000",
			"district": [{
				"id": 410929,
				"name": "其它区",
				"parent_id": 410900,
				"type": 4,
				"zip": ""
			}, {
				"id": 410928,
				"name": "濮阳县",
				"parent_id": 410900,
				"type": 4,
				"zip": "457100"
			}, {
				"id": 410922,
				"name": "清丰县",
				"parent_id": 410900,
				"type": 4,
				"zip": "457300"
			}, {
				"id": 410923,
				"name": "南乐县",
				"parent_id": 410900,
				"type": 4,
				"zip": "457400"
			}, {
				"id": 410926,
				"name": "范县",
				"parent_id": 410900,
				"type": 4,
				"zip": "457500"
			}, {
				"id": 410927,
				"name": "台前县",
				"parent_id": 410900,
				"type": 4,
				"zip": "457600"
			}, {
				"id": 410902,
				"name": "华龙区",
				"parent_id": 410900,
				"type": 4,
				"zip": "457001"
			}]
		}, {
			"id": 410881,
			"name": "济源市",
			"parent_id": 410000,
			"type": 4,
			"zip": "454650",
			"district": [{
				"id": 41088110,
				"name": "沁园街道办事处",
				"parent_id": 410881,
				"type": 4,
				"zip": ""
			}, {
				"id": 41088111,
				"name": "济水街道办事处",
				"parent_id": 410881,
				"type": 4,
				"zip": ""
			}, {
				"id": 41088112,
				"name": "北海街道办事处",
				"parent_id": 410881,
				"type": 4,
				"zip": ""
			}, {
				"id": 41088113,
				"name": "天坛街道办事处",
				"parent_id": 410881,
				"type": 4,
				"zip": ""
			}, {
				"id": 41088114,
				"name": "玉泉街道办事处",
				"parent_id": 410881,
				"type": 4,
				"zip": ""
			}, {
				"id": 41088115,
				"name": "克井镇",
				"parent_id": 410881,
				"type": 4,
				"zip": ""
			}, {
				"id": 41088116,
				"name": "五龙口镇",
				"parent_id": 410881,
				"type": 4,
				"zip": ""
			}, {
				"id": 41088117,
				"name": "轵城镇",
				"parent_id": 410881,
				"type": 4,
				"zip": ""
			}, {
				"id": 41088118,
				"name": "承留镇",
				"parent_id": 410881,
				"type": 4,
				"zip": ""
			}, {
				"id": 41088120,
				"name": "邵原镇",
				"parent_id": 410881,
				"type": 4,
				"zip": ""
			}, {
				"id": 41088121,
				"name": "坡头镇",
				"parent_id": 410881,
				"type": 4,
				"zip": ""
			}, {
				"id": 41088122,
				"name": "梨林镇",
				"parent_id": 410881,
				"type": 4,
				"zip": ""
			}, {
				"id": 41088123,
				"name": "大峪镇",
				"parent_id": 410881,
				"type": 4,
				"zip": ""
			}, {
				"id": 41088124,
				"name": "思礼镇",
				"parent_id": 410881,
				"type": 4,
				"zip": ""
			}, {
				"id": 41088125,
				"name": "王屋镇",
				"parent_id": 410881,
				"type": 4,
				"zip": ""
			}, {
				"id": 41088126,
				"name": "下冶镇",
				"parent_id": 410881,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 411000,
			"name": "许昌市",
			"parent_id": 410000,
			"type": 3,
			"zip": "461000",
			"district": [{
				"id": 411024,
				"name": "鄢陵县",
				"parent_id": 411000,
				"type": 4,
				"zip": "461200"
			}, {
				"id": 411025,
				"name": "襄城县",
				"parent_id": 411000,
				"type": 4,
				"zip": "461700"
			}, {
				"id": 411023,
				"name": "许昌县",
				"parent_id": 411000,
				"type": 4,
				"zip": "461100"
			}, {
				"id": 411081,
				"name": "禹州市",
				"parent_id": 411000,
				"type": 4,
				"zip": "461670"
			}, {
				"id": 411083,
				"name": "其它区",
				"parent_id": 411000,
				"type": 4,
				"zip": ""
			}, {
				"id": 411082,
				"name": "长葛市",
				"parent_id": 411000,
				"type": 4,
				"zip": "461500"
			}, {
				"id": 411002,
				"name": "魏都区",
				"parent_id": 411000,
				"type": 4,
				"zip": "461000"
			}]
		}, {
			"id": 411300,
			"name": "南阳市",
			"parent_id": 410000,
			"type": 3,
			"zip": "473000",
			"district": [{
				"id": 411303,
				"name": "卧龙区",
				"parent_id": 411300,
				"type": 4,
				"zip": "473003"
			}, {
				"id": 411302,
				"name": "宛城区",
				"parent_id": 411300,
				"type": 4,
				"zip": "473001"
			}, {
				"id": 411324,
				"name": "镇平县",
				"parent_id": 411300,
				"type": 4,
				"zip": "474250"
			}, {
				"id": 411325,
				"name": "内乡县",
				"parent_id": 411300,
				"type": 4,
				"zip": "474350"
			}, {
				"id": 411326,
				"name": "淅川县",
				"parent_id": 411300,
				"type": 4,
				"zip": "474450"
			}, {
				"id": 411327,
				"name": "社旗县",
				"parent_id": 411300,
				"type": 4,
				"zip": "473300"
			}, {
				"id": 411321,
				"name": "南召县",
				"parent_id": 411300,
				"type": 4,
				"zip": "474650"
			}, {
				"id": 411322,
				"name": "方城县",
				"parent_id": 411300,
				"type": 4,
				"zip": "473200"
			}, {
				"id": 411323,
				"name": "西峡县",
				"parent_id": 411300,
				"type": 4,
				"zip": "474550"
			}, {
				"id": 411330,
				"name": "桐柏县",
				"parent_id": 411300,
				"type": 4,
				"zip": "474750"
			}, {
				"id": 411329,
				"name": "新野县",
				"parent_id": 411300,
				"type": 4,
				"zip": "473500"
			}, {
				"id": 411328,
				"name": "唐河县",
				"parent_id": 411300,
				"type": 4,
				"zip": "473400"
			}, {
				"id": 411381,
				"name": "邓州市",
				"parent_id": 411300,
				"type": 4,
				"zip": "474150"
			}, {
				"id": 411382,
				"name": "其它区",
				"parent_id": 411300,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 411200,
			"name": "三门峡市",
			"parent_id": 410000,
			"type": 3,
			"zip": "472000",
			"district": [{
				"id": 411282,
				"name": "灵宝市",
				"parent_id": 411200,
				"type": 4,
				"zip": "472500"
			}, {
				"id": 411283,
				"name": "其它区",
				"parent_id": 411200,
				"type": 4,
				"zip": ""
			}, {
				"id": 411281,
				"name": "义马市",
				"parent_id": 411200,
				"type": 4,
				"zip": "472300"
			}, {
				"id": 411202,
				"name": "湖滨区",
				"parent_id": 411200,
				"type": 4,
				"zip": "472000"
			}, {
				"id": 411224,
				"name": "卢氏县",
				"parent_id": 411200,
				"type": 4,
				"zip": "472200"
			}, {
				"id": 411222,
				"name": "陕县",
				"parent_id": 411200,
				"type": 4,
				"zip": "472100"
			}, {
				"id": 411221,
				"name": "渑池县",
				"parent_id": 411200,
				"type": 4,
				"zip": "472400"
			}]
		}, {
			"id": 411600,
			"name": "周口市",
			"parent_id": 410000,
			"type": 3,
			"zip": "466000",
			"district": [{
				"id": 411681,
				"name": "项城市",
				"parent_id": 411600,
				"type": 4,
				"zip": "466200"
			}, {
				"id": 411682,
				"name": "其它区",
				"parent_id": 411600,
				"type": 4,
				"zip": ""
			}, {
				"id": 411602,
				"name": "川汇区",
				"parent_id": 411600,
				"type": 4,
				"zip": "466000"
			}, {
				"id": 411623,
				"name": "商水县",
				"parent_id": 411600,
				"type": 4,
				"zip": "466100"
			}, {
				"id": 411622,
				"name": "西华县",
				"parent_id": 411600,
				"type": 4,
				"zip": "466600"
			}, {
				"id": 411621,
				"name": "扶沟县",
				"parent_id": 411600,
				"type": 4,
				"zip": "461300"
			}, {
				"id": 411627,
				"name": "太康县",
				"parent_id": 411600,
				"type": 4,
				"zip": "475400"
			}, {
				"id": 411626,
				"name": "淮阳县",
				"parent_id": 411600,
				"type": 4,
				"zip": "466700"
			}, {
				"id": 411625,
				"name": "郸城县",
				"parent_id": 411600,
				"type": 4,
				"zip": "477150"
			}, {
				"id": 411624,
				"name": "沈丘县",
				"parent_id": 411600,
				"type": 4,
				"zip": "466300"
			}, {
				"id": 411628,
				"name": "鹿邑县",
				"parent_id": 411600,
				"type": 4,
				"zip": "477200"
			}]
		}, {
			"id": 411400,
			"name": "商丘市",
			"parent_id": 410000,
			"type": 3,
			"zip": "476000",
			"district": [{
				"id": 411421,
				"name": "民权县",
				"parent_id": 411400,
				"type": 4,
				"zip": "476800"
			}, {
				"id": 411423,
				"name": "宁陵县",
				"parent_id": 411400,
				"type": 4,
				"zip": "476700"
			}, {
				"id": 411422,
				"name": "睢县",
				"parent_id": 411400,
				"type": 4,
				"zip": "476900"
			}, {
				"id": 411402,
				"name": "梁园区",
				"parent_id": 411400,
				"type": 4,
				"zip": "476000"
			}, {
				"id": 411403,
				"name": "睢阳区",
				"parent_id": 411400,
				"type": 4,
				"zip": "476100"
			}, {
				"id": 411426,
				"name": "夏邑县",
				"parent_id": 411400,
				"type": 4,
				"zip": "476400"
			}, {
				"id": 411424,
				"name": "柘城县",
				"parent_id": 411400,
				"type": 4,
				"zip": "476200"
			}, {
				"id": 411425,
				"name": "虞城县",
				"parent_id": 411400,
				"type": 4,
				"zip": "476300"
			}, {
				"id": 411481,
				"name": "永城市",
				"parent_id": 411400,
				"type": 4,
				"zip": "476600"
			}, {
				"id": 411482,
				"name": "其它区",
				"parent_id": 411400,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 411500,
			"name": "信阳市",
			"parent_id": 410000,
			"type": 3,
			"zip": "464000",
			"district": [{
				"id": 411525,
				"name": "固始县",
				"parent_id": 411500,
				"type": 4,
				"zip": "465200"
			}, {
				"id": 411524,
				"name": "商城县",
				"parent_id": 411500,
				"type": 4,
				"zip": "465350"
			}, {
				"id": 411527,
				"name": "淮滨县",
				"parent_id": 411500,
				"type": 4,
				"zip": "464400"
			}, {
				"id": 411526,
				"name": "潢川县",
				"parent_id": 411500,
				"type": 4,
				"zip": "465150"
			}, {
				"id": 411521,
				"name": "罗山县",
				"parent_id": 411500,
				"type": 4,
				"zip": "464200"
			}, {
				"id": 411523,
				"name": "新县",
				"parent_id": 411500,
				"type": 4,
				"zip": "465550"
			}, {
				"id": 411522,
				"name": "光山县",
				"parent_id": 411500,
				"type": 4,
				"zip": "465450"
			}, {
				"id": 411529,
				"name": "其它区",
				"parent_id": 411500,
				"type": 4,
				"zip": ""
			}, {
				"id": 411528,
				"name": "息县",
				"parent_id": 411500,
				"type": 4,
				"zip": "464300"
			}, {
				"id": 411502,
				"name": "浉河区",
				"parent_id": 411500,
				"type": 4,
				"zip": "464000"
			}, {
				"id": 411503,
				"name": "平桥区",
				"parent_id": 411500,
				"type": 4,
				"zip": "464100"
			}]
		}]
	}, {
		"id": 640000,
		"name": "宁夏回族自治区",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 640300,
			"name": "吴忠市",
			"parent_id": 640000,
			"type": 3,
			"zip": "751100",
			"district": [{
				"id": 640323,
				"name": "盐池县",
				"parent_id": 640300,
				"type": 4,
				"zip": "751500"
			}, {
				"id": 640324,
				"name": "同心县",
				"parent_id": 640300,
				"type": 4,
				"zip": "751300"
			}, {
				"id": 640381,
				"name": "青铜峡市",
				"parent_id": 640300,
				"type": 4,
				"zip": "751600"
			}, {
				"id": 640382,
				"name": "其它区",
				"parent_id": 640300,
				"type": 4,
				"zip": ""
			}, {
				"id": 640302,
				"name": "利通区",
				"parent_id": 640300,
				"type": 4,
				"zip": "751100"
			}, {
				"id": 640303,
				"name": "红寺堡区",
				"parent_id": 640300,
				"type": 4,
				"zip": "751900"
			}]
		}, {
			"id": 640500,
			"name": "中卫市",
			"parent_id": 640000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 640521,
				"name": "中宁县",
				"parent_id": 640500,
				"type": 4,
				"zip": "751200"
			}, {
				"id": 640522,
				"name": "海原县",
				"parent_id": 640500,
				"type": 4,
				"zip": "756100"
			}, {
				"id": 640523,
				"name": "其它区",
				"parent_id": 640500,
				"type": 4,
				"zip": ""
			}, {
				"id": 640502,
				"name": "沙坡头区",
				"parent_id": 640500,
				"type": 4,
				"zip": "751700"
			}]
		}, {
			"id": 640400,
			"name": "固原市",
			"parent_id": 640000,
			"type": 3,
			"zip": "756000",
			"district": [{
				"id": 640402,
				"name": "原州区",
				"parent_id": 640400,
				"type": 4,
				"zip": "756000"
			}, {
				"id": 640423,
				"name": "隆德县",
				"parent_id": 640400,
				"type": 4,
				"zip": "756300"
			}, {
				"id": 640422,
				"name": "西吉县",
				"parent_id": 640400,
				"type": 4,
				"zip": "756200"
			}, {
				"id": 640425,
				"name": "彭阳县",
				"parent_id": 640400,
				"type": 4,
				"zip": "756500"
			}, {
				"id": 640424,
				"name": "泾源县",
				"parent_id": 640400,
				"type": 4,
				"zip": "756400"
			}, {
				"id": 640426,
				"name": "其它区",
				"parent_id": 640400,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 640100,
			"name": "银川市",
			"parent_id": 640000,
			"type": 3,
			"zip": "750000",
			"district": [{
				"id": 640122,
				"name": "贺兰县",
				"parent_id": 640100,
				"type": 4,
				"zip": "750200"
			}, {
				"id": 640121,
				"name": "永宁县",
				"parent_id": 640100,
				"type": 4,
				"zip": "750100"
			}, {
				"id": 640106,
				"name": "金凤区",
				"parent_id": 640100,
				"type": 4,
				"zip": "750011"
			}, {
				"id": 640104,
				"name": "兴庆区",
				"parent_id": 640100,
				"type": 4,
				"zip": "750001"
			}, {
				"id": 640105,
				"name": "西夏区",
				"parent_id": 640100,
				"type": 4,
				"zip": "750027"
			}, {
				"id": 640182,
				"name": "其它区",
				"parent_id": 640100,
				"type": 4,
				"zip": ""
			}, {
				"id": 640181,
				"name": "灵武市",
				"parent_id": 640100,
				"type": 4,
				"zip": "751400"
			}]
		}, {
			"id": 640200,
			"name": "石嘴山市",
			"parent_id": 640000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 640221,
				"name": "平罗县",
				"parent_id": 640200,
				"type": 4,
				"zip": "753400"
			}, {
				"id": 640222,
				"name": "其它区",
				"parent_id": 640200,
				"type": 4,
				"zip": ""
			}, {
				"id": 640202,
				"name": "大武口区",
				"parent_id": 640200,
				"type": 4,
				"zip": "753000"
			}, {
				"id": 640205,
				"name": "惠农区",
				"parent_id": 640200,
				"type": 4,
				"zip": "753200"
			}]
		}]
	}, {
		"id": 820000,
		"name": "澳门特别行政区",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 820200,
			"name": "离岛",
			"parent_id": 820000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 82020010,
				"name": "离岛",
				"parent_id": 820200,
				"type": 4,
				"zip": ""
			}, {
				"id": 82020011,
				"name": "澳门半岛",
				"parent_id": 820200,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 820100,
			"name": "澳门半岛",
			"parent_id": 820000,
			"type": 3,
			"zip": ""
		}]
	}, {
		"id": 330000,
		"name": "浙江省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 330400,
			"name": "嘉兴市",
			"parent_id": 330000,
			"type": 3,
			"zip": "314000",
			"district": [{
				"id": 330484,
				"name": "其它区",
				"parent_id": 330400,
				"type": 4,
				"zip": ""
			}, {
				"id": 330483,
				"name": "桐乡市",
				"parent_id": 330400,
				"type": 4,
				"zip": "314500"
			}, {
				"id": 330482,
				"name": "平湖市",
				"parent_id": 330400,
				"type": 4,
				"zip": "314200"
			}, {
				"id": 330481,
				"name": "海宁市",
				"parent_id": 330400,
				"type": 4,
				"zip": "314400"
			}, {
				"id": 330411,
				"name": "秀洲区",
				"parent_id": 330400,
				"type": 4,
				"zip": "314001"
			}, {
				"id": 330402,
				"name": "南湖区",
				"parent_id": 330400,
				"type": 4,
				"zip": "314000"
			}, {
				"id": 330424,
				"name": "海盐县",
				"parent_id": 330400,
				"type": 4,
				"zip": "314300"
			}, {
				"id": 330421,
				"name": "嘉善县",
				"parent_id": 330400,
				"type": 4,
				"zip": "314100"
			}]
		}, {
			"id": 330300,
			"name": "温州市",
			"parent_id": 330000,
			"type": 3,
			"zip": "325000",
			"district": [{
				"id": 330381,
				"name": "瑞安市",
				"parent_id": 330300,
				"type": 4,
				"zip": "325200"
			}, {
				"id": 330382,
				"name": "乐清市",
				"parent_id": 330300,
				"type": 4,
				"zip": "325600"
			}, {
				"id": 330383,
				"name": "其它区",
				"parent_id": 330300,
				"type": 4,
				"zip": ""
			}, {
				"id": 330304,
				"name": "瓯海区",
				"parent_id": 330300,
				"type": 4,
				"zip": "325005"
			}, {
				"id": 330324,
				"name": "永嘉县",
				"parent_id": 330300,
				"type": 4,
				"zip": "325100"
			}, {
				"id": 330326,
				"name": "平阳县",
				"parent_id": 330300,
				"type": 4,
				"zip": "325400"
			}, {
				"id": 330327,
				"name": "苍南县",
				"parent_id": 330300,
				"type": 4,
				"zip": "325800"
			}, {
				"id": 330322,
				"name": "洞头县",
				"parent_id": 330300,
				"type": 4,
				"zip": "325700"
			}, {
				"id": 330328,
				"name": "文成县",
				"parent_id": 330300,
				"type": 4,
				"zip": "325300"
			}, {
				"id": 330329,
				"name": "泰顺县",
				"parent_id": 330300,
				"type": 4,
				"zip": "325500"
			}, {
				"id": 330302,
				"name": "鹿城区",
				"parent_id": 330300,
				"type": 4,
				"zip": "325000"
			}, {
				"id": 330303,
				"name": "龙湾区",
				"parent_id": 330300,
				"type": 4,
				"zip": "325024"
			}]
		}, {
			"id": 330700,
			"name": "金华市",
			"parent_id": 330000,
			"type": 3,
			"zip": "321000",
			"district": [{
				"id": 330726,
				"name": "浦江县",
				"parent_id": 330700,
				"type": 4,
				"zip": "322200"
			}, {
				"id": 330727,
				"name": "磐安县",
				"parent_id": 330700,
				"type": 4,
				"zip": "322300"
			}, {
				"id": 330723,
				"name": "武义县",
				"parent_id": 330700,
				"type": 4,
				"zip": "321200"
			}, {
				"id": 330702,
				"name": "婺城区",
				"parent_id": 330700,
				"type": 4,
				"zip": "321051"
			}, {
				"id": 330703,
				"name": "金东区",
				"parent_id": 330700,
				"type": 4,
				"zip": "321002"
			}, {
				"id": 330781,
				"name": "兰溪市",
				"parent_id": 330700,
				"type": 4,
				"zip": "321100"
			}, {
				"id": 330782,
				"name": "义乌市",
				"parent_id": 330700,
				"type": 4,
				"zip": "322000"
			}, {
				"id": 330783,
				"name": "东阳市",
				"parent_id": 330700,
				"type": 4,
				"zip": "322100"
			}, {
				"id": 330785,
				"name": "其它区",
				"parent_id": 330700,
				"type": 4,
				"zip": ""
			}, {
				"id": 330784,
				"name": "永康市",
				"parent_id": 330700,
				"type": 4,
				"zip": "321300"
			}]
		}, {
			"id": 330600,
			"name": "绍兴市",
			"parent_id": 330000,
			"type": 3,
			"zip": "312000",
			"district": [{
				"id": 330681,
				"name": "诸暨市",
				"parent_id": 330600,
				"type": 4,
				"zip": "311800"
			}, {
				"id": 330683,
				"name": "嵊州市",
				"parent_id": 330600,
				"type": 4,
				"zip": "312400"
			}, {
				"id": 330682,
				"name": "上虞市",
				"parent_id": 330600,
				"type": 4,
				"zip": "312300"
			}, {
				"id": 330684,
				"name": "其它区",
				"parent_id": 330600,
				"type": 4,
				"zip": ""
			}, {
				"id": 330624,
				"name": "新昌县",
				"parent_id": 330600,
				"type": 4,
				"zip": "312500"
			}, {
				"id": 330621,
				"name": "绍兴县",
				"parent_id": 330600,
				"type": 4,
				"zip": "312000"
			}, {
				"id": 330602,
				"name": "越城区",
				"parent_id": 330600,
				"type": 4,
				"zip": "312000"
			}]
		}, {
			"id": 330500,
			"name": "湖州市",
			"parent_id": 330000,
			"type": 3,
			"zip": "313000",
			"district": [{
				"id": 330522,
				"name": "长兴县",
				"parent_id": 330500,
				"type": 4,
				"zip": "313100"
			}, {
				"id": 330523,
				"name": "安吉县",
				"parent_id": 330500,
				"type": 4,
				"zip": "313300"
			}, {
				"id": 330521,
				"name": "德清县",
				"parent_id": 330500,
				"type": 4,
				"zip": "313200"
			}, {
				"id": 330524,
				"name": "其它区",
				"parent_id": 330500,
				"type": 4,
				"zip": ""
			}, {
				"id": 330503,
				"name": "南浔区",
				"parent_id": 330500,
				"type": 4,
				"zip": "313009"
			}, {
				"id": 330502,
				"name": "吴兴区",
				"parent_id": 330500,
				"type": 4,
				"zip": "313000"
			}]
		}, {
			"id": 330200,
			"name": "宁波市",
			"parent_id": 330000,
			"type": 3,
			"zip": "315000",
			"district": [{
				"id": 330283,
				"name": "奉化市",
				"parent_id": 330200,
				"type": 4,
				"zip": "315500"
			}, {
				"id": 330282,
				"name": "慈溪市",
				"parent_id": 330200,
				"type": 4,
				"zip": "315300"
			}, {
				"id": 330281,
				"name": "余姚市",
				"parent_id": 330200,
				"type": 4,
				"zip": "315400"
			}, {
				"id": 330284,
				"name": "其它区",
				"parent_id": 330200,
				"type": 4,
				"zip": ""
			}, {
				"id": 330203,
				"name": "海曙区",
				"parent_id": 330200,
				"type": 4,
				"zip": "315000"
			}, {
				"id": 330206,
				"name": "北仑区",
				"parent_id": 330200,
				"type": 4,
				"zip": "315800"
			}, {
				"id": 330205,
				"name": "江北区",
				"parent_id": 330200,
				"type": 4,
				"zip": "315020"
			}, {
				"id": 330204,
				"name": "江东区",
				"parent_id": 330200,
				"type": 4,
				"zip": "315040"
			}, {
				"id": 330225,
				"name": "象山县",
				"parent_id": 330200,
				"type": 4,
				"zip": "315700"
			}, {
				"id": 330226,
				"name": "宁海县",
				"parent_id": 330200,
				"type": 4,
				"zip": "315600"
			}, {
				"id": 330211,
				"name": "镇海区",
				"parent_id": 330200,
				"type": 4,
				"zip": "315200"
			}, {
				"id": 330212,
				"name": "鄞州区",
				"parent_id": 330200,
				"type": 4,
				"zip": "315100"
			}]
		}, {
			"id": 330100,
			"name": "杭州市",
			"parent_id": 330000,
			"type": 3,
			"zip": "310000",
			"district": [{
				"id": 330186,
				"name": "其它区",
				"parent_id": 330100,
				"type": 4,
				"zip": ""
			}, {
				"id": 330185,
				"name": "临安市",
				"parent_id": 330100,
				"type": 4,
				"zip": "311300"
			}, {
				"id": 330182,
				"name": "建德市",
				"parent_id": 330100,
				"type": 4,
				"zip": "311600"
			}, {
				"id": 330183,
				"name": "富阳市",
				"parent_id": 330100,
				"type": 4,
				"zip": "311400"
			}, {
				"id": 330127,
				"name": "淳安县",
				"parent_id": 330100,
				"type": 4,
				"zip": "311700"
			}, {
				"id": 330122,
				"name": "桐庐县",
				"parent_id": 330100,
				"type": 4,
				"zip": "311500"
			}, {
				"id": 330102,
				"name": "上城区",
				"parent_id": 330100,
				"type": 4,
				"zip": "311500"
			}, {
				"id": 330103,
				"name": "下城区",
				"parent_id": 330100,
				"type": 4,
				"zip": "310006"
			}, {
				"id": 330104,
				"name": "江干区",
				"parent_id": 330100,
				"type": 4,
				"zip": "310002"
			}, {
				"id": 330105,
				"name": "拱墅区",
				"parent_id": 330100,
				"type": 4,
				"zip": "310011"
			}, {
				"id": 330106,
				"name": "西湖区",
				"parent_id": 330100,
				"type": 4,
				"zip": "310013"
			}, {
				"id": 330108,
				"name": "滨江区",
				"parent_id": 330100,
				"type": 4,
				"zip": "310051"
			}, {
				"id": 330109,
				"name": "萧山区",
				"parent_id": 330100,
				"type": 4,
				"zip": "311200"
			}, {
				"id": 330110,
				"name": "余杭区",
				"parent_id": 330100,
				"type": 4,
				"zip": "311100"
			}]
		}, {
			"id": 330900,
			"name": "舟山市",
			"parent_id": 330000,
			"type": 3,
			"zip": "316000",
			"district": [{
				"id": 330903,
				"name": "普陀区",
				"parent_id": 330900,
				"type": 4,
				"zip": "316100"
			}, {
				"id": 330902,
				"name": "定海区",
				"parent_id": 330900,
				"type": 4,
				"zip": "316000"
			}, {
				"id": 330922,
				"name": "嵊泗县",
				"parent_id": 330900,
				"type": 4,
				"zip": "202400"
			}, {
				"id": 330923,
				"name": "其它区",
				"parent_id": 330900,
				"type": 4,
				"zip": ""
			}, {
				"id": 330921,
				"name": "岱山县",
				"parent_id": 330900,
				"type": 4,
				"zip": "316200"
			}]
		}, {
			"id": 331000,
			"name": "台州市",
			"parent_id": 330000,
			"type": 3,
			"zip": "318000",
			"district": [{
				"id": 331003,
				"name": "黄岩区",
				"parent_id": 331000,
				"type": 4,
				"zip": "318020"
			}, {
				"id": 331002,
				"name": "椒江区",
				"parent_id": 331000,
				"type": 4,
				"zip": "318000"
			}, {
				"id": 331004,
				"name": "路桥区",
				"parent_id": 331000,
				"type": 4,
				"zip": "318050"
			}, {
				"id": 331024,
				"name": "仙居县",
				"parent_id": 331000,
				"type": 4,
				"zip": "317300"
			}, {
				"id": 331023,
				"name": "天台县",
				"parent_id": 331000,
				"type": 4,
				"zip": "317200"
			}, {
				"id": 331022,
				"name": "三门县",
				"parent_id": 331000,
				"type": 4,
				"zip": "317100"
			}, {
				"id": 331021,
				"name": "玉环县",
				"parent_id": 331000,
				"type": 4,
				"zip": "317600"
			}, {
				"id": 331083,
				"name": "其它区",
				"parent_id": 331000,
				"type": 4,
				"zip": ""
			}, {
				"id": 331082,
				"name": "临海市",
				"parent_id": 331000,
				"type": 4,
				"zip": "317000"
			}, {
				"id": 331081,
				"name": "温岭市",
				"parent_id": 331000,
				"type": 4,
				"zip": "317500"
			}]
		}, {
			"id": 330800,
			"name": "衢州市",
			"parent_id": 330000,
			"type": 3,
			"zip": "324000",
			"district": [{
				"id": 330881,
				"name": "江山市",
				"parent_id": 330800,
				"type": 4,
				"zip": "324100"
			}, {
				"id": 330882,
				"name": "其它区",
				"parent_id": 330800,
				"type": 4,
				"zip": ""
			}, {
				"id": 330802,
				"name": "柯城区",
				"parent_id": 330800,
				"type": 4,
				"zip": "324000"
			}, {
				"id": 330803,
				"name": "衢江区",
				"parent_id": 330800,
				"type": 4,
				"zip": "324000"
			}, {
				"id": 330825,
				"name": "龙游县",
				"parent_id": 330800,
				"type": 4,
				"zip": "324400"
			}, {
				"id": 330824,
				"name": "开化县",
				"parent_id": 330800,
				"type": 4,
				"zip": "324300"
			}, {
				"id": 330822,
				"name": "常山县",
				"parent_id": 330800,
				"type": 4,
				"zip": "324200"
			}]
		}, {
			"id": 331100,
			"name": "丽水市",
			"parent_id": 330000,
			"type": 3,
			"zip": "323000",
			"district": [{
				"id": 331181,
				"name": "龙泉市",
				"parent_id": 331100,
				"type": 4,
				"zip": "323700"
			}, {
				"id": 331182,
				"name": "其它区",
				"parent_id": 331100,
				"type": 4,
				"zip": ""
			}, {
				"id": 331102,
				"name": "莲都区",
				"parent_id": 331100,
				"type": 4,
				"zip": "323000"
			}, {
				"id": 331121,
				"name": "青田县",
				"parent_id": 331100,
				"type": 4,
				"zip": "323900"
			}, {
				"id": 331122,
				"name": "缙云县",
				"parent_id": 331100,
				"type": 4,
				"zip": "321400"
			}, {
				"id": 331123,
				"name": "遂昌县",
				"parent_id": 331100,
				"type": 4,
				"zip": "323300"
			}, {
				"id": 331124,
				"name": "松阳县",
				"parent_id": 331100,
				"type": 4,
				"zip": "323400"
			}, {
				"id": 331125,
				"name": "云和县",
				"parent_id": 331100,
				"type": 4,
				"zip": "323600"
			}, {
				"id": 331126,
				"name": "庆元县",
				"parent_id": 331100,
				"type": 4,
				"zip": "323800"
			}, {
				"id": 331127,
				"name": "景宁畲族自治县",
				"parent_id": 331100,
				"type": 4,
				"zip": "323500"
			}]
		}]
	}, {
		"id": 650000,
		"name": "新疆维吾尔自治区",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 650200,
			"name": "克拉玛依市",
			"parent_id": 650000,
			"type": 3,
			"zip": "834000",
			"district": [{
				"id": 650204,
				"name": "白碱滩区",
				"parent_id": 650200,
				"type": 4,
				"zip": "834009"
			}, {
				"id": 650205,
				"name": "乌尔禾区",
				"parent_id": 650200,
				"type": 4,
				"zip": "834014"
			}, {
				"id": 650206,
				"name": "其它区",
				"parent_id": 650200,
				"type": 4,
				"zip": ""
			}, {
				"id": 650202,
				"name": "独山子区",
				"parent_id": 650200,
				"type": 4,
				"zip": "838600"
			}, {
				"id": 650203,
				"name": "克拉玛依区",
				"parent_id": 650200,
				"type": 4,
				"zip": "834000"
			}]
		}, {
			"id": 650100,
			"name": "乌鲁木齐市",
			"parent_id": 650000,
			"type": 3,
			"zip": "830000",
			"district": [{
				"id": 650121,
				"name": "乌鲁木齐县",
				"parent_id": 650100,
				"type": 4,
				"zip": "830063"
			}, {
				"id": 650122,
				"name": "其它区",
				"parent_id": 650100,
				"type": 4,
				"zip": ""
			}, {
				"id": 650103,
				"name": "沙依巴克区",
				"parent_id": 650100,
				"type": 4,
				"zip": "830000"
			}, {
				"id": 650102,
				"name": "天山区",
				"parent_id": 650100,
				"type": 4,
				"zip": "830002"
			}, {
				"id": 650109,
				"name": "米东区",
				"parent_id": 650100,
				"type": 4,
				"zip": "831400"
			}, {
				"id": 650108,
				"name": "东山区",
				"parent_id": 650100,
				"type": 4,
				"zip": "830019"
			}, {
				"id": 650107,
				"name": "达坂城区",
				"parent_id": 650100,
				"type": 4,
				"zip": "830039"
			}, {
				"id": 650106,
				"name": "头屯河区",
				"parent_id": 650100,
				"type": 4,
				"zip": "830023"
			}, {
				"id": 650105,
				"name": "水磨沟区",
				"parent_id": 650100,
				"type": 4,
				"zip": "830017"
			}, {
				"id": 650104,
				"name": "新市区",
				"parent_id": 650100,
				"type": 4,
				"zip": "830011"
			}]
		}, {
			"id": 654000,
			"name": "伊犁哈萨克自治州",
			"parent_id": 650000,
			"type": 3,
			"zip": "835000",
			"district": [{
				"id": 654028,
				"name": "尼勒克县",
				"parent_id": 654000,
				"type": 4,
				"zip": "835700"
			}, {
				"id": 654029,
				"name": "其它区",
				"parent_id": 654000,
				"type": 4,
				"zip": ""
			}, {
				"id": 654026,
				"name": "昭苏县",
				"parent_id": 654000,
				"type": 4,
				"zip": "835600"
			}, {
				"id": 654027,
				"name": "特克斯县",
				"parent_id": 654000,
				"type": 4,
				"zip": "835500"
			}, {
				"id": 654024,
				"name": "巩留县",
				"parent_id": 654000,
				"type": 4,
				"zip": "835400"
			}, {
				"id": 654025,
				"name": "新源县",
				"parent_id": 654000,
				"type": 4,
				"zip": "835800"
			}, {
				"id": 654022,
				"name": "察布查尔锡伯自治县",
				"parent_id": 654000,
				"type": 4,
				"zip": "835300"
			}, {
				"id": 654023,
				"name": "霍城县",
				"parent_id": 654000,
				"type": 4,
				"zip": "835200"
			}, {
				"id": 654021,
				"name": "伊宁县",
				"parent_id": 654000,
				"type": 4,
				"zip": "835100"
			}, {
				"id": 654003,
				"name": "奎屯市",
				"parent_id": 654000,
				"type": 4,
				"zip": "833200"
			}, {
				"id": 654002,
				"name": "伊宁市",
				"parent_id": 654000,
				"type": 4,
				"zip": "835000"
			}]
		}, {
			"id": 654300,
			"name": "阿勒泰地区",
			"parent_id": 650000,
			"type": 3,
			"zip": "836500",
			"district": [{
				"id": 654301,
				"name": "阿勒泰市",
				"parent_id": 654300,
				"type": 4,
				"zip": "836500"
			}, {
				"id": 654327,
				"name": "其它区",
				"parent_id": 654300,
				"type": 4,
				"zip": ""
			}, {
				"id": 654326,
				"name": "吉木乃县",
				"parent_id": 654300,
				"type": 4,
				"zip": "836800"
			}, {
				"id": 654325,
				"name": "青河县",
				"parent_id": 654300,
				"type": 4,
				"zip": "836200"
			}, {
				"id": 654324,
				"name": "哈巴河县",
				"parent_id": 654300,
				"type": 4,
				"zip": "836700"
			}, {
				"id": 654323,
				"name": "福海县",
				"parent_id": 654300,
				"type": 4,
				"zip": "836400"
			}, {
				"id": 654322,
				"name": "富蕴县",
				"parent_id": 654300,
				"type": 4,
				"zip": "836100"
			}, {
				"id": 654321,
				"name": "布尔津县",
				"parent_id": 654300,
				"type": 4,
				"zip": "836600"
			}]
		}, {
			"id": 654200,
			"name": "塔城地区",
			"parent_id": 650000,
			"type": 3,
			"zip": "834700",
			"district": [{
				"id": 654225,
				"name": "裕民县",
				"parent_id": 654200,
				"type": 4,
				"zip": "834800"
			}, {
				"id": 654224,
				"name": "托里县",
				"parent_id": 654200,
				"type": 4,
				"zip": "834500"
			}, {
				"id": 654227,
				"name": "其它区",
				"parent_id": 654200,
				"type": 4,
				"zip": ""
			}, {
				"id": 654226,
				"name": "和布克赛尔蒙古自治县",
				"parent_id": 654200,
				"type": 4,
				"zip": "834400"
			}, {
				"id": 654221,
				"name": "额敏县",
				"parent_id": 654200,
				"type": 4,
				"zip": "834600"
			}, {
				"id": 654223,
				"name": "沙湾县",
				"parent_id": 654200,
				"type": 4,
				"zip": "832100"
			}, {
				"id": 654202,
				"name": "乌苏市",
				"parent_id": 654200,
				"type": 4,
				"zip": "833000"
			}, {
				"id": 654201,
				"name": "塔城市",
				"parent_id": 654200,
				"type": 4,
				"zip": "834700"
			}]
		}, {
			"id": 652300,
			"name": "昌吉回族自治州",
			"parent_id": 650000,
			"type": 3,
			"zip": "831100",
			"district": [{
				"id": 652329,
				"name": "其它区",
				"parent_id": 652300,
				"type": 4,
				"zip": ""
			}, {
				"id": 652328,
				"name": "木垒哈萨克自治县",
				"parent_id": 652300,
				"type": 4,
				"zip": "831900"
			}, {
				"id": 652325,
				"name": "奇台县",
				"parent_id": 652300,
				"type": 4,
				"zip": "831800"
			}, {
				"id": 652324,
				"name": "玛纳斯县",
				"parent_id": 652300,
				"type": 4,
				"zip": "832200"
			}, {
				"id": 652327,
				"name": "吉木萨尔县",
				"parent_id": 652300,
				"type": 4,
				"zip": "831700"
			}, {
				"id": 652323,
				"name": "呼图壁县",
				"parent_id": 652300,
				"type": 4,
				"zip": "831200"
			}, {
				"id": 652303,
				"name": "米泉市",
				"parent_id": 652300,
				"type": 4,
				"zip": "831400"
			}, {
				"id": 652302,
				"name": "阜康市",
				"parent_id": 652300,
				"type": 4,
				"zip": "831500"
			}, {
				"id": 652301,
				"name": "昌吉市",
				"parent_id": 652300,
				"type": 4,
				"zip": "831100"
			}]
		}, {
			"id": 652700,
			"name": "博尔塔拉蒙古自治州",
			"parent_id": 650000,
			"type": 3,
			"zip": "833400",
			"district": [{
				"id": 652724,
				"name": "其它区",
				"parent_id": 652700,
				"type": 4,
				"zip": ""
			}, {
				"id": 652723,
				"name": "温泉县",
				"parent_id": 652700,
				"type": 4,
				"zip": "833500"
			}, {
				"id": 652722,
				"name": "精河县",
				"parent_id": 652700,
				"type": 4,
				"zip": "833300"
			}, {
				"id": 652701,
				"name": "博乐市",
				"parent_id": 652700,
				"type": 4,
				"zip": "833400"
			}, {
				"id": 652702,
				"name": "阿拉山口市",
				"parent_id": 652700,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 652800,
			"name": "巴音郭楞蒙古自治州",
			"parent_id": 650000,
			"type": 3,
			"zip": "841000",
			"district": [{
				"id": 652826,
				"name": "焉耆回族自治县",
				"parent_id": 652800,
				"type": 4,
				"zip": "841100"
			}, {
				"id": 652827,
				"name": "和静县",
				"parent_id": 652800,
				"type": 4,
				"zip": "841300"
			}, {
				"id": 652824,
				"name": "若羌县",
				"parent_id": 652800,
				"type": 4,
				"zip": "841800"
			}, {
				"id": 652825,
				"name": "且末县",
				"parent_id": 652800,
				"type": 4,
				"zip": "841900"
			}, {
				"id": 652830,
				"name": "其它区",
				"parent_id": 652800,
				"type": 4,
				"zip": ""
			}, {
				"id": 652828,
				"name": "和硕县",
				"parent_id": 652800,
				"type": 4,
				"zip": "841200"
			}, {
				"id": 652829,
				"name": "博湖县",
				"parent_id": 652800,
				"type": 4,
				"zip": "841400"
			}, {
				"id": 652822,
				"name": "轮台县",
				"parent_id": 652800,
				"type": 4,
				"zip": "841600"
			}, {
				"id": 652823,
				"name": "尉犁县",
				"parent_id": 652800,
				"type": 4,
				"zip": "841500"
			}, {
				"id": 652801,
				"name": "库尔勒市",
				"parent_id": 652800,
				"type": 4,
				"zip": "841000"
			}]
		}, {
			"id": 652900,
			"name": "阿克苏地区",
			"parent_id": 650000,
			"type": 3,
			"zip": "843000",
			"district": [{
				"id": 652924,
				"name": "沙雅县",
				"parent_id": 652900,
				"type": 4,
				"zip": "842200"
			}, {
				"id": 652925,
				"name": "新和县",
				"parent_id": 652900,
				"type": 4,
				"zip": "842100"
			}, {
				"id": 652926,
				"name": "拜城县",
				"parent_id": 652900,
				"type": 4,
				"zip": "842300"
			}, {
				"id": 652927,
				"name": "乌什县",
				"parent_id": 652900,
				"type": 4,
				"zip": "843400"
			}, {
				"id": 652922,
				"name": "温宿县",
				"parent_id": 652900,
				"type": 4,
				"zip": "843100"
			}, {
				"id": 652923,
				"name": "库车县",
				"parent_id": 652900,
				"type": 4,
				"zip": "842000"
			}, {
				"id": 652901,
				"name": "阿克苏市",
				"parent_id": 652900,
				"type": 4,
				"zip": "843000"
			}, {
				"id": 652930,
				"name": "其它区",
				"parent_id": 652900,
				"type": 4,
				"zip": ""
			}, {
				"id": 652928,
				"name": "阿瓦提县",
				"parent_id": 652900,
				"type": 4,
				"zip": "843200"
			}, {
				"id": 652929,
				"name": "柯坪县",
				"parent_id": 652900,
				"type": 4,
				"zip": "843600"
			}]
		}, {
			"id": 653000,
			"name": "克孜勒苏柯尔克孜自治州",
			"parent_id": 650000,
			"type": 3,
			"zip": "845350",
			"district": [{
				"id": 653023,
				"name": "阿合奇县",
				"parent_id": 653000,
				"type": 4,
				"zip": "843500"
			}, {
				"id": 653022,
				"name": "阿克陶县",
				"parent_id": 653000,
				"type": 4,
				"zip": "845550"
			}, {
				"id": 653001,
				"name": "阿图什市",
				"parent_id": 653000,
				"type": 4,
				"zip": "845350"
			}, {
				"id": 653024,
				"name": "乌恰县",
				"parent_id": 653000,
				"type": 4,
				"zip": "845450"
			}, {
				"id": 653025,
				"name": "其它区",
				"parent_id": 653000,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 653100,
			"name": "喀什地区",
			"parent_id": 650000,
			"type": 3,
			"zip": "844000",
			"district": [{
				"id": 653101,
				"name": "喀什市",
				"parent_id": 653100,
				"type": 4,
				"zip": "844000"
			}, {
				"id": 653132,
				"name": "其它区",
				"parent_id": 653100,
				"type": 4,
				"zip": ""
			}, {
				"id": 653129,
				"name": "伽师县",
				"parent_id": 653100,
				"type": 4,
				"zip": "844300"
			}, {
				"id": 653128,
				"name": "岳普湖县",
				"parent_id": 653100,
				"type": 4,
				"zip": "844400"
			}, {
				"id": 653131,
				"name": "塔什库尔干塔吉克自治县",
				"parent_id": 653100,
				"type": 4,
				"zip": "845250"
			}, {
				"id": 653130,
				"name": "巴楚县",
				"parent_id": 653100,
				"type": 4,
				"zip": "843800"
			}, {
				"id": 653125,
				"name": "莎车县",
				"parent_id": 653100,
				"type": 4,
				"zip": "844700"
			}, {
				"id": 653124,
				"name": "泽普县",
				"parent_id": 653100,
				"type": 4,
				"zip": "844800"
			}, {
				"id": 653127,
				"name": "麦盖提县",
				"parent_id": 653100,
				"type": 4,
				"zip": "844600"
			}, {
				"id": 653126,
				"name": "叶城县",
				"parent_id": 653100,
				"type": 4,
				"zip": "844900"
			}, {
				"id": 653121,
				"name": "疏附县",
				"parent_id": 653100,
				"type": 4,
				"zip": "844100"
			}, {
				"id": 653123,
				"name": "英吉沙县",
				"parent_id": 653100,
				"type": 4,
				"zip": "844500"
			}, {
				"id": 653122,
				"name": "疏勒县",
				"parent_id": 653100,
				"type": 4,
				"zip": "844200"
			}]
		}, {
			"id": 653200,
			"name": "和田地区",
			"parent_id": 650000,
			"type": 3,
			"zip": "848000",
			"district": [{
				"id": 653201,
				"name": "和田市",
				"parent_id": 653200,
				"type": 4,
				"zip": "848000"
			}, {
				"id": 653222,
				"name": "墨玉县",
				"parent_id": 653200,
				"type": 4,
				"zip": "848100"
			}, {
				"id": 653223,
				"name": "皮山县",
				"parent_id": 653200,
				"type": 4,
				"zip": "845150"
			}, {
				"id": 653221,
				"name": "和田县",
				"parent_id": 653200,
				"type": 4,
				"zip": "848000"
			}, {
				"id": 653226,
				"name": "于田县",
				"parent_id": 653200,
				"type": 4,
				"zip": "848400"
			}, {
				"id": 653227,
				"name": "民丰县",
				"parent_id": 653200,
				"type": 4,
				"zip": "848500"
			}, {
				"id": 653224,
				"name": "洛浦县",
				"parent_id": 653200,
				"type": 4,
				"zip": "848200"
			}, {
				"id": 653225,
				"name": "策勒县",
				"parent_id": 653200,
				"type": 4,
				"zip": "848300"
			}, {
				"id": 653228,
				"name": "其它区",
				"parent_id": 653200,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 652100,
			"name": "吐鲁番地区",
			"parent_id": 650000,
			"type": 3,
			"zip": "838000",
			"district": [{
				"id": 652101,
				"name": "吐鲁番市",
				"parent_id": 652100,
				"type": 4,
				"zip": "838000"
			}, {
				"id": 652124,
				"name": "其它区",
				"parent_id": 652100,
				"type": 4,
				"zip": ""
			}, {
				"id": 652122,
				"name": "鄯善县",
				"parent_id": 652100,
				"type": 4,
				"zip": "838200"
			}, {
				"id": 652123,
				"name": "托克逊县",
				"parent_id": 652100,
				"type": 4,
				"zip": "838100"
			}]
		}, {
			"id": 652200,
			"name": "哈密地区",
			"parent_id": 650000,
			"type": 3,
			"zip": "839000",
			"district": [{
				"id": 652224,
				"name": "其它区",
				"parent_id": 652200,
				"type": 4,
				"zip": ""
			}, {
				"id": 652201,
				"name": "哈密市",
				"parent_id": 652200,
				"type": 4,
				"zip": "839000"
			}, {
				"id": 652223,
				"name": "伊吾县",
				"parent_id": 652200,
				"type": 4,
				"zip": "839300"
			}, {
				"id": 652222,
				"name": "巴里坤哈萨克自治县",
				"parent_id": 652200,
				"type": 4,
				"zip": "839200"
			}]
		}, {
			"id": 659004,
			"name": "五家渠市",
			"parent_id": 650000,
			"type": 4,
			"zip": "831300",
			"district": [{
				"id": 65900410,
				"name": "军垦路街道办事处",
				"parent_id": 659004,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900411,
				"name": "青湖路街道办事处",
				"parent_id": 659004,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900412,
				"name": "人民路街道办事处",
				"parent_id": 659004,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900413,
				"name": "兵团一零一团",
				"parent_id": 659004,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900414,
				"name": "兵团一零二团",
				"parent_id": 659004,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900415,
				"name": "兵团一零三团",
				"parent_id": 659004,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 659001,
			"name": "石河子市",
			"parent_id": 650000,
			"type": 4,
			"zip": "832000",
			"district": [{
				"id": 65900110,
				"name": "新城街道办事处",
				"parent_id": 659001,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900111,
				"name": "向阳街道办事处",
				"parent_id": 659001,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900112,
				"name": "红山街道办事处",
				"parent_id": 659001,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900113,
				"name": "老街街道办事处",
				"parent_id": 659001,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900114,
				"name": "东城街道办事处",
				"parent_id": 659001,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900115,
				"name": "北泉镇",
				"parent_id": 659001,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900116,
				"name": "石河子乡",
				"parent_id": 659001,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900117,
				"name": "兵团一五二团",
				"parent_id": 659001,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 659002,
			"name": "阿拉尔市",
			"parent_id": 650000,
			"type": 4,
			"zip": "843300",
			"district": [{
				"id": 65900210,
				"name": "金银川路街道办事处",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900211,
				"name": "幸福路街道办事处",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900212,
				"name": "青松路街道办事处",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900213,
				"name": "南口街道办事处",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900214,
				"name": "托喀依乡",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900215,
				"name": "工业园区",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900216,
				"name": "兵团七团",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900217,
				"name": "兵团八团",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900218,
				"name": "兵团十团",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900219,
				"name": "兵团十一团",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900220,
				"name": "兵团十二团",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900221,
				"name": "兵团十三团",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900222,
				"name": "兵团十四团",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900223,
				"name": "兵团十六团",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900224,
				"name": "兵团第一师水利水电工程处",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900225,
				"name": "兵团第一师塔里木灌区水利管理处",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900226,
				"name": "阿拉尔农场",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900227,
				"name": "兵团第一师幸福农场",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900228,
				"name": "中心监狱",
				"parent_id": 659002,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 659003,
			"name": "图木舒克市",
			"parent_id": 650000,
			"type": 4,
			"zip": "843806",
			"district": [{
				"id": 65900310,
				"name": "齐干却勒街道办事处",
				"parent_id": 659003,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900311,
				"name": "前海街道办事处",
				"parent_id": 659003,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900312,
				"name": "永安坝街道办事处",
				"parent_id": 659003,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900313,
				"name": "兵团四十四团",
				"parent_id": 659003,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900314,
				"name": "兵团四十九团",
				"parent_id": 659003,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900315,
				"name": "兵团五十团",
				"parent_id": 659003,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900316,
				"name": "兵团五十一团",
				"parent_id": 659003,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900317,
				"name": "兵团五十三团",
				"parent_id": 659003,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900318,
				"name": "兵团图木舒克市喀拉拜勒镇",
				"parent_id": 659003,
				"type": 4,
				"zip": ""
			}, {
				"id": 65900319,
				"name": "兵团图木舒克市永安坝",
				"parent_id": 659003,
				"type": 4,
				"zip": ""
			}]
		}]
	}, {
		"id": 220000,
		"name": "吉林省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 222400,
			"name": "延边朝鲜族自治州",
			"parent_id": 220000,
			"type": 3,
			"zip": "133000",
			"district": [{
				"id": 222424,
				"name": "汪清县",
				"parent_id": 222400,
				"type": 4,
				"zip": "133200"
			}, {
				"id": 222427,
				"name": "其它区",
				"parent_id": 222400,
				"type": 4,
				"zip": ""
			}, {
				"id": 222426,
				"name": "安图县",
				"parent_id": 222400,
				"type": 4,
				"zip": "133600"
			}, {
				"id": 222401,
				"name": "延吉市",
				"parent_id": 222400,
				"type": 4,
				"zip": "133000"
			}, {
				"id": 222402,
				"name": "图们市",
				"parent_id": 222400,
				"type": 4,
				"zip": "133100"
			}, {
				"id": 222403,
				"name": "敦化市",
				"parent_id": 222400,
				"type": 4,
				"zip": "133700"
			}, {
				"id": 222404,
				"name": "珲春市",
				"parent_id": 222400,
				"type": 4,
				"zip": "133300"
			}, {
				"id": 222405,
				"name": "龙井市",
				"parent_id": 222400,
				"type": 4,
				"zip": "133400"
			}, {
				"id": 222406,
				"name": "和龙市",
				"parent_id": 222400,
				"type": 4,
				"zip": "133500"
			}]
		}, {
			"id": 220100,
			"name": "长春市",
			"parent_id": 220000,
			"type": 3,
			"zip": "130000",
			"district": [{
				"id": 220122,
				"name": "农安县",
				"parent_id": 220100,
				"type": 4,
				"zip": "130200"
			}, {
				"id": 220112,
				"name": "双阳区",
				"parent_id": 220100,
				"type": 4,
				"zip": "130600"
			}, {
				"id": 220105,
				"name": "二道区",
				"parent_id": 220100,
				"type": 4,
				"zip": "130031"
			}, {
				"id": 220104,
				"name": "朝阳区",
				"parent_id": 220100,
				"type": 4,
				"zip": "130012"
			}, {
				"id": 220106,
				"name": "绿园区",
				"parent_id": 220100,
				"type": 4,
				"zip": "130062"
			}, {
				"id": 220103,
				"name": "宽城区",
				"parent_id": 220100,
				"type": 4,
				"zip": "130051"
			}, {
				"id": 220102,
				"name": "南关区",
				"parent_id": 220100,
				"type": 4,
				"zip": "130022"
			}, {
				"id": 220188,
				"name": "其它区",
				"parent_id": 220100,
				"type": 4,
				"zip": ""
			}, {
				"id": 220187,
				"name": "净月旅游开发区",
				"parent_id": 220100,
				"type": 4,
				"zip": ""
			}, {
				"id": 220186,
				"name": "经济技术开发区",
				"parent_id": 220100,
				"type": 4,
				"zip": ""
			}, {
				"id": 220185,
				"name": "汽车产业开发区",
				"parent_id": 220100,
				"type": 4,
				"zip": ""
			}, {
				"id": 220184,
				"name": "高新技术产业开发区",
				"parent_id": 220100,
				"type": 4,
				"zip": ""
			}, {
				"id": 220183,
				"name": "德惠市",
				"parent_id": 220100,
				"type": 4,
				"zip": "130300"
			}, {
				"id": 220182,
				"name": "榆树市",
				"parent_id": 220100,
				"type": 4,
				"zip": "130400"
			}, {
				"id": 220181,
				"name": "九台市",
				"parent_id": 220100,
				"type": 4,
				"zip": "130500"
			}]
		}, {
			"id": 220700,
			"name": "松原市",
			"parent_id": 220000,
			"type": 3,
			"zip": "138000",
			"district": [{
				"id": 220721,
				"name": "前郭尔罗斯蒙古族自治县",
				"parent_id": 220700,
				"type": 4,
				"zip": "131100"
			}, {
				"id": 220723,
				"name": "乾安县",
				"parent_id": 220700,
				"type": 4,
				"zip": "131400"
			}, {
				"id": 220722,
				"name": "长岭县",
				"parent_id": 220700,
				"type": 4,
				"zip": "131500"
			}, {
				"id": 220725,
				"name": "其它区",
				"parent_id": 220700,
				"type": 4,
				"zip": ""
			}, {
				"id": 220724,
				"name": "扶余市",
				"parent_id": 220700,
				"type": 4,
				"zip": "131200"
			}, {
				"id": 220702,
				"name": "宁江区",
				"parent_id": 220700,
				"type": 4,
				"zip": "138000"
			}]
		}, {
			"id": 220800,
			"name": "白城市",
			"parent_id": 220000,
			"type": 3,
			"zip": "137000",
			"district": [{
				"id": 220882,
				"name": "大安市",
				"parent_id": 220800,
				"type": 4,
				"zip": "131300"
			}, {
				"id": 220883,
				"name": "其它区",
				"parent_id": 220800,
				"type": 4,
				"zip": ""
			}, {
				"id": 220881,
				"name": "洮南市",
				"parent_id": 220800,
				"type": 4,
				"zip": "137100"
			}, {
				"id": 220802,
				"name": "洮北区",
				"parent_id": 220800,
				"type": 4,
				"zip": "137000"
			}, {
				"id": 220822,
				"name": "通榆县",
				"parent_id": 220800,
				"type": 4,
				"zip": "137200"
			}, {
				"id": 220821,
				"name": "镇赉县",
				"parent_id": 220800,
				"type": 4,
				"zip": "137300"
			}]
		}, {
			"id": 220500,
			"name": "通化市",
			"parent_id": 220000,
			"type": 3,
			"zip": "134000",
			"district": [{
				"id": 220503,
				"name": "二道江区",
				"parent_id": 220500,
				"type": 4,
				"zip": "134303"
			}, {
				"id": 220502,
				"name": "东昌区",
				"parent_id": 220500,
				"type": 4,
				"zip": "134001"
			}, {
				"id": 220523,
				"name": "辉南县",
				"parent_id": 220500,
				"type": 4,
				"zip": "135100"
			}, {
				"id": 220521,
				"name": "通化县",
				"parent_id": 220500,
				"type": 4,
				"zip": "134100"
			}, {
				"id": 220524,
				"name": "柳河县",
				"parent_id": 220500,
				"type": 4,
				"zip": "135300"
			}, {
				"id": 220583,
				"name": "其它区",
				"parent_id": 220500,
				"type": 4,
				"zip": ""
			}, {
				"id": 220582,
				"name": "集安市",
				"parent_id": 220500,
				"type": 4,
				"zip": "134200"
			}, {
				"id": 220581,
				"name": "梅河口市",
				"parent_id": 220500,
				"type": 4,
				"zip": "135000"
			}]
		}, {
			"id": 220600,
			"name": "白山市",
			"parent_id": 220000,
			"type": 3,
			"zip": "134300",
			"district": [{
				"id": 220682,
				"name": "其它区",
				"parent_id": 220600,
				"type": 4,
				"zip": ""
			}, {
				"id": 220681,
				"name": "临江市",
				"parent_id": 220600,
				"type": 4,
				"zip": "134600"
			}, {
				"id": 220625,
				"name": "江源区",
				"parent_id": 220600,
				"type": 4,
				"zip": "134700"
			}, {
				"id": 220621,
				"name": "抚松县",
				"parent_id": 220600,
				"type": 4,
				"zip": "134500"
			}, {
				"id": 220623,
				"name": "长白朝鲜族自治县",
				"parent_id": 220600,
				"type": 4,
				"zip": "134400"
			}, {
				"id": 220622,
				"name": "靖宇县",
				"parent_id": 220600,
				"type": 4,
				"zip": "135200"
			}, {
				"id": 220602,
				"name": "浑江区",
				"parent_id": 220600,
				"type": 4,
				"zip": "134300"
			}]
		}, {
			"id": 220200,
			"name": "吉林市",
			"parent_id": 220000,
			"type": 3,
			"zip": "132000",
			"district": [{
				"id": 220281,
				"name": "蛟河市",
				"parent_id": 220200,
				"type": 4,
				"zip": "132500"
			}, {
				"id": 220283,
				"name": "舒兰市",
				"parent_id": 220200,
				"type": 4,
				"zip": "132600"
			}, {
				"id": 220282,
				"name": "桦甸市",
				"parent_id": 220200,
				"type": 4,
				"zip": "132400"
			}, {
				"id": 220285,
				"name": "其它区",
				"parent_id": 220200,
				"type": 4,
				"zip": ""
			}, {
				"id": 220284,
				"name": "磐石市",
				"parent_id": 220200,
				"type": 4,
				"zip": "132300"
			}, {
				"id": 220204,
				"name": "船营区",
				"parent_id": 220200,
				"type": 4,
				"zip": "132011"
			}, {
				"id": 220202,
				"name": "昌邑区",
				"parent_id": 220200,
				"type": 4,
				"zip": "132002"
			}, {
				"id": 220203,
				"name": "龙潭区",
				"parent_id": 220200,
				"type": 4,
				"zip": "132021"
			}, {
				"id": 220221,
				"name": "永吉县",
				"parent_id": 220200,
				"type": 4,
				"zip": "132100"
			}, {
				"id": 220211,
				"name": "丰满区",
				"parent_id": 220200,
				"type": 4,
				"zip": "132113"
			}]
		}, {
			"id": 220400,
			"name": "辽源市",
			"parent_id": 220000,
			"type": 3,
			"zip": "136200",
			"district": [{
				"id": 220421,
				"name": "东丰县",
				"parent_id": 220400,
				"type": 4,
				"zip": "136300"
			}, {
				"id": 220422,
				"name": "东辽县",
				"parent_id": 220400,
				"type": 4,
				"zip": "136600"
			}, {
				"id": 220423,
				"name": "其它区",
				"parent_id": 220400,
				"type": 4,
				"zip": ""
			}, {
				"id": 220402,
				"name": "龙山区",
				"parent_id": 220400,
				"type": 4,
				"zip": "136200"
			}, {
				"id": 220403,
				"name": "西安区",
				"parent_id": 220400,
				"type": 4,
				"zip": "136201"
			}]
		}, {
			"id": 220300,
			"name": "四平市",
			"parent_id": 220000,
			"type": 3,
			"zip": "136000",
			"district": [{
				"id": 220382,
				"name": "双辽市",
				"parent_id": 220300,
				"type": 4,
				"zip": "136400"
			}, {
				"id": 220383,
				"name": "其它区",
				"parent_id": 220300,
				"type": 4,
				"zip": ""
			}, {
				"id": 220381,
				"name": "公主岭市",
				"parent_id": 220300,
				"type": 4,
				"zip": "136100"
			}, {
				"id": 220303,
				"name": "铁东区",
				"parent_id": 220300,
				"type": 4,
				"zip": "136001"
			}, {
				"id": 220302,
				"name": "铁西区",
				"parent_id": 220300,
				"type": 4,
				"zip": "136000"
			}, {
				"id": 220323,
				"name": "伊通满族自治县",
				"parent_id": 220300,
				"type": 4,
				"zip": "130700"
			}, {
				"id": 220322,
				"name": "梨树县",
				"parent_id": 220300,
				"type": 4,
				"zip": "136500"
			}]
		}]
	}, {
		"id": 340000,
		"name": "安徽省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 340300,
			"name": "蚌埠市",
			"parent_id": 340000,
			"type": 3,
			"zip": "233000",
			"district": [{
				"id": 340322,
				"name": "五河县",
				"parent_id": 340300,
				"type": 4,
				"zip": "233300"
			}, {
				"id": 340323,
				"name": "固镇县",
				"parent_id": 340300,
				"type": 4,
				"zip": "233200"
			}, {
				"id": 340321,
				"name": "怀远县",
				"parent_id": 340300,
				"type": 4,
				"zip": "233400"
			}, {
				"id": 340324,
				"name": "其它区",
				"parent_id": 340300,
				"type": 4,
				"zip": ""
			}, {
				"id": 340302,
				"name": "龙子湖区",
				"parent_id": 340300,
				"type": 4,
				"zip": "233000"
			}, {
				"id": 340303,
				"name": "蚌山区",
				"parent_id": 340300,
				"type": 4,
				"zip": "233000"
			}, {
				"id": 340304,
				"name": "禹会区",
				"parent_id": 340300,
				"type": 4,
				"zip": "233010"
			}, {
				"id": 340311,
				"name": "淮上区",
				"parent_id": 340300,
				"type": 4,
				"zip": "233002"
			}]
		}, {
			"id": 340400,
			"name": "淮南市",
			"parent_id": 340000,
			"type": 3,
			"zip": "232000",
			"district": [{
				"id": 340406,
				"name": "潘集区",
				"parent_id": 340400,
				"type": 4,
				"zip": "232082"
			}, {
				"id": 340404,
				"name": "谢家集区",
				"parent_id": 340400,
				"type": 4,
				"zip": "232052"
			}, {
				"id": 340405,
				"name": "八公山区",
				"parent_id": 340400,
				"type": 4,
				"zip": "232072"
			}, {
				"id": 340402,
				"name": "大通区",
				"parent_id": 340400,
				"type": 4,
				"zip": "232033"
			}, {
				"id": 340403,
				"name": "田家庵区",
				"parent_id": 340400,
				"type": 4,
				"zip": "232000"
			}, {
				"id": 340421,
				"name": "凤台县",
				"parent_id": 340400,
				"type": 4,
				"zip": "232100"
			}, {
				"id": 340422,
				"name": "其它区",
				"parent_id": 340400,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 340100,
			"name": "合肥市",
			"parent_id": 340000,
			"type": 3,
			"zip": "230000",
			"district": [{
				"id": 340151,
				"name": "高新区",
				"parent_id": 340100,
				"type": 4,
				"zip": ""
			}, {
				"id": 340122,
				"name": "肥东县",
				"parent_id": 340100,
				"type": 4,
				"zip": "231600"
			}, {
				"id": 340123,
				"name": "肥西县",
				"parent_id": 340100,
				"type": 4,
				"zip": "231200"
			}, {
				"id": 340121,
				"name": "长丰县",
				"parent_id": 340100,
				"type": 4,
				"zip": "231100"
			}, {
				"id": 340111,
				"name": "包河区",
				"parent_id": 340100,
				"type": 4,
				"zip": "230041"
			}, {
				"id": 340104,
				"name": "蜀山区",
				"parent_id": 340100,
				"type": 4,
				"zip": "230061"
			}, {
				"id": 340103,
				"name": "庐阳区",
				"parent_id": 340100,
				"type": 4,
				"zip": "230001"
			}, {
				"id": 340102,
				"name": "瑶海区",
				"parent_id": 340100,
				"type": 4,
				"zip": "230011"
			}, {
				"id": 340192,
				"name": "其它区",
				"parent_id": 340100,
				"type": 4,
				"zip": ""
			}, {
				"id": 340191,
				"name": "中区",
				"parent_id": 340100,
				"type": 4,
				"zip": ""
			}, {
				"id": 341421,
				"name": "庐江县",
				"parent_id": 340100,
				"type": 4,
				"zip": "231500"
			}, {
				"id": 341400,
				"name": "巢湖市",
				"parent_id": 340100,
				"type": 4,
				"zip": "238000"
			}, {
				"id": 341402,
				"name": "居巢区",
				"parent_id": 340100,
				"type": 4,
				"zip": "238000"
			}]
		}, {
			"id": 340200,
			"name": "芜湖市",
			"parent_id": 340000,
			"type": 3,
			"zip": "241000",
			"district": [{
				"id": 340224,
				"name": "其它区",
				"parent_id": 340200,
				"type": 4,
				"zip": ""
			}, {
				"id": 340221,
				"name": "芜湖县",
				"parent_id": 340200,
				"type": 4,
				"zip": "241100"
			}, {
				"id": 340222,
				"name": "繁昌县",
				"parent_id": 340200,
				"type": 4,
				"zip": "241200"
			}, {
				"id": 340223,
				"name": "南陵县",
				"parent_id": 340200,
				"type": 4,
				"zip": "242400"
			}, {
				"id": 340208,
				"name": "三山区",
				"parent_id": 340200,
				"type": 4,
				"zip": "241000"
			}, {
				"id": 340203,
				"name": "弋江区",
				"parent_id": 340200,
				"type": 4,
				"zip": "241000"
			}, {
				"id": 340202,
				"name": "镜湖区",
				"parent_id": 340200,
				"type": 4,
				"zip": "241000"
			}, {
				"id": 340207,
				"name": "鸠江区",
				"parent_id": 340200,
				"type": 4,
				"zip": "241000"
			}, {
				"id": 341422,
				"name": "无为县",
				"parent_id": 340200,
				"type": 4,
				"zip": "238300"
			}]
		}, {
			"id": 340800,
			"name": "安庆市",
			"parent_id": 340000,
			"type": 3,
			"zip": "246000",
			"district": [{
				"id": 340802,
				"name": "迎江区",
				"parent_id": 340800,
				"type": 4,
				"zip": "246003"
			}, {
				"id": 340803,
				"name": "大观区",
				"parent_id": 340800,
				"type": 4,
				"zip": "246004"
			}, {
				"id": 340811,
				"name": "宜秀区",
				"parent_id": 340800,
				"type": 4,
				"zip": "246003"
			}, {
				"id": 340823,
				"name": "枞阳县",
				"parent_id": 340800,
				"type": 4,
				"zip": "246700"
			}, {
				"id": 340822,
				"name": "怀宁县",
				"parent_id": 340800,
				"type": 4,
				"zip": "246100"
			}, {
				"id": 340828,
				"name": "岳西县",
				"parent_id": 340800,
				"type": 4,
				"zip": "246600"
			}, {
				"id": 340825,
				"name": "太湖县",
				"parent_id": 340800,
				"type": 4,
				"zip": "246400"
			}, {
				"id": 340824,
				"name": "潜山县",
				"parent_id": 340800,
				"type": 4,
				"zip": "246300"
			}, {
				"id": 340827,
				"name": "望江县",
				"parent_id": 340800,
				"type": 4,
				"zip": "246200"
			}, {
				"id": 340826,
				"name": "宿松县",
				"parent_id": 340800,
				"type": 4,
				"zip": "246500"
			}, {
				"id": 340881,
				"name": "桐城市",
				"parent_id": 340800,
				"type": 4,
				"zip": "231400"
			}, {
				"id": 340882,
				"name": "其它区",
				"parent_id": 340800,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 340500,
			"name": "马鞍山市",
			"parent_id": 340000,
			"type": 3,
			"zip": "243000",
			"district": [{
				"id": 340503,
				"name": "花山区",
				"parent_id": 340500,
				"type": 4,
				"zip": "243000"
			}, {
				"id": 340502,
				"name": "金家庄区",
				"parent_id": 340500,
				"type": 4,
				"zip": "243021"
			}, {
				"id": 340506,
				"name": "博望区",
				"parent_id": 340500,
				"type": 4,
				"zip": ""
			}, {
				"id": 340504,
				"name": "雨山区",
				"parent_id": 340500,
				"type": 4,
				"zip": "243071"
			}, {
				"id": 340521,
				"name": "当涂县",
				"parent_id": 340500,
				"type": 4,
				"zip": "243100"
			}, {
				"id": 340522,
				"name": "其它区",
				"parent_id": 340500,
				"type": 4,
				"zip": ""
			}, {
				"id": 341423,
				"name": "含山县",
				"parent_id": 340500,
				"type": 4,
				"zip": "238100"
			}, {
				"id": 341424,
				"name": "和县",
				"parent_id": 340500,
				"type": 4,
				"zip": "238200"
			}]
		}, {
			"id": 340600,
			"name": "淮北市",
			"parent_id": 340000,
			"type": 3,
			"zip": "235000",
			"district": [{
				"id": 340604,
				"name": "烈山区",
				"parent_id": 340600,
				"type": 4,
				"zip": "235025"
			}, {
				"id": 340603,
				"name": "相山区",
				"parent_id": 340600,
				"type": 4,
				"zip": "235000"
			}, {
				"id": 340602,
				"name": "杜集区",
				"parent_id": 340600,
				"type": 4,
				"zip": "235047"
			}, {
				"id": 340622,
				"name": "其它区",
				"parent_id": 340600,
				"type": 4,
				"zip": ""
			}, {
				"id": 340621,
				"name": "濉溪县",
				"parent_id": 340600,
				"type": 4,
				"zip": "235100"
			}]
		}, {
			"id": 340700,
			"name": "铜陵市",
			"parent_id": 340000,
			"type": 3,
			"zip": "244000",
			"district": [{
				"id": 340702,
				"name": "铜官山区",
				"parent_id": 340700,
				"type": 4,
				"zip": "244000"
			}, {
				"id": 340703,
				"name": "狮子山区",
				"parent_id": 340700,
				"type": 4,
				"zip": "244031"
			}, {
				"id": 340721,
				"name": "铜陵县",
				"parent_id": 340700,
				"type": 4,
				"zip": "244100"
			}, {
				"id": 340722,
				"name": "其它区",
				"parent_id": 340700,
				"type": 4,
				"zip": ""
			}, {
				"id": 340711,
				"name": "郊区",
				"parent_id": 340700,
				"type": 4,
				"zip": "244000"
			}]
		}, {
			"id": 341300,
			"name": "宿州市",
			"parent_id": 340000,
			"type": 3,
			"zip": "234000",
			"district": [{
				"id": 341321,
				"name": "砀山县",
				"parent_id": 341300,
				"type": 4,
				"zip": "235300"
			}, {
				"id": 341322,
				"name": "萧县",
				"parent_id": 341300,
				"type": 4,
				"zip": "235200"
			}, {
				"id": 341323,
				"name": "灵璧县",
				"parent_id": 341300,
				"type": 4,
				"zip": "234200"
			}, {
				"id": 341324,
				"name": "泗县",
				"parent_id": 341300,
				"type": 4,
				"zip": "234300"
			}, {
				"id": 341325,
				"name": "其它区",
				"parent_id": 341300,
				"type": 4,
				"zip": ""
			}, {
				"id": 341302,
				"name": "埇桥区",
				"parent_id": 341300,
				"type": 4,
				"zip": "234000"
			}]
		}, {
			"id": 341500,
			"name": "六安市",
			"parent_id": 340000,
			"type": 3,
			"zip": "237000",
			"district": [{
				"id": 341502,
				"name": "金安区",
				"parent_id": 341500,
				"type": 4,
				"zip": "237005"
			}, {
				"id": 341503,
				"name": "裕安区",
				"parent_id": 341500,
				"type": 4,
				"zip": "237010"
			}, {
				"id": 341523,
				"name": "舒城县",
				"parent_id": 341500,
				"type": 4,
				"zip": "231300"
			}, {
				"id": 341522,
				"name": "霍邱县",
				"parent_id": 341500,
				"type": 4,
				"zip": "237400"
			}, {
				"id": 341521,
				"name": "寿县",
				"parent_id": 341500,
				"type": 4,
				"zip": "232200"
			}, {
				"id": 341526,
				"name": "其它区",
				"parent_id": 341500,
				"type": 4,
				"zip": ""
			}, {
				"id": 341525,
				"name": "霍山县",
				"parent_id": 341500,
				"type": 4,
				"zip": "237200"
			}, {
				"id": 341524,
				"name": "金寨县",
				"parent_id": 341500,
				"type": 4,
				"zip": "237300"
			}]
		}, {
			"id": 341100,
			"name": "滁州市",
			"parent_id": 340000,
			"type": 3,
			"zip": "239000",
			"district": [{
				"id": 341102,
				"name": "琅琊区",
				"parent_id": 341100,
				"type": 4,
				"zip": "239000"
			}, {
				"id": 341103,
				"name": "南谯区",
				"parent_id": 341100,
				"type": 4,
				"zip": "239000"
			}, {
				"id": 341181,
				"name": "天长市",
				"parent_id": 341100,
				"type": 4,
				"zip": "239300"
			}, {
				"id": 341182,
				"name": "明光市",
				"parent_id": 341100,
				"type": 4,
				"zip": "239400"
			}, {
				"id": 341183,
				"name": "其它区",
				"parent_id": 341100,
				"type": 4,
				"zip": ""
			}, {
				"id": 341126,
				"name": "凤阳县",
				"parent_id": 341100,
				"type": 4,
				"zip": "233100"
			}, {
				"id": 341125,
				"name": "定远县",
				"parent_id": 341100,
				"type": 4,
				"zip": "233200"
			}, {
				"id": 341124,
				"name": "全椒县",
				"parent_id": 341100,
				"type": 4,
				"zip": "239500"
			}, {
				"id": 341122,
				"name": "来安县",
				"parent_id": 341100,
				"type": 4,
				"zip": "239200"
			}]
		}, {
			"id": 341000,
			"name": "黄山市",
			"parent_id": 340000,
			"type": 3,
			"zip": "245000",
			"district": [{
				"id": 341024,
				"name": "祁门县",
				"parent_id": 341000,
				"type": 4,
				"zip": "245600"
			}, {
				"id": 341025,
				"name": "其它区",
				"parent_id": 341000,
				"type": 4,
				"zip": ""
			}, {
				"id": 341023,
				"name": "黟县",
				"parent_id": 341000,
				"type": 4,
				"zip": "245500"
			}, {
				"id": 341022,
				"name": "休宁县",
				"parent_id": 341000,
				"type": 4,
				"zip": "245400"
			}, {
				"id": 341021,
				"name": "歙县",
				"parent_id": 341000,
				"type": 4,
				"zip": "245200"
			}, {
				"id": 341004,
				"name": "徽州区",
				"parent_id": 341000,
				"type": 4,
				"zip": "245061"
			}, {
				"id": 341002,
				"name": "屯溪区",
				"parent_id": 341000,
				"type": 4,
				"zip": "245000"
			}, {
				"id": 341003,
				"name": "黄山区",
				"parent_id": 341000,
				"type": 4,
				"zip": "242700"
			}]
		}, {
			"id": 341200,
			"name": "阜阳市",
			"parent_id": 340000,
			"type": 3,
			"zip": "236000",
			"district": [{
				"id": 341282,
				"name": "界首市",
				"parent_id": 341200,
				"type": 4,
				"zip": "236500"
			}, {
				"id": 341283,
				"name": "其它区",
				"parent_id": 341200,
				"type": 4,
				"zip": ""
			}, {
				"id": 341221,
				"name": "临泉县",
				"parent_id": 341200,
				"type": 4,
				"zip": "236400"
			}, {
				"id": 341222,
				"name": "太和县",
				"parent_id": 341200,
				"type": 4,
				"zip": "236600"
			}, {
				"id": 341225,
				"name": "阜南县",
				"parent_id": 341200,
				"type": 4,
				"zip": "236300"
			}, {
				"id": 341226,
				"name": "颍上县",
				"parent_id": 341200,
				"type": 4,
				"zip": "236200"
			}, {
				"id": 341202,
				"name": "颍州区",
				"parent_id": 341200,
				"type": 4,
				"zip": "236001"
			}, {
				"id": 341203,
				"name": "颍东区",
				"parent_id": 341200,
				"type": 4,
				"zip": "236058"
			}, {
				"id": 341204,
				"name": "颍泉区",
				"parent_id": 341200,
				"type": 4,
				"zip": "236045"
			}]
		}, {
			"id": 341800,
			"name": "宣城市",
			"parent_id": 340000,
			"type": 3,
			"zip": "242000",
			"district": [{
				"id": 341824,
				"name": "绩溪县",
				"parent_id": 341800,
				"type": 4,
				"zip": "245300"
			}, {
				"id": 341825,
				"name": "旌德县",
				"parent_id": 341800,
				"type": 4,
				"zip": "242600"
			}, {
				"id": 341882,
				"name": "其它区",
				"parent_id": 341800,
				"type": 4,
				"zip": ""
			}, {
				"id": 341881,
				"name": "宁国市",
				"parent_id": 341800,
				"type": 4,
				"zip": "242300"
			}, {
				"id": 341802,
				"name": "宣州区",
				"parent_id": 341800,
				"type": 4,
				"zip": "242000"
			}, {
				"id": 341823,
				"name": "泾县",
				"parent_id": 341800,
				"type": 4,
				"zip": "242500"
			}, {
				"id": 341822,
				"name": "广德县",
				"parent_id": 341800,
				"type": 4,
				"zip": "242200"
			}, {
				"id": 341821,
				"name": "郎溪县",
				"parent_id": 341800,
				"type": 4,
				"zip": "242100"
			}]
		}, {
			"id": 341600,
			"name": "亳州市",
			"parent_id": 340000,
			"type": 3,
			"zip": "236800",
			"district": [{
				"id": 341624,
				"name": "其它区",
				"parent_id": 341600,
				"type": 4,
				"zip": ""
			}, {
				"id": 341621,
				"name": "涡阳县",
				"parent_id": 341600,
				"type": 4,
				"zip": "233600"
			}, {
				"id": 341623,
				"name": "利辛县",
				"parent_id": 341600,
				"type": 4,
				"zip": "236700"
			}, {
				"id": 341622,
				"name": "蒙城县",
				"parent_id": 341600,
				"type": 4,
				"zip": "233500"
			}, {
				"id": 341602,
				"name": "谯城区",
				"parent_id": 341600,
				"type": 4,
				"zip": "236800"
			}]
		}, {
			"id": 341700,
			"name": "池州市",
			"parent_id": 340000,
			"type": 3,
			"zip": "247000",
			"district": [{
				"id": 341724,
				"name": "其它区",
				"parent_id": 341700,
				"type": 4,
				"zip": ""
			}, {
				"id": 341722,
				"name": "石台县",
				"parent_id": 341700,
				"type": 4,
				"zip": "245100"
			}, {
				"id": 341723,
				"name": "青阳县",
				"parent_id": 341700,
				"type": 4,
				"zip": "242800"
			}, {
				"id": 341721,
				"name": "东至县",
				"parent_id": 341700,
				"type": 4,
				"zip": "247200"
			}, {
				"id": 341702,
				"name": "贵池区",
				"parent_id": 341700,
				"type": 4,
				"zip": "247100"
			}]
		}]
	}, {
		"id": 150000,
		"name": "内蒙古自治区",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 150100,
			"name": "呼和浩特市",
			"parent_id": 150000,
			"type": 3,
			"zip": "010000",
			"district": [{
				"id": 150103,
				"name": "回民区",
				"parent_id": 150100,
				"type": 4,
				"zip": "010030"
			}, {
				"id": 150102,
				"name": "新城区",
				"parent_id": 150100,
				"type": 4,
				"zip": "010050"
			}, {
				"id": 150105,
				"name": "赛罕区",
				"parent_id": 150100,
				"type": 4,
				"zip": "010020"
			}, {
				"id": 150104,
				"name": "玉泉区",
				"parent_id": 150100,
				"type": 4,
				"zip": "010020"
			}, {
				"id": 150124,
				"name": "清水河县",
				"parent_id": 150100,
				"type": 4,
				"zip": "011600"
			}, {
				"id": 150125,
				"name": "武川县",
				"parent_id": 150100,
				"type": 4,
				"zip": "011700"
			}, {
				"id": 150126,
				"name": "其它区",
				"parent_id": 150100,
				"type": 4,
				"zip": ""
			}, {
				"id": 150121,
				"name": "土默特左旗",
				"parent_id": 150100,
				"type": 4,
				"zip": "010100"
			}, {
				"id": 150122,
				"name": "托克托县",
				"parent_id": 150100,
				"type": 4,
				"zip": "010200"
			}, {
				"id": 150123,
				"name": "和林格尔县",
				"parent_id": 150100,
				"type": 4,
				"zip": "011500"
			}]
		}, {
			"id": 150200,
			"name": "包头市",
			"parent_id": 150000,
			"type": 3,
			"zip": "014000",
			"district": [{
				"id": 150202,
				"name": "东河区",
				"parent_id": 150200,
				"type": 4,
				"zip": "014040"
			}, {
				"id": 150203,
				"name": "昆都仑区",
				"parent_id": 150200,
				"type": 4,
				"zip": "014010"
			}, {
				"id": 150204,
				"name": "青山区",
				"parent_id": 150200,
				"type": 4,
				"zip": "014030"
			}, {
				"id": 150205,
				"name": "石拐区",
				"parent_id": 150200,
				"type": 4,
				"zip": "014070"
			}, {
				"id": 150206,
				"name": "白云鄂博矿区",
				"parent_id": 150200,
				"type": 4,
				"zip": "014080"
			}, {
				"id": 150207,
				"name": "九原区",
				"parent_id": 150200,
				"type": 4,
				"zip": "014060"
			}, {
				"id": 150224,
				"name": "其它区",
				"parent_id": 150200,
				"type": 4,
				"zip": ""
			}, {
				"id": 150223,
				"name": "达尔罕茂明安联合旗",
				"parent_id": 150200,
				"type": 4,
				"zip": "014500"
			}, {
				"id": 150222,
				"name": "固阳县",
				"parent_id": 150200,
				"type": 4,
				"zip": "014200"
			}, {
				"id": 150221,
				"name": "土默特右旗",
				"parent_id": 150200,
				"type": 4,
				"zip": "014100"
			}]
		}, {
			"id": 150300,
			"name": "乌海市",
			"parent_id": 150000,
			"type": 3,
			"zip": "016000",
			"district": [{
				"id": 150303,
				"name": "海南区",
				"parent_id": 150300,
				"type": 4,
				"zip": "016030"
			}, {
				"id": 150302,
				"name": "海勃湾区",
				"parent_id": 150300,
				"type": 4,
				"zip": "016000"
			}, {
				"id": 150304,
				"name": "乌达区",
				"parent_id": 150300,
				"type": 4,
				"zip": "016040"
			}, {
				"id": 150305,
				"name": "其它区",
				"parent_id": 150300,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 150400,
			"name": "赤峰市",
			"parent_id": 150000,
			"type": 3,
			"zip": "024000",
			"district": [{
				"id": 150403,
				"name": "元宝山区",
				"parent_id": 150400,
				"type": 4,
				"zip": "024076"
			}, {
				"id": 150402,
				"name": "红山区",
				"parent_id": 150400,
				"type": 4,
				"zip": "024020"
			}, {
				"id": 150404,
				"name": "松山区",
				"parent_id": 150400,
				"type": 4,
				"zip": "024005"
			}, {
				"id": 150424,
				"name": "林西县",
				"parent_id": 150400,
				"type": 4,
				"zip": "025250"
			}, {
				"id": 150425,
				"name": "克什克腾旗",
				"parent_id": 150400,
				"type": 4,
				"zip": "025350"
			}, {
				"id": 150426,
				"name": "翁牛特旗",
				"parent_id": 150400,
				"type": 4,
				"zip": "024500"
			}, {
				"id": 150428,
				"name": "喀喇沁旗",
				"parent_id": 150400,
				"type": 4,
				"zip": "024400"
			}, {
				"id": 150429,
				"name": "宁城县",
				"parent_id": 150400,
				"type": 4,
				"zip": "024200"
			}, {
				"id": 150430,
				"name": "敖汉旗",
				"parent_id": 150400,
				"type": 4,
				"zip": "024300"
			}, {
				"id": 150431,
				"name": "其它区",
				"parent_id": 150400,
				"type": 4,
				"zip": ""
			}, {
				"id": 150421,
				"name": "阿鲁科尔沁旗",
				"parent_id": 150400,
				"type": 4,
				"zip": "025550"
			}, {
				"id": 150422,
				"name": "巴林左旗",
				"parent_id": 150400,
				"type": 4,
				"zip": "025450"
			}, {
				"id": 150423,
				"name": "巴林右旗",
				"parent_id": 150400,
				"type": 4,
				"zip": "025150"
			}]
		}, {
			"id": 150500,
			"name": "通辽市",
			"parent_id": 150000,
			"type": 3,
			"zip": "028000",
			"district": [{
				"id": 150502,
				"name": "科尔沁区",
				"parent_id": 150500,
				"type": 4,
				"zip": "028000"
			}, {
				"id": 150526,
				"name": "扎鲁特旗",
				"parent_id": 150500,
				"type": 4,
				"zip": "029100"
			}, {
				"id": 150524,
				"name": "库伦旗",
				"parent_id": 150500,
				"type": 4,
				"zip": "028200"
			}, {
				"id": 150525,
				"name": "奈曼旗",
				"parent_id": 150500,
				"type": 4,
				"zip": "028300"
			}, {
				"id": 150522,
				"name": "科尔沁左翼后旗",
				"parent_id": 150500,
				"type": 4,
				"zip": "028100"
			}, {
				"id": 150523,
				"name": "开鲁县",
				"parent_id": 150500,
				"type": 4,
				"zip": "028400"
			}, {
				"id": 150521,
				"name": "科尔沁左翼中旗",
				"parent_id": 150500,
				"type": 4,
				"zip": "029300"
			}, {
				"id": 150581,
				"name": "霍林郭勒市",
				"parent_id": 150500,
				"type": 4,
				"zip": "029200"
			}, {
				"id": 150582,
				"name": "其它区",
				"parent_id": 150500,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 150600,
			"name": "鄂尔多斯市",
			"parent_id": 150000,
			"type": 3,
			"zip": "017004",
			"district": [{
				"id": 150624,
				"name": "鄂托克旗",
				"parent_id": 150600,
				"type": 4,
				"zip": "016100"
			}, {
				"id": 150625,
				"name": "杭锦旗",
				"parent_id": 150600,
				"type": 4,
				"zip": "017400"
			}, {
				"id": 150626,
				"name": "乌审旗",
				"parent_id": 150600,
				"type": 4,
				"zip": "017300"
			}, {
				"id": 150627,
				"name": "伊金霍洛旗",
				"parent_id": 150600,
				"type": 4,
				"zip": "017200"
			}, {
				"id": 150628,
				"name": "其它区",
				"parent_id": 150600,
				"type": 4,
				"zip": ""
			}, {
				"id": 150623,
				"name": "鄂托克前旗",
				"parent_id": 150600,
				"type": 4,
				"zip": "016200"
			}, {
				"id": 150622,
				"name": "准格尔旗",
				"parent_id": 150600,
				"type": 4,
				"zip": "017100"
			}, {
				"id": 150621,
				"name": "达拉特旗",
				"parent_id": 150600,
				"type": 4,
				"zip": "014300"
			}, {
				"id": 150602,
				"name": "东胜区",
				"parent_id": 150600,
				"type": 4,
				"zip": "017000"
			}]
		}, {
			"id": 150700,
			"name": "呼伦贝尔市",
			"parent_id": 150000,
			"type": 3,
			"zip": "021008",
			"district": [{
				"id": 150781,
				"name": "满洲里市",
				"parent_id": 150700,
				"type": 4,
				"zip": "021400"
			}, {
				"id": 150782,
				"name": "牙克石市",
				"parent_id": 150700,
				"type": 4,
				"zip": "162650"
			}, {
				"id": 150783,
				"name": "扎兰屯市",
				"parent_id": 150700,
				"type": 4,
				"zip": "162650"
			}, {
				"id": 150723,
				"name": "鄂伦春自治旗",
				"parent_id": 150700,
				"type": 4,
				"zip": "165450"
			}, {
				"id": 150722,
				"name": "莫力达瓦达斡尔族自治旗",
				"parent_id": 150700,
				"type": 4,
				"zip": "162850"
			}, {
				"id": 150721,
				"name": "阿荣旗",
				"parent_id": 150700,
				"type": 4,
				"zip": "162750"
			}, {
				"id": 150727,
				"name": "新巴尔虎右旗",
				"parent_id": 150700,
				"type": 4,
				"zip": "021300"
			}, {
				"id": 150726,
				"name": "新巴尔虎左旗",
				"parent_id": 150700,
				"type": 4,
				"zip": "021200"
			}, {
				"id": 150725,
				"name": "陈巴尔虎旗",
				"parent_id": 150700,
				"type": 4,
				"zip": "021500"
			}, {
				"id": 150724,
				"name": "鄂温克族自治旗",
				"parent_id": 150700,
				"type": 4,
				"zip": "021100"
			}, {
				"id": 150703,
				"name": "扎赉诺尔区",
				"parent_id": 150700,
				"type": 4,
				"zip": ""
			}, {
				"id": 150702,
				"name": "海拉尔区",
				"parent_id": 150700,
				"type": 4,
				"zip": "021000"
			}, {
				"id": 150784,
				"name": "额尔古纳市",
				"parent_id": 150700,
				"type": 4,
				"zip": "022250"
			}, {
				"id": 150785,
				"name": "根河市",
				"parent_id": 150700,
				"type": 4,
				"zip": "022350"
			}, {
				"id": 150786,
				"name": "其它区",
				"parent_id": 150700,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 150900,
			"name": "乌兰察布市",
			"parent_id": 150000,
			"type": 3,
			"zip": "012000",
			"district": [{
				"id": 150902,
				"name": "集宁区",
				"parent_id": 150900,
				"type": 4,
				"zip": "012000"
			}, {
				"id": 150981,
				"name": "丰镇市",
				"parent_id": 150900,
				"type": 4,
				"zip": "012100"
			}, {
				"id": 150982,
				"name": "其它区",
				"parent_id": 150900,
				"type": 4,
				"zip": ""
			}, {
				"id": 150925,
				"name": "凉城县",
				"parent_id": 150900,
				"type": 4,
				"zip": "013750"
			}, {
				"id": 150924,
				"name": "兴和县",
				"parent_id": 150900,
				"type": 4,
				"zip": "013650"
			}, {
				"id": 150927,
				"name": "察哈尔右翼中旗",
				"parent_id": 150900,
				"type": 4,
				"zip": "013550"
			}, {
				"id": 150926,
				"name": "察哈尔右翼前旗",
				"parent_id": 150900,
				"type": 4,
				"zip": "012200"
			}, {
				"id": 150921,
				"name": "卓资县",
				"parent_id": 150900,
				"type": 4,
				"zip": "012300"
			}, {
				"id": 150923,
				"name": "商都县",
				"parent_id": 150900,
				"type": 4,
				"zip": "013400"
			}, {
				"id": 150922,
				"name": "化德县",
				"parent_id": 150900,
				"type": 4,
				"zip": "013350"
			}, {
				"id": 150928,
				"name": "察哈尔右翼后旗",
				"parent_id": 150900,
				"type": 4,
				"zip": "012400"
			}, {
				"id": 150929,
				"name": "四子王旗",
				"parent_id": 150900,
				"type": 4,
				"zip": "011800"
			}]
		}, {
			"id": 150800,
			"name": "巴彦淖尔市",
			"parent_id": 150000,
			"type": 3,
			"zip": "015001",
			"district": [{
				"id": 150826,
				"name": "杭锦后旗",
				"parent_id": 150800,
				"type": 4,
				"zip": "015400"
			}, {
				"id": 150827,
				"name": "其它区",
				"parent_id": 150800,
				"type": 4,
				"zip": ""
			}, {
				"id": 150824,
				"name": "乌拉特中旗",
				"parent_id": 150800,
				"type": 4,
				"zip": "015300"
			}, {
				"id": 150825,
				"name": "乌拉特后旗",
				"parent_id": 150800,
				"type": 4,
				"zip": "015500"
			}, {
				"id": 150822,
				"name": "磴口县",
				"parent_id": 150800,
				"type": 4,
				"zip": "015200"
			}, {
				"id": 150823,
				"name": "乌拉特前旗",
				"parent_id": 150800,
				"type": 4,
				"zip": "015400"
			}, {
				"id": 150821,
				"name": "五原县",
				"parent_id": 150800,
				"type": 4,
				"zip": "015100"
			}, {
				"id": 150802,
				"name": "临河区",
				"parent_id": 150800,
				"type": 4,
				"zip": "015001"
			}]
		}, {
			"id": 152500,
			"name": "锡林郭勒盟",
			"parent_id": 150000,
			"type": 3,
			"zip": "026021",
			"district": [{
				"id": 152502,
				"name": "锡林浩特市",
				"parent_id": 152500,
				"type": 4,
				"zip": "026000"
			}, {
				"id": 152501,
				"name": "二连浩特市",
				"parent_id": 152500,
				"type": 4,
				"zip": "011100"
			}, {
				"id": 152532,
				"name": "其它区",
				"parent_id": 152500,
				"type": 4,
				"zip": ""
			}, {
				"id": 152529,
				"name": "正镶白旗",
				"parent_id": 152500,
				"type": 4,
				"zip": "013800"
			}, {
				"id": 152528,
				"name": "镶黄旗",
				"parent_id": 152500,
				"type": 4,
				"zip": "013250"
			}, {
				"id": 152531,
				"name": "多伦县",
				"parent_id": 152500,
				"type": 4,
				"zip": "027300"
			}, {
				"id": 152530,
				"name": "正蓝旗",
				"parent_id": 152500,
				"type": 4,
				"zip": "027200"
			}, {
				"id": 152524,
				"name": "苏尼特右旗",
				"parent_id": 152500,
				"type": 4,
				"zip": "011200"
			}, {
				"id": 152525,
				"name": "东乌珠穆沁旗",
				"parent_id": 152500,
				"type": 4,
				"zip": "026300"
			}, {
				"id": 152526,
				"name": "西乌珠穆沁旗",
				"parent_id": 152500,
				"type": 4,
				"zip": "026200"
			}, {
				"id": 152527,
				"name": "太仆寺旗",
				"parent_id": 152500,
				"type": 4,
				"zip": "027000"
			}, {
				"id": 152522,
				"name": "阿巴嘎旗",
				"parent_id": 152500,
				"type": 4,
				"zip": "011400"
			}, {
				"id": 152523,
				"name": "苏尼特左旗",
				"parent_id": 152500,
				"type": 4,
				"zip": "011300"
			}]
		}, {
			"id": 152200,
			"name": "兴安盟",
			"parent_id": 150000,
			"type": 3,
			"zip": "137401",
			"district": [{
				"id": 152224,
				"name": "突泉县",
				"parent_id": 152200,
				"type": 4,
				"zip": "137500"
			}, {
				"id": 152225,
				"name": "其它区",
				"parent_id": 152200,
				"type": 4,
				"zip": ""
			}, {
				"id": 152202,
				"name": "阿尔山市",
				"parent_id": 152200,
				"type": 4,
				"zip": "137800"
			}, {
				"id": 152201,
				"name": "乌兰浩特市",
				"parent_id": 152200,
				"type": 4,
				"zip": "137400"
			}, {
				"id": 152223,
				"name": "扎赉特旗",
				"parent_id": 152200,
				"type": 4,
				"zip": "137600"
			}, {
				"id": 152222,
				"name": "科尔沁右翼中旗",
				"parent_id": 152200,
				"type": 4,
				"zip": "029400"
			}, {
				"id": 152221,
				"name": "科尔沁右翼前旗",
				"parent_id": 152200,
				"type": 4,
				"zip": "137400"
			}]
		}, {
			"id": 152900,
			"name": "阿拉善盟",
			"parent_id": 150000,
			"type": 3,
			"zip": "750306",
			"district": [{
				"id": 152921,
				"name": "阿拉善左旗",
				"parent_id": 152900,
				"type": 4,
				"zip": "750300"
			}, {
				"id": 152922,
				"name": "阿拉善右旗",
				"parent_id": 152900,
				"type": 4,
				"zip": "737300"
			}, {
				"id": 152923,
				"name": "额济纳旗",
				"parent_id": 152900,
				"type": 4,
				"zip": "735400"
			}, {
				"id": 152924,
				"name": "其它区",
				"parent_id": 152900,
				"type": 4,
				"zip": ""
			}]
		}]
	}, {
		"id": 710000,
		"name": "台湾",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 712800,
			"name": "连江县",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 712807,
				"name": "莒光乡",
				"parent_id": 712800,
				"type": 4,
				"zip": ""
			}, {
				"id": 712806,
				"name": "北竿乡",
				"parent_id": 712800,
				"type": 4,
				"zip": ""
			}, {
				"id": 712805,
				"name": "南竿乡",
				"parent_id": 712800,
				"type": 4,
				"zip": ""
			}, {
				"id": 712808,
				"name": "东引乡",
				"parent_id": 712800,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 710800,
			"name": "新竹市",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 710804,
				"name": "其它区",
				"parent_id": 710800,
				"type": 4,
				"zip": ""
			}, {
				"id": 710802,
				"name": "北区",
				"parent_id": 710800,
				"type": 4,
				"zip": ""
			}, {
				"id": 710803,
				"name": "香山区",
				"parent_id": 710800,
				"type": 4,
				"zip": ""
			}, {
				"id": 710801,
				"name": "东区",
				"parent_id": 710800,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 710900,
			"name": "嘉义市",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 710901,
				"name": "东区",
				"parent_id": 710900,
				"type": 4,
				"zip": ""
			}, {
				"id": 710902,
				"name": "西区",
				"parent_id": 710900,
				"type": 4,
				"zip": ""
			}, {
				"id": 710903,
				"name": "其它区",
				"parent_id": 710900,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 710700,
			"name": "基隆市",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 710708,
				"name": "其它区",
				"parent_id": 710700,
				"type": 4,
				"zip": ""
			}, {
				"id": 710705,
				"name": "安乐区",
				"parent_id": 710700,
				"type": 4,
				"zip": "204"
			}, {
				"id": 710704,
				"name": "中山区",
				"parent_id": 710700,
				"type": 4,
				"zip": "203"
			}, {
				"id": 710707,
				"name": "七堵区",
				"parent_id": 710700,
				"type": 4,
				"zip": "206"
			}, {
				"id": 710706,
				"name": "暖暖区",
				"parent_id": 710700,
				"type": 4,
				"zip": "205"
			}, {
				"id": 710701,
				"name": "仁爱区",
				"parent_id": 710700,
				"type": 4,
				"zip": "200"
			}, {
				"id": 710702,
				"name": "信义区",
				"parent_id": 710700,
				"type": 4,
				"zip": "201"
			}, {
				"id": 710703,
				"name": "中正区",
				"parent_id": 710700,
				"type": 4,
				"zip": "202"
			}]
		}, {
			"id": 711100,
			"name": "新北市",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 711130,
				"name": "万里区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711131,
				"name": "金山区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711132,
				"name": "板桥区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711133,
				"name": "汐止区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711134,
				"name": "深坑区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711135,
				"name": "石碇区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711147,
				"name": "树林区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711146,
				"name": "三峡区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711145,
				"name": "土城区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711144,
				"name": "中和区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711151,
				"name": "泰山区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711150,
				"name": "新庄区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711149,
				"name": "三重区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711148,
				"name": "莺歌区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711139,
				"name": "贡寮区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711138,
				"name": "双溪区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711137,
				"name": "平溪区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711136,
				"name": "瑞芳区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711143,
				"name": "永和区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711142,
				"name": "乌来区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711141,
				"name": "坪林区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711140,
				"name": "新店区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711154,
				"name": "五股区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711155,
				"name": "八里区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711152,
				"name": "林口区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711153,
				"name": "芦洲区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711158,
				"name": "石门区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711156,
				"name": "淡水区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}, {
				"id": 711157,
				"name": "三芝区",
				"parent_id": 711100,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 711300,
			"name": "新竹县",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 711322,
				"name": "五峰乡",
				"parent_id": 711300,
				"type": 4,
				"zip": ""
			}, {
				"id": 711323,
				"name": "横山乡",
				"parent_id": 711300,
				"type": 4,
				"zip": ""
			}, {
				"id": 711320,
				"name": "宝山乡",
				"parent_id": 711300,
				"type": 4,
				"zip": ""
			}, {
				"id": 711321,
				"name": "竹东镇",
				"parent_id": 711300,
				"type": 4,
				"zip": ""
			}, {
				"id": 711326,
				"name": "峨眉乡",
				"parent_id": 711300,
				"type": 4,
				"zip": ""
			}, {
				"id": 711324,
				"name": "尖石乡",
				"parent_id": 711300,
				"type": 4,
				"zip": ""
			}, {
				"id": 711325,
				"name": "北埔乡",
				"parent_id": 711300,
				"type": 4,
				"zip": ""
			}, {
				"id": 711314,
				"name": "竹北市",
				"parent_id": 711300,
				"type": 4,
				"zip": ""
			}, {
				"id": 711315,
				"name": "湖口乡",
				"parent_id": 711300,
				"type": 4,
				"zip": ""
			}, {
				"id": 711318,
				"name": "关西镇",
				"parent_id": 711300,
				"type": 4,
				"zip": ""
			}, {
				"id": 711319,
				"name": "芎林乡",
				"parent_id": 711300,
				"type": 4,
				"zip": ""
			}, {
				"id": 711316,
				"name": "新丰乡",
				"parent_id": 711300,
				"type": 4,
				"zip": ""
			}, {
				"id": 711317,
				"name": "新埔镇",
				"parent_id": 711300,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 711400,
			"name": "桃园县",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 711420,
				"name": "桃园市",
				"parent_id": 711400,
				"type": 4,
				"zip": ""
			}, {
				"id": 711421,
				"name": "龟山乡",
				"parent_id": 711400,
				"type": 4,
				"zip": ""
			}, {
				"id": 711422,
				"name": "八德市",
				"parent_id": 711400,
				"type": 4,
				"zip": ""
			}, {
				"id": 711423,
				"name": "大溪镇",
				"parent_id": 711400,
				"type": 4,
				"zip": ""
			}, {
				"id": 711416,
				"name": "龙潭乡",
				"parent_id": 711400,
				"type": 4,
				"zip": ""
			}, {
				"id": 711417,
				"name": "杨梅市",
				"parent_id": 711400,
				"type": 4,
				"zip": ""
			}, {
				"id": 711418,
				"name": "新屋乡",
				"parent_id": 711400,
				"type": 4,
				"zip": ""
			}, {
				"id": 711419,
				"name": "观音乡",
				"parent_id": 711400,
				"type": 4,
				"zip": ""
			}, {
				"id": 711414,
				"name": "中坜市",
				"parent_id": 711400,
				"type": 4,
				"zip": ""
			}, {
				"id": 711415,
				"name": "平镇市",
				"parent_id": 711400,
				"type": 4,
				"zip": ""
			}, {
				"id": 711424,
				"name": "复兴乡",
				"parent_id": 711400,
				"type": 4,
				"zip": ""
			}, {
				"id": 711425,
				"name": "大园乡",
				"parent_id": 711400,
				"type": 4,
				"zip": ""
			}, {
				"id": 711426,
				"name": "芦竹乡",
				"parent_id": 711400,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 711200,
			"name": "宜兰县",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 711217,
				"name": "壮围乡",
				"parent_id": 711200,
				"type": 4,
				"zip": ""
			}, {
				"id": 711216,
				"name": "礁溪乡",
				"parent_id": 711200,
				"type": 4,
				"zip": ""
			}, {
				"id": 711219,
				"name": "罗东镇",
				"parent_id": 711200,
				"type": 4,
				"zip": ""
			}, {
				"id": 711218,
				"name": "员山乡",
				"parent_id": 711200,
				"type": 4,
				"zip": ""
			}, {
				"id": 711221,
				"name": "大同乡",
				"parent_id": 711200,
				"type": 4,
				"zip": ""
			}, {
				"id": 711220,
				"name": "三星乡",
				"parent_id": 711200,
				"type": 4,
				"zip": ""
			}, {
				"id": 711223,
				"name": "冬山乡",
				"parent_id": 711200,
				"type": 4,
				"zip": ""
			}, {
				"id": 711222,
				"name": "五结乡",
				"parent_id": 711200,
				"type": 4,
				"zip": ""
			}, {
				"id": 711225,
				"name": "南澳乡",
				"parent_id": 711200,
				"type": 4,
				"zip": ""
			}, {
				"id": 711224,
				"name": "苏澳镇",
				"parent_id": 711200,
				"type": 4,
				"zip": ""
			}, {
				"id": 711226,
				"name": "钓鱼台",
				"parent_id": 711200,
				"type": 4,
				"zip": ""
			}, {
				"id": 711214,
				"name": "宜兰市",
				"parent_id": 711200,
				"type": 4,
				"zip": ""
			}, {
				"id": 711215,
				"name": "头城镇",
				"parent_id": 711200,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 711500,
			"name": "苗栗县",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 711526,
				"name": "苑里镇",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}, {
				"id": 711527,
				"name": "苗栗市",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}, {
				"id": 711524,
				"name": "后龙镇",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}, {
				"id": 711525,
				"name": "通霄镇",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}, {
				"id": 711522,
				"name": "南庄乡",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}, {
				"id": 711523,
				"name": "狮潭乡",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}, {
				"id": 711520,
				"name": "头份镇",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}, {
				"id": 711521,
				"name": "三湾乡",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}, {
				"id": 711534,
				"name": "三义乡",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}, {
				"id": 711535,
				"name": "西湖乡",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}, {
				"id": 711532,
				"name": "泰安乡",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}, {
				"id": 711533,
				"name": "铜锣乡",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}, {
				"id": 711530,
				"name": "公馆乡",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}, {
				"id": 711531,
				"name": "大湖乡",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}, {
				"id": 711528,
				"name": "造桥乡",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}, {
				"id": 711529,
				"name": "头屋乡",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}, {
				"id": 711536,
				"name": "卓兰镇",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}, {
				"id": 711519,
				"name": "竹南镇",
				"parent_id": 711500,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 711900,
			"name": "嘉义县",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 711920,
				"name": "梅山乡",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}, {
				"id": 711921,
				"name": "竹崎乡",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}, {
				"id": 711922,
				"name": "阿里山乡",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}, {
				"id": 711923,
				"name": "中埔乡",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}, {
				"id": 711924,
				"name": "大埔乡",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}, {
				"id": 711925,
				"name": "水上乡",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}, {
				"id": 711926,
				"name": "鹿草乡",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}, {
				"id": 711927,
				"name": "太保市",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}, {
				"id": 711928,
				"name": "朴子市",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}, {
				"id": 711929,
				"name": "东石乡",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}, {
				"id": 711930,
				"name": "六脚乡",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}, {
				"id": 711931,
				"name": "新港乡",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}, {
				"id": 711932,
				"name": "民雄乡",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}, {
				"id": 711933,
				"name": "大林镇",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}, {
				"id": 711934,
				"name": "溪口乡",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}, {
				"id": 711935,
				"name": "义竹乡",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}, {
				"id": 711919,
				"name": "番路乡",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}, {
				"id": 711936,
				"name": "布袋镇",
				"parent_id": 711900,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 711700,
			"name": "彰化县",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 711752,
				"name": "二水乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711746,
				"name": "埤头乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711747,
				"name": "溪州乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711744,
				"name": "北斗镇",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711745,
				"name": "田尾乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711750,
				"name": "大城乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711751,
				"name": "芳苑乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711748,
				"name": "竹塘乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711749,
				"name": "二林镇",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711741,
				"name": "大村乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711740,
				"name": "溪湖镇",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711743,
				"name": "田中镇",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711742,
				"name": "埔盐乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711737,
				"name": "社头乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711736,
				"name": "员林镇",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711739,
				"name": "埔心乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711738,
				"name": "永靖乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711733,
				"name": "线西乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711732,
				"name": "福兴乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711735,
				"name": "伸港乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711734,
				"name": "和美镇",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711729,
				"name": "花坛乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711728,
				"name": "芬园乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711731,
				"name": "鹿港镇",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711730,
				"name": "秀水乡",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}, {
				"id": 711727,
				"name": "彰化市",
				"parent_id": 711700,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 712100,
			"name": "云林县",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 712129,
				"name": "麦寮乡",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712128,
				"name": "仑背乡",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712131,
				"name": "林内乡",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712130,
				"name": "斗六市",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712133,
				"name": "莿桐乡",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712132,
				"name": "古坑乡",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712135,
				"name": "二仑乡",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712134,
				"name": "西螺镇",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712137,
				"name": "水林乡",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712136,
				"name": "北港镇",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712139,
				"name": "四湖乡",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712138,
				"name": "口湖乡",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712140,
				"name": "元长乡",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712126,
				"name": "东势乡",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712127,
				"name": "台西乡",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712124,
				"name": "土库镇",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712125,
				"name": "褒忠乡",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712122,
				"name": "大埤乡",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712123,
				"name": "虎尾镇",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}, {
				"id": 712121,
				"name": "斗南镇",
				"parent_id": 712100,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 712400,
			"name": "屏东县",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 712436,
				"name": "雾台乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712437,
				"name": "玛家乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712438,
				"name": "九如乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712439,
				"name": "里港乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712434,
				"name": "屏东市",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712435,
				"name": "三地门乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712444,
				"name": "竹田乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712445,
				"name": "内埔乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712446,
				"name": "万丹乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712447,
				"name": "潮州镇",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712440,
				"name": "高树乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712441,
				"name": "盐埔乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712442,
				"name": "长治乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712443,
				"name": "麟洛乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712456,
				"name": "琉球乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712457,
				"name": "佳冬乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712458,
				"name": "新园乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712459,
				"name": "枋寮乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712460,
				"name": "枋山乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712461,
				"name": "春日乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712462,
				"name": "狮子乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712463,
				"name": "车城乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712448,
				"name": "泰武乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712449,
				"name": "来义乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712450,
				"name": "万峦乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712451,
				"name": "崁顶乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712452,
				"name": "新埤乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712453,
				"name": "南州乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712454,
				"name": "林边乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712455,
				"name": "东港镇",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712465,
				"name": "恒春镇",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712464,
				"name": "牡丹乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}, {
				"id": 712466,
				"name": "满州乡",
				"parent_id": 712400,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 712700,
			"name": "澎湖县",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 712709,
				"name": "望安乡",
				"parent_id": 712700,
				"type": 4,
				"zip": ""
			}, {
				"id": 712708,
				"name": "西屿乡",
				"parent_id": 712700,
				"type": 4,
				"zip": ""
			}, {
				"id": 712711,
				"name": "白沙乡",
				"parent_id": 712700,
				"type": 4,
				"zip": ""
			}, {
				"id": 712710,
				"name": "七美乡",
				"parent_id": 712700,
				"type": 4,
				"zip": ""
			}, {
				"id": 712707,
				"name": "马公市",
				"parent_id": 712700,
				"type": 4,
				"zip": ""
			}, {
				"id": 712712,
				"name": "湖西乡",
				"parent_id": 712700,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 712600,
			"name": "花莲县",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 712615,
				"name": "花莲市",
				"parent_id": 712600,
				"type": 4,
				"zip": ""
			}, {
				"id": 712619,
				"name": "吉安乡",
				"parent_id": 712600,
				"type": 4,
				"zip": ""
			}, {
				"id": 712618,
				"name": "秀林乡",
				"parent_id": 712600,
				"type": 4,
				"zip": ""
			}, {
				"id": 712617,
				"name": "太鲁阁",
				"parent_id": 712600,
				"type": 4,
				"zip": ""
			}, {
				"id": 712616,
				"name": "新城乡",
				"parent_id": 712600,
				"type": 4,
				"zip": ""
			}, {
				"id": 712623,
				"name": "丰滨乡",
				"parent_id": 712600,
				"type": 4,
				"zip": ""
			}, {
				"id": 712622,
				"name": "光复乡",
				"parent_id": 712600,
				"type": 4,
				"zip": ""
			}, {
				"id": 712621,
				"name": "凤林镇",
				"parent_id": 712600,
				"type": 4,
				"zip": ""
			}, {
				"id": 712620,
				"name": "寿丰乡",
				"parent_id": 712600,
				"type": 4,
				"zip": ""
			}, {
				"id": 712626,
				"name": "玉里镇",
				"parent_id": 712600,
				"type": 4,
				"zip": ""
			}, {
				"id": 712627,
				"name": "卓溪乡",
				"parent_id": 712600,
				"type": 4,
				"zip": ""
			}, {
				"id": 712624,
				"name": "瑞穗乡",
				"parent_id": 712600,
				"type": 4,
				"zip": ""
			}, {
				"id": 712625,
				"name": "万荣乡",
				"parent_id": 712600,
				"type": 4,
				"zip": ""
			}, {
				"id": 712628,
				"name": "富里乡",
				"parent_id": 712600,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 712500,
			"name": "台东县",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 712524,
				"name": "海端乡",
				"parent_id": 712500,
				"type": 4,
				"zip": ""
			}, {
				"id": 712525,
				"name": "池上乡",
				"parent_id": 712500,
				"type": 4,
				"zip": ""
			}, {
				"id": 712526,
				"name": "东河乡",
				"parent_id": 712500,
				"type": 4,
				"zip": ""
			}, {
				"id": 712527,
				"name": "成功镇",
				"parent_id": 712500,
				"type": 4,
				"zip": ""
			}, {
				"id": 712520,
				"name": "延平乡",
				"parent_id": 712500,
				"type": 4,
				"zip": ""
			}, {
				"id": 712521,
				"name": "卑南乡",
				"parent_id": 712500,
				"type": 4,
				"zip": ""
			}, {
				"id": 712522,
				"name": "鹿野乡",
				"parent_id": 712500,
				"type": 4,
				"zip": ""
			}, {
				"id": 712523,
				"name": "关山镇",
				"parent_id": 712500,
				"type": 4,
				"zip": ""
			}, {
				"id": 712517,
				"name": "台东市",
				"parent_id": 712500,
				"type": 4,
				"zip": ""
			}, {
				"id": 712518,
				"name": "绿岛乡",
				"parent_id": 712500,
				"type": 4,
				"zip": ""
			}, {
				"id": 712519,
				"name": "兰屿乡",
				"parent_id": 712500,
				"type": 4,
				"zip": ""
			}, {
				"id": 712532,
				"name": "太麻里乡",
				"parent_id": 712500,
				"type": 4,
				"zip": ""
			}, {
				"id": 712529,
				"name": "金峰乡",
				"parent_id": 712500,
				"type": 4,
				"zip": ""
			}, {
				"id": 712528,
				"name": "长滨乡",
				"parent_id": 712500,
				"type": 4,
				"zip": ""
			}, {
				"id": 712531,
				"name": "达仁乡",
				"parent_id": 712500,
				"type": 4,
				"zip": ""
			}, {
				"id": 712530,
				"name": "大武乡",
				"parent_id": 712500,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 710100,
			"name": "台北市",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 710101,
				"name": "中正区",
				"parent_id": 710100,
				"type": 4,
				"zip": "100"
			}, {
				"id": 710102,
				"name": "大同区",
				"parent_id": 710100,
				"type": 4,
				"zip": "103"
			}, {
				"id": 710103,
				"name": "中山区",
				"parent_id": 710100,
				"type": 4,
				"zip": "104"
			}, {
				"id": 710104,
				"name": "松山区",
				"parent_id": 710100,
				"type": 4,
				"zip": "105"
			}, {
				"id": 710105,
				"name": "大安区",
				"parent_id": 710100,
				"type": 4,
				"zip": "106"
			}, {
				"id": 710106,
				"name": "万华区",
				"parent_id": 710100,
				"type": 4,
				"zip": "108"
			}, {
				"id": 710107,
				"name": "信义区",
				"parent_id": 710100,
				"type": 4,
				"zip": "110"
			}, {
				"id": 710108,
				"name": "士林区",
				"parent_id": 710100,
				"type": 4,
				"zip": "111"
			}, {
				"id": 710109,
				"name": "北投区",
				"parent_id": 710100,
				"type": 4,
				"zip": "112"
			}, {
				"id": 710110,
				"name": "内湖区",
				"parent_id": 710100,
				"type": 4,
				"zip": "114"
			}, {
				"id": 710111,
				"name": "南港区",
				"parent_id": 710100,
				"type": 4,
				"zip": "115"
			}, {
				"id": 710113,
				"name": "其它区",
				"parent_id": 710100,
				"type": 4,
				"zip": ""
			}, {
				"id": 710112,
				"name": "文山区",
				"parent_id": 710100,
				"type": 4,
				"zip": "116"
			}]
		}, {
			"id": 710200,
			"name": "高雄市",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 710252,
				"name": "永安区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710253,
				"name": "湖内区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710254,
				"name": "凤山区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710255,
				"name": "大寮区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710248,
				"name": "燕巢区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710249,
				"name": "桥头区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710250,
				"name": "梓官区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710251,
				"name": "弥陀区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710244,
				"name": "冈山区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710245,
				"name": "路竹区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710246,
				"name": "阿莲区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710247,
				"name": "田寮区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710241,
				"name": "苓雅区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710242,
				"name": "仁武区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710243,
				"name": "大社区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710268,
				"name": "茄萣区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710265,
				"name": "桃源区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710264,
				"name": "甲仙区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710267,
				"name": "茂林区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710266,
				"name": "那玛夏区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710261,
				"name": "六龟区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710260,
				"name": "美浓区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710263,
				"name": "杉林区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710262,
				"name": "内门区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710257,
				"name": "鸟松区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710256,
				"name": "林园区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710259,
				"name": "旗山区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710258,
				"name": "大树区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710212,
				"name": "其它区",
				"parent_id": 710200,
				"type": 4,
				"zip": ""
			}, {
				"id": 710210,
				"name": "楠梓区",
				"parent_id": 710200,
				"type": 4,
				"zip": "811"
			}, {
				"id": 710211,
				"name": "小港区",
				"parent_id": 710200,
				"type": 4,
				"zip": "812"
			}, {
				"id": 710208,
				"name": "三民区",
				"parent_id": 710200,
				"type": 4,
				"zip": "807"
			}, {
				"id": 710209,
				"name": "左营区",
				"parent_id": 710200,
				"type": 4,
				"zip": "813"
			}, {
				"id": 710201,
				"name": "新兴区",
				"parent_id": 710200,
				"type": 4,
				"zip": "800"
			}, {
				"id": 710203,
				"name": "芩雅区",
				"parent_id": 710200,
				"type": 4,
				"zip": "802"
			}, {
				"id": 710202,
				"name": "前金区",
				"parent_id": 710200,
				"type": 4,
				"zip": "801"
			}, {
				"id": 710205,
				"name": "鼓山区",
				"parent_id": 710200,
				"type": 4,
				"zip": "804"
			}, {
				"id": 710204,
				"name": "盐埕区",
				"parent_id": 710200,
				"type": 4,
				"zip": "803"
			}, {
				"id": 710207,
				"name": "前镇区",
				"parent_id": 710200,
				"type": 4,
				"zip": "806"
			}, {
				"id": 710206,
				"name": "旗津区",
				"parent_id": 710200,
				"type": 4,
				"zip": "805"
			}]
		}, {
			"id": 710300,
			"name": "台南市",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 710369,
				"name": "安定区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710368,
				"name": "新市区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710343,
				"name": "玉井区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710342,
				"name": "左镇区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710341,
				"name": "新化区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710340,
				"name": "归仁区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710339,
				"name": "永康区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710351,
				"name": "佳里区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710350,
				"name": "麻豆区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710349,
				"name": "官田区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710348,
				"name": "龙崎区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710347,
				"name": "关庙区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710346,
				"name": "仁德区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710345,
				"name": "南化区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710344,
				"name": "楠西区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710358,
				"name": "后壁区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710359,
				"name": "白河区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710356,
				"name": "北门区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710357,
				"name": "新营区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710354,
				"name": "将军区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710355,
				"name": "学甲区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710352,
				"name": "西港区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710353,
				"name": "七股区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710366,
				"name": "大内区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710367,
				"name": "山上区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710364,
				"name": "盐水区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710365,
				"name": "善化区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710362,
				"name": "下营区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710363,
				"name": "柳营区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710360,
				"name": "东山区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710361,
				"name": "六甲区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710305,
				"name": "安平区",
				"parent_id": 710300,
				"type": 4,
				"zip": "708"
			}, {
				"id": 710304,
				"name": "北区",
				"parent_id": 710300,
				"type": 4,
				"zip": "704"
			}, {
				"id": 710307,
				"name": "其它区",
				"parent_id": 710300,
				"type": 4,
				"zip": ""
			}, {
				"id": 710306,
				"name": "安南区",
				"parent_id": 710300,
				"type": 4,
				"zip": "709"
			}, {
				"id": 710302,
				"name": "东区",
				"parent_id": 710300,
				"type": 4,
				"zip": "701"
			}, {
				"id": 710303,
				"name": "南区",
				"parent_id": 710300,
				"type": 4,
				"zip": "702"
			}, {
				"id": 710301,
				"name": "中西区",
				"parent_id": 710300,
				"type": 4,
				"zip": "703"
			}]
		}, {
			"id": 710500,
			"name": "金门县",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 710512,
				"name": "乌坵乡",
				"parent_id": 710500,
				"type": 4,
				"zip": ""
			}, {
				"id": 710510,
				"name": "金城镇",
				"parent_id": 710500,
				"type": 4,
				"zip": ""
			}, {
				"id": 710511,
				"name": "烈屿乡",
				"parent_id": 710500,
				"type": 4,
				"zip": ""
			}, {
				"id": 710508,
				"name": "金湖镇",
				"parent_id": 710500,
				"type": 4,
				"zip": ""
			}, {
				"id": 710509,
				"name": "金宁乡",
				"parent_id": 710500,
				"type": 4,
				"zip": ""
			}, {
				"id": 710507,
				"name": "金沙镇",
				"parent_id": 710500,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 710400,
			"name": "台中市",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 710451,
				"name": "大安区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710450,
				"name": "外埔区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710449,
				"name": "大甲区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710448,
				"name": "清水区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710442,
				"name": "大雅区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710443,
				"name": "神冈区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710440,
				"name": "新社区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710441,
				"name": "潭子区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710446,
				"name": "龙井区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710447,
				"name": "梧栖区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710444,
				"name": "大肚区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710445,
				"name": "沙鹿区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710434,
				"name": "乌日区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710435,
				"name": "丰原区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710432,
				"name": "大里区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710433,
				"name": "雾峰区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710438,
				"name": "东势区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710439,
				"name": "和平区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710436,
				"name": "后里区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710437,
				"name": "石冈区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710431,
				"name": "太平区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710408,
				"name": "南屯区",
				"parent_id": 710400,
				"type": 4,
				"zip": "408"
			}, {
				"id": 710409,
				"name": "其它区",
				"parent_id": 710400,
				"type": 4,
				"zip": ""
			}, {
				"id": 710401,
				"name": "中区",
				"parent_id": 710400,
				"type": 4,
				"zip": "400"
			}, {
				"id": 710402,
				"name": "东区",
				"parent_id": 710400,
				"type": 4,
				"zip": "401"
			}, {
				"id": 710403,
				"name": "南区",
				"parent_id": 710400,
				"type": 4,
				"zip": "402"
			}, {
				"id": 710404,
				"name": "西区",
				"parent_id": 710400,
				"type": 4,
				"zip": "403"
			}, {
				"id": 710405,
				"name": "北区",
				"parent_id": 710400,
				"type": 4,
				"zip": "404"
			}, {
				"id": 710406,
				"name": "北屯区",
				"parent_id": 710400,
				"type": 4,
				"zip": "406"
			}, {
				"id": 710407,
				"name": "西屯区",
				"parent_id": 710400,
				"type": 4,
				"zip": "407"
			}]
		}, {
			"id": 710600,
			"name": "南投县",
			"parent_id": 710000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 710626,
				"name": "鹿谷乡",
				"parent_id": 710600,
				"type": 4,
				"zip": ""
			}, {
				"id": 710625,
				"name": "竹山镇",
				"parent_id": 710600,
				"type": 4,
				"zip": ""
			}, {
				"id": 710624,
				"name": "信义乡",
				"parent_id": 710600,
				"type": 4,
				"zip": ""
			}, {
				"id": 710614,
				"name": "南投市",
				"parent_id": 710600,
				"type": 4,
				"zip": ""
			}, {
				"id": 710615,
				"name": "中寮乡",
				"parent_id": 710600,
				"type": 4,
				"zip": ""
			}, {
				"id": 710620,
				"name": "名间乡",
				"parent_id": 710600,
				"type": 4,
				"zip": ""
			}, {
				"id": 710621,
				"name": "集集镇",
				"parent_id": 710600,
				"type": 4,
				"zip": ""
			}, {
				"id": 710622,
				"name": "水里乡",
				"parent_id": 710600,
				"type": 4,
				"zip": ""
			}, {
				"id": 710623,
				"name": "鱼池乡",
				"parent_id": 710600,
				"type": 4,
				"zip": ""
			}, {
				"id": 710616,
				"name": "草屯镇",
				"parent_id": 710600,
				"type": 4,
				"zip": ""
			}, {
				"id": 710617,
				"name": "国姓乡",
				"parent_id": 710600,
				"type": 4,
				"zip": ""
			}, {
				"id": 710618,
				"name": "埔里镇",
				"parent_id": 710600,
				"type": 4,
				"zip": ""
			}, {
				"id": 710619,
				"name": "仁爱乡",
				"parent_id": 710600,
				"type": 4,
				"zip": ""
			}]
		}]
	}, {
		"id": 460000,
		"name": "海南省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 469031,
			"name": "昌江黎族自治县",
			"parent_id": 460000,
			"type": 4,
			"zip": "572700",
			"district": [{
				"id": 46903110,
				"name": "石碌镇",
				"parent_id": 469031,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903111,
				"name": "叉河镇",
				"parent_id": 469031,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903112,
				"name": "十月田镇",
				"parent_id": 469031,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903113,
				"name": "乌烈镇",
				"parent_id": 469031,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903114,
				"name": "昌化镇",
				"parent_id": 469031,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903115,
				"name": "海尾镇",
				"parent_id": 469031,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903116,
				"name": "七叉镇",
				"parent_id": 469031,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903117,
				"name": "王下乡",
				"parent_id": 469031,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903118,
				"name": "国营红林农场",
				"parent_id": 469031,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903119,
				"name": "国营霸王岭林场",
				"parent_id": 469031,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903120,
				"name": "海南矿业联合有限公司",
				"parent_id": 469031,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469030,
			"name": "白沙黎族自治县",
			"parent_id": 460000,
			"type": 4,
			"zip": "572800",
			"district": [{
				"id": 46903010,
				"name": "牙叉镇",
				"parent_id": 469030,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903011,
				"name": "七坊镇",
				"parent_id": 469030,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903012,
				"name": "邦溪镇",
				"parent_id": 469030,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903013,
				"name": "打安镇",
				"parent_id": 469030,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903014,
				"name": "细水乡",
				"parent_id": 469030,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903015,
				"name": "元门乡",
				"parent_id": 469030,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903016,
				"name": "南开乡",
				"parent_id": 469030,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903017,
				"name": "阜龙乡",
				"parent_id": 469030,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903018,
				"name": "青松乡",
				"parent_id": 469030,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903019,
				"name": "金波乡",
				"parent_id": 469030,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903020,
				"name": "荣邦乡",
				"parent_id": 469030,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903021,
				"name": "国营白沙农场",
				"parent_id": 469030,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903022,
				"name": "国营龙江农场",
				"parent_id": 469030,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903023,
				"name": "国营邦溪农场",
				"parent_id": 469030,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469028,
			"name": "临高县",
			"parent_id": 460000,
			"type": 4,
			"zip": "571800",
			"district": [{
				"id": 46902810,
				"name": "临城镇",
				"parent_id": 469028,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902811,
				"name": "波莲镇",
				"parent_id": 469028,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902812,
				"name": "东英镇",
				"parent_id": 469028,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902813,
				"name": "博厚镇",
				"parent_id": 469028,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902814,
				"name": "皇桐镇",
				"parent_id": 469028,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902815,
				"name": "多文镇",
				"parent_id": 469028,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902816,
				"name": "和舍镇",
				"parent_id": 469028,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902817,
				"name": "南宝镇",
				"parent_id": 469028,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902818,
				"name": "新盈镇",
				"parent_id": 469028,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902819,
				"name": "调楼镇",
				"parent_id": 469028,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902820,
				"name": "国营红华农场",
				"parent_id": 469028,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902821,
				"name": "国营加来农场",
				"parent_id": 469028,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469027,
			"name": "澄迈县",
			"parent_id": 460000,
			"type": 4,
			"zip": "571900",
			"district": [{
				"id": 46902710,
				"name": "金江镇",
				"parent_id": 469027,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902711,
				"name": "老城镇",
				"parent_id": 469027,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902712,
				"name": "瑞溪镇",
				"parent_id": 469027,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902713,
				"name": "永发镇",
				"parent_id": 469027,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902714,
				"name": "加乐镇",
				"parent_id": 469027,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902715,
				"name": "文儒镇",
				"parent_id": 469027,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902716,
				"name": "中兴镇",
				"parent_id": 469027,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902717,
				"name": "仁兴镇",
				"parent_id": 469027,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902718,
				"name": "福山镇",
				"parent_id": 469027,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902719,
				"name": "桥头镇",
				"parent_id": 469027,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902720,
				"name": "大丰镇",
				"parent_id": 469027,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902721,
				"name": "国营红光农场",
				"parent_id": 469027,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902722,
				"name": "国营西达农场",
				"parent_id": 469027,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902723,
				"name": "国营金安农场",
				"parent_id": 469027,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469026,
			"name": "屯昌县",
			"parent_id": 460000,
			"type": 4,
			"zip": "571600",
			"district": [{
				"id": 46902610,
				"name": "屯城镇",
				"parent_id": 469026,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902611,
				"name": "新兴镇",
				"parent_id": 469026,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902612,
				"name": "枫木镇",
				"parent_id": 469026,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902613,
				"name": "乌坡镇",
				"parent_id": 469026,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902614,
				"name": "南吕镇",
				"parent_id": 469026,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902615,
				"name": "南坤镇",
				"parent_id": 469026,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902616,
				"name": "坡心镇",
				"parent_id": 469026,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902617,
				"name": "西昌镇",
				"parent_id": 469026,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902618,
				"name": "国营中建农场",
				"parent_id": 469026,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902619,
				"name": "国营中坤农场",
				"parent_id": 469026,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469025,
			"name": "定安县",
			"parent_id": 460000,
			"type": 4,
			"zip": "571200",
			"district": [{
				"id": 46902510,
				"name": "定城镇",
				"parent_id": 469025,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902511,
				"name": "新竹镇",
				"parent_id": 469025,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902512,
				"name": "龙湖镇",
				"parent_id": 469025,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902513,
				"name": "黄竹镇",
				"parent_id": 469025,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902514,
				"name": "雷鸣镇",
				"parent_id": 469025,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902515,
				"name": "龙门镇",
				"parent_id": 469025,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902516,
				"name": "龙河镇",
				"parent_id": 469025,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902517,
				"name": "岭口镇",
				"parent_id": 469025,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902518,
				"name": "翰林镇",
				"parent_id": 469025,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902519,
				"name": "富文镇",
				"parent_id": 469025,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902520,
				"name": "国营中瑞农场",
				"parent_id": 469025,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902521,
				"name": "国营南海农场",
				"parent_id": 469025,
				"type": 4,
				"zip": ""
			}, {
				"id": 46902522,
				"name": "国营金鸡岭农场",
				"parent_id": 469025,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469039,
			"name": "中沙群岛的岛礁及其海域",
			"parent_id": 460000,
			"type": 4,
			"zip": "573100",
			"district": [{
				"id": 46903910,
				"name": "中沙岛礁",
				"parent_id": 469039,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469038,
			"name": "南沙群岛",
			"parent_id": 460000,
			"type": 4,
			"zip": "573100",
			"district": [{
				"id": 46903810,
				"name": "永暑岛",
				"parent_id": 469038,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469037,
			"name": "西沙群岛",
			"parent_id": 460000,
			"type": 4,
			"zip": "573100",
			"district": [{
				"id": 46903710,
				"name": "永兴岛",
				"parent_id": 469037,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469036,
			"name": "琼中黎族苗族自治县",
			"parent_id": 460000,
			"type": 4,
			"zip": "572900",
			"district": [{
				"id": 46903610,
				"name": "营根镇",
				"parent_id": 469036,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903611,
				"name": "湾岭镇",
				"parent_id": 469036,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903612,
				"name": "黎母山镇",
				"parent_id": 469036,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903613,
				"name": "和平镇",
				"parent_id": 469036,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903614,
				"name": "长征镇",
				"parent_id": 469036,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903615,
				"name": "红毛镇",
				"parent_id": 469036,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903616,
				"name": "中平镇",
				"parent_id": 469036,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903617,
				"name": "吊罗山乡",
				"parent_id": 469036,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903618,
				"name": "上安乡",
				"parent_id": 469036,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903619,
				"name": "什运乡",
				"parent_id": 469036,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903620,
				"name": "国营阳江农场",
				"parent_id": 469036,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903621,
				"name": "国营乌石农场",
				"parent_id": 469036,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903622,
				"name": "国营加钗农场",
				"parent_id": 469036,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903623,
				"name": "国营长征农场",
				"parent_id": 469036,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903624,
				"name": "国营黎母山林业公司",
				"parent_id": 469036,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469035,
			"name": "保亭黎族苗族自治县",
			"parent_id": 460000,
			"type": 4,
			"zip": "572300",
			"district": [{
				"id": 46903510,
				"name": "保城镇",
				"parent_id": 469035,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903511,
				"name": "什玲镇",
				"parent_id": 469035,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903512,
				"name": "加茂镇",
				"parent_id": 469035,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903513,
				"name": "响水镇",
				"parent_id": 469035,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903514,
				"name": "新政镇",
				"parent_id": 469035,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903515,
				"name": "三道镇",
				"parent_id": 469035,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903516,
				"name": "六弓乡",
				"parent_id": 469035,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903517,
				"name": "南林乡",
				"parent_id": 469035,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903518,
				"name": "毛感乡",
				"parent_id": 469035,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903519,
				"name": "国营新星农场",
				"parent_id": 469035,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903520,
				"name": "海南保亭热带作物研究所",
				"parent_id": 469035,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903521,
				"name": "国营金江农场",
				"parent_id": 469035,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903522,
				"name": "国营三道农场",
				"parent_id": 469035,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469034,
			"name": "陵水黎族自治县",
			"parent_id": 460000,
			"type": 4,
			"zip": "572400",
			"district": [{
				"id": 46903410,
				"name": "椰林镇",
				"parent_id": 469034,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903411,
				"name": "光坡镇",
				"parent_id": 469034,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903412,
				"name": "三才镇",
				"parent_id": 469034,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903413,
				"name": "英州镇",
				"parent_id": 469034,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903414,
				"name": "隆广镇",
				"parent_id": 469034,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903415,
				"name": "文罗镇",
				"parent_id": 469034,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903416,
				"name": "本号镇",
				"parent_id": 469034,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903417,
				"name": "新村镇",
				"parent_id": 469034,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903418,
				"name": "黎安镇",
				"parent_id": 469034,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903419,
				"name": "提蒙乡",
				"parent_id": 469034,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903420,
				"name": "群英乡",
				"parent_id": 469034,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903421,
				"name": "国营岭门农场",
				"parent_id": 469034,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903422,
				"name": "国营南平农场",
				"parent_id": 469034,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903423,
				"name": "国营吊罗山林业公司",
				"parent_id": 469034,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469033,
			"name": "乐东黎族自治县",
			"parent_id": 460000,
			"type": 4,
			"zip": "572500",
			"district": [{
				"id": 46903310,
				"name": "抱由镇",
				"parent_id": 469033,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903311,
				"name": "万冲镇",
				"parent_id": 469033,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903312,
				"name": "大安镇",
				"parent_id": 469033,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903313,
				"name": "志仲镇",
				"parent_id": 469033,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903314,
				"name": "千家镇",
				"parent_id": 469033,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903315,
				"name": "九所镇",
				"parent_id": 469033,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903316,
				"name": "利国镇",
				"parent_id": 469033,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903317,
				"name": "黄流镇",
				"parent_id": 469033,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903318,
				"name": "佛罗镇",
				"parent_id": 469033,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903319,
				"name": "尖峰镇",
				"parent_id": 469033,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903320,
				"name": "莺歌海镇",
				"parent_id": 469033,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903321,
				"name": "国营山荣农场",
				"parent_id": 469033,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903322,
				"name": "国营乐光农场",
				"parent_id": 469033,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903323,
				"name": "国营保国农场",
				"parent_id": 469033,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903324,
				"name": "国营尖峰岭林业公司",
				"parent_id": 469033,
				"type": 4,
				"zip": ""
			}, {
				"id": 46903325,
				"name": "国营莺歌海盐场",
				"parent_id": 469033,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469005,
			"name": "文昌市",
			"parent_id": 460000,
			"type": 4,
			"zip": "571300",
			"district": [{
				"id": 46900510,
				"name": "文城镇",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900511,
				"name": "重兴镇",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900512,
				"name": "蓬莱镇",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900513,
				"name": "会文镇",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900514,
				"name": "东路镇",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900515,
				"name": "潭牛镇",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900516,
				"name": "东阁镇",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900517,
				"name": "文教镇",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900518,
				"name": "东郊镇",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900519,
				"name": "龙楼镇",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900520,
				"name": "昌洒镇",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900521,
				"name": "翁田镇",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900522,
				"name": "抱罗镇",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900523,
				"name": "冯坡镇",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900524,
				"name": "锦山镇",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900525,
				"name": "铺前镇",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900526,
				"name": "公坡镇",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900527,
				"name": "国营东路农场",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900528,
				"name": "国营南阳农场",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900529,
				"name": "国营罗豆农场",
				"parent_id": 469005,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469007,
			"name": "东方市",
			"parent_id": 460000,
			"type": 4,
			"zip": "572600",
			"district": [{
				"id": 46900710,
				"name": "八所镇",
				"parent_id": 469007,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900711,
				"name": "东河镇",
				"parent_id": 469007,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900712,
				"name": "大田镇",
				"parent_id": 469007,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900713,
				"name": "感城镇",
				"parent_id": 469007,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900714,
				"name": "板桥镇",
				"parent_id": 469007,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900715,
				"name": "三家镇",
				"parent_id": 469007,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900716,
				"name": "四更镇",
				"parent_id": 469007,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900717,
				"name": "新龙镇",
				"parent_id": 469007,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900718,
				"name": "天安乡",
				"parent_id": 469007,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900719,
				"name": "江边乡",
				"parent_id": 469007,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900720,
				"name": "国营广坝农场",
				"parent_id": 469007,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900721,
				"name": "东方华侨农场",
				"parent_id": 469007,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469006,
			"name": "万宁市",
			"parent_id": 460000,
			"type": 4,
			"zip": "571500",
			"district": [{
				"id": 46900610,
				"name": "万城镇",
				"parent_id": 469006,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900611,
				"name": "龙滚镇",
				"parent_id": 469006,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900612,
				"name": "和乐镇",
				"parent_id": 469006,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900613,
				"name": "后安镇",
				"parent_id": 469006,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900614,
				"name": "大茂镇",
				"parent_id": 469006,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900615,
				"name": "东澳镇",
				"parent_id": 469006,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900616,
				"name": "礼纪镇",
				"parent_id": 469006,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900617,
				"name": "长丰镇",
				"parent_id": 469006,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900618,
				"name": "山根镇",
				"parent_id": 469006,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900619,
				"name": "北大镇",
				"parent_id": 469006,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900620,
				"name": "南桥镇",
				"parent_id": 469006,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900621,
				"name": "三更罗镇",
				"parent_id": 469006,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900622,
				"name": "国营东兴农场",
				"parent_id": 469006,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900623,
				"name": "国营东和农场",
				"parent_id": 469006,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900624,
				"name": "国营新中农场",
				"parent_id": 469006,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900625,
				"name": "兴隆华侨农场",
				"parent_id": 469006,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900626,
				"name": "地方国营六连林场",
				"parent_id": 469006,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469001,
			"name": "五指山市",
			"parent_id": 460000,
			"type": 4,
			"zip": "572200",
			"district": [{
				"id": 46900110,
				"name": "通什镇",
				"parent_id": 469001,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900111,
				"name": "南圣镇",
				"parent_id": 469001,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900112,
				"name": "毛阳镇",
				"parent_id": 469001,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900113,
				"name": "番阳镇",
				"parent_id": 469001,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900114,
				"name": "畅好乡",
				"parent_id": 469001,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900115,
				"name": "毛道乡",
				"parent_id": 469001,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900116,
				"name": "水满乡",
				"parent_id": 469001,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900117,
				"name": "国营畅好农场",
				"parent_id": 469001,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469003,
			"name": "儋州市",
			"parent_id": 460000,
			"type": 4,
			"zip": "571700",
			"district": [{
				"id": 46900310,
				"name": "那大镇",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900311,
				"name": "和庆镇",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900312,
				"name": "南丰镇",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900313,
				"name": "大成镇",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900314,
				"name": "雅星镇",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900315,
				"name": "兰洋镇",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900316,
				"name": "光村镇",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900317,
				"name": "木棠镇",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900318,
				"name": "海头镇",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900319,
				"name": "峨蔓镇",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900320,
				"name": "三都镇",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900321,
				"name": "王五镇",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900322,
				"name": "白马井镇",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900323,
				"name": "中和镇",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900324,
				"name": "排浦镇",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900325,
				"name": "东成镇",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900326,
				"name": "新州镇",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900327,
				"name": "国营西培农场",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900328,
				"name": "国营西联农场",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900329,
				"name": "国营蓝洋农场",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900330,
				"name": "国营八一农场",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900331,
				"name": "洋浦经济开发区",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900332,
				"name": "华南热作学院",
				"parent_id": 469003,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 469002,
			"name": "琼海市",
			"parent_id": 460000,
			"type": 4,
			"zip": "571400",
			"district": [{
				"id": 46900210,
				"name": "嘉积镇",
				"parent_id": 469002,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900211,
				"name": "万泉镇",
				"parent_id": 469002,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900212,
				"name": "石壁镇",
				"parent_id": 469002,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900213,
				"name": "中原镇",
				"parent_id": 469002,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900214,
				"name": "博鳌镇",
				"parent_id": 469002,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900215,
				"name": "阳江镇",
				"parent_id": 469002,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900216,
				"name": "龙江镇",
				"parent_id": 469002,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900217,
				"name": "潭门镇",
				"parent_id": 469002,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900218,
				"name": "塔洋镇",
				"parent_id": 469002,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900219,
				"name": "长坡镇",
				"parent_id": 469002,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900220,
				"name": "大路镇",
				"parent_id": 469002,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900221,
				"name": "会山镇",
				"parent_id": 469002,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900222,
				"name": "国营东太农场",
				"parent_id": 469002,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900223,
				"name": "国营东红农场",
				"parent_id": 469002,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900224,
				"name": "国营东升农场",
				"parent_id": 469002,
				"type": 4,
				"zip": ""
			}, {
				"id": 46900225,
				"name": "彬村山华侨农场",
				"parent_id": 469002,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 460300,
			"name": "三沙市",
			"parent_id": 460000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 460321,
				"name": "西沙群岛",
				"parent_id": 460300,
				"type": 4,
				"zip": ""
			}, {
				"id": 460323,
				"name": "中沙群岛的岛礁及其海域",
				"parent_id": 460300,
				"type": 4,
				"zip": ""
			}, {
				"id": 460322,
				"name": "南沙群岛",
				"parent_id": 460300,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 460100,
			"name": "海口市",
			"parent_id": 460000,
			"type": 3,
			"zip": "570000",
			"district": [{
				"id": 460105,
				"name": "秀英区",
				"parent_id": 460100,
				"type": 4,
				"zip": "570311"
			}, {
				"id": 460107,
				"name": "琼山区",
				"parent_id": 460100,
				"type": 4,
				"zip": "571100"
			}, {
				"id": 460106,
				"name": "龙华区",
				"parent_id": 460100,
				"type": 4,
				"zip": "570105"
			}, {
				"id": 460109,
				"name": "其它区",
				"parent_id": 460100,
				"type": 4,
				"zip": ""
			}, {
				"id": 460108,
				"name": "美兰区",
				"parent_id": 460100,
				"type": 4,
				"zip": "570203"
			}]
		}, {
			"id": 460200,
			"name": "三亚市",
			"parent_id": 460000,
			"type": 3,
			"zip": "572000",
			"district": [{
				"id": 46020010,
				"name": "海棠湾镇",
				"parent_id": 460200,
				"type": 4,
				"zip": ""
			}, {
				"id": 46020011,
				"name": "吉阳镇",
				"parent_id": 460200,
				"type": 4,
				"zip": ""
			}, {
				"id": 46020012,
				"name": "凤凰镇",
				"parent_id": 460200,
				"type": 4,
				"zip": ""
			}, {
				"id": 46020013,
				"name": "崖城镇",
				"parent_id": 460200,
				"type": 4,
				"zip": ""
			}, {
				"id": 46020014,
				"name": "天涯镇",
				"parent_id": 460200,
				"type": 4,
				"zip": ""
			}, {
				"id": 46020015,
				"name": "育才镇",
				"parent_id": 460200,
				"type": 4,
				"zip": ""
			}, {
				"id": 46020016,
				"name": "国营南田农场",
				"parent_id": 460200,
				"type": 4,
				"zip": ""
			}, {
				"id": 46020017,
				"name": "国营南新农场",
				"parent_id": 460200,
				"type": 4,
				"zip": ""
			}, {
				"id": 46020018,
				"name": "国营立才农场",
				"parent_id": 460200,
				"type": 4,
				"zip": ""
			}, {
				"id": 46020019,
				"name": "国营南滨农场",
				"parent_id": 460200,
				"type": 4,
				"zip": ""
			}, {
				"id": 46020020,
				"name": "河西区街道办",
				"parent_id": 460200,
				"type": 4,
				"zip": ""
			}, {
				"id": 46020021,
				"name": "河东区街道办",
				"parent_id": 460200,
				"type": 4,
				"zip": ""
			}]
		}]
	}, {
		"id": 810000,
		"name": "香港特别行政区",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 810300,
			"name": "新界",
			"parent_id": 810000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 810301,
				"name": "北区",
				"parent_id": 810300,
				"type": 4,
				"zip": "810301"
			}, {
				"id": 810303,
				"name": "沙田区",
				"parent_id": 810300,
				"type": 4,
				"zip": "810303"
			}, {
				"id": 810302,
				"name": "大埔区",
				"parent_id": 810300,
				"type": 4,
				"zip": "810302"
			}, {
				"id": 810308,
				"name": "葵青区",
				"parent_id": 810300,
				"type": 4,
				"zip": "810308"
			}, {
				"id": 810309,
				"name": "离岛区",
				"parent_id": 810300,
				"type": 4,
				"zip": "810309"
			}, {
				"id": 810306,
				"name": "屯门区",
				"parent_id": 810300,
				"type": 4,
				"zip": "810306"
			}, {
				"id": 810307,
				"name": "荃湾区",
				"parent_id": 810300,
				"type": 4,
				"zip": "810307"
			}, {
				"id": 810304,
				"name": "西贡区",
				"parent_id": 810300,
				"type": 4,
				"zip": "810304"
			}, {
				"id": 810305,
				"name": "元朗区",
				"parent_id": 810300,
				"type": 4,
				"zip": "810305"
			}]
		}, {
			"id": 810200,
			"name": "九龙",
			"parent_id": 810000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 810204,
				"name": "黄大仙区",
				"parent_id": 810200,
				"type": 4,
				"zip": "810204"
			}, {
				"id": 810205,
				"name": "观塘区",
				"parent_id": 810200,
				"type": 4,
				"zip": "810205"
			}, {
				"id": 810201,
				"name": "九龙城区",
				"parent_id": 810200,
				"type": 4,
				"zip": "810201"
			}, {
				"id": 810202,
				"name": "油尖旺区",
				"parent_id": 810200,
				"type": 4,
				"zip": "810202"
			}, {
				"id": 810203,
				"name": "深水埗区",
				"parent_id": 810200,
				"type": 4,
				"zip": "810203"
			}]
		}, {
			"id": 810100,
			"name": "香港岛",
			"parent_id": 810000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 810103,
				"name": "东区",
				"parent_id": 810100,
				"type": 4,
				"zip": "810103"
			}, {
				"id": 810102,
				"name": "湾仔",
				"parent_id": 810100,
				"type": 4,
				"zip": "810102"
			}, {
				"id": 810101,
				"name": "中西区",
				"parent_id": 810100,
				"type": 4,
				"zip": "810101"
			}, {
				"id": 810104,
				"name": "南区",
				"parent_id": 810100,
				"type": 4,
				"zip": "810104"
			}]
		}]
	}, {
		"id": 530000,
		"name": "云南省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 530400,
			"name": "玉溪市",
			"parent_id": 530000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 530424,
				"name": "华宁县",
				"parent_id": 530400,
				"type": 4,
				"zip": "652800"
			}, {
				"id": 530425,
				"name": "易门县",
				"parent_id": 530400,
				"type": 4,
				"zip": "651100"
			}, {
				"id": 530426,
				"name": "峨山彝族自治县",
				"parent_id": 530400,
				"type": 4,
				"zip": "653200"
			}, {
				"id": 530427,
				"name": "新平彝族傣族自治县",
				"parent_id": 530400,
				"type": 4,
				"zip": "653400"
			}, {
				"id": 530428,
				"name": "元江哈尼族彝族傣族自治县",
				"parent_id": 530400,
				"type": 4,
				"zip": "653300"
			}, {
				"id": 530429,
				"name": "其它区",
				"parent_id": 530400,
				"type": 4,
				"zip": ""
			}, {
				"id": 530421,
				"name": "江川县",
				"parent_id": 530400,
				"type": 4,
				"zip": "652600"
			}, {
				"id": 530422,
				"name": "澄江县",
				"parent_id": 530400,
				"type": 4,
				"zip": "652500"
			}, {
				"id": 530423,
				"name": "通海县",
				"parent_id": 530400,
				"type": 4,
				"zip": "652700"
			}, {
				"id": 530402,
				"name": "红塔区",
				"parent_id": 530400,
				"type": 4,
				"zip": "653100"
			}]
		}, {
			"id": 530300,
			"name": "曲靖市",
			"parent_id": 530000,
			"type": 3,
			"zip": "655000",
			"district": [{
				"id": 530382,
				"name": "其它区",
				"parent_id": 530300,
				"type": 4,
				"zip": ""
			}, {
				"id": 530381,
				"name": "宣威市",
				"parent_id": 530300,
				"type": 4,
				"zip": "655400"
			}, {
				"id": 530328,
				"name": "沾益县",
				"parent_id": 530300,
				"type": 4,
				"zip": "655331"
			}, {
				"id": 530326,
				"name": "会泽县",
				"parent_id": 530300,
				"type": 4,
				"zip": "654200"
			}, {
				"id": 530324,
				"name": "罗平县",
				"parent_id": 530300,
				"type": 4,
				"zip": "655800"
			}, {
				"id": 530325,
				"name": "富源县",
				"parent_id": 530300,
				"type": 4,
				"zip": "655500"
			}, {
				"id": 530322,
				"name": "陆良县",
				"parent_id": 530300,
				"type": 4,
				"zip": "655600"
			}, {
				"id": 530323,
				"name": "师宗县",
				"parent_id": 530300,
				"type": 4,
				"zip": "655700"
			}, {
				"id": 530321,
				"name": "马龙县",
				"parent_id": 530300,
				"type": 4,
				"zip": "655100"
			}, {
				"id": 530302,
				"name": "麒麟区",
				"parent_id": 530300,
				"type": 4,
				"zip": "655000"
			}]
		}, {
			"id": 530100,
			"name": "昆明市",
			"parent_id": 530000,
			"type": 3,
			"zip": "650000",
			"district": [{
				"id": 530182,
				"name": "其它区",
				"parent_id": 530100,
				"type": 4,
				"zip": ""
			}, {
				"id": 530181,
				"name": "安宁市",
				"parent_id": 530100,
				"type": 4,
				"zip": "650300"
			}, {
				"id": 530121,
				"name": "呈贡区",
				"parent_id": 530100,
				"type": 4,
				"zip": "650500"
			}, {
				"id": 530122,
				"name": "晋宁县",
				"parent_id": 530100,
				"type": 4,
				"zip": "650600"
			}, {
				"id": 530125,
				"name": "宜良县",
				"parent_id": 530100,
				"type": 4,
				"zip": "652100"
			}, {
				"id": 530124,
				"name": "富民县",
				"parent_id": 530100,
				"type": 4,
				"zip": "650400"
			}, {
				"id": 530127,
				"name": "嵩明县",
				"parent_id": 530100,
				"type": 4,
				"zip": "651700"
			}, {
				"id": 530126,
				"name": "石林彝族自治县",
				"parent_id": 530100,
				"type": 4,
				"zip": "652200"
			}, {
				"id": 530113,
				"name": "东川区",
				"parent_id": 530100,
				"type": 4,
				"zip": "654100"
			}, {
				"id": 530112,
				"name": "西山区",
				"parent_id": 530100,
				"type": 4,
				"zip": "650100"
			}, {
				"id": 530128,
				"name": "禄劝彝族苗族自治县",
				"parent_id": 530100,
				"type": 4,
				"zip": "651500"
			}, {
				"id": 530129,
				"name": "寻甸回族彝族自治县",
				"parent_id": 530100,
				"type": 4,
				"zip": "655200"
			}, {
				"id": 530111,
				"name": "官渡区",
				"parent_id": 530100,
				"type": 4,
				"zip": "650220"
			}, {
				"id": 530102,
				"name": "五华区",
				"parent_id": 530100,
				"type": 4,
				"zip": "650032"
			}, {
				"id": 530103,
				"name": "盘龙区",
				"parent_id": 530100,
				"type": 4,
				"zip": "650051"
			}]
		}, {
			"id": 530700,
			"name": "丽江市",
			"parent_id": 530000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 530721,
				"name": "玉龙纳西族自治县",
				"parent_id": 530700,
				"type": 4,
				"zip": "674100"
			}, {
				"id": 530722,
				"name": "永胜县",
				"parent_id": 530700,
				"type": 4,
				"zip": "674200"
			}, {
				"id": 530723,
				"name": "华坪县",
				"parent_id": 530700,
				"type": 4,
				"zip": "674800"
			}, {
				"id": 530724,
				"name": "宁蒗彝族自治县",
				"parent_id": 530700,
				"type": 4,
				"zip": "674300"
			}, {
				"id": 530725,
				"name": "其它区",
				"parent_id": 530700,
				"type": 4,
				"zip": ""
			}, {
				"id": 530702,
				"name": "古城区",
				"parent_id": 530700,
				"type": 4,
				"zip": "674100"
			}]
		}, {
			"id": 530800,
			"name": "普洱市",
			"parent_id": 530000,
			"type": 3,
			"zip": "665000",
			"district": [{
				"id": 530802,
				"name": "思茅区",
				"parent_id": 530800,
				"type": 4,
				"zip": "665000"
			}, {
				"id": 530823,
				"name": "景东彝族自治县",
				"parent_id": 530800,
				"type": 4,
				"zip": "676200"
			}, {
				"id": 530822,
				"name": "墨江哈尼族自治县",
				"parent_id": 530800,
				"type": 4,
				"zip": "654800"
			}, {
				"id": 530821,
				"name": "宁洱哈尼族彝族自治县",
				"parent_id": 530800,
				"type": 4,
				"zip": "665100"
			}, {
				"id": 530827,
				"name": "孟连傣族拉祜族佤族自治县",
				"parent_id": 530800,
				"type": 4,
				"zip": "665800"
			}, {
				"id": 530826,
				"name": "江城哈尼族彝族自治县",
				"parent_id": 530800,
				"type": 4,
				"zip": "665900"
			}, {
				"id": 530825,
				"name": "镇沅彝族哈尼族拉祜族自治县",
				"parent_id": 530800,
				"type": 4,
				"zip": "666500"
			}, {
				"id": 530824,
				"name": "景谷傣族彝族自治县",
				"parent_id": 530800,
				"type": 4,
				"zip": "666400"
			}, {
				"id": 530830,
				"name": "其它区",
				"parent_id": 530800,
				"type": 4,
				"zip": ""
			}, {
				"id": 530829,
				"name": "西盟佤族自治县",
				"parent_id": 530800,
				"type": 4,
				"zip": "665700"
			}, {
				"id": 530828,
				"name": "澜沧拉祜族自治县",
				"parent_id": 530800,
				"type": 4,
				"zip": "665600"
			}]
		}, {
			"id": 530900,
			"name": "临沧市",
			"parent_id": 530000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 530925,
				"name": "双江拉祜族佤族布朗族傣族自治县",
				"parent_id": 530900,
				"type": 4,
				"zip": "677300"
			}, {
				"id": 530924,
				"name": "镇康县",
				"parent_id": 530900,
				"type": 4,
				"zip": "677700"
			}, {
				"id": 530927,
				"name": "沧源佤族自治县",
				"parent_id": 530900,
				"type": 4,
				"zip": "677400"
			}, {
				"id": 530926,
				"name": "耿马傣族佤族自治县",
				"parent_id": 530900,
				"type": 4,
				"zip": "677500"
			}, {
				"id": 530921,
				"name": "凤庆县",
				"parent_id": 530900,
				"type": 4,
				"zip": "675900"
			}, {
				"id": 530923,
				"name": "永德县",
				"parent_id": 530900,
				"type": 4,
				"zip": "677600"
			}, {
				"id": 530922,
				"name": "云县",
				"parent_id": 530900,
				"type": 4,
				"zip": "675800"
			}, {
				"id": 530928,
				"name": "其它区",
				"parent_id": 530900,
				"type": 4,
				"zip": ""
			}, {
				"id": 530902,
				"name": "临翔区",
				"parent_id": 530900,
				"type": 4,
				"zip": "677000"
			}]
		}, {
			"id": 530500,
			"name": "保山市",
			"parent_id": 530000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 530525,
				"name": "其它区",
				"parent_id": 530500,
				"type": 4,
				"zip": ""
			}, {
				"id": 530524,
				"name": "昌宁县",
				"parent_id": 530500,
				"type": 4,
				"zip": "678100"
			}, {
				"id": 530521,
				"name": "施甸县",
				"parent_id": 530500,
				"type": 4,
				"zip": "678200"
			}, {
				"id": 530523,
				"name": "龙陵县",
				"parent_id": 530500,
				"type": 4,
				"zip": "678300"
			}, {
				"id": 530522,
				"name": "腾冲县",
				"parent_id": 530500,
				"type": 4,
				"zip": "679100"
			}, {
				"id": 530502,
				"name": "隆阳区",
				"parent_id": 530500,
				"type": 4,
				"zip": "678000"
			}]
		}, {
			"id": 530600,
			"name": "昭通市",
			"parent_id": 530000,
			"type": 3,
			"zip": "657000",
			"district": [{
				"id": 530622,
				"name": "巧家县",
				"parent_id": 530600,
				"type": 4,
				"zip": "654600"
			}, {
				"id": 530623,
				"name": "盐津县",
				"parent_id": 530600,
				"type": 4,
				"zip": "657500"
			}, {
				"id": 530621,
				"name": "鲁甸县",
				"parent_id": 530600,
				"type": 4,
				"zip": "657100"
			}, {
				"id": 530602,
				"name": "昭阳区",
				"parent_id": 530600,
				"type": 4,
				"zip": "657000"
			}, {
				"id": 530629,
				"name": "威信县",
				"parent_id": 530600,
				"type": 4,
				"zip": "657900"
			}, {
				"id": 530628,
				"name": "彝良县",
				"parent_id": 530600,
				"type": 4,
				"zip": "657600"
			}, {
				"id": 530631,
				"name": "其它区",
				"parent_id": 530600,
				"type": 4,
				"zip": ""
			}, {
				"id": 530630,
				"name": "水富县",
				"parent_id": 530600,
				"type": 4,
				"zip": "657800"
			}, {
				"id": 530625,
				"name": "永善县",
				"parent_id": 530600,
				"type": 4,
				"zip": "657300"
			}, {
				"id": 530624,
				"name": "大关县",
				"parent_id": 530600,
				"type": 4,
				"zip": "657400"
			}, {
				"id": 530627,
				"name": "镇雄县",
				"parent_id": 530600,
				"type": 4,
				"zip": "657200"
			}, {
				"id": 530626,
				"name": "绥江县",
				"parent_id": 530600,
				"type": 4,
				"zip": "657700"
			}]
		}, {
			"id": 532300,
			"name": "楚雄彝族自治州",
			"parent_id": 530000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 532301,
				"name": "楚雄市",
				"parent_id": 532300,
				"type": 4,
				"zip": "675000"
			}, {
				"id": 532322,
				"name": "双柏县",
				"parent_id": 532300,
				"type": 4,
				"zip": "675100"
			}, {
				"id": 532323,
				"name": "牟定县",
				"parent_id": 532300,
				"type": 4,
				"zip": "675500"
			}, {
				"id": 532324,
				"name": "南华县",
				"parent_id": 532300,
				"type": 4,
				"zip": "675200"
			}, {
				"id": 532325,
				"name": "姚安县",
				"parent_id": 532300,
				"type": 4,
				"zip": "675300"
			}, {
				"id": 532326,
				"name": "大姚县",
				"parent_id": 532300,
				"type": 4,
				"zip": "675400"
			}, {
				"id": 532327,
				"name": "永仁县",
				"parent_id": 532300,
				"type": 4,
				"zip": "651400"
			}, {
				"id": 532328,
				"name": "元谋县",
				"parent_id": 532300,
				"type": 4,
				"zip": "651300"
			}, {
				"id": 532329,
				"name": "武定县",
				"parent_id": 532300,
				"type": 4,
				"zip": "651600"
			}, {
				"id": 532331,
				"name": "禄丰县",
				"parent_id": 532300,
				"type": 4,
				"zip": "651200"
			}, {
				"id": 532332,
				"name": "其它区",
				"parent_id": 532300,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 533100,
			"name": "德宏傣族景颇族自治州",
			"parent_id": 530000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 533124,
				"name": "陇川县",
				"parent_id": 533100,
				"type": 4,
				"zip": "678700"
			}, {
				"id": 533125,
				"name": "其它区",
				"parent_id": 533100,
				"type": 4,
				"zip": ""
			}, {
				"id": 533122,
				"name": "梁河县",
				"parent_id": 533100,
				"type": 4,
				"zip": "679200"
			}, {
				"id": 533123,
				"name": "盈江县",
				"parent_id": 533100,
				"type": 4,
				"zip": "679300"
			}, {
				"id": 533103,
				"name": "芒市",
				"parent_id": 533100,
				"type": 4,
				"zip": "678400"
			}, {
				"id": 533102,
				"name": "瑞丽市",
				"parent_id": 533100,
				"type": 4,
				"zip": "678600"
			}]
		}, {
			"id": 533400,
			"name": "迪庆藏族自治州",
			"parent_id": 530000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 533424,
				"name": "其它区",
				"parent_id": 533400,
				"type": 4,
				"zip": ""
			}, {
				"id": 533422,
				"name": "德钦县",
				"parent_id": 533400,
				"type": 4,
				"zip": "674500"
			}, {
				"id": 533423,
				"name": "维西傈僳族自治县",
				"parent_id": 533400,
				"type": 4,
				"zip": "674600"
			}, {
				"id": 533421,
				"name": "香格里拉县",
				"parent_id": 533400,
				"type": 4,
				"zip": "674400"
			}]
		}, {
			"id": 533300,
			"name": "怒江傈僳族自治州",
			"parent_id": 530000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 533321,
				"name": "泸水县",
				"parent_id": 533300,
				"type": 4,
				"zip": "673100"
			}, {
				"id": 533323,
				"name": "福贡县",
				"parent_id": 533300,
				"type": 4,
				"zip": "673400"
			}, {
				"id": 533325,
				"name": "兰坪白族普米族自治县",
				"parent_id": 533300,
				"type": 4,
				"zip": "671400"
			}, {
				"id": 533324,
				"name": "贡山独龙族怒族自治县",
				"parent_id": 533300,
				"type": 4,
				"zip": "673500"
			}, {
				"id": 533326,
				"name": "其它区",
				"parent_id": 533300,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 532600,
			"name": "文山壮族苗族自治州",
			"parent_id": 530000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 532622,
				"name": "砚山县",
				"parent_id": 532600,
				"type": 4,
				"zip": "663100"
			}, {
				"id": 532623,
				"name": "西畴县",
				"parent_id": 532600,
				"type": 4,
				"zip": "663500"
			}, {
				"id": 532621,
				"name": "文山市",
				"parent_id": 532600,
				"type": 4,
				"zip": "663000"
			}, {
				"id": 532627,
				"name": "广南县",
				"parent_id": 532600,
				"type": 4,
				"zip": "663300"
			}, {
				"id": 532626,
				"name": "丘北县",
				"parent_id": 532600,
				"type": 4,
				"zip": "663200"
			}, {
				"id": 532625,
				"name": "马关县",
				"parent_id": 532600,
				"type": 4,
				"zip": "663700"
			}, {
				"id": 532624,
				"name": "麻栗坡县",
				"parent_id": 532600,
				"type": 4,
				"zip": "663600"
			}, {
				"id": 532629,
				"name": "其它区",
				"parent_id": 532600,
				"type": 4,
				"zip": ""
			}, {
				"id": 532628,
				"name": "富宁县",
				"parent_id": 532600,
				"type": 4,
				"zip": "663400"
			}]
		}, {
			"id": 532500,
			"name": "红河哈尼族彝族自治州",
			"parent_id": 530000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 532502,
				"name": "开远市",
				"parent_id": 532500,
				"type": 4,
				"zip": "661600"
			}, {
				"id": 532501,
				"name": "个旧市",
				"parent_id": 532500,
				"type": 4,
				"zip": "661000"
			}, {
				"id": 532523,
				"name": "屏边苗族自治县",
				"parent_id": 532500,
				"type": 4,
				"zip": "661200"
			}, {
				"id": 532522,
				"name": "蒙自市",
				"parent_id": 532500,
				"type": 4,
				"zip": "661100"
			}, {
				"id": 532525,
				"name": "石屏县",
				"parent_id": 532500,
				"type": 4,
				"zip": "662200"
			}, {
				"id": 532524,
				"name": "建水县",
				"parent_id": 532500,
				"type": 4,
				"zip": "654300"
			}, {
				"id": 532527,
				"name": "泸西县",
				"parent_id": 532500,
				"type": 4,
				"zip": "652400"
			}, {
				"id": 532526,
				"name": "弥勒市",
				"parent_id": 532500,
				"type": 4,
				"zip": "652300"
			}, {
				"id": 532528,
				"name": "元阳县",
				"parent_id": 532500,
				"type": 4,
				"zip": "662400"
			}, {
				"id": 532529,
				"name": "红河县",
				"parent_id": 532500,
				"type": 4,
				"zip": "654400"
			}, {
				"id": 532530,
				"name": "金平苗族瑶族傣族自治县",
				"parent_id": 532500,
				"type": 4,
				"zip": "661500"
			}, {
				"id": 532531,
				"name": "绿春县",
				"parent_id": 532500,
				"type": 4,
				"zip": "662500"
			}, {
				"id": 532532,
				"name": "河口瑶族自治县",
				"parent_id": 532500,
				"type": 4,
				"zip": "661300"
			}, {
				"id": 532533,
				"name": "其它区",
				"parent_id": 532500,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 532900,
			"name": "大理白族自治州",
			"parent_id": 530000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 532932,
				"name": "鹤庆县",
				"parent_id": 532900,
				"type": 4,
				"zip": "671500"
			}, {
				"id": 532933,
				"name": "其它区",
				"parent_id": 532900,
				"type": 4,
				"zip": ""
			}, {
				"id": 532928,
				"name": "永平县",
				"parent_id": 532900,
				"type": 4,
				"zip": "672600"
			}, {
				"id": 532929,
				"name": "云龙县",
				"parent_id": 532900,
				"type": 4,
				"zip": "672700"
			}, {
				"id": 532930,
				"name": "洱源县",
				"parent_id": 532900,
				"type": 4,
				"zip": "671200"
			}, {
				"id": 532931,
				"name": "剑川县",
				"parent_id": 532900,
				"type": 4,
				"zip": "671300"
			}, {
				"id": 532923,
				"name": "祥云县",
				"parent_id": 532900,
				"type": 4,
				"zip": "672100"
			}, {
				"id": 532922,
				"name": "漾濞彝族自治县",
				"parent_id": 532900,
				"type": 4,
				"zip": "672500"
			}, {
				"id": 532927,
				"name": "巍山彝族回族自治县",
				"parent_id": 532900,
				"type": 4,
				"zip": "672400"
			}, {
				"id": 532926,
				"name": "南涧彝族自治县",
				"parent_id": 532900,
				"type": 4,
				"zip": "675700"
			}, {
				"id": 532925,
				"name": "弥渡县",
				"parent_id": 532900,
				"type": 4,
				"zip": "675600"
			}, {
				"id": 532924,
				"name": "宾川县",
				"parent_id": 532900,
				"type": 4,
				"zip": "671600"
			}, {
				"id": 532901,
				"name": "大理市",
				"parent_id": 532900,
				"type": 4,
				"zip": "671000"
			}]
		}, {
			"id": 532800,
			"name": "西双版纳傣族自治州",
			"parent_id": 530000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 532824,
				"name": "其它区",
				"parent_id": 532800,
				"type": 4,
				"zip": ""
			}, {
				"id": 532822,
				"name": "勐海县",
				"parent_id": 532800,
				"type": 4,
				"zip": "666200"
			}, {
				"id": 532823,
				"name": "勐腊县",
				"parent_id": 532800,
				"type": 4,
				"zip": "666300"
			}, {
				"id": 532801,
				"name": "景洪市",
				"parent_id": 532800,
				"type": 4,
				"zip": "666100"
			}]
		}]
	}, {
		"id": 520000,
		"name": "贵州省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 520400,
			"name": "安顺市",
			"parent_id": 520000,
			"type": 3,
			"zip": "561000",
			"district": [{
				"id": 520402,
				"name": "西秀区",
				"parent_id": 520400,
				"type": 4,
				"zip": "561000"
			}, {
				"id": 520423,
				"name": "镇宁布依族苗族自治县",
				"parent_id": 520400,
				"type": 4,
				"zip": "561200"
			}, {
				"id": 520422,
				"name": "普定县",
				"parent_id": 520400,
				"type": 4,
				"zip": "562100"
			}, {
				"id": 520421,
				"name": "平坝县",
				"parent_id": 520400,
				"type": 4,
				"zip": "561100"
			}, {
				"id": 520426,
				"name": "其它区",
				"parent_id": 520400,
				"type": 4,
				"zip": ""
			}, {
				"id": 520425,
				"name": "紫云苗族布依族自治县",
				"parent_id": 520400,
				"type": 4,
				"zip": "550800"
			}, {
				"id": 520424,
				"name": "关岭布依族苗族自治县",
				"parent_id": 520400,
				"type": 4,
				"zip": "561300"
			}]
		}, {
			"id": 520200,
			"name": "六盘水市",
			"parent_id": 520000,
			"type": 3,
			"zip": "553000",
			"district": [{
				"id": 520221,
				"name": "水城县",
				"parent_id": 520200,
				"type": 4,
				"zip": "553600"
			}, {
				"id": 520223,
				"name": "其它区",
				"parent_id": 520200,
				"type": 4,
				"zip": ""
			}, {
				"id": 520222,
				"name": "盘县",
				"parent_id": 520200,
				"type": 4,
				"zip": "561601"
			}, {
				"id": 520201,
				"name": "钟山区",
				"parent_id": 520200,
				"type": 4,
				"zip": "553000"
			}, {
				"id": 520203,
				"name": "六枝特区",
				"parent_id": 520200,
				"type": 4,
				"zip": "553400"
			}]
		}, {
			"id": 520300,
			"name": "遵义市",
			"parent_id": 520000,
			"type": 3,
			"zip": "563000",
			"district": [{
				"id": 520321,
				"name": "遵义县",
				"parent_id": 520300,
				"type": 4,
				"zip": "563100"
			}, {
				"id": 520323,
				"name": "绥阳县",
				"parent_id": 520300,
				"type": 4,
				"zip": "563300"
			}, {
				"id": 520322,
				"name": "桐梓县",
				"parent_id": 520300,
				"type": 4,
				"zip": "563200"
			}, {
				"id": 520325,
				"name": "道真仡佬族苗族自治县",
				"parent_id": 520300,
				"type": 4,
				"zip": "563500"
			}, {
				"id": 520324,
				"name": "正安县",
				"parent_id": 520300,
				"type": 4,
				"zip": "563400"
			}, {
				"id": 520327,
				"name": "凤冈县",
				"parent_id": 520300,
				"type": 4,
				"zip": "564200"
			}, {
				"id": 520326,
				"name": "务川仡佬族苗族自治县",
				"parent_id": 520300,
				"type": 4,
				"zip": "564300"
			}, {
				"id": 520329,
				"name": "余庆县",
				"parent_id": 520300,
				"type": 4,
				"zip": "564400"
			}, {
				"id": 520328,
				"name": "湄潭县",
				"parent_id": 520300,
				"type": 4,
				"zip": "564100"
			}, {
				"id": 520330,
				"name": "习水县",
				"parent_id": 520300,
				"type": 4,
				"zip": "564600"
			}, {
				"id": 520382,
				"name": "仁怀市",
				"parent_id": 520300,
				"type": 4,
				"zip": "564500"
			}, {
				"id": 520383,
				"name": "其它区",
				"parent_id": 520300,
				"type": 4,
				"zip": ""
			}, {
				"id": 520381,
				"name": "赤水市",
				"parent_id": 520300,
				"type": 4,
				"zip": "564700"
			}, {
				"id": 520302,
				"name": "红花岗区",
				"parent_id": 520300,
				"type": 4,
				"zip": "563000"
			}, {
				"id": 520303,
				"name": "汇川区",
				"parent_id": 520300,
				"type": 4,
				"zip": "563000"
			}]
		}, {
			"id": 522200,
			"name": "铜仁市",
			"parent_id": 520000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 522223,
				"name": "玉屏侗族自治县",
				"parent_id": 522200,
				"type": 4,
				"zip": "554000"
			}, {
				"id": 522222,
				"name": "江口县",
				"parent_id": 522200,
				"type": 4,
				"zip": "554400"
			}, {
				"id": 522224,
				"name": "石阡县",
				"parent_id": 522200,
				"type": 4,
				"zip": "555100"
			}, {
				"id": 522225,
				"name": "思南县",
				"parent_id": 522200,
				"type": 4,
				"zip": "565100"
			}, {
				"id": 522226,
				"name": "印江土家族苗族自治县",
				"parent_id": 522200,
				"type": 4,
				"zip": "555200"
			}, {
				"id": 522227,
				"name": "德江县",
				"parent_id": 522200,
				"type": 4,
				"zip": "565200"
			}, {
				"id": 522228,
				"name": "沿河土家族自治县",
				"parent_id": 522200,
				"type": 4,
				"zip": "565300"
			}, {
				"id": 522229,
				"name": "松桃苗族自治县",
				"parent_id": 522200,
				"type": 4,
				"zip": "554100"
			}, {
				"id": 522230,
				"name": "万山区",
				"parent_id": 522200,
				"type": 4,
				"zip": "554200"
			}, {
				"id": 522231,
				"name": "其它区",
				"parent_id": 522200,
				"type": 4,
				"zip": ""
			}, {
				"id": 522201,
				"name": "碧江区",
				"parent_id": 522200,
				"type": 4,
				"zip": "554300"
			}]
		}, {
			"id": 522300,
			"name": "黔西南布依族苗族自治州",
			"parent_id": 520000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 522301,
				"name": "兴义市",
				"parent_id": 522300,
				"type": 4,
				"zip": "562400"
			}, {
				"id": 522329,
				"name": "其它区",
				"parent_id": 522300,
				"type": 4,
				"zip": ""
			}, {
				"id": 522328,
				"name": "安龙县",
				"parent_id": 522300,
				"type": 4,
				"zip": "552400"
			}, {
				"id": 522325,
				"name": "贞丰县",
				"parent_id": 522300,
				"type": 4,
				"zip": "562200"
			}, {
				"id": 522324,
				"name": "晴隆县",
				"parent_id": 522300,
				"type": 4,
				"zip": "561400"
			}, {
				"id": 522327,
				"name": "册亨县",
				"parent_id": 522300,
				"type": 4,
				"zip": "552200"
			}, {
				"id": 522326,
				"name": "望谟县",
				"parent_id": 522300,
				"type": 4,
				"zip": "552300"
			}, {
				"id": 522323,
				"name": "普安县",
				"parent_id": 522300,
				"type": 4,
				"zip": "561500"
			}, {
				"id": 522322,
				"name": "兴仁县",
				"parent_id": 522300,
				"type": 4,
				"zip": "562300"
			}]
		}, {
			"id": 522400,
			"name": "毕节市",
			"parent_id": 520000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 522401,
				"name": "七星关区",
				"parent_id": 522400,
				"type": 4,
				"zip": "551700"
			}, {
				"id": 522422,
				"name": "大方县",
				"parent_id": 522400,
				"type": 4,
				"zip": "551600"
			}, {
				"id": 522423,
				"name": "黔西县",
				"parent_id": 522400,
				"type": 4,
				"zip": "551500"
			}, {
				"id": 522426,
				"name": "纳雍县",
				"parent_id": 522400,
				"type": 4,
				"zip": "553300"
			}, {
				"id": 522427,
				"name": "威宁彝族回族苗族自治县",
				"parent_id": 522400,
				"type": 4,
				"zip": "553100"
			}, {
				"id": 522424,
				"name": "金沙县",
				"parent_id": 522400,
				"type": 4,
				"zip": "551800"
			}, {
				"id": 522425,
				"name": "织金县",
				"parent_id": 522400,
				"type": 4,
				"zip": "552100"
			}, {
				"id": 522428,
				"name": "赫章县",
				"parent_id": 522400,
				"type": 4,
				"zip": "553200"
			}, {
				"id": 522429,
				"name": "其它区",
				"parent_id": 522400,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 522600,
			"name": "黔东南苗族侗族自治州",
			"parent_id": 520000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 522623,
				"name": "施秉县",
				"parent_id": 522600,
				"type": 4,
				"zip": "556200"
			}, {
				"id": 522622,
				"name": "黄平县",
				"parent_id": 522600,
				"type": 4,
				"zip": "556100"
			}, {
				"id": 522601,
				"name": "凯里市",
				"parent_id": 522600,
				"type": 4,
				"zip": "556000"
			}, {
				"id": 522627,
				"name": "天柱县",
				"parent_id": 522600,
				"type": 4,
				"zip": "556600"
			}, {
				"id": 522626,
				"name": "岑巩县",
				"parent_id": 522600,
				"type": 4,
				"zip": "557800"
			}, {
				"id": 522625,
				"name": "镇远县",
				"parent_id": 522600,
				"type": 4,
				"zip": "557700"
			}, {
				"id": 522624,
				"name": "三穗县",
				"parent_id": 522600,
				"type": 4,
				"zip": "556500"
			}, {
				"id": 522631,
				"name": "黎平县",
				"parent_id": 522600,
				"type": 4,
				"zip": "557300"
			}, {
				"id": 522630,
				"name": "台江县",
				"parent_id": 522600,
				"type": 4,
				"zip": "556300"
			}, {
				"id": 522629,
				"name": "剑河县",
				"parent_id": 522600,
				"type": 4,
				"zip": "556400"
			}, {
				"id": 522628,
				"name": "锦屏县",
				"parent_id": 522600,
				"type": 4,
				"zip": "556700"
			}, {
				"id": 522635,
				"name": "麻江县",
				"parent_id": 522600,
				"type": 4,
				"zip": "557600"
			}, {
				"id": 522634,
				"name": "雷山县",
				"parent_id": 522600,
				"type": 4,
				"zip": "557100"
			}, {
				"id": 522633,
				"name": "从江县",
				"parent_id": 522600,
				"type": 4,
				"zip": "557400"
			}, {
				"id": 522632,
				"name": "榕江县",
				"parent_id": 522600,
				"type": 4,
				"zip": "557200"
			}, {
				"id": 522637,
				"name": "其它区",
				"parent_id": 522600,
				"type": 4,
				"zip": ""
			}, {
				"id": 522636,
				"name": "丹寨县",
				"parent_id": 522600,
				"type": 4,
				"zip": "557500"
			}]
		}, {
			"id": 522700,
			"name": "黔南布依族苗族自治州",
			"parent_id": 520000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 522702,
				"name": "福泉市",
				"parent_id": 522700,
				"type": 4,
				"zip": "550500"
			}, {
				"id": 522701,
				"name": "都匀市",
				"parent_id": 522700,
				"type": 4,
				"zip": "558000"
			}, {
				"id": 522725,
				"name": "瓮安县",
				"parent_id": 522700,
				"type": 4,
				"zip": "550400"
			}, {
				"id": 522727,
				"name": "平塘县",
				"parent_id": 522700,
				"type": 4,
				"zip": "558300"
			}, {
				"id": 522726,
				"name": "独山县",
				"parent_id": 522700,
				"type": 4,
				"zip": "558200"
			}, {
				"id": 522723,
				"name": "贵定县",
				"parent_id": 522700,
				"type": 4,
				"zip": "551300"
			}, {
				"id": 522722,
				"name": "荔波县",
				"parent_id": 522700,
				"type": 4,
				"zip": "558400"
			}, {
				"id": 522733,
				"name": "其它区",
				"parent_id": 522700,
				"type": 4,
				"zip": ""
			}, {
				"id": 522732,
				"name": "三都水族自治县",
				"parent_id": 522700,
				"type": 4,
				"zip": "558100"
			}, {
				"id": 522729,
				"name": "长顺县",
				"parent_id": 522700,
				"type": 4,
				"zip": "550700"
			}, {
				"id": 522728,
				"name": "罗甸县",
				"parent_id": 522700,
				"type": 4,
				"zip": "550100"
			}, {
				"id": 522731,
				"name": "惠水县",
				"parent_id": 522700,
				"type": 4,
				"zip": "550600"
			}, {
				"id": 522730,
				"name": "龙里县",
				"parent_id": 522700,
				"type": 4,
				"zip": "551200"
			}]
		}, {
			"id": 520100,
			"name": "贵阳市",
			"parent_id": 520000,
			"type": 3,
			"zip": "550000",
			"district": [{
				"id": 520151,
				"name": "观山湖区",
				"parent_id": 520100,
				"type": 4,
				"zip": ""
			}, {
				"id": 520181,
				"name": "清镇市",
				"parent_id": 520100,
				"type": 4,
				"zip": "551400"
			}, {
				"id": 520182,
				"name": "其它区",
				"parent_id": 520100,
				"type": 4,
				"zip": ""
			}, {
				"id": 520121,
				"name": "开阳县",
				"parent_id": 520100,
				"type": 4,
				"zip": "550300"
			}, {
				"id": 520123,
				"name": "修文县",
				"parent_id": 520100,
				"type": 4,
				"zip": "550200"
			}, {
				"id": 520122,
				"name": "息烽县",
				"parent_id": 520100,
				"type": 4,
				"zip": "551100"
			}, {
				"id": 520113,
				"name": "白云区",
				"parent_id": 520100,
				"type": 4,
				"zip": "550014"
			}, {
				"id": 520112,
				"name": "乌当区",
				"parent_id": 520100,
				"type": 4,
				"zip": "550018"
			}, {
				"id": 520114,
				"name": "小河区",
				"parent_id": 520100,
				"type": 4,
				"zip": "550009"
			}, {
				"id": 520111,
				"name": "花溪区",
				"parent_id": 520100,
				"type": 4,
				"zip": "550025"
			}, {
				"id": 520102,
				"name": "南明区",
				"parent_id": 520100,
				"type": 4,
				"zip": "550002"
			}, {
				"id": 520103,
				"name": "云岩区",
				"parent_id": 520100,
				"type": 4,
				"zip": "550001"
			}]
		}]
	}, {
		"id": 320000,
		"name": "江苏省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 321300,
			"name": "宿迁市",
			"parent_id": 320000,
			"type": 3,
			"zip": "223800",
			"district": [{
				"id": 321324,
				"name": "泗洪县",
				"parent_id": 321300,
				"type": 4,
				"zip": "223900"
			}, {
				"id": 321325,
				"name": "其它区",
				"parent_id": 321300,
				"type": 4,
				"zip": ""
			}, {
				"id": 321322,
				"name": "沭阳县",
				"parent_id": 321300,
				"type": 4,
				"zip": "223600"
			}, {
				"id": 321323,
				"name": "泗阳县",
				"parent_id": 321300,
				"type": 4,
				"zip": "223700"
			}, {
				"id": 321302,
				"name": "宿城区",
				"parent_id": 321300,
				"type": 4,
				"zip": "223800"
			}, {
				"id": 321311,
				"name": "宿豫区",
				"parent_id": 321300,
				"type": 4,
				"zip": "223800"
			}]
		}, {
			"id": 321200,
			"name": "泰州市",
			"parent_id": 320000,
			"type": 3,
			"zip": "225300",
			"district": [{
				"id": 321284,
				"name": "姜堰区",
				"parent_id": 321200,
				"type": 4,
				"zip": "225500"
			}, {
				"id": 321285,
				"name": "其它区",
				"parent_id": 321200,
				"type": 4,
				"zip": ""
			}, {
				"id": 321281,
				"name": "兴化市",
				"parent_id": 321200,
				"type": 4,
				"zip": "225700"
			}, {
				"id": 321282,
				"name": "靖江市",
				"parent_id": 321200,
				"type": 4,
				"zip": "214500"
			}, {
				"id": 321283,
				"name": "泰兴市",
				"parent_id": 321200,
				"type": 4,
				"zip": "225400"
			}, {
				"id": 321202,
				"name": "海陵区",
				"parent_id": 321200,
				"type": 4,
				"zip": "225300"
			}, {
				"id": 321203,
				"name": "高港区",
				"parent_id": 321200,
				"type": 4,
				"zip": "225321"
			}]
		}, {
			"id": 321100,
			"name": "镇江市",
			"parent_id": 320000,
			"type": 3,
			"zip": "212000",
			"district": [{
				"id": 321184,
				"name": "其它区",
				"parent_id": 321100,
				"type": 4,
				"zip": ""
			}, {
				"id": 321182,
				"name": "扬中市",
				"parent_id": 321100,
				"type": 4,
				"zip": "212200"
			}, {
				"id": 321183,
				"name": "句容市",
				"parent_id": 321100,
				"type": 4,
				"zip": "212400"
			}, {
				"id": 321181,
				"name": "丹阳市",
				"parent_id": 321100,
				"type": 4,
				"zip": "212300"
			}, {
				"id": 321102,
				"name": "京口区",
				"parent_id": 321100,
				"type": 4,
				"zip": "212001"
			}, {
				"id": 321111,
				"name": "润州区",
				"parent_id": 321100,
				"type": 4,
				"zip": "212004"
			}, {
				"id": 321112,
				"name": "丹徒区",
				"parent_id": 321100,
				"type": 4,
				"zip": "212001"
			}]
		}, {
			"id": 321000,
			"name": "扬州市",
			"parent_id": 320000,
			"type": 3,
			"zip": "225000",
			"district": [{
				"id": 321088,
				"name": "江都区",
				"parent_id": 321000,
				"type": 4,
				"zip": "225200"
			}, {
				"id": 321092,
				"name": "经济开发区",
				"parent_id": 321000,
				"type": 4,
				"zip": ""
			}, {
				"id": 321093,
				"name": "其它区",
				"parent_id": 321000,
				"type": 4,
				"zip": ""
			}, {
				"id": 321084,
				"name": "高邮市",
				"parent_id": 321000,
				"type": 4,
				"zip": "225600"
			}, {
				"id": 321081,
				"name": "仪征市",
				"parent_id": 321000,
				"type": 4,
				"zip": "211400"
			}, {
				"id": 321023,
				"name": "宝应县",
				"parent_id": 321000,
				"type": 4,
				"zip": "225800"
			}, {
				"id": 321011,
				"name": "维扬区",
				"parent_id": 321000,
				"type": 4,
				"zip": "225002"
			}, {
				"id": 321003,
				"name": "邗江区",
				"parent_id": 321000,
				"type": 4,
				"zip": "225100"
			}, {
				"id": 321002,
				"name": "广陵区",
				"parent_id": 321000,
				"type": 4,
				"zip": "225002"
			}]
		}, {
			"id": 320900,
			"name": "盐城市",
			"parent_id": 320000,
			"type": 3,
			"zip": "224000",
			"district": [{
				"id": 320981,
				"name": "东台市",
				"parent_id": 320900,
				"type": 4,
				"zip": "224200"
			}, {
				"id": 320982,
				"name": "大丰市",
				"parent_id": 320900,
				"type": 4,
				"zip": "224100"
			}, {
				"id": 320983,
				"name": "其它区",
				"parent_id": 320900,
				"type": 4,
				"zip": ""
			}, {
				"id": 320921,
				"name": "响水县",
				"parent_id": 320900,
				"type": 4,
				"zip": "224600"
			}, {
				"id": 320922,
				"name": "滨海县",
				"parent_id": 320900,
				"type": 4,
				"zip": "224500"
			}, {
				"id": 320923,
				"name": "阜宁县",
				"parent_id": 320900,
				"type": 4,
				"zip": "224400"
			}, {
				"id": 320924,
				"name": "射阳县",
				"parent_id": 320900,
				"type": 4,
				"zip": "224300"
			}, {
				"id": 320925,
				"name": "建湖县",
				"parent_id": 320900,
				"type": 4,
				"zip": "224700"
			}, {
				"id": 320903,
				"name": "盐都区",
				"parent_id": 320900,
				"type": 4,
				"zip": "224055"
			}, {
				"id": 320902,
				"name": "亭湖区",
				"parent_id": 320900,
				"type": 4,
				"zip": "224005"
			}]
		}, {
			"id": 320800,
			"name": "淮安市",
			"parent_id": 320000,
			"type": 3,
			"zip": "223200",
			"district": [{
				"id": 320832,
				"name": "其它区",
				"parent_id": 320800,
				"type": 4,
				"zip": ""
			}, {
				"id": 320826,
				"name": "涟水县",
				"parent_id": 320800,
				"type": 4,
				"zip": "223400"
			}, {
				"id": 320831,
				"name": "金湖县",
				"parent_id": 320800,
				"type": 4,
				"zip": "211600"
			}, {
				"id": 320830,
				"name": "盱眙县",
				"parent_id": 320800,
				"type": 4,
				"zip": "211700"
			}, {
				"id": 320829,
				"name": "洪泽县",
				"parent_id": 320800,
				"type": 4,
				"zip": "223100"
			}, {
				"id": 320802,
				"name": "清河区",
				"parent_id": 320800,
				"type": 4,
				"zip": "223001"
			}, {
				"id": 320803,
				"name": "淮安区",
				"parent_id": 320800,
				"type": 4,
				"zip": "223200"
			}, {
				"id": 320804,
				"name": "淮阴区",
				"parent_id": 320800,
				"type": 4,
				"zip": "223000"
			}, {
				"id": 320811,
				"name": "清浦区",
				"parent_id": 320800,
				"type": 4,
				"zip": "223002"
			}]
		}, {
			"id": 320700,
			"name": "连云港市",
			"parent_id": 320000,
			"type": 3,
			"zip": "222000",
			"district": [{
				"id": 320706,
				"name": "海州区",
				"parent_id": 320700,
				"type": 4,
				"zip": "222023"
			}, {
				"id": 320705,
				"name": "新浦区",
				"parent_id": 320700,
				"type": 4,
				"zip": "222003"
			}, {
				"id": 320724,
				"name": "灌南县",
				"parent_id": 320700,
				"type": 4,
				"zip": "222500"
			}, {
				"id": 320725,
				"name": "其它区",
				"parent_id": 320700,
				"type": 4,
				"zip": ""
			}, {
				"id": 320722,
				"name": "东海县",
				"parent_id": 320700,
				"type": 4,
				"zip": "222300"
			}, {
				"id": 320723,
				"name": "灌云县",
				"parent_id": 320700,
				"type": 4,
				"zip": "222200"
			}, {
				"id": 320721,
				"name": "赣榆县",
				"parent_id": 320700,
				"type": 4,
				"zip": "222100"
			}, {
				"id": 320703,
				"name": "连云区",
				"parent_id": 320700,
				"type": 4,
				"zip": "222042"
			}]
		}, {
			"id": 320600,
			"name": "南通市",
			"parent_id": 320000,
			"type": 3,
			"zip": "226000",
			"district": [{
				"id": 320681,
				"name": "启东市",
				"parent_id": 320600,
				"type": 4,
				"zip": "226200"
			}, {
				"id": 320683,
				"name": "通州市",
				"parent_id": 320600,
				"type": 4,
				"zip": "226300"
			}, {
				"id": 320682,
				"name": "如皋市",
				"parent_id": 320600,
				"type": 4,
				"zip": "226500"
			}, {
				"id": 320684,
				"name": "海门市",
				"parent_id": 320600,
				"type": 4,
				"zip": "226100"
			}, {
				"id": 320693,
				"name": "开发区",
				"parent_id": 320600,
				"type": 4,
				"zip": ""
			}, {
				"id": 320694,
				"name": "其它区",
				"parent_id": 320600,
				"type": 4,
				"zip": ""
			}, {
				"id": 320602,
				"name": "崇川区",
				"parent_id": 320600,
				"type": 4,
				"zip": "226001"
			}, {
				"id": 320612,
				"name": "通州区",
				"parent_id": 320600,
				"type": 4,
				"zip": "226321"
			}, {
				"id": 320611,
				"name": "港闸区",
				"parent_id": 320600,
				"type": 4,
				"zip": "226001"
			}, {
				"id": 320621,
				"name": "海安县",
				"parent_id": 320600,
				"type": 4,
				"zip": "226600"
			}, {
				"id": 320623,
				"name": "如东县",
				"parent_id": 320600,
				"type": 4,
				"zip": "226400"
			}]
		}, {
			"id": 320400,
			"name": "常州市",
			"parent_id": 320000,
			"type": 3,
			"zip": "213000",
			"district": [{
				"id": 320404,
				"name": "钟楼区",
				"parent_id": 320400,
				"type": 4,
				"zip": "213002"
			}, {
				"id": 320405,
				"name": "戚墅堰区",
				"parent_id": 320400,
				"type": 4,
				"zip": "213011"
			}, {
				"id": 320402,
				"name": "天宁区",
				"parent_id": 320400,
				"type": 4,
				"zip": "213003"
			}, {
				"id": 320412,
				"name": "武进区",
				"parent_id": 320400,
				"type": 4,
				"zip": "213161"
			}, {
				"id": 320411,
				"name": "新北区",
				"parent_id": 320400,
				"type": 4,
				"zip": "213001"
			}, {
				"id": 320483,
				"name": "其它区",
				"parent_id": 320400,
				"type": 4,
				"zip": ""
			}, {
				"id": 320482,
				"name": "金坛市",
				"parent_id": 320400,
				"type": 4,
				"zip": "213200"
			}, {
				"id": 320481,
				"name": "溧阳市",
				"parent_id": 320400,
				"type": 4,
				"zip": "213300"
			}]
		}, {
			"id": 320500,
			"name": "苏州市",
			"parent_id": 320000,
			"type": 3,
			"zip": "215000",
			"district": [{
				"id": 320582,
				"name": "张家港市",
				"parent_id": 320500,
				"type": 4,
				"zip": "215600"
			}, {
				"id": 320583,
				"name": "昆山市",
				"parent_id": 320500,
				"type": 4,
				"zip": "215300"
			}, {
				"id": 320581,
				"name": "常熟市",
				"parent_id": 320500,
				"type": 4,
				"zip": "215500"
			}, {
				"id": 320584,
				"name": "吴江区",
				"parent_id": 320500,
				"type": 4,
				"zip": "215200"
			}, {
				"id": 320585,
				"name": "太仓市",
				"parent_id": 320500,
				"type": 4,
				"zip": "215400"
			}, {
				"id": 320596,
				"name": "其它区",
				"parent_id": 320500,
				"type": 4,
				"zip": ""
			}, {
				"id": 320595,
				"name": "园区",
				"parent_id": 320500,
				"type": 4,
				"zip": ""
			}, {
				"id": 320594,
				"name": "新区",
				"parent_id": 320500,
				"type": 4,
				"zip": ""
			}, {
				"id": 320502,
				"name": "沧浪区",
				"parent_id": 320500,
				"type": 4,
				"zip": "215006"
			}, {
				"id": 320503,
				"name": "平江区",
				"parent_id": 320500,
				"type": 4,
				"zip": "215005"
			}, {
				"id": 320506,
				"name": "吴中区",
				"parent_id": 320500,
				"type": 4,
				"zip": "215128"
			}, {
				"id": 320507,
				"name": "相城区",
				"parent_id": 320500,
				"type": 4,
				"zip": "215131"
			}, {
				"id": 320504,
				"name": "金阊区",
				"parent_id": 320500,
				"type": 4,
				"zip": "215008"
			}, {
				"id": 320505,
				"name": "虎丘区",
				"parent_id": 320500,
				"type": 4,
				"zip": "215004"
			}, {
				"id": 320508,
				"name": "姑苏区",
				"parent_id": 320500,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 320300,
			"name": "徐州市",
			"parent_id": 320000,
			"type": 3,
			"zip": "221000",
			"district": [{
				"id": 320311,
				"name": "泉山区",
				"parent_id": 320300,
				"type": 4,
				"zip": "220006"
			}, {
				"id": 320305,
				"name": "贾汪区",
				"parent_id": 320300,
				"type": 4,
				"zip": "220011"
			}, {
				"id": 320304,
				"name": "九里区",
				"parent_id": 320300,
				"type": 4,
				"zip": "220040"
			}, {
				"id": 320302,
				"name": "鼓楼区",
				"parent_id": 320300,
				"type": 4,
				"zip": "220005"
			}, {
				"id": 320303,
				"name": "云龙区",
				"parent_id": 320300,
				"type": 4,
				"zip": "220009"
			}, {
				"id": 320383,
				"name": "其它区",
				"parent_id": 320300,
				"type": 4,
				"zip": ""
			}, {
				"id": 320382,
				"name": "邳州市",
				"parent_id": 320300,
				"type": 4,
				"zip": "221300"
			}, {
				"id": 320381,
				"name": "新沂市",
				"parent_id": 320300,
				"type": 4,
				"zip": "221400"
			}, {
				"id": 320321,
				"name": "丰县",
				"parent_id": 320300,
				"type": 4,
				"zip": "221700"
			}, {
				"id": 320322,
				"name": "沛县",
				"parent_id": 320300,
				"type": 4,
				"zip": "221600"
			}, {
				"id": 320323,
				"name": "铜山区",
				"parent_id": 320300,
				"type": 4,
				"zip": "221112"
			}, {
				"id": 320324,
				"name": "睢宁县",
				"parent_id": 320300,
				"type": 4,
				"zip": "221200"
			}]
		}, {
			"id": 320200,
			"name": "无锡市",
			"parent_id": 320000,
			"type": 3,
			"zip": "214000",
			"district": [{
				"id": 320296,
				"name": "新区",
				"parent_id": 320200,
				"type": 4,
				"zip": ""
			}, {
				"id": 320297,
				"name": "其它区",
				"parent_id": 320200,
				"type": 4,
				"zip": ""
			}, {
				"id": 320281,
				"name": "江阴市",
				"parent_id": 320200,
				"type": 4,
				"zip": "214400"
			}, {
				"id": 320282,
				"name": "宜兴市",
				"parent_id": 320200,
				"type": 4,
				"zip": "214200"
			}, {
				"id": 320203,
				"name": "南长区",
				"parent_id": 320200,
				"type": 4,
				"zip": "214021"
			}, {
				"id": 320202,
				"name": "崇安区",
				"parent_id": 320200,
				"type": 4,
				"zip": "214002"
			}, {
				"id": 320206,
				"name": "惠山区",
				"parent_id": 320200,
				"type": 4,
				"zip": "214187"
			}, {
				"id": 320205,
				"name": "锡山区",
				"parent_id": 320200,
				"type": 4,
				"zip": "214101"
			}, {
				"id": 320204,
				"name": "北塘区",
				"parent_id": 320200,
				"type": 4,
				"zip": "214044"
			}, {
				"id": 320211,
				"name": "滨湖区",
				"parent_id": 320200,
				"type": 4,
				"zip": "214062"
			}]
		}, {
			"id": 320100,
			"name": "南京市",
			"parent_id": 320000,
			"type": 3,
			"zip": "210000",
			"district": [{
				"id": 320104,
				"name": "秦淮区",
				"parent_id": 320100,
				"type": 4,
				"zip": "210001"
			}, {
				"id": 320105,
				"name": "建邺区",
				"parent_id": 320100,
				"type": 4,
				"zip": "210004"
			}, {
				"id": 320106,
				"name": "鼓楼区",
				"parent_id": 320100,
				"type": 4,
				"zip": "210009"
			}, {
				"id": 320107,
				"name": "下关区",
				"parent_id": 320100,
				"type": 4,
				"zip": "210011"
			}, {
				"id": 320111,
				"name": "浦口区",
				"parent_id": 320100,
				"type": 4,
				"zip": "211800"
			}, {
				"id": 320102,
				"name": "玄武区",
				"parent_id": 320100,
				"type": 4,
				"zip": "210018"
			}, {
				"id": 320103,
				"name": "白下区",
				"parent_id": 320100,
				"type": 4,
				"zip": "210002"
			}, {
				"id": 320125,
				"name": "高淳区",
				"parent_id": 320100,
				"type": 4,
				"zip": "211300"
			}, {
				"id": 320124,
				"name": "溧水区",
				"parent_id": 320100,
				"type": 4,
				"zip": "211200"
			}, {
				"id": 320126,
				"name": "其它区",
				"parent_id": 320100,
				"type": 4,
				"zip": ""
			}, {
				"id": 320113,
				"name": "栖霞区",
				"parent_id": 320100,
				"type": 4,
				"zip": "210046"
			}, {
				"id": 320115,
				"name": "江宁区",
				"parent_id": 320100,
				"type": 4,
				"zip": "211100"
			}, {
				"id": 320114,
				"name": "雨花台区",
				"parent_id": 320100,
				"type": 4,
				"zip": "210012"
			}, {
				"id": 320116,
				"name": "六合区",
				"parent_id": 320100,
				"type": 4,
				"zip": "211500"
			}]
		}]
	}, {
		"id": 540000,
		"name": "西藏自治区",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 540100,
			"name": "拉萨市",
			"parent_id": 540000,
			"type": 3,
			"zip": "850000",
			"district": [{
				"id": 540128,
				"name": "其它区",
				"parent_id": 540100,
				"type": 4,
				"zip": ""
			}, {
				"id": 540102,
				"name": "城关区",
				"parent_id": 540100,
				"type": 4,
				"zip": "850000"
			}, {
				"id": 540124,
				"name": "曲水县",
				"parent_id": 540100,
				"type": 4,
				"zip": "850600"
			}, {
				"id": 540125,
				"name": "堆龙德庆县",
				"parent_id": 540100,
				"type": 4,
				"zip": "851400"
			}, {
				"id": 540126,
				"name": "达孜县",
				"parent_id": 540100,
				"type": 4,
				"zip": "850100"
			}, {
				"id": 540127,
				"name": "墨竹工卡县",
				"parent_id": 540100,
				"type": 4,
				"zip": "850200"
			}, {
				"id": 540121,
				"name": "林周县",
				"parent_id": 540100,
				"type": 4,
				"zip": "851600"
			}, {
				"id": 540122,
				"name": "当雄县",
				"parent_id": 540100,
				"type": 4,
				"zip": "851500"
			}, {
				"id": 540123,
				"name": "尼木县",
				"parent_id": 540100,
				"type": 4,
				"zip": "851300"
			}]
		}, {
			"id": 542200,
			"name": "山南地区",
			"parent_id": 540000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 542221,
				"name": "乃东县",
				"parent_id": 542200,
				"type": 4,
				"zip": "856100"
			}, {
				"id": 542223,
				"name": "贡嘎县",
				"parent_id": 542200,
				"type": 4,
				"zip": "850700"
			}, {
				"id": 542222,
				"name": "扎囊县",
				"parent_id": 542200,
				"type": 4,
				"zip": "850800"
			}, {
				"id": 542224,
				"name": "桑日县",
				"parent_id": 542200,
				"type": 4,
				"zip": "856200"
			}, {
				"id": 542225,
				"name": "琼结县",
				"parent_id": 542200,
				"type": 4,
				"zip": "856800"
			}, {
				"id": 542226,
				"name": "曲松县",
				"parent_id": 542200,
				"type": 4,
				"zip": "856300"
			}, {
				"id": 542227,
				"name": "措美县",
				"parent_id": 542200,
				"type": 4,
				"zip": "856900"
			}, {
				"id": 542228,
				"name": "洛扎县",
				"parent_id": 542200,
				"type": 4,
				"zip": "851200"
			}, {
				"id": 542229,
				"name": "加查县",
				"parent_id": 542200,
				"type": 4,
				"zip": "856400"
			}, {
				"id": 542231,
				"name": "隆子县",
				"parent_id": 542200,
				"type": 4,
				"zip": "856600"
			}, {
				"id": 542232,
				"name": "错那县",
				"parent_id": 542200,
				"type": 4,
				"zip": "856700"
			}, {
				"id": 542233,
				"name": "浪卡子县",
				"parent_id": 542200,
				"type": 4,
				"zip": "851100"
			}, {
				"id": 542234,
				"name": "其它区",
				"parent_id": 542200,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 542100,
			"name": "昌都地区",
			"parent_id": 540000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 542133,
				"name": "边坝县",
				"parent_id": 542100,
				"type": 4,
				"zip": "855500"
			}, {
				"id": 542132,
				"name": "洛隆县",
				"parent_id": 542100,
				"type": 4,
				"zip": "855400"
			}, {
				"id": 542134,
				"name": "其它区",
				"parent_id": 542100,
				"type": 4,
				"zip": ""
			}, {
				"id": 542129,
				"name": "芒康县",
				"parent_id": 542100,
				"type": 4,
				"zip": "854500"
			}, {
				"id": 542128,
				"name": "左贡县",
				"parent_id": 542100,
				"type": 4,
				"zip": "854400"
			}, {
				"id": 542124,
				"name": "类乌齐县",
				"parent_id": 542100,
				"type": 4,
				"zip": "855600"
			}, {
				"id": 542125,
				"name": "丁青县",
				"parent_id": 542100,
				"type": 4,
				"zip": "855700"
			}, {
				"id": 542126,
				"name": "察雅县",
				"parent_id": 542100,
				"type": 4,
				"zip": "854300"
			}, {
				"id": 542127,
				"name": "八宿县",
				"parent_id": 542100,
				"type": 4,
				"zip": "854600"
			}, {
				"id": 542121,
				"name": "昌都县",
				"parent_id": 542100,
				"type": 4,
				"zip": "854000"
			}, {
				"id": 542122,
				"name": "江达县",
				"parent_id": 542100,
				"type": 4,
				"zip": "854100"
			}, {
				"id": 542123,
				"name": "贡觉县",
				"parent_id": 542100,
				"type": 4,
				"zip": "854200"
			}]
		}, {
			"id": 542300,
			"name": "日喀则地区",
			"parent_id": 540000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 542326,
				"name": "拉孜县",
				"parent_id": 542300,
				"type": 4,
				"zip": "858100"
			}, {
				"id": 542327,
				"name": "昂仁县",
				"parent_id": 542300,
				"type": 4,
				"zip": "858500"
			}, {
				"id": 542324,
				"name": "定日县",
				"parent_id": 542300,
				"type": 4,
				"zip": "858200"
			}, {
				"id": 542325,
				"name": "萨迦县",
				"parent_id": 542300,
				"type": 4,
				"zip": "857800"
			}, {
				"id": 542322,
				"name": "南木林县",
				"parent_id": 542300,
				"type": 4,
				"zip": "857100"
			}, {
				"id": 542323,
				"name": "江孜县",
				"parent_id": 542300,
				"type": 4,
				"zip": "857400"
			}, {
				"id": 542334,
				"name": "亚东县",
				"parent_id": 542300,
				"type": 4,
				"zip": "857600"
			}, {
				"id": 542335,
				"name": "吉隆县",
				"parent_id": 542300,
				"type": 4,
				"zip": "858700"
			}, {
				"id": 542332,
				"name": "定结县",
				"parent_id": 542300,
				"type": 4,
				"zip": "857900"
			}, {
				"id": 542333,
				"name": "仲巴县",
				"parent_id": 542300,
				"type": 4,
				"zip": "858800"
			}, {
				"id": 542330,
				"name": "仁布县",
				"parent_id": 542300,
				"type": 4,
				"zip": "857200"
			}, {
				"id": 542331,
				"name": "康马县",
				"parent_id": 542300,
				"type": 4,
				"zip": "857500"
			}, {
				"id": 542328,
				"name": "谢通门县",
				"parent_id": 542300,
				"type": 4,
				"zip": "858900"
			}, {
				"id": 542329,
				"name": "白朗县",
				"parent_id": 542300,
				"type": 4,
				"zip": "857300"
			}, {
				"id": 542301,
				"name": "日喀则市",
				"parent_id": 542300,
				"type": 4,
				"zip": "857000"
			}, {
				"id": 542336,
				"name": "聂拉木县",
				"parent_id": 542300,
				"type": 4,
				"zip": "858300"
			}, {
				"id": 542337,
				"name": "萨嘎县",
				"parent_id": 542300,
				"type": 4,
				"zip": "858600"
			}, {
				"id": 542338,
				"name": "岗巴县",
				"parent_id": 542300,
				"type": 4,
				"zip": "857700"
			}, {
				"id": 542339,
				"name": "其它区",
				"parent_id": 542300,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 542400,
			"name": "那曲地区",
			"parent_id": 540000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 542432,
				"name": "双湖县",
				"parent_id": 542400,
				"type": 4,
				"zip": ""
			}, {
				"id": 542429,
				"name": "巴青县",
				"parent_id": 542400,
				"type": 4,
				"zip": "852100"
			}, {
				"id": 542428,
				"name": "班戈县",
				"parent_id": 542400,
				"type": 4,
				"zip": "852500"
			}, {
				"id": 542431,
				"name": "其它区",
				"parent_id": 542400,
				"type": 4,
				"zip": ""
			}, {
				"id": 542430,
				"name": "尼玛县",
				"parent_id": 542400,
				"type": 4,
				"zip": "852600"
			}, {
				"id": 542425,
				"name": "安多县",
				"parent_id": 542400,
				"type": 4,
				"zip": "853400"
			}, {
				"id": 542424,
				"name": "聂荣县",
				"parent_id": 542400,
				"type": 4,
				"zip": "853500"
			}, {
				"id": 542427,
				"name": "索县",
				"parent_id": 542400,
				"type": 4,
				"zip": "852200"
			}, {
				"id": 542426,
				"name": "申扎县",
				"parent_id": 542400,
				"type": 4,
				"zip": "853100"
			}, {
				"id": 542421,
				"name": "那曲县",
				"parent_id": 542400,
				"type": 4,
				"zip": "852000"
			}, {
				"id": 542423,
				"name": "比如县",
				"parent_id": 542400,
				"type": 4,
				"zip": "852300"
			}, {
				"id": 542422,
				"name": "嘉黎县",
				"parent_id": 542400,
				"type": 4,
				"zip": "852400"
			}]
		}, {
			"id": 542500,
			"name": "阿里地区",
			"parent_id": 540000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 542528,
				"name": "其它区",
				"parent_id": 542500,
				"type": 4,
				"zip": ""
			}, {
				"id": 542521,
				"name": "普兰县",
				"parent_id": 542500,
				"type": 4,
				"zip": "859500"
			}, {
				"id": 542522,
				"name": "札达县",
				"parent_id": 542500,
				"type": 4,
				"zip": "859600"
			}, {
				"id": 542523,
				"name": "噶尔县",
				"parent_id": 542500,
				"type": 4,
				"zip": "859400"
			}, {
				"id": 542524,
				"name": "日土县",
				"parent_id": 542500,
				"type": 4,
				"zip": "859700"
			}, {
				"id": 542525,
				"name": "革吉县",
				"parent_id": 542500,
				"type": 4,
				"zip": "859100"
			}, {
				"id": 542526,
				"name": "改则县",
				"parent_id": 542500,
				"type": 4,
				"zip": "859200"
			}, {
				"id": 542527,
				"name": "措勤县",
				"parent_id": 542500,
				"type": 4,
				"zip": "859300"
			}]
		}, {
			"id": 542600,
			"name": "林芝地区",
			"parent_id": 540000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 542624,
				"name": "墨脱县",
				"parent_id": 542600,
				"type": 4,
				"zip": "860700"
			}, {
				"id": 542625,
				"name": "波密县",
				"parent_id": 542600,
				"type": 4,
				"zip": "860300"
			}, {
				"id": 542626,
				"name": "察隅县",
				"parent_id": 542600,
				"type": 4,
				"zip": "860600"
			}, {
				"id": 542627,
				"name": "朗县",
				"parent_id": 542600,
				"type": 4,
				"zip": "860400"
			}, {
				"id": 542628,
				"name": "其它区",
				"parent_id": 542600,
				"type": 4,
				"zip": ""
			}, {
				"id": 542623,
				"name": "米林县",
				"parent_id": 542600,
				"type": 4,
				"zip": "860500"
			}, {
				"id": 542622,
				"name": "工布江达县",
				"parent_id": 542600,
				"type": 4,
				"zip": "860200"
			}, {
				"id": 542621,
				"name": "林芝县",
				"parent_id": 542600,
				"type": 4,
				"zip": "860100"
			}]
		}]
	}, {
		"id": 110000,
		"name": "北京",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 110100,
			"name": "北京市",
			"parent_id": 110000,
			"type": 3,
			"zip": "100000",
			"district": [{
				"id": 110230,
				"name": "其它区",
				"parent_id": 110100,
				"type": 4,
				"zip": ""
			}, {
				"id": 110229,
				"name": "延庆县",
				"parent_id": 110100,
				"type": 4,
				"zip": "102100"
			}, {
				"id": 110228,
				"name": "密云县",
				"parent_id": 110100,
				"type": 4,
				"zip": "101500"
			}, {
				"id": 110117,
				"name": "平谷区",
				"parent_id": 110100,
				"type": 4,
				"zip": "101200"
			}, {
				"id": 110116,
				"name": "怀柔区",
				"parent_id": 110100,
				"type": 4,
				"zip": "101400"
			}, {
				"id": 110113,
				"name": "顺义区",
				"parent_id": 110100,
				"type": 4,
				"zip": "101300"
			}, {
				"id": 110112,
				"name": "通州区",
				"parent_id": 110100,
				"type": 4,
				"zip": "101100"
			}, {
				"id": 110115,
				"name": "大兴区",
				"parent_id": 110100,
				"type": 4,
				"zip": "102600"
			}, {
				"id": 110114,
				"name": "昌平区",
				"parent_id": 110100,
				"type": 4,
				"zip": "102200"
			}, {
				"id": 110102,
				"name": "西城区",
				"parent_id": 110100,
				"type": 4,
				"zip": "100032"
			}, {
				"id": 110103,
				"name": "崇文区",
				"parent_id": 110100,
				"type": 4,
				"zip": "100061"
			}, {
				"id": 110101,
				"name": "东城区",
				"parent_id": 110100,
				"type": 4,
				"zip": "100010"
			}, {
				"id": 110111,
				"name": "房山区",
				"parent_id": 110100,
				"type": 4,
				"zip": "102488"
			}, {
				"id": 110108,
				"name": "海淀区",
				"parent_id": 110100,
				"type": 4,
				"zip": "100091"
			}, {
				"id": 110109,
				"name": "门头沟区",
				"parent_id": 110100,
				"type": 4,
				"zip": "102300"
			}, {
				"id": 110106,
				"name": "丰台区",
				"parent_id": 110100,
				"type": 4,
				"zip": "100071"
			}, {
				"id": 110107,
				"name": "石景山区",
				"parent_id": 110100,
				"type": 4,
				"zip": "100071"
			}, {
				"id": 110104,
				"name": "宣武区",
				"parent_id": 110100,
				"type": 4,
				"zip": "100054"
			}, {
				"id": 110105,
				"name": "朝阳区",
				"parent_id": 110100,
				"type": 4,
				"zip": "100011"
			}]
		}]
	}, {
		"id": 510000,
		"name": "四川省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 512000,
			"name": "资阳市",
			"parent_id": 510000,
			"type": 3,
			"zip": "641300",
			"district": [{
				"id": 512082,
				"name": "其它区",
				"parent_id": 512000,
				"type": 4,
				"zip": ""
			}, {
				"id": 512081,
				"name": "简阳市",
				"parent_id": 512000,
				"type": 4,
				"zip": "641400"
			}, {
				"id": 512022,
				"name": "乐至县",
				"parent_id": 512000,
				"type": 4,
				"zip": "641500"
			}, {
				"id": 512021,
				"name": "安岳县",
				"parent_id": 512000,
				"type": 4,
				"zip": "642350"
			}, {
				"id": 512002,
				"name": "雁江区",
				"parent_id": 512000,
				"type": 4,
				"zip": "641300"
			}]
		}, {
			"id": 513200,
			"name": "阿坝藏族羌族自治州",
			"parent_id": 510000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 513234,
				"name": "其它区",
				"parent_id": 513200,
				"type": 4,
				"zip": ""
			}, {
				"id": 513232,
				"name": "若尔盖县",
				"parent_id": 513200,
				"type": 4,
				"zip": "624500"
			}, {
				"id": 513233,
				"name": "红原县",
				"parent_id": 513200,
				"type": 4,
				"zip": "624400"
			}, {
				"id": 513231,
				"name": "阿坝县",
				"parent_id": 513200,
				"type": 4,
				"zip": "624600"
			}, {
				"id": 513230,
				"name": "壤塘县",
				"parent_id": 513200,
				"type": 4,
				"zip": "624300"
			}, {
				"id": 513229,
				"name": "马尔康县",
				"parent_id": 513200,
				"type": 4,
				"zip": "624000"
			}, {
				"id": 513228,
				"name": "黑水县",
				"parent_id": 513200,
				"type": 4,
				"zip": "623500"
			}, {
				"id": 513227,
				"name": "小金县",
				"parent_id": 513200,
				"type": 4,
				"zip": "624200"
			}, {
				"id": 513226,
				"name": "金川县",
				"parent_id": 513200,
				"type": 4,
				"zip": "624100"
			}, {
				"id": 513225,
				"name": "九寨沟县",
				"parent_id": 513200,
				"type": 4,
				"zip": "623400"
			}, {
				"id": 513224,
				"name": "松潘县",
				"parent_id": 513200,
				"type": 4,
				"zip": "623300"
			}, {
				"id": 513223,
				"name": "茂县",
				"parent_id": 513200,
				"type": 4,
				"zip": "623200"
			}, {
				"id": 513222,
				"name": "理县",
				"parent_id": 513200,
				"type": 4,
				"zip": "632100"
			}, {
				"id": 513221,
				"name": "汶川县",
				"parent_id": 513200,
				"type": 4,
				"zip": "623000"
			}]
		}, {
			"id": 513300,
			"name": "甘孜藏族自治州",
			"parent_id": 510000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 513322,
				"name": "泸定县",
				"parent_id": 513300,
				"type": 4,
				"zip": "626100"
			}, {
				"id": 513323,
				"name": "丹巴县",
				"parent_id": 513300,
				"type": 4,
				"zip": "626300"
			}, {
				"id": 513321,
				"name": "康定县",
				"parent_id": 513300,
				"type": 4,
				"zip": "626000"
			}, {
				"id": 513326,
				"name": "道孚县",
				"parent_id": 513300,
				"type": 4,
				"zip": "626400"
			}, {
				"id": 513327,
				"name": "炉霍县",
				"parent_id": 513300,
				"type": 4,
				"zip": "626500"
			}, {
				"id": 513324,
				"name": "九龙县",
				"parent_id": 513300,
				"type": 4,
				"zip": "626200"
			}, {
				"id": 513325,
				"name": "雅江县",
				"parent_id": 513300,
				"type": 4,
				"zip": "627450"
			}, {
				"id": 513331,
				"name": "白玉县",
				"parent_id": 513300,
				"type": 4,
				"zip": "627150"
			}, {
				"id": 513330,
				"name": "德格县",
				"parent_id": 513300,
				"type": 4,
				"zip": "627250"
			}, {
				"id": 513329,
				"name": "新龙县",
				"parent_id": 513300,
				"type": 4,
				"zip": "626800"
			}, {
				"id": 513328,
				"name": "甘孜县",
				"parent_id": 513300,
				"type": 4,
				"zip": "626700"
			}, {
				"id": 513335,
				"name": "巴塘县",
				"parent_id": 513300,
				"type": 4,
				"zip": "627650"
			}, {
				"id": 513334,
				"name": "理塘县",
				"parent_id": 513300,
				"type": 4,
				"zip": "627550"
			}, {
				"id": 513333,
				"name": "色达县",
				"parent_id": 513300,
				"type": 4,
				"zip": "626600"
			}, {
				"id": 513332,
				"name": "石渠县",
				"parent_id": 513300,
				"type": 4,
				"zip": "627350"
			}, {
				"id": 513339,
				"name": "其它区",
				"parent_id": 513300,
				"type": 4,
				"zip": ""
			}, {
				"id": 513338,
				"name": "得荣县",
				"parent_id": 513300,
				"type": 4,
				"zip": "627950"
			}, {
				"id": 513337,
				"name": "稻城县",
				"parent_id": 513300,
				"type": 4,
				"zip": "627750"
			}, {
				"id": 513336,
				"name": "乡城县",
				"parent_id": 513300,
				"type": 4,
				"zip": "627850"
			}]
		}, {
			"id": 513400,
			"name": "凉山彝族自治州",
			"parent_id": 510000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 513423,
				"name": "盐源县",
				"parent_id": 513400,
				"type": 4,
				"zip": "615700"
			}, {
				"id": 513422,
				"name": "木里藏族自治县",
				"parent_id": 513400,
				"type": 4,
				"zip": "615800"
			}, {
				"id": 513432,
				"name": "喜德县",
				"parent_id": 513400,
				"type": 4,
				"zip": "616750"
			}, {
				"id": 513433,
				"name": "冕宁县",
				"parent_id": 513400,
				"type": 4,
				"zip": "615600"
			}, {
				"id": 513434,
				"name": "越西县",
				"parent_id": 513400,
				"type": 4,
				"zip": "616650"
			}, {
				"id": 513435,
				"name": "甘洛县",
				"parent_id": 513400,
				"type": 4,
				"zip": "616850"
			}, {
				"id": 513436,
				"name": "美姑县",
				"parent_id": 513400,
				"type": 4,
				"zip": "616450"
			}, {
				"id": 513437,
				"name": "雷波县",
				"parent_id": 513400,
				"type": 4,
				"zip": "616550"
			}, {
				"id": 513438,
				"name": "其它区",
				"parent_id": 513400,
				"type": 4,
				"zip": ""
			}, {
				"id": 513424,
				"name": "德昌县",
				"parent_id": 513400,
				"type": 4,
				"zip": "615500"
			}, {
				"id": 513425,
				"name": "会理县",
				"parent_id": 513400,
				"type": 4,
				"zip": "615100"
			}, {
				"id": 513426,
				"name": "会东县",
				"parent_id": 513400,
				"type": 4,
				"zip": "615200"
			}, {
				"id": 513427,
				"name": "宁南县",
				"parent_id": 513400,
				"type": 4,
				"zip": "615400"
			}, {
				"id": 513428,
				"name": "普格县",
				"parent_id": 513400,
				"type": 4,
				"zip": "615300"
			}, {
				"id": 513429,
				"name": "布拖县",
				"parent_id": 513400,
				"type": 4,
				"zip": "616350"
			}, {
				"id": 513430,
				"name": "金阳县",
				"parent_id": 513400,
				"type": 4,
				"zip": "616250"
			}, {
				"id": 513431,
				"name": "昭觉县",
				"parent_id": 513400,
				"type": 4,
				"zip": "616150"
			}, {
				"id": 513401,
				"name": "西昌市",
				"parent_id": 513400,
				"type": 4,
				"zip": "615000"
			}]
		}, {
			"id": 510800,
			"name": "广元市",
			"parent_id": 510000,
			"type": 3,
			"zip": "628000",
			"district": [{
				"id": 510811,
				"name": "昭化区",
				"parent_id": 510800,
				"type": 4,
				"zip": "628021"
			}, {
				"id": 510812,
				"name": "朝天区",
				"parent_id": 510800,
				"type": 4,
				"zip": "628012"
			}, {
				"id": 510802,
				"name": "利州区",
				"parent_id": 510800,
				"type": 4,
				"zip": "628017"
			}, {
				"id": 510825,
				"name": "其它区",
				"parent_id": 510800,
				"type": 4,
				"zip": ""
			}, {
				"id": 510824,
				"name": "苍溪县",
				"parent_id": 510800,
				"type": 4,
				"zip": "628400"
			}, {
				"id": 510823,
				"name": "剑阁县",
				"parent_id": 510800,
				"type": 4,
				"zip": "628300"
			}, {
				"id": 510822,
				"name": "青川县",
				"parent_id": 510800,
				"type": 4,
				"zip": "628100"
			}, {
				"id": 510821,
				"name": "旺苍县",
				"parent_id": 510800,
				"type": 4,
				"zip": "628200"
			}]
		}, {
			"id": 510900,
			"name": "遂宁市",
			"parent_id": 510000,
			"type": 3,
			"zip": "629000",
			"district": [{
				"id": 510921,
				"name": "蓬溪县",
				"parent_id": 510900,
				"type": 4,
				"zip": "629100"
			}, {
				"id": 510922,
				"name": "射洪县",
				"parent_id": 510900,
				"type": 4,
				"zip": "629200"
			}, {
				"id": 510923,
				"name": "大英县",
				"parent_id": 510900,
				"type": 4,
				"zip": "629300"
			}, {
				"id": 510924,
				"name": "其它区",
				"parent_id": 510900,
				"type": 4,
				"zip": ""
			}, {
				"id": 510903,
				"name": "船山区",
				"parent_id": 510900,
				"type": 4,
				"zip": "629000"
			}, {
				"id": 510904,
				"name": "安居区",
				"parent_id": 510900,
				"type": 4,
				"zip": "629000"
			}]
		}, {
			"id": 510500,
			"name": "泸州市",
			"parent_id": 510000,
			"type": 3,
			"zip": "646000",
			"district": [{
				"id": 510504,
				"name": "龙马潭区",
				"parent_id": 510500,
				"type": 4,
				"zip": "646000"
			}, {
				"id": 510503,
				"name": "纳溪区",
				"parent_id": 510500,
				"type": 4,
				"zip": "646300"
			}, {
				"id": 510502,
				"name": "江阳区",
				"parent_id": 510500,
				"type": 4,
				"zip": "646000"
			}, {
				"id": 510524,
				"name": "叙永县",
				"parent_id": 510500,
				"type": 4,
				"zip": "646400"
			}, {
				"id": 510525,
				"name": "古蔺县",
				"parent_id": 510500,
				"type": 4,
				"zip": "646500"
			}, {
				"id": 510526,
				"name": "其它区",
				"parent_id": 510500,
				"type": 4,
				"zip": ""
			}, {
				"id": 510521,
				"name": "泸县",
				"parent_id": 510500,
				"type": 4,
				"zip": "646100"
			}, {
				"id": 510522,
				"name": "合江县",
				"parent_id": 510500,
				"type": 4,
				"zip": "646200"
			}]
		}, {
			"id": 510700,
			"name": "绵阳市",
			"parent_id": 510000,
			"type": 3,
			"zip": "621000",
			"district": [{
				"id": 510751,
				"name": "高新区",
				"parent_id": 510700,
				"type": 4,
				"zip": ""
			}, {
				"id": 510725,
				"name": "梓潼县",
				"parent_id": 510700,
				"type": 4,
				"zip": "622150"
			}, {
				"id": 510724,
				"name": "安县",
				"parent_id": 510700,
				"type": 4,
				"zip": "622650"
			}, {
				"id": 510727,
				"name": "平武县",
				"parent_id": 510700,
				"type": 4,
				"zip": "621550"
			}, {
				"id": 510726,
				"name": "北川羌族自治县",
				"parent_id": 510700,
				"type": 4,
				"zip": "622750"
			}, {
				"id": 510723,
				"name": "盐亭县",
				"parent_id": 510700,
				"type": 4,
				"zip": "621600"
			}, {
				"id": 510722,
				"name": "三台县",
				"parent_id": 510700,
				"type": 4,
				"zip": "621100"
			}, {
				"id": 510782,
				"name": "其它区",
				"parent_id": 510700,
				"type": 4,
				"zip": ""
			}, {
				"id": 510781,
				"name": "江油市",
				"parent_id": 510700,
				"type": 4,
				"zip": "621700"
			}, {
				"id": 510703,
				"name": "涪城区",
				"parent_id": 510700,
				"type": 4,
				"zip": "621000"
			}, {
				"id": 510704,
				"name": "游仙区",
				"parent_id": 510700,
				"type": 4,
				"zip": "621022"
			}]
		}, {
			"id": 510600,
			"name": "德阳市",
			"parent_id": 510000,
			"type": 3,
			"zip": "618000",
			"district": [{
				"id": 510683,
				"name": "绵竹市",
				"parent_id": 510600,
				"type": 4,
				"zip": "618200"
			}, {
				"id": 510682,
				"name": "什邡市",
				"parent_id": 510600,
				"type": 4,
				"zip": "618400"
			}, {
				"id": 510681,
				"name": "广汉市",
				"parent_id": 510600,
				"type": 4,
				"zip": "618300"
			}, {
				"id": 510684,
				"name": "其它区",
				"parent_id": 510600,
				"type": 4,
				"zip": ""
			}, {
				"id": 510603,
				"name": "旌阳区",
				"parent_id": 510600,
				"type": 4,
				"zip": "618000"
			}, {
				"id": 510623,
				"name": "中江县",
				"parent_id": 510600,
				"type": 4,
				"zip": "618300"
			}, {
				"id": 510626,
				"name": "罗江县",
				"parent_id": 510600,
				"type": 4,
				"zip": "618500"
			}]
		}, {
			"id": 510300,
			"name": "自贡市",
			"parent_id": 510000,
			"type": 3,
			"zip": "643000",
			"district": [{
				"id": 510322,
				"name": "富顺县",
				"parent_id": 510300,
				"type": 4,
				"zip": "643200"
			}, {
				"id": 510323,
				"name": "其它区",
				"parent_id": 510300,
				"type": 4,
				"zip": ""
			}, {
				"id": 510321,
				"name": "荣县",
				"parent_id": 510300,
				"type": 4,
				"zip": "643100"
			}, {
				"id": 510311,
				"name": "沿滩区",
				"parent_id": 510300,
				"type": 4,
				"zip": "643030"
			}, {
				"id": 510304,
				"name": "大安区",
				"parent_id": 510300,
				"type": 4,
				"zip": "643010"
			}, {
				"id": 510302,
				"name": "自流井区",
				"parent_id": 510300,
				"type": 4,
				"zip": "643000"
			}, {
				"id": 510303,
				"name": "贡井区",
				"parent_id": 510300,
				"type": 4,
				"zip": "643020"
			}]
		}, {
			"id": 510400,
			"name": "攀枝花市",
			"parent_id": 510000,
			"type": 3,
			"zip": "617000",
			"district": [{
				"id": 510421,
				"name": "米易县",
				"parent_id": 510400,
				"type": 4,
				"zip": "617200"
			}, {
				"id": 510423,
				"name": "其它区",
				"parent_id": 510400,
				"type": 4,
				"zip": ""
			}, {
				"id": 510422,
				"name": "盐边县",
				"parent_id": 510400,
				"type": 4,
				"zip": "617100"
			}, {
				"id": 510402,
				"name": "东区",
				"parent_id": 510400,
				"type": 4,
				"zip": "617067"
			}, {
				"id": 510403,
				"name": "西区",
				"parent_id": 510400,
				"type": 4,
				"zip": "617012"
			}, {
				"id": 510411,
				"name": "仁和区",
				"parent_id": 510400,
				"type": 4,
				"zip": "617061"
			}]
		}, {
			"id": 510100,
			"name": "成都市",
			"parent_id": 510000,
			"type": 3,
			"zip": "610000",
			"district": [{
				"id": 510181,
				"name": "都江堰市",
				"parent_id": 510100,
				"type": 4,
				"zip": "611830"
			}, {
				"id": 510182,
				"name": "彭州市",
				"parent_id": 510100,
				"type": 4,
				"zip": "611930"
			}, {
				"id": 510183,
				"name": "邛崃市",
				"parent_id": 510100,
				"type": 4,
				"zip": "611530"
			}, {
				"id": 510184,
				"name": "崇州市",
				"parent_id": 510100,
				"type": 4,
				"zip": "611230"
			}, {
				"id": 510185,
				"name": "其它区",
				"parent_id": 510100,
				"type": 4,
				"zip": ""
			}, {
				"id": 510112,
				"name": "龙泉驿区",
				"parent_id": 510100,
				"type": 4,
				"zip": "610100"
			}, {
				"id": 510113,
				"name": "青白江区",
				"parent_id": 510100,
				"type": 4,
				"zip": "610300"
			}, {
				"id": 510114,
				"name": "新都区",
				"parent_id": 510100,
				"type": 4,
				"zip": "610500"
			}, {
				"id": 510115,
				"name": "温江区",
				"parent_id": 510100,
				"type": 4,
				"zip": "611130"
			}, {
				"id": 510121,
				"name": "金堂县",
				"parent_id": 510100,
				"type": 4,
				"zip": "610400"
			}, {
				"id": 510122,
				"name": "双流县",
				"parent_id": 510100,
				"type": 4,
				"zip": "610200"
			}, {
				"id": 510124,
				"name": "郫县",
				"parent_id": 510100,
				"type": 4,
				"zip": "611730"
			}, {
				"id": 510129,
				"name": "大邑县",
				"parent_id": 510100,
				"type": 4,
				"zip": "611330"
			}, {
				"id": 510131,
				"name": "蒲江县",
				"parent_id": 510100,
				"type": 4,
				"zip": "611630"
			}, {
				"id": 510132,
				"name": "新津县",
				"parent_id": 510100,
				"type": 4,
				"zip": "611430"
			}, {
				"id": 510107,
				"name": "武侯区",
				"parent_id": 510100,
				"type": 4,
				"zip": "610041"
			}, {
				"id": 510106,
				"name": "金牛区",
				"parent_id": 510100,
				"type": 4,
				"zip": "610036"
			}, {
				"id": 510105,
				"name": "青羊区",
				"parent_id": 510100,
				"type": 4,
				"zip": "610031"
			}, {
				"id": 510104,
				"name": "锦江区",
				"parent_id": 510100,
				"type": 4,
				"zip": "610011"
			}, {
				"id": 510108,
				"name": "成华区",
				"parent_id": 510100,
				"type": 4,
				"zip": "610066"
			}]
		}, {
			"id": 511800,
			"name": "雅安市",
			"parent_id": 510000,
			"type": 3,
			"zip": "625000",
			"district": [{
				"id": 511802,
				"name": "雨城区",
				"parent_id": 511800,
				"type": 4,
				"zip": "625000"
			}, {
				"id": 511824,
				"name": "石棉县",
				"parent_id": 511800,
				"type": 4,
				"zip": "625400"
			}, {
				"id": 511825,
				"name": "天全县",
				"parent_id": 511800,
				"type": 4,
				"zip": "625500"
			}, {
				"id": 511826,
				"name": "芦山县",
				"parent_id": 511800,
				"type": 4,
				"zip": "625600"
			}, {
				"id": 511827,
				"name": "宝兴县",
				"parent_id": 511800,
				"type": 4,
				"zip": "625700"
			}, {
				"id": 511828,
				"name": "其它区",
				"parent_id": 511800,
				"type": 4,
				"zip": ""
			}, {
				"id": 511821,
				"name": "名山区",
				"parent_id": 511800,
				"type": 4,
				"zip": "625100"
			}, {
				"id": 511823,
				"name": "汉源县",
				"parent_id": 511800,
				"type": 4,
				"zip": "625300"
			}, {
				"id": 511822,
				"name": "荥经县",
				"parent_id": 511800,
				"type": 4,
				"zip": "625200"
			}]
		}, {
			"id": 511900,
			"name": "巴中市",
			"parent_id": 510000,
			"type": 3,
			"zip": "636000",
			"district": [{
				"id": 511903,
				"name": "恩阳区",
				"parent_id": 511900,
				"type": 4,
				"zip": ""
			}, {
				"id": 511902,
				"name": "巴州区",
				"parent_id": 511900,
				"type": 4,
				"zip": "636601"
			}, {
				"id": 511924,
				"name": "其它区",
				"parent_id": 511900,
				"type": 4,
				"zip": ""
			}, {
				"id": 511923,
				"name": "平昌县",
				"parent_id": 511900,
				"type": 4,
				"zip": "636400"
			}, {
				"id": 511922,
				"name": "南江县",
				"parent_id": 511900,
				"type": 4,
				"zip": "636600"
			}, {
				"id": 511921,
				"name": "通江县",
				"parent_id": 511900,
				"type": 4,
				"zip": "636700"
			}]
		}, {
			"id": 511500,
			"name": "宜宾市",
			"parent_id": 510000,
			"type": 3,
			"zip": "644000",
			"district": [{
				"id": 511502,
				"name": "翠屏区",
				"parent_id": 511500,
				"type": 4,
				"zip": "644000"
			}, {
				"id": 511525,
				"name": "高县",
				"parent_id": 511500,
				"type": 4,
				"zip": "645150"
			}, {
				"id": 511524,
				"name": "长宁县",
				"parent_id": 511500,
				"type": 4,
				"zip": "644300"
			}, {
				"id": 511527,
				"name": "筠连县",
				"parent_id": 511500,
				"type": 4,
				"zip": "645250"
			}, {
				"id": 511526,
				"name": "珙县",
				"parent_id": 511500,
				"type": 4,
				"zip": "644500"
			}, {
				"id": 511521,
				"name": "宜宾县",
				"parent_id": 511500,
				"type": 4,
				"zip": "644600"
			}, {
				"id": 511523,
				"name": "江安县",
				"parent_id": 511500,
				"type": 4,
				"zip": "644200"
			}, {
				"id": 511522,
				"name": "南溪区",
				"parent_id": 511500,
				"type": 4,
				"zip": "644100"
			}, {
				"id": 511529,
				"name": "屏山县",
				"parent_id": 511500,
				"type": 4,
				"zip": "645350"
			}, {
				"id": 511528,
				"name": "兴文县",
				"parent_id": 511500,
				"type": 4,
				"zip": "644400"
			}, {
				"id": 511530,
				"name": "其它区",
				"parent_id": 511500,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 511600,
			"name": "广安市",
			"parent_id": 510000,
			"type": 3,
			"zip": "638000",
			"district": [{
				"id": 511602,
				"name": "广安区",
				"parent_id": 511600,
				"type": 4,
				"zip": "638550"
			}, {
				"id": 511603,
				"name": "前锋区",
				"parent_id": 511600,
				"type": 4,
				"zip": ""
			}, {
				"id": 511622,
				"name": "武胜县",
				"parent_id": 511600,
				"type": 4,
				"zip": "638420"
			}, {
				"id": 511623,
				"name": "邻水县",
				"parent_id": 511600,
				"type": 4,
				"zip": "638520"
			}, {
				"id": 511621,
				"name": "岳池县",
				"parent_id": 511600,
				"type": 4,
				"zip": "638300"
			}, {
				"id": 511682,
				"name": "市辖区",
				"parent_id": 511600,
				"type": 4,
				"zip": ""
			}, {
				"id": 511683,
				"name": "其它区",
				"parent_id": 511600,
				"type": 4,
				"zip": ""
			}, {
				"id": 511681,
				"name": "华蓥市",
				"parent_id": 511600,
				"type": 4,
				"zip": "638650"
			}]
		}, {
			"id": 511700,
			"name": "达州市",
			"parent_id": 510000,
			"type": 3,
			"zip": "635000",
			"district": [{
				"id": 511782,
				"name": "其它区",
				"parent_id": 511700,
				"type": 4,
				"zip": ""
			}, {
				"id": 511781,
				"name": "万源市",
				"parent_id": 511700,
				"type": 4,
				"zip": "636350"
			}, {
				"id": 511702,
				"name": "通川区",
				"parent_id": 511700,
				"type": 4,
				"zip": "635000"
			}, {
				"id": 511721,
				"name": "达川区",
				"parent_id": 511700,
				"type": 4,
				"zip": "635006"
			}, {
				"id": 511722,
				"name": "宣汉县",
				"parent_id": 511700,
				"type": 4,
				"zip": "636150"
			}, {
				"id": 511723,
				"name": "开江县",
				"parent_id": 511700,
				"type": 4,
				"zip": "636250"
			}, {
				"id": 511724,
				"name": "大竹县",
				"parent_id": 511700,
				"type": 4,
				"zip": "635100"
			}, {
				"id": 511725,
				"name": "渠县",
				"parent_id": 511700,
				"type": 4,
				"zip": "635200"
			}]
		}, {
			"id": 511300,
			"name": "南充市",
			"parent_id": 510000,
			"type": 3,
			"zip": "637000",
			"district": [{
				"id": 511324,
				"name": "仪陇县",
				"parent_id": 511300,
				"type": 4,
				"zip": "637600"
			}, {
				"id": 511325,
				"name": "西充县",
				"parent_id": 511300,
				"type": 4,
				"zip": "637200"
			}, {
				"id": 511321,
				"name": "南部县",
				"parent_id": 511300,
				"type": 4,
				"zip": "637300"
			}, {
				"id": 511322,
				"name": "营山县",
				"parent_id": 511300,
				"type": 4,
				"zip": "638150"
			}, {
				"id": 511323,
				"name": "蓬安县",
				"parent_id": 511300,
				"type": 4,
				"zip": "638250"
			}, {
				"id": 511303,
				"name": "高坪区",
				"parent_id": 511300,
				"type": 4,
				"zip": "637100"
			}, {
				"id": 511302,
				"name": "顺庆区",
				"parent_id": 511300,
				"type": 4,
				"zip": "637500"
			}, {
				"id": 511304,
				"name": "嘉陵区",
				"parent_id": 511300,
				"type": 4,
				"zip": "637900"
			}, {
				"id": 511381,
				"name": "阆中市",
				"parent_id": 511300,
				"type": 4,
				"zip": "637400"
			}, {
				"id": 511382,
				"name": "其它区",
				"parent_id": 511300,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 511400,
			"name": "眉山市",
			"parent_id": 510000,
			"type": 3,
			"zip": "620000",
			"district": [{
				"id": 511423,
				"name": "洪雅县",
				"parent_id": 511400,
				"type": 4,
				"zip": "620360"
			}, {
				"id": 511422,
				"name": "彭山县",
				"parent_id": 511400,
				"type": 4,
				"zip": "620860"
			}, {
				"id": 511421,
				"name": "仁寿县",
				"parent_id": 511400,
				"type": 4,
				"zip": "620500"
			}, {
				"id": 511402,
				"name": "东坡区",
				"parent_id": 511400,
				"type": 4,
				"zip": "620010"
			}, {
				"id": 511424,
				"name": "丹棱县",
				"parent_id": 511400,
				"type": 4,
				"zip": "620200"
			}, {
				"id": 511425,
				"name": "青神县",
				"parent_id": 511400,
				"type": 4,
				"zip": "620460"
			}, {
				"id": 511426,
				"name": "其它区",
				"parent_id": 511400,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 511000,
			"name": "内江市",
			"parent_id": 510000,
			"type": 3,
			"zip": "641000",
			"district": [{
				"id": 511011,
				"name": "东兴区",
				"parent_id": 511000,
				"type": 4,
				"zip": "641100"
			}, {
				"id": 511024,
				"name": "威远县",
				"parent_id": 511000,
				"type": 4,
				"zip": "642450"
			}, {
				"id": 511025,
				"name": "资中县",
				"parent_id": 511000,
				"type": 4,
				"zip": "641200"
			}, {
				"id": 511028,
				"name": "隆昌县",
				"parent_id": 511000,
				"type": 4,
				"zip": "642150"
			}, {
				"id": 511029,
				"name": "其它区",
				"parent_id": 511000,
				"type": 4,
				"zip": ""
			}, {
				"id": 511002,
				"name": "市中区",
				"parent_id": 511000,
				"type": 4,
				"zip": "641000"
			}]
		}, {
			"id": 511100,
			"name": "乐山市",
			"parent_id": 510000,
			"type": 3,
			"zip": "614000",
			"district": [{
				"id": 511102,
				"name": "市中区",
				"parent_id": 511100,
				"type": 4,
				"zip": "614000"
			}, {
				"id": 511112,
				"name": "五通桥区",
				"parent_id": 511100,
				"type": 4,
				"zip": "614800"
			}, {
				"id": 511113,
				"name": "金口河区",
				"parent_id": 511100,
				"type": 4,
				"zip": "614700"
			}, {
				"id": 511111,
				"name": "沙湾区",
				"parent_id": 511100,
				"type": 4,
				"zip": "614900"
			}, {
				"id": 511129,
				"name": "沐川县",
				"parent_id": 511100,
				"type": 4,
				"zip": "614500"
			}, {
				"id": 511133,
				"name": "马边彝族自治县",
				"parent_id": 511100,
				"type": 4,
				"zip": "614600"
			}, {
				"id": 511132,
				"name": "峨边彝族自治县",
				"parent_id": 511100,
				"type": 4,
				"zip": "614300"
			}, {
				"id": 511123,
				"name": "犍为县",
				"parent_id": 511100,
				"type": 4,
				"zip": "614400"
			}, {
				"id": 511126,
				"name": "夹江县",
				"parent_id": 511100,
				"type": 4,
				"zip": "614100"
			}, {
				"id": 511124,
				"name": "井研县",
				"parent_id": 511100,
				"type": 4,
				"zip": "613100"
			}, {
				"id": 511182,
				"name": "其它区",
				"parent_id": 511100,
				"type": 4,
				"zip": ""
			}, {
				"id": 511181,
				"name": "峨眉山市",
				"parent_id": 511100,
				"type": 4,
				"zip": "614200"
			}]
		}]
	}, {
		"id": 230000,
		"name": "黑龙江省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 232700,
			"name": "大兴安岭地区",
			"parent_id": 230000,
			"type": 3,
			"zip": "165000",
			"district": [{
				"id": 232721,
				"name": "呼玛县",
				"parent_id": 232700,
				"type": 4,
				"zip": "165100"
			}, {
				"id": 232722,
				"name": "塔河县",
				"parent_id": 232700,
				"type": 4,
				"zip": "165200"
			}, {
				"id": 232723,
				"name": "漠河县",
				"parent_id": 232700,
				"type": 4,
				"zip": "165300"
			}, {
				"id": 232724,
				"name": "加格达奇区",
				"parent_id": 232700,
				"type": 4,
				"zip": "165300"
			}, {
				"id": 232725,
				"name": "其它区",
				"parent_id": 232700,
				"type": 4,
				"zip": ""
			}, {
				"id": 232704,
				"name": "呼中区",
				"parent_id": 232700,
				"type": 4,
				"zip": ""
			}, {
				"id": 232703,
				"name": "新林区",
				"parent_id": 232700,
				"type": 4,
				"zip": ""
			}, {
				"id": 232702,
				"name": "松岭区",
				"parent_id": 232700,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 231200,
			"name": "绥化市",
			"parent_id": 230000,
			"type": 3,
			"zip": "152000",
			"district": [{
				"id": 231282,
				"name": "肇东市",
				"parent_id": 231200,
				"type": 4,
				"zip": "151100"
			}, {
				"id": 231283,
				"name": "海伦市",
				"parent_id": 231200,
				"type": 4,
				"zip": "152300"
			}, {
				"id": 231281,
				"name": "安达市",
				"parent_id": 231200,
				"type": 4,
				"zip": "151400"
			}, {
				"id": 231284,
				"name": "其它区",
				"parent_id": 231200,
				"type": 4,
				"zip": ""
			}, {
				"id": 231202,
				"name": "北林区",
				"parent_id": 231200,
				"type": 4,
				"zip": "152000"
			}, {
				"id": 231222,
				"name": "兰西县",
				"parent_id": 231200,
				"type": 4,
				"zip": "151500"
			}, {
				"id": 231223,
				"name": "青冈县",
				"parent_id": 231200,
				"type": 4,
				"zip": "151600"
			}, {
				"id": 231221,
				"name": "望奎县",
				"parent_id": 231200,
				"type": 4,
				"zip": "152100"
			}, {
				"id": 231226,
				"name": "绥棱县",
				"parent_id": 231200,
				"type": 4,
				"zip": "152200"
			}, {
				"id": 231224,
				"name": "庆安县",
				"parent_id": 231200,
				"type": 4,
				"zip": "152400"
			}, {
				"id": 231225,
				"name": "明水县",
				"parent_id": 231200,
				"type": 4,
				"zip": "151700"
			}]
		}, {
			"id": 231000,
			"name": "牡丹江市",
			"parent_id": 230000,
			"type": 3,
			"zip": "157000",
			"district": [{
				"id": 231002,
				"name": "东安区",
				"parent_id": 231000,
				"type": 4,
				"zip": "157000"
			}, {
				"id": 231003,
				"name": "阳明区",
				"parent_id": 231000,
				"type": 4,
				"zip": "157013"
			}, {
				"id": 231004,
				"name": "爱民区",
				"parent_id": 231000,
				"type": 4,
				"zip": "157009"
			}, {
				"id": 231005,
				"name": "西安区",
				"parent_id": 231000,
				"type": 4,
				"zip": "157000"
			}, {
				"id": 231024,
				"name": "东宁县",
				"parent_id": 231000,
				"type": 4,
				"zip": "157200"
			}, {
				"id": 231025,
				"name": "林口县",
				"parent_id": 231000,
				"type": 4,
				"zip": "157600"
			}, {
				"id": 231084,
				"name": "宁安市",
				"parent_id": 231000,
				"type": 4,
				"zip": "157400"
			}, {
				"id": 231085,
				"name": "穆棱市",
				"parent_id": 231000,
				"type": 4,
				"zip": "157500"
			}, {
				"id": 231086,
				"name": "其它区",
				"parent_id": 231000,
				"type": 4,
				"zip": ""
			}, {
				"id": 231081,
				"name": "绥芬河市",
				"parent_id": 231000,
				"type": 4,
				"zip": "157300"
			}, {
				"id": 231083,
				"name": "海林市",
				"parent_id": 231000,
				"type": 4,
				"zip": "157100"
			}]
		}, {
			"id": 231100,
			"name": "黑河市",
			"parent_id": 230000,
			"type": 3,
			"zip": "164300",
			"district": [{
				"id": 231181,
				"name": "北安市",
				"parent_id": 231100,
				"type": 4,
				"zip": "164000"
			}, {
				"id": 231183,
				"name": "其它区",
				"parent_id": 231100,
				"type": 4,
				"zip": ""
			}, {
				"id": 231182,
				"name": "五大连池市",
				"parent_id": 231100,
				"type": 4,
				"zip": "164100"
			}, {
				"id": 231123,
				"name": "逊克县",
				"parent_id": 231100,
				"type": 4,
				"zip": "164400"
			}, {
				"id": 231121,
				"name": "嫩江县",
				"parent_id": 231100,
				"type": 4,
				"zip": "161400"
			}, {
				"id": 231124,
				"name": "孙吴县",
				"parent_id": 231100,
				"type": 4,
				"zip": "164200"
			}, {
				"id": 231102,
				"name": "爱辉区",
				"parent_id": 231100,
				"type": 4,
				"zip": "164300"
			}]
		}, {
			"id": 230700,
			"name": "伊春市",
			"parent_id": 230000,
			"type": 3,
			"zip": "153000",
			"district": [{
				"id": 230782,
				"name": "其它区",
				"parent_id": 230700,
				"type": 4,
				"zip": ""
			}, {
				"id": 230781,
				"name": "铁力市",
				"parent_id": 230700,
				"type": 4,
				"zip": "152500"
			}, {
				"id": 230722,
				"name": "嘉荫县",
				"parent_id": 230700,
				"type": 4,
				"zip": "153200"
			}, {
				"id": 230703,
				"name": "南岔区",
				"parent_id": 230700,
				"type": 4,
				"zip": "153100"
			}, {
				"id": 230702,
				"name": "伊春区",
				"parent_id": 230700,
				"type": 4,
				"zip": "153000"
			}, {
				"id": 230706,
				"name": "翠峦区",
				"parent_id": 230700,
				"type": 4,
				"zip": "153013"
			}, {
				"id": 230707,
				"name": "新青区",
				"parent_id": 230700,
				"type": 4,
				"zip": "153036"
			}, {
				"id": 230704,
				"name": "友好区",
				"parent_id": 230700,
				"type": 4,
				"zip": "153031"
			}, {
				"id": 230705,
				"name": "西林区",
				"parent_id": 230700,
				"type": 4,
				"zip": "153025"
			}, {
				"id": 230710,
				"name": "五营区",
				"parent_id": 230700,
				"type": 4,
				"zip": "153033"
			}, {
				"id": 230711,
				"name": "乌马河区",
				"parent_id": 230700,
				"type": 4,
				"zip": "153011"
			}, {
				"id": 230708,
				"name": "美溪区",
				"parent_id": 230700,
				"type": 4,
				"zip": "153021"
			}, {
				"id": 230709,
				"name": "金山屯区",
				"parent_id": 230700,
				"type": 4,
				"zip": "152026"
			}, {
				"id": 230714,
				"name": "乌伊岭区",
				"parent_id": 230700,
				"type": 4,
				"zip": "153038"
			}, {
				"id": 230715,
				"name": "红星区",
				"parent_id": 230700,
				"type": 4,
				"zip": "153035"
			}, {
				"id": 230712,
				"name": "汤旺河区",
				"parent_id": 230700,
				"type": 4,
				"zip": "153037"
			}, {
				"id": 230713,
				"name": "带岭区",
				"parent_id": 230700,
				"type": 4,
				"zip": "153106"
			}, {
				"id": 230716,
				"name": "上甘岭区",
				"parent_id": 230700,
				"type": 4,
				"zip": "153032"
			}]
		}, {
			"id": 230900,
			"name": "七台河市",
			"parent_id": 230000,
			"type": 3,
			"zip": "154600",
			"district": [{
				"id": 230922,
				"name": "其它区",
				"parent_id": 230900,
				"type": 4,
				"zip": ""
			}, {
				"id": 230921,
				"name": "勃利县",
				"parent_id": 230900,
				"type": 4,
				"zip": "154500"
			}, {
				"id": 230904,
				"name": "茄子河区",
				"parent_id": 230900,
				"type": 4,
				"zip": "154622"
			}, {
				"id": 230903,
				"name": "桃山区",
				"parent_id": 230900,
				"type": 4,
				"zip": "154600"
			}, {
				"id": 230902,
				"name": "新兴区",
				"parent_id": 230900,
				"type": 4,
				"zip": "154604"
			}]
		}, {
			"id": 230800,
			"name": "佳木斯市",
			"parent_id": 230000,
			"type": 3,
			"zip": "154000",
			"district": [{
				"id": 230882,
				"name": "富锦市",
				"parent_id": 230800,
				"type": 4,
				"zip": "156100"
			}, {
				"id": 230883,
				"name": "其它区",
				"parent_id": 230800,
				"type": 4,
				"zip": ""
			}, {
				"id": 230881,
				"name": "同江市",
				"parent_id": 230800,
				"type": 4,
				"zip": "156400"
			}, {
				"id": 230826,
				"name": "桦川县",
				"parent_id": 230800,
				"type": 4,
				"zip": "154300"
			}, {
				"id": 230828,
				"name": "汤原县",
				"parent_id": 230800,
				"type": 4,
				"zip": "154700"
			}, {
				"id": 230822,
				"name": "桦南县",
				"parent_id": 230800,
				"type": 4,
				"zip": "154400"
			}, {
				"id": 230833,
				"name": "抚远县",
				"parent_id": 230800,
				"type": 4,
				"zip": "156500"
			}, {
				"id": 230811,
				"name": "郊区",
				"parent_id": 230800,
				"type": 4,
				"zip": "154004"
			}, {
				"id": 230803,
				"name": "向阳区",
				"parent_id": 230800,
				"type": 4,
				"zip": "154002"
			}, {
				"id": 230802,
				"name": "永红区",
				"parent_id": 230800,
				"type": 4,
				"zip": "154003"
			}, {
				"id": 230805,
				"name": "东风区",
				"parent_id": 230800,
				"type": 4,
				"zip": "154005"
			}, {
				"id": 230804,
				"name": "前进区",
				"parent_id": 230800,
				"type": 4,
				"zip": "154002"
			}]
		}, {
			"id": 230500,
			"name": "双鸭山市",
			"parent_id": 230000,
			"type": 3,
			"zip": "155100",
			"district": [{
				"id": 230524,
				"name": "饶河县",
				"parent_id": 230500,
				"type": 4,
				"zip": "155700"
			}, {
				"id": 230525,
				"name": "其它区",
				"parent_id": 230500,
				"type": 4,
				"zip": ""
			}, {
				"id": 230521,
				"name": "集贤县",
				"parent_id": 230500,
				"type": 4,
				"zip": "155900"
			}, {
				"id": 230522,
				"name": "友谊县",
				"parent_id": 230500,
				"type": 4,
				"zip": "155800"
			}, {
				"id": 230523,
				"name": "宝清县",
				"parent_id": 230500,
				"type": 4,
				"zip": "155600"
			}, {
				"id": 230503,
				"name": "岭东区",
				"parent_id": 230500,
				"type": 4,
				"zip": "155120"
			}, {
				"id": 230502,
				"name": "尖山区",
				"parent_id": 230500,
				"type": 4,
				"zip": "155100"
			}, {
				"id": 230505,
				"name": "四方台区",
				"parent_id": 230500,
				"type": 4,
				"zip": "155130"
			}, {
				"id": 230506,
				"name": "宝山区",
				"parent_id": 230500,
				"type": 4,
				"zip": "155131"
			}]
		}, {
			"id": 230400,
			"name": "鹤岗市",
			"parent_id": 230000,
			"type": 3,
			"zip": "154100",
			"district": [{
				"id": 230422,
				"name": "绥滨县",
				"parent_id": 230400,
				"type": 4,
				"zip": "156200"
			}, {
				"id": 230423,
				"name": "其它区",
				"parent_id": 230400,
				"type": 4,
				"zip": ""
			}, {
				"id": 230421,
				"name": "萝北县",
				"parent_id": 230400,
				"type": 4,
				"zip": "154200"
			}, {
				"id": 230403,
				"name": "工农区",
				"parent_id": 230400,
				"type": 4,
				"zip": "154101"
			}, {
				"id": 230402,
				"name": "向阳区",
				"parent_id": 230400,
				"type": 4,
				"zip": "154100"
			}, {
				"id": 230407,
				"name": "兴山区",
				"parent_id": 230400,
				"type": 4,
				"zip": "154105"
			}, {
				"id": 230406,
				"name": "东山区",
				"parent_id": 230400,
				"type": 4,
				"zip": "154106"
			}, {
				"id": 230405,
				"name": "兴安区",
				"parent_id": 230400,
				"type": 4,
				"zip": "154102"
			}, {
				"id": 230404,
				"name": "南山区",
				"parent_id": 230400,
				"type": 4,
				"zip": "154104"
			}]
		}, {
			"id": 230600,
			"name": "大庆市",
			"parent_id": 230000,
			"type": 3,
			"zip": "163000",
			"district": [{
				"id": 230624,
				"name": "杜尔伯特蒙古族自治县",
				"parent_id": 230600,
				"type": 4,
				"zip": "166200"
			}, {
				"id": 230625,
				"name": "其它区",
				"parent_id": 230600,
				"type": 4,
				"zip": ""
			}, {
				"id": 230623,
				"name": "林甸县",
				"parent_id": 230600,
				"type": 4,
				"zip": "166300"
			}, {
				"id": 230622,
				"name": "肇源县",
				"parent_id": 230600,
				"type": 4,
				"zip": "166500"
			}, {
				"id": 230621,
				"name": "肇州县",
				"parent_id": 230600,
				"type": 4,
				"zip": "166400"
			}, {
				"id": 230606,
				"name": "大同区",
				"parent_id": 230600,
				"type": 4,
				"zip": "163814"
			}, {
				"id": 230604,
				"name": "让胡路区",
				"parent_id": 230600,
				"type": 4,
				"zip": "163453"
			}, {
				"id": 230605,
				"name": "红岗区",
				"parent_id": 230600,
				"type": 4,
				"zip": "163512"
			}, {
				"id": 230602,
				"name": "萨尔图区",
				"parent_id": 230600,
				"type": 4,
				"zip": "163311"
			}, {
				"id": 230603,
				"name": "龙凤区",
				"parent_id": 230600,
				"type": 4,
				"zip": "163711"
			}]
		}, {
			"id": 230200,
			"name": "齐齐哈尔市",
			"parent_id": 230000,
			"type": 3,
			"zip": "161000",
			"district": [{
				"id": 230206,
				"name": "富拉尔基区",
				"parent_id": 230200,
				"type": 4,
				"zip": "161041"
			}, {
				"id": 230207,
				"name": "碾子山区",
				"parent_id": 230200,
				"type": 4,
				"zip": "161046"
			}, {
				"id": 230204,
				"name": "铁锋区",
				"parent_id": 230200,
				"type": 4,
				"zip": "161000"
			}, {
				"id": 230205,
				"name": "昂昂溪区",
				"parent_id": 230200,
				"type": 4,
				"zip": "161031"
			}, {
				"id": 230202,
				"name": "龙沙区",
				"parent_id": 230200,
				"type": 4,
				"zip": "161000"
			}, {
				"id": 230203,
				"name": "建华区",
				"parent_id": 230200,
				"type": 4,
				"zip": "161006"
			}, {
				"id": 230221,
				"name": "龙江县",
				"parent_id": 230200,
				"type": 4,
				"zip": "161100"
			}, {
				"id": 230223,
				"name": "依安县",
				"parent_id": 230200,
				"type": 4,
				"zip": "161500"
			}, {
				"id": 230208,
				"name": "梅里斯达斡尔族区",
				"parent_id": 230200,
				"type": 4,
				"zip": "161021"
			}, {
				"id": 230224,
				"name": "泰来县",
				"parent_id": 230200,
				"type": 4,
				"zip": "162400"
			}, {
				"id": 230225,
				"name": "甘南县",
				"parent_id": 230200,
				"type": 4,
				"zip": "162100"
			}, {
				"id": 230227,
				"name": "富裕县",
				"parent_id": 230200,
				"type": 4,
				"zip": "161200"
			}, {
				"id": 230229,
				"name": "克山县",
				"parent_id": 230200,
				"type": 4,
				"zip": "161600"
			}, {
				"id": 230230,
				"name": "克东县",
				"parent_id": 230200,
				"type": 4,
				"zip": "164800"
			}, {
				"id": 230231,
				"name": "拜泉县",
				"parent_id": 230200,
				"type": 4,
				"zip": "164700"
			}, {
				"id": 230281,
				"name": "讷河市",
				"parent_id": 230200,
				"type": 4,
				"zip": "161300"
			}, {
				"id": 230282,
				"name": "其它区",
				"parent_id": 230200,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 230300,
			"name": "鸡西市",
			"parent_id": 230000,
			"type": 3,
			"zip": "158100",
			"district": [{
				"id": 230303,
				"name": "恒山区",
				"parent_id": 230300,
				"type": 4,
				"zip": "158130"
			}, {
				"id": 230302,
				"name": "鸡冠区",
				"parent_id": 230300,
				"type": 4,
				"zip": "158100"
			}, {
				"id": 230306,
				"name": "城子河区",
				"parent_id": 230300,
				"type": 4,
				"zip": "158170"
			}, {
				"id": 230307,
				"name": "麻山区",
				"parent_id": 230300,
				"type": 4,
				"zip": "158180"
			}, {
				"id": 230304,
				"name": "滴道区",
				"parent_id": 230300,
				"type": 4,
				"zip": "158150"
			}, {
				"id": 230305,
				"name": "梨树区",
				"parent_id": 230300,
				"type": 4,
				"zip": "158160"
			}, {
				"id": 230321,
				"name": "鸡东县",
				"parent_id": 230300,
				"type": 4,
				"zip": "158200"
			}, {
				"id": 230382,
				"name": "密山市",
				"parent_id": 230300,
				"type": 4,
				"zip": "158300"
			}, {
				"id": 230383,
				"name": "其它区",
				"parent_id": 230300,
				"type": 4,
				"zip": ""
			}, {
				"id": 230381,
				"name": "虎林市",
				"parent_id": 230300,
				"type": 4,
				"zip": "158400"
			}]
		}, {
			"id": 230100,
			"name": "哈尔滨市",
			"parent_id": 230000,
			"type": 3,
			"zip": "150000",
			"district": [{
				"id": 230186,
				"name": "其它区",
				"parent_id": 230100,
				"type": 4,
				"zip": ""
			}, {
				"id": 230185,
				"name": "阿城市",
				"parent_id": 230100,
				"type": 4,
				"zip": "150300"
			}, {
				"id": 230184,
				"name": "五常市",
				"parent_id": 230100,
				"type": 4,
				"zip": "150200"
			}, {
				"id": 230183,
				"name": "尚志市",
				"parent_id": 230100,
				"type": 4,
				"zip": "150600"
			}, {
				"id": 230182,
				"name": "双城市",
				"parent_id": 230100,
				"type": 4,
				"zip": "150100"
			}, {
				"id": 230181,
				"name": "阿城区",
				"parent_id": 230100,
				"type": 4,
				"zip": "150300"
			}, {
				"id": 230103,
				"name": "南岗区",
				"parent_id": 230100,
				"type": 4,
				"zip": "150006"
			}, {
				"id": 230102,
				"name": "道里区",
				"parent_id": 230100,
				"type": 4,
				"zip": "150010"
			}, {
				"id": 230107,
				"name": "动力区",
				"parent_id": 230100,
				"type": 4,
				"zip": "150040"
			}, {
				"id": 230106,
				"name": "香坊区",
				"parent_id": 230100,
				"type": 4,
				"zip": "150036"
			}, {
				"id": 230104,
				"name": "道外区",
				"parent_id": 230100,
				"type": 4,
				"zip": "150026"
			}, {
				"id": 230111,
				"name": "呼兰区",
				"parent_id": 230100,
				"type": 4,
				"zip": "150500"
			}, {
				"id": 230109,
				"name": "松北区",
				"parent_id": 230100,
				"type": 4,
				"zip": "150028"
			}, {
				"id": 230108,
				"name": "平房区",
				"parent_id": 230100,
				"type": 4,
				"zip": "150060"
			}, {
				"id": 230129,
				"name": "延寿县",
				"parent_id": 230100,
				"type": 4,
				"zip": "150700"
			}, {
				"id": 230128,
				"name": "通河县",
				"parent_id": 230100,
				"type": 4,
				"zip": "150900"
			}, {
				"id": 230123,
				"name": "依兰县",
				"parent_id": 230100,
				"type": 4,
				"zip": "154800"
			}, {
				"id": 230124,
				"name": "方正县",
				"parent_id": 230100,
				"type": 4,
				"zip": "150800"
			}, {
				"id": 230125,
				"name": "宾县",
				"parent_id": 230100,
				"type": 4,
				"zip": "150400"
			}, {
				"id": 230126,
				"name": "巴彦县",
				"parent_id": 230100,
				"type": 4,
				"zip": "151800"
			}, {
				"id": 230127,
				"name": "木兰县",
				"parent_id": 230100,
				"type": 4,
				"zip": "151900"
			}]
		}]
	}, {
		"id": 450000,
		"name": "广西壮族自治区",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 451400,
			"name": "崇左市",
			"parent_id": 450000,
			"type": 3,
			"zip": "532200",
			"district": [{
				"id": 451482,
				"name": "其它区",
				"parent_id": 451400,
				"type": 4,
				"zip": ""
			}, {
				"id": 451481,
				"name": "凭祥市",
				"parent_id": 451400,
				"type": 4,
				"zip": "532600"
			}, {
				"id": 451423,
				"name": "龙州县",
				"parent_id": 451400,
				"type": 4,
				"zip": "532400"
			}, {
				"id": 451422,
				"name": "宁明县",
				"parent_id": 451400,
				"type": 4,
				"zip": "532500"
			}, {
				"id": 451421,
				"name": "扶绥县",
				"parent_id": 451400,
				"type": 4,
				"zip": "532100"
			}, {
				"id": 451402,
				"name": "江州区",
				"parent_id": 451400,
				"type": 4,
				"zip": "532200"
			}, {
				"id": 451424,
				"name": "大新县",
				"parent_id": 451400,
				"type": 4,
				"zip": "532300"
			}, {
				"id": 451425,
				"name": "天等县",
				"parent_id": 451400,
				"type": 4,
				"zip": "532800"
			}]
		}, {
			"id": 451200,
			"name": "河池市",
			"parent_id": 450000,
			"type": 3,
			"zip": "547000",
			"district": [{
				"id": 451202,
				"name": "金城江区",
				"parent_id": 451200,
				"type": 4,
				"zip": "547000"
			}, {
				"id": 451221,
				"name": "南丹县",
				"parent_id": 451200,
				"type": 4,
				"zip": "547200"
			}, {
				"id": 451222,
				"name": "天峨县",
				"parent_id": 451200,
				"type": 4,
				"zip": "547300"
			}, {
				"id": 451223,
				"name": "凤山县",
				"parent_id": 451200,
				"type": 4,
				"zip": "547600"
			}, {
				"id": 451228,
				"name": "都安瑶族自治县",
				"parent_id": 451200,
				"type": 4,
				"zip": "530700"
			}, {
				"id": 451229,
				"name": "大化瑶族自治县",
				"parent_id": 451200,
				"type": 4,
				"zip": "530800"
			}, {
				"id": 451224,
				"name": "东兰县",
				"parent_id": 451200,
				"type": 4,
				"zip": "547400"
			}, {
				"id": 451225,
				"name": "罗城仫佬族自治县",
				"parent_id": 451200,
				"type": 4,
				"zip": "546400"
			}, {
				"id": 451226,
				"name": "环江毛南族自治县",
				"parent_id": 451200,
				"type": 4,
				"zip": "547100"
			}, {
				"id": 451227,
				"name": "巴马瑶族自治县",
				"parent_id": 451200,
				"type": 4,
				"zip": "547500"
			}, {
				"id": 451281,
				"name": "宜州市",
				"parent_id": 451200,
				"type": 4,
				"zip": "546300"
			}, {
				"id": 451282,
				"name": "其它区",
				"parent_id": 451200,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 451300,
			"name": "来宾市",
			"parent_id": 450000,
			"type": 3,
			"zip": "546100",
			"district": [{
				"id": 451381,
				"name": "合山市",
				"parent_id": 451300,
				"type": 4,
				"zip": "546500"
			}, {
				"id": 451382,
				"name": "其它区",
				"parent_id": 451300,
				"type": 4,
				"zip": ""
			}, {
				"id": 451302,
				"name": "兴宾区",
				"parent_id": 451300,
				"type": 4,
				"zip": "546100"
			}, {
				"id": 451322,
				"name": "象州县",
				"parent_id": 451300,
				"type": 4,
				"zip": "545800"
			}, {
				"id": 451323,
				"name": "武宣县",
				"parent_id": 451300,
				"type": 4,
				"zip": "545900"
			}, {
				"id": 451321,
				"name": "忻城县",
				"parent_id": 451300,
				"type": 4,
				"zip": "546200"
			}, {
				"id": 451324,
				"name": "金秀瑶族自治县",
				"parent_id": 451300,
				"type": 4,
				"zip": "545700"
			}]
		}, {
			"id": 451100,
			"name": "贺州市",
			"parent_id": 450000,
			"type": 3,
			"zip": "542800",
			"district": [{
				"id": 451102,
				"name": "八步区",
				"parent_id": 451100,
				"type": 4,
				"zip": "542800"
			}, {
				"id": 451119,
				"name": "平桂管理区",
				"parent_id": 451100,
				"type": 4,
				"zip": ""
			}, {
				"id": 451124,
				"name": "其它区",
				"parent_id": 451100,
				"type": 4,
				"zip": ""
			}, {
				"id": 451123,
				"name": "富川瑶族自治县",
				"parent_id": 451100,
				"type": 4,
				"zip": "542700"
			}, {
				"id": 451122,
				"name": "钟山县",
				"parent_id": 451100,
				"type": 4,
				"zip": "542600"
			}, {
				"id": 451121,
				"name": "昭平县",
				"parent_id": 451100,
				"type": 4,
				"zip": "546800"
			}]
		}, {
			"id": 451000,
			"name": "百色市",
			"parent_id": 450000,
			"type": 3,
			"zip": "533000",
			"district": [{
				"id": 451002,
				"name": "右江区",
				"parent_id": 451000,
				"type": 4,
				"zip": "533000"
			}, {
				"id": 451030,
				"name": "西林县",
				"parent_id": 451000,
				"type": 4,
				"zip": "533500"
			}, {
				"id": 451031,
				"name": "隆林各族自治县",
				"parent_id": 451000,
				"type": 4,
				"zip": "533400"
			}, {
				"id": 451028,
				"name": "乐业县",
				"parent_id": 451000,
				"type": 4,
				"zip": "533200"
			}, {
				"id": 451029,
				"name": "田林县",
				"parent_id": 451000,
				"type": 4,
				"zip": "533300"
			}, {
				"id": 451026,
				"name": "那坡县",
				"parent_id": 451000,
				"type": 4,
				"zip": "533900"
			}, {
				"id": 451027,
				"name": "凌云县",
				"parent_id": 451000,
				"type": 4,
				"zip": "533100"
			}, {
				"id": 451024,
				"name": "德保县",
				"parent_id": 451000,
				"type": 4,
				"zip": "533700"
			}, {
				"id": 451025,
				"name": "靖西县",
				"parent_id": 451000,
				"type": 4,
				"zip": "533800"
			}, {
				"id": 451032,
				"name": "其它区",
				"parent_id": 451000,
				"type": 4,
				"zip": ""
			}, {
				"id": 451023,
				"name": "平果县",
				"parent_id": 451000,
				"type": 4,
				"zip": "531400"
			}, {
				"id": 451022,
				"name": "田东县",
				"parent_id": 451000,
				"type": 4,
				"zip": "531500"
			}, {
				"id": 451021,
				"name": "田阳县",
				"parent_id": 451000,
				"type": 4,
				"zip": "533600"
			}]
		}, {
			"id": 450900,
			"name": "玉林市",
			"parent_id": 450000,
			"type": 3,
			"zip": "537000",
			"district": [{
				"id": 450981,
				"name": "北流市",
				"parent_id": 450900,
				"type": 4,
				"zip": "537400"
			}, {
				"id": 450982,
				"name": "其它区",
				"parent_id": 450900,
				"type": 4,
				"zip": ""
			}, {
				"id": 450924,
				"name": "兴业县",
				"parent_id": 450900,
				"type": 4,
				"zip": "537800"
			}, {
				"id": 450921,
				"name": "容县",
				"parent_id": 450900,
				"type": 4,
				"zip": "537500"
			}, {
				"id": 450922,
				"name": "陆川县",
				"parent_id": 450900,
				"type": 4,
				"zip": "537700"
			}, {
				"id": 450923,
				"name": "博白县",
				"parent_id": 450900,
				"type": 4,
				"zip": "537600"
			}, {
				"id": 450903,
				"name": "福绵区",
				"parent_id": 450900,
				"type": 4,
				"zip": ""
			}, {
				"id": 450902,
				"name": "玉州区",
				"parent_id": 450900,
				"type": 4,
				"zip": "537000"
			}]
		}, {
			"id": 450700,
			"name": "钦州市",
			"parent_id": 450000,
			"type": 3,
			"zip": "535000",
			"district": [{
				"id": 450723,
				"name": "其它区",
				"parent_id": 450700,
				"type": 4,
				"zip": ""
			}, {
				"id": 450722,
				"name": "浦北县",
				"parent_id": 450700,
				"type": 4,
				"zip": "535300"
			}, {
				"id": 450721,
				"name": "灵山县",
				"parent_id": 450700,
				"type": 4,
				"zip": "535400"
			}, {
				"id": 450703,
				"name": "钦北区",
				"parent_id": 450700,
				"type": 4,
				"zip": "535000"
			}, {
				"id": 450702,
				"name": "钦南区",
				"parent_id": 450700,
				"type": 4,
				"zip": "535000"
			}]
		}, {
			"id": 450800,
			"name": "贵港市",
			"parent_id": 450000,
			"type": 3,
			"zip": "537100",
			"district": [{
				"id": 450821,
				"name": "平南县",
				"parent_id": 450800,
				"type": 4,
				"zip": "537300"
			}, {
				"id": 450882,
				"name": "其它区",
				"parent_id": 450800,
				"type": 4,
				"zip": ""
			}, {
				"id": 450881,
				"name": "桂平市",
				"parent_id": 450800,
				"type": 4,
				"zip": "537200"
			}, {
				"id": 450804,
				"name": "覃塘区",
				"parent_id": 450800,
				"type": 4,
				"zip": "537121"
			}, {
				"id": 450802,
				"name": "港北区",
				"parent_id": 450800,
				"type": 4,
				"zip": "537100"
			}, {
				"id": 450803,
				"name": "港南区",
				"parent_id": 450800,
				"type": 4,
				"zip": "537132"
			}]
		}, {
			"id": 450600,
			"name": "防城港市",
			"parent_id": 450000,
			"type": 3,
			"zip": "538000",
			"district": [{
				"id": 450602,
				"name": "港口区",
				"parent_id": 450600,
				"type": 4,
				"zip": "538001"
			}, {
				"id": 450603,
				"name": "防城区",
				"parent_id": 450600,
				"type": 4,
				"zip": "538021"
			}, {
				"id": 450621,
				"name": "上思县",
				"parent_id": 450600,
				"type": 4,
				"zip": "535500"
			}, {
				"id": 450682,
				"name": "其它区",
				"parent_id": 450600,
				"type": 4,
				"zip": ""
			}, {
				"id": 450681,
				"name": "东兴市",
				"parent_id": 450600,
				"type": 4,
				"zip": "538100"
			}]
		}, {
			"id": 450100,
			"name": "南宁市",
			"parent_id": 450000,
			"type": 3,
			"zip": "530000",
			"district": [{
				"id": 450102,
				"name": "兴宁区",
				"parent_id": 450100,
				"type": 4,
				"zip": "530012"
			}, {
				"id": 450103,
				"name": "青秀区",
				"parent_id": 450100,
				"type": 4,
				"zip": "530022"
			}, {
				"id": 450108,
				"name": "良庆区",
				"parent_id": 450100,
				"type": 4,
				"zip": "530200"
			}, {
				"id": 450109,
				"name": "邕宁区",
				"parent_id": 450100,
				"type": 4,
				"zip": "530200"
			}, {
				"id": 450105,
				"name": "江南区",
				"parent_id": 450100,
				"type": 4,
				"zip": "530031"
			}, {
				"id": 450107,
				"name": "西乡塘区",
				"parent_id": 450100,
				"type": 4,
				"zip": "530001"
			}, {
				"id": 450128,
				"name": "其它区",
				"parent_id": 450100,
				"type": 4,
				"zip": ""
			}, {
				"id": 450123,
				"name": "隆安县",
				"parent_id": 450100,
				"type": 4,
				"zip": "532700"
			}, {
				"id": 450122,
				"name": "武鸣县",
				"parent_id": 450100,
				"type": 4,
				"zip": "530100"
			}, {
				"id": 450127,
				"name": "横县",
				"parent_id": 450100,
				"type": 4,
				"zip": "530300"
			}, {
				"id": 450126,
				"name": "宾阳县",
				"parent_id": 450100,
				"type": 4,
				"zip": "530400"
			}, {
				"id": 450125,
				"name": "上林县",
				"parent_id": 450100,
				"type": 4,
				"zip": "530500"
			}, {
				"id": 450124,
				"name": "马山县",
				"parent_id": 450100,
				"type": 4,
				"zip": "530600"
			}]
		}, {
			"id": 450200,
			"name": "柳州市",
			"parent_id": 450000,
			"type": 3,
			"zip": "545000",
			"district": [{
				"id": 450225,
				"name": "融水苗族自治县",
				"parent_id": 450200,
				"type": 4,
				"zip": "545300"
			}, {
				"id": 450224,
				"name": "融安县",
				"parent_id": 450200,
				"type": 4,
				"zip": "545400"
			}, {
				"id": 450227,
				"name": "其它区",
				"parent_id": 450200,
				"type": 4,
				"zip": ""
			}, {
				"id": 450226,
				"name": "三江侗族自治县",
				"parent_id": 450200,
				"type": 4,
				"zip": "545500"
			}, {
				"id": 450221,
				"name": "柳江县",
				"parent_id": 450200,
				"type": 4,
				"zip": "545100"
			}, {
				"id": 450222,
				"name": "柳城县",
				"parent_id": 450200,
				"type": 4,
				"zip": "545200"
			}, {
				"id": 450223,
				"name": "鹿寨县",
				"parent_id": 450200,
				"type": 4,
				"zip": "545600"
			}, {
				"id": 450205,
				"name": "柳北区",
				"parent_id": 450200,
				"type": 4,
				"zip": "545001"
			}, {
				"id": 450204,
				"name": "柳南区",
				"parent_id": 450200,
				"type": 4,
				"zip": "545005"
			}, {
				"id": 450203,
				"name": "鱼峰区",
				"parent_id": 450200,
				"type": 4,
				"zip": "545005"
			}, {
				"id": 450202,
				"name": "城中区",
				"parent_id": 450200,
				"type": 4,
				"zip": "545001"
			}]
		}, {
			"id": 450300,
			"name": "桂林市",
			"parent_id": 450000,
			"type": 3,
			"zip": "541000",
			"district": [{
				"id": 450303,
				"name": "叠彩区",
				"parent_id": 450300,
				"type": 4,
				"zip": "541001"
			}, {
				"id": 450302,
				"name": "秀峰区",
				"parent_id": 450300,
				"type": 4,
				"zip": "541001"
			}, {
				"id": 450311,
				"name": "雁山区",
				"parent_id": 450300,
				"type": 4,
				"zip": "541006"
			}, {
				"id": 450305,
				"name": "七星区",
				"parent_id": 450300,
				"type": 4,
				"zip": "541004"
			}, {
				"id": 450304,
				"name": "象山区",
				"parent_id": 450300,
				"type": 4,
				"zip": "541002"
			}, {
				"id": 450324,
				"name": "全州县",
				"parent_id": 450300,
				"type": 4,
				"zip": "541500"
			}, {
				"id": 450325,
				"name": "兴安县",
				"parent_id": 450300,
				"type": 4,
				"zip": "541300"
			}, {
				"id": 450326,
				"name": "永福县",
				"parent_id": 450300,
				"type": 4,
				"zip": "541800"
			}, {
				"id": 450327,
				"name": "灌阳县",
				"parent_id": 450300,
				"type": 4,
				"zip": "541600"
			}, {
				"id": 450321,
				"name": "阳朔县",
				"parent_id": 450300,
				"type": 4,
				"zip": "541900"
			}, {
				"id": 450322,
				"name": "临桂区",
				"parent_id": 450300,
				"type": 4,
				"zip": "541100"
			}, {
				"id": 450323,
				"name": "灵川县",
				"parent_id": 450300,
				"type": 4,
				"zip": "541200"
			}, {
				"id": 450332,
				"name": "恭城瑶族自治县",
				"parent_id": 450300,
				"type": 4,
				"zip": "542500"
			}, {
				"id": 450333,
				"name": "其它区",
				"parent_id": 450300,
				"type": 4,
				"zip": ""
			}, {
				"id": 450328,
				"name": "龙胜各族自治县",
				"parent_id": 450300,
				"type": 4,
				"zip": "541700"
			}, {
				"id": 450329,
				"name": "资源县",
				"parent_id": 450300,
				"type": 4,
				"zip": "541400"
			}, {
				"id": 450330,
				"name": "平乐县",
				"parent_id": 450300,
				"type": 4,
				"zip": "542400"
			}, {
				"id": 450331,
				"name": "荔浦县",
				"parent_id": 450300,
				"type": 4,
				"zip": "546600"
			}]
		}, {
			"id": 450400,
			"name": "梧州市",
			"parent_id": 450000,
			"type": 3,
			"zip": "543000",
			"district": [{
				"id": 450403,
				"name": "万秀区",
				"parent_id": 450400,
				"type": 4,
				"zip": "543000"
			}, {
				"id": 450406,
				"name": "龙圩区",
				"parent_id": 450400,
				"type": 4,
				"zip": ""
			}, {
				"id": 450405,
				"name": "长洲区",
				"parent_id": 450400,
				"type": 4,
				"zip": "543002"
			}, {
				"id": 450404,
				"name": "蝶山区",
				"parent_id": 450400,
				"type": 4,
				"zip": "543002"
			}, {
				"id": 450422,
				"name": "藤县",
				"parent_id": 450400,
				"type": 4,
				"zip": "543300"
			}, {
				"id": 450423,
				"name": "蒙山县",
				"parent_id": 450400,
				"type": 4,
				"zip": "546700"
			}, {
				"id": 450421,
				"name": "苍梧县",
				"parent_id": 450400,
				"type": 4,
				"zip": "543100"
			}, {
				"id": 450482,
				"name": "其它区",
				"parent_id": 450400,
				"type": 4,
				"zip": ""
			}, {
				"id": 450481,
				"name": "岑溪市",
				"parent_id": 450400,
				"type": 4,
				"zip": "543200"
			}]
		}, {
			"id": 450500,
			"name": "北海市",
			"parent_id": 450000,
			"type": 3,
			"zip": "536000",
			"district": [{
				"id": 450502,
				"name": "海城区",
				"parent_id": 450500,
				"type": 4,
				"zip": "536000"
			}, {
				"id": 450503,
				"name": "银海区",
				"parent_id": 450500,
				"type": 4,
				"zip": "536000"
			}, {
				"id": 450521,
				"name": "合浦县",
				"parent_id": 450500,
				"type": 4,
				"zip": "536100"
			}, {
				"id": 450522,
				"name": "其它区",
				"parent_id": 450500,
				"type": 4,
				"zip": ""
			}, {
				"id": 450512,
				"name": "铁山港区",
				"parent_id": 450500,
				"type": 4,
				"zip": "536017"
			}]
		}]
	}, {
		"id": 610000,
		"name": "陕西省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 610300,
			"name": "宝鸡市",
			"parent_id": 610000,
			"type": 3,
			"zip": "721000",
			"district": [{
				"id": 610302,
				"name": "渭滨区",
				"parent_id": 610300,
				"type": 4,
				"zip": "721000"
			}, {
				"id": 610303,
				"name": "金台区",
				"parent_id": 610300,
				"type": 4,
				"zip": "721001"
			}, {
				"id": 610332,
				"name": "其它区",
				"parent_id": 610300,
				"type": 4,
				"zip": ""
			}, {
				"id": 610328,
				"name": "千阳县",
				"parent_id": 610300,
				"type": 4,
				"zip": "721100"
			}, {
				"id": 610329,
				"name": "麟游县",
				"parent_id": 610300,
				"type": 4,
				"zip": "721500"
			}, {
				"id": 610330,
				"name": "凤县",
				"parent_id": 610300,
				"type": 4,
				"zip": "721700"
			}, {
				"id": 610331,
				"name": "太白县",
				"parent_id": 610300,
				"type": 4,
				"zip": "721600"
			}, {
				"id": 610324,
				"name": "扶风县",
				"parent_id": 610300,
				"type": 4,
				"zip": "722200"
			}, {
				"id": 610326,
				"name": "眉县",
				"parent_id": 610300,
				"type": 4,
				"zip": "722300"
			}, {
				"id": 610327,
				"name": "陇县",
				"parent_id": 610300,
				"type": 4,
				"zip": "721200"
			}, {
				"id": 610322,
				"name": "凤翔县",
				"parent_id": 610300,
				"type": 4,
				"zip": "721400"
			}, {
				"id": 610323,
				"name": "岐山县",
				"parent_id": 610300,
				"type": 4,
				"zip": "722400"
			}, {
				"id": 610304,
				"name": "陈仓区",
				"parent_id": 610300,
				"type": 4,
				"zip": "721300"
			}]
		}, {
			"id": 610200,
			"name": "铜川市",
			"parent_id": 610000,
			"type": 3,
			"zip": "727000",
			"district": [{
				"id": 610223,
				"name": "其它区",
				"parent_id": 610200,
				"type": 4,
				"zip": ""
			}, {
				"id": 610222,
				"name": "宜君县",
				"parent_id": 610200,
				"type": 4,
				"zip": "727200"
			}, {
				"id": 610202,
				"name": "王益区",
				"parent_id": 610200,
				"type": 4,
				"zip": "727000"
			}, {
				"id": 610203,
				"name": "印台区",
				"parent_id": 610200,
				"type": 4,
				"zip": "727007"
			}, {
				"id": 610204,
				"name": "耀州区",
				"parent_id": 610200,
				"type": 4,
				"zip": "727100"
			}]
		}, {
			"id": 610100,
			"name": "西安市",
			"parent_id": 610000,
			"type": 3,
			"zip": "710000",
			"district": [{
				"id": 610116,
				"name": "长安区",
				"parent_id": 610100,
				"type": 4,
				"zip": "710100"
			}, {
				"id": 610114,
				"name": "阎良区",
				"parent_id": 610100,
				"type": 4,
				"zip": "710089"
			}, {
				"id": 610115,
				"name": "临潼区",
				"parent_id": 610100,
				"type": 4,
				"zip": "710600"
			}, {
				"id": 610112,
				"name": "未央区",
				"parent_id": 610100,
				"type": 4,
				"zip": "710016"
			}, {
				"id": 610113,
				"name": "雁塔区",
				"parent_id": 610100,
				"type": 4,
				"zip": "710061"
			}, {
				"id": 610126,
				"name": "高陵县",
				"parent_id": 610100,
				"type": 4,
				"zip": "710200"
			}, {
				"id": 610127,
				"name": "其它区",
				"parent_id": 610100,
				"type": 4,
				"zip": ""
			}, {
				"id": 610124,
				"name": "周至县",
				"parent_id": 610100,
				"type": 4,
				"zip": "710400"
			}, {
				"id": 610125,
				"name": "户县",
				"parent_id": 610100,
				"type": 4,
				"zip": "710300"
			}, {
				"id": 610122,
				"name": "蓝田县",
				"parent_id": 610100,
				"type": 4,
				"zip": "710500"
			}, {
				"id": 610103,
				"name": "碑林区",
				"parent_id": 610100,
				"type": 4,
				"zip": "710001"
			}, {
				"id": 610102,
				"name": "新城区",
				"parent_id": 610100,
				"type": 4,
				"zip": "710005"
			}, {
				"id": 610104,
				"name": "莲湖区",
				"parent_id": 610100,
				"type": 4,
				"zip": "710003"
			}, {
				"id": 610111,
				"name": "灞桥区",
				"parent_id": 610100,
				"type": 4,
				"zip": "710038"
			}]
		}, {
			"id": 610900,
			"name": "安康市",
			"parent_id": 610000,
			"type": 3,
			"zip": "725000",
			"district": [{
				"id": 610902,
				"name": "汉滨区",
				"parent_id": 610900,
				"type": 4,
				"zip": "725000"
			}, {
				"id": 610930,
				"name": "其它区",
				"parent_id": 610900,
				"type": 4,
				"zip": ""
			}, {
				"id": 610928,
				"name": "旬阳县",
				"parent_id": 610900,
				"type": 4,
				"zip": "725700"
			}, {
				"id": 610929,
				"name": "白河县",
				"parent_id": 610900,
				"type": 4,
				"zip": "725800"
			}, {
				"id": 610927,
				"name": "镇坪县",
				"parent_id": 610900,
				"type": 4,
				"zip": "725600"
			}, {
				"id": 610926,
				"name": "平利县",
				"parent_id": 610900,
				"type": 4,
				"zip": "725500"
			}, {
				"id": 610925,
				"name": "岚皋县",
				"parent_id": 610900,
				"type": 4,
				"zip": "725400"
			}, {
				"id": 610924,
				"name": "紫阳县",
				"parent_id": 610900,
				"type": 4,
				"zip": "725300"
			}, {
				"id": 610923,
				"name": "宁陕县",
				"parent_id": 610900,
				"type": 4,
				"zip": "711600"
			}, {
				"id": 610922,
				"name": "石泉县",
				"parent_id": 610900,
				"type": 4,
				"zip": "725200"
			}, {
				"id": 610921,
				"name": "汉阴县",
				"parent_id": 610900,
				"type": 4,
				"zip": "725100"
			}]
		}, {
			"id": 611000,
			"name": "商洛市",
			"parent_id": 610000,
			"type": 3,
			"zip": "726000",
			"district": [{
				"id": 611002,
				"name": "商州区",
				"parent_id": 611000,
				"type": 4,
				"zip": "726000"
			}, {
				"id": 611025,
				"name": "镇安县",
				"parent_id": 611000,
				"type": 4,
				"zip": "711500"
			}, {
				"id": 611024,
				"name": "山阳县",
				"parent_id": 611000,
				"type": 4,
				"zip": "726400"
			}, {
				"id": 611027,
				"name": "其它区",
				"parent_id": 611000,
				"type": 4,
				"zip": ""
			}, {
				"id": 611026,
				"name": "柞水县",
				"parent_id": 611000,
				"type": 4,
				"zip": "711400"
			}, {
				"id": 611021,
				"name": "洛南县",
				"parent_id": 611000,
				"type": 4,
				"zip": "726100"
			}, {
				"id": 611022,
				"name": "丹凤县",
				"parent_id": 611000,
				"type": 4,
				"zip": "726200"
			}, {
				"id": 611023,
				"name": "商南县",
				"parent_id": 611000,
				"type": 4,
				"zip": "726300"
			}]
		}, {
			"id": 610600,
			"name": "延安市",
			"parent_id": 610000,
			"type": 3,
			"zip": "716000",
			"district": [{
				"id": 610602,
				"name": "宝塔区",
				"parent_id": 610600,
				"type": 4,
				"zip": "716000"
			}, {
				"id": 610621,
				"name": "延长县",
				"parent_id": 610600,
				"type": 4,
				"zip": "717100"
			}, {
				"id": 610622,
				"name": "延川县",
				"parent_id": 610600,
				"type": 4,
				"zip": "717200"
			}, {
				"id": 610623,
				"name": "子长县",
				"parent_id": 610600,
				"type": 4,
				"zip": "717300"
			}, {
				"id": 610633,
				"name": "其它区",
				"parent_id": 610600,
				"type": 4,
				"zip": ""
			}, {
				"id": 610632,
				"name": "黄陵县",
				"parent_id": 610600,
				"type": 4,
				"zip": "727300"
			}, {
				"id": 610627,
				"name": "甘泉县",
				"parent_id": 610600,
				"type": 4,
				"zip": "716100"
			}, {
				"id": 610626,
				"name": "吴起县",
				"parent_id": 610600,
				"type": 4,
				"zip": "717600"
			}, {
				"id": 610625,
				"name": "志丹县",
				"parent_id": 610600,
				"type": 4,
				"zip": "717500"
			}, {
				"id": 610624,
				"name": "安塞县",
				"parent_id": 610600,
				"type": 4,
				"zip": "717400"
			}, {
				"id": 610631,
				"name": "黄龙县",
				"parent_id": 610600,
				"type": 4,
				"zip": "715700"
			}, {
				"id": 610630,
				"name": "宜川县",
				"parent_id": 610600,
				"type": 4,
				"zip": "716200"
			}, {
				"id": 610629,
				"name": "洛川县",
				"parent_id": 610600,
				"type": 4,
				"zip": "727400"
			}, {
				"id": 610628,
				"name": "富县",
				"parent_id": 610600,
				"type": 4,
				"zip": "727500"
			}]
		}, {
			"id": 610700,
			"name": "汉中市",
			"parent_id": 610000,
			"type": 3,
			"zip": "723000",
			"district": [{
				"id": 610724,
				"name": "西乡县",
				"parent_id": 610700,
				"type": 4,
				"zip": "723500"
			}, {
				"id": 610725,
				"name": "勉县",
				"parent_id": 610700,
				"type": 4,
				"zip": "724200"
			}, {
				"id": 610726,
				"name": "宁强县",
				"parent_id": 610700,
				"type": 4,
				"zip": "724400"
			}, {
				"id": 610727,
				"name": "略阳县",
				"parent_id": 610700,
				"type": 4,
				"zip": "724300"
			}, {
				"id": 610721,
				"name": "南郑县",
				"parent_id": 610700,
				"type": 4,
				"zip": "723100"
			}, {
				"id": 610722,
				"name": "城固县",
				"parent_id": 610700,
				"type": 4,
				"zip": "723200"
			}, {
				"id": 610723,
				"name": "洋县",
				"parent_id": 610700,
				"type": 4,
				"zip": "723300"
			}, {
				"id": 610728,
				"name": "镇巴县",
				"parent_id": 610700,
				"type": 4,
				"zip": "723600"
			}, {
				"id": 610729,
				"name": "留坝县",
				"parent_id": 610700,
				"type": 4,
				"zip": "724100"
			}, {
				"id": 610730,
				"name": "佛坪县",
				"parent_id": 610700,
				"type": 4,
				"zip": "723400"
			}, {
				"id": 610731,
				"name": "其它区",
				"parent_id": 610700,
				"type": 4,
				"zip": ""
			}, {
				"id": 610702,
				"name": "汉台区",
				"parent_id": 610700,
				"type": 4,
				"zip": "723000"
			}]
		}, {
			"id": 610800,
			"name": "榆林市",
			"parent_id": 610000,
			"type": 3,
			"zip": "719000",
			"district": [{
				"id": 610832,
				"name": "其它区",
				"parent_id": 610800,
				"type": 4,
				"zip": ""
			}, {
				"id": 610825,
				"name": "定边县",
				"parent_id": 610800,
				"type": 4,
				"zip": "718600"
			}, {
				"id": 610824,
				"name": "靖边县",
				"parent_id": 610800,
				"type": 4,
				"zip": "718500"
			}, {
				"id": 610827,
				"name": "米脂县",
				"parent_id": 610800,
				"type": 4,
				"zip": "718100"
			}, {
				"id": 610826,
				"name": "绥德县",
				"parent_id": 610800,
				"type": 4,
				"zip": "718000"
			}, {
				"id": 610829,
				"name": "吴堡县",
				"parent_id": 610800,
				"type": 4,
				"zip": "718200"
			}, {
				"id": 610828,
				"name": "佳县",
				"parent_id": 610800,
				"type": 4,
				"zip": "719200"
			}, {
				"id": 610831,
				"name": "子洲县",
				"parent_id": 610800,
				"type": 4,
				"zip": "718400"
			}, {
				"id": 610830,
				"name": "清涧县",
				"parent_id": 610800,
				"type": 4,
				"zip": "718300"
			}, {
				"id": 610821,
				"name": "神木县",
				"parent_id": 610800,
				"type": 4,
				"zip": "719300"
			}, {
				"id": 610823,
				"name": "横山县",
				"parent_id": 610800,
				"type": 4,
				"zip": "719100"
			}, {
				"id": 610822,
				"name": "府谷县",
				"parent_id": 610800,
				"type": 4,
				"zip": "719400"
			}, {
				"id": 610802,
				"name": "榆阳区",
				"parent_id": 610800,
				"type": 4,
				"zip": "719000"
			}]
		}, {
			"id": 610400,
			"name": "咸阳市",
			"parent_id": 610000,
			"type": 3,
			"zip": "712000",
			"district": [{
				"id": 610426,
				"name": "永寿县",
				"parent_id": 610400,
				"type": 4,
				"zip": "713400"
			}, {
				"id": 610427,
				"name": "彬县",
				"parent_id": 610400,
				"type": 4,
				"zip": "713500"
			}, {
				"id": 610424,
				"name": "乾县",
				"parent_id": 610400,
				"type": 4,
				"zip": "713300"
			}, {
				"id": 610425,
				"name": "礼泉县",
				"parent_id": 610400,
				"type": 4,
				"zip": "713200"
			}, {
				"id": 610430,
				"name": "淳化县",
				"parent_id": 610400,
				"type": 4,
				"zip": "711200"
			}, {
				"id": 610431,
				"name": "武功县",
				"parent_id": 610400,
				"type": 4,
				"zip": "712200"
			}, {
				"id": 610428,
				"name": "长武县",
				"parent_id": 610400,
				"type": 4,
				"zip": "713600"
			}, {
				"id": 610429,
				"name": "旬邑县",
				"parent_id": 610400,
				"type": 4,
				"zip": "711300"
			}, {
				"id": 610422,
				"name": "三原县",
				"parent_id": 610400,
				"type": 4,
				"zip": "713800"
			}, {
				"id": 610423,
				"name": "泾阳县",
				"parent_id": 610400,
				"type": 4,
				"zip": "713700"
			}, {
				"id": 610403,
				"name": "杨陵区",
				"parent_id": 610400,
				"type": 4,
				"zip": "712100"
			}, {
				"id": 610402,
				"name": "秦都区",
				"parent_id": 610400,
				"type": 4,
				"zip": "712000"
			}, {
				"id": 610404,
				"name": "渭城区",
				"parent_id": 610400,
				"type": 4,
				"zip": "712000"
			}, {
				"id": 610482,
				"name": "其它区",
				"parent_id": 610400,
				"type": 4,
				"zip": ""
			}, {
				"id": 610481,
				"name": "兴平市",
				"parent_id": 610400,
				"type": 4,
				"zip": "713100"
			}]
		}, {
			"id": 610500,
			"name": "渭南市",
			"parent_id": 610000,
			"type": 3,
			"zip": "714000",
			"district": [{
				"id": 610582,
				"name": "华阴市",
				"parent_id": 610500,
				"type": 4,
				"zip": "714200"
			}, {
				"id": 610583,
				"name": "其它区",
				"parent_id": 610500,
				"type": 4,
				"zip": ""
			}, {
				"id": 610581,
				"name": "韩城市",
				"parent_id": 610500,
				"type": 4,
				"zip": "715400"
			}, {
				"id": 610528,
				"name": "富平县",
				"parent_id": 610500,
				"type": 4,
				"zip": "711700"
			}, {
				"id": 610521,
				"name": "华县",
				"parent_id": 610500,
				"type": 4,
				"zip": "714100"
			}, {
				"id": 610523,
				"name": "大荔县",
				"parent_id": 610500,
				"type": 4,
				"zip": "715100"
			}, {
				"id": 610522,
				"name": "潼关县",
				"parent_id": 610500,
				"type": 4,
				"zip": "714300"
			}, {
				"id": 610525,
				"name": "澄城县",
				"parent_id": 610500,
				"type": 4,
				"zip": "715200"
			}, {
				"id": 610524,
				"name": "合阳县",
				"parent_id": 610500,
				"type": 4,
				"zip": "715300"
			}, {
				"id": 610527,
				"name": "白水县",
				"parent_id": 610500,
				"type": 4,
				"zip": "715600"
			}, {
				"id": 610526,
				"name": "蒲城县",
				"parent_id": 610500,
				"type": 4,
				"zip": "715500"
			}, {
				"id": 610502,
				"name": "临渭区",
				"parent_id": 610500,
				"type": 4,
				"zip": "714000"
			}]
		}]
	}, {
		"id": 120000,
		"name": "天津",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 120100,
			"name": "天津市",
			"parent_id": 120000,
			"type": 3,
			"zip": "300000",
			"district": [{
				"id": 120225,
				"name": "蓟县",
				"parent_id": 120100,
				"type": 4,
				"zip": "301900"
			}, {
				"id": 120226,
				"name": "其它区",
				"parent_id": 120100,
				"type": 4,
				"zip": ""
			}, {
				"id": 120223,
				"name": "静海县",
				"parent_id": 120100,
				"type": 4,
				"zip": "301600"
			}, {
				"id": 120221,
				"name": "宁河县",
				"parent_id": 120100,
				"type": 4,
				"zip": "301500"
			}, {
				"id": 120101,
				"name": "和平区",
				"parent_id": 120100,
				"type": 4,
				"zip": "300041"
			}, {
				"id": 120102,
				"name": "河东区",
				"parent_id": 120100,
				"type": 4,
				"zip": "300171"
			}, {
				"id": 120103,
				"name": "河西区",
				"parent_id": 120100,
				"type": 4,
				"zip": "300202"
			}, {
				"id": 120108,
				"name": "汉沽区",
				"parent_id": 120100,
				"type": 4,
				"zip": "300480"
			}, {
				"id": 120109,
				"name": "大港区",
				"parent_id": 120100,
				"type": 4,
				"zip": "300270"
			}, {
				"id": 120110,
				"name": "东丽区",
				"parent_id": 120100,
				"type": 4,
				"zip": "300300"
			}, {
				"id": 120111,
				"name": "西青区",
				"parent_id": 120100,
				"type": 4,
				"zip": "300380"
			}, {
				"id": 120104,
				"name": "南开区",
				"parent_id": 120100,
				"type": 4,
				"zip": "300100"
			}, {
				"id": 120105,
				"name": "河北区",
				"parent_id": 120100,
				"type": 4,
				"zip": "300143"
			}, {
				"id": 120106,
				"name": "红桥区",
				"parent_id": 120100,
				"type": 4,
				"zip": "300131"
			}, {
				"id": 120107,
				"name": "塘沽区",
				"parent_id": 120100,
				"type": 4,
				"zip": "300450"
			}, {
				"id": 120116,
				"name": "滨海新区",
				"parent_id": 120100,
				"type": 4,
				"zip": "300457"
			}, {
				"id": 120113,
				"name": "北辰区",
				"parent_id": 120100,
				"type": 4,
				"zip": "300400"
			}, {
				"id": 120112,
				"name": "津南区",
				"parent_id": 120100,
				"type": 4,
				"zip": "300350"
			}, {
				"id": 120115,
				"name": "宝坻区",
				"parent_id": 120100,
				"type": 4,
				"zip": "301800"
			}, {
				"id": 120114,
				"name": "武清区",
				"parent_id": 120100,
				"type": 4,
				"zip": "301700"
			}]
		}]
	}, {
		"id": 440000,
		"name": "广东省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 445300,
			"name": "云浮市",
			"parent_id": 440000,
			"type": 3,
			"zip": "527300",
			"district": [{
				"id": 445302,
				"name": "云城区",
				"parent_id": 445300,
				"type": 4,
				"zip": "527300"
			}, {
				"id": 445381,
				"name": "罗定市",
				"parent_id": 445300,
				"type": 4,
				"zip": "527200"
			}, {
				"id": 445382,
				"name": "其它区",
				"parent_id": 445300,
				"type": 4,
				"zip": ""
			}, {
				"id": 445321,
				"name": "新兴县",
				"parent_id": 445300,
				"type": 4,
				"zip": "527400"
			}, {
				"id": 445323,
				"name": "云安县",
				"parent_id": 445300,
				"type": 4,
				"zip": "527500"
			}, {
				"id": 445322,
				"name": "郁南县",
				"parent_id": 445300,
				"type": 4,
				"zip": "527100"
			}]
		}, {
			"id": 445200,
			"name": "揭阳市",
			"parent_id": 440000,
			"type": 3,
			"zip": "522000",
			"district": [{
				"id": 445281,
				"name": "普宁市",
				"parent_id": 445200,
				"type": 4,
				"zip": "515300"
			}, {
				"id": 445284,
				"name": "东山区",
				"parent_id": 445200,
				"type": 4,
				"zip": ""
			}, {
				"id": 445285,
				"name": "其它区",
				"parent_id": 445200,
				"type": 4,
				"zip": ""
			}, {
				"id": 445202,
				"name": "榕城区",
				"parent_id": 445200,
				"type": 4,
				"zip": "522095"
			}, {
				"id": 445224,
				"name": "惠来县",
				"parent_id": 445200,
				"type": 4,
				"zip": "515200"
			}, {
				"id": 445222,
				"name": "揭西县",
				"parent_id": 445200,
				"type": 4,
				"zip": "515400"
			}, {
				"id": 445221,
				"name": "揭东区",
				"parent_id": 445200,
				"type": 4,
				"zip": "515500"
			}]
		}, {
			"id": 445100,
			"name": "潮州市",
			"parent_id": 440000,
			"type": 3,
			"zip": "521000",
			"district": [{
				"id": 445185,
				"name": "枫溪区",
				"parent_id": 445100,
				"type": 4,
				"zip": ""
			}, {
				"id": 445186,
				"name": "其它区",
				"parent_id": 445100,
				"type": 4,
				"zip": ""
			}, {
				"id": 445122,
				"name": "饶平县",
				"parent_id": 445100,
				"type": 4,
				"zip": "515700"
			}, {
				"id": 445121,
				"name": "潮安区",
				"parent_id": 445100,
				"type": 4,
				"zip": "515600"
			}, {
				"id": 445102,
				"name": "湘桥区",
				"parent_id": 445100,
				"type": 4,
				"zip": "521000"
			}]
		}, {
			"id": 440100,
			"name": "广州市",
			"parent_id": 440000,
			"type": 3,
			"zip": "510000",
			"district": [{
				"id": 440183,
				"name": "增城市",
				"parent_id": 440100,
				"type": 4,
				"zip": "511300"
			}, {
				"id": 440188,
				"name": "东山区",
				"parent_id": 440100,
				"type": 4,
				"zip": ""
			}, {
				"id": 440189,
				"name": "其它区",
				"parent_id": 440100,
				"type": 4,
				"zip": ""
			}, {
				"id": 440184,
				"name": "从化市",
				"parent_id": 440100,
				"type": 4,
				"zip": "510900"
			}, {
				"id": 440112,
				"name": "黄埔区",
				"parent_id": 440100,
				"type": 4,
				"zip": "510700"
			}, {
				"id": 440113,
				"name": "番禺区",
				"parent_id": 440100,
				"type": 4,
				"zip": "511400"
			}, {
				"id": 440114,
				"name": "花都区",
				"parent_id": 440100,
				"type": 4,
				"zip": "510800"
			}, {
				"id": 440115,
				"name": "南沙区",
				"parent_id": 440100,
				"type": 4,
				"zip": ""
			}, {
				"id": 440116,
				"name": "萝岗区",
				"parent_id": 440100,
				"type": 4,
				"zip": ""
			}, {
				"id": 440103,
				"name": "荔湾区",
				"parent_id": 440100,
				"type": 4,
				"zip": "510145"
			}, {
				"id": 440105,
				"name": "海珠区",
				"parent_id": 440100,
				"type": 4,
				"zip": "510220"
			}, {
				"id": 440104,
				"name": "越秀区",
				"parent_id": 440100,
				"type": 4,
				"zip": "510180"
			}, {
				"id": 440106,
				"name": "天河区",
				"parent_id": 440100,
				"type": 4,
				"zip": "510510"
			}, {
				"id": 440111,
				"name": "白云区",
				"parent_id": 440100,
				"type": 4,
				"zip": "510440"
			}]
		}, {
			"id": 440300,
			"name": "深圳市",
			"parent_id": 440000,
			"type": 3,
			"zip": "518000",
			"district": [{
				"id": 440309,
				"name": "其它区",
				"parent_id": 440300,
				"type": 4,
				"zip": ""
			}, {
				"id": 440308,
				"name": "盐田区",
				"parent_id": 440300,
				"type": 4,
				"zip": "518083"
			}, {
				"id": 440305,
				"name": "南山区",
				"parent_id": 440300,
				"type": 4,
				"zip": "518052"
			}, {
				"id": 440304,
				"name": "福田区",
				"parent_id": 440300,
				"type": 4,
				"zip": "518031"
			}, {
				"id": 440307,
				"name": "龙岗区",
				"parent_id": 440300,
				"type": 4,
				"zip": "518116"
			}, {
				"id": 440306,
				"name": "宝安区",
				"parent_id": 440300,
				"type": 4,
				"zip": "518101"
			}, {
				"id": 440303,
				"name": "罗湖区",
				"parent_id": 440300,
				"type": 4,
				"zip": "518002"
			}, {
				"id": 440321,
				"name": "坪山新区",
				"parent_id": 440300,
				"type": 4,
				"zip": "518118"
			}, {
				"id": 440320,
				"name": "光明新区",
				"parent_id": 440300,
				"type": 4,
				"zip": "518107"
			}, {
				"id": 440323,
				"name": "龙华新区",
				"parent_id": 440300,
				"type": 4,
				"zip": "518131"
			}, {
				"id": 440322,
				"name": "大鹏新区",
				"parent_id": 440300,
				"type": 4,
				"zip": "518108"
			}]
		}, {
			"id": 440200,
			"name": "韶关市",
			"parent_id": 440000,
			"type": 3,
			"zip": "512000",
			"district": [{
				"id": 440283,
				"name": "其它区",
				"parent_id": 440200,
				"type": 4,
				"zip": ""
			}, {
				"id": 440282,
				"name": "南雄市",
				"parent_id": 440200,
				"type": 4,
				"zip": "512400"
			}, {
				"id": 440281,
				"name": "乐昌市",
				"parent_id": 440200,
				"type": 4,
				"zip": "512200"
			}, {
				"id": 440232,
				"name": "乳源瑶族自治县",
				"parent_id": 440200,
				"type": 4,
				"zip": "512700"
			}, {
				"id": 440233,
				"name": "新丰县",
				"parent_id": 440200,
				"type": 4,
				"zip": "511100"
			}, {
				"id": 440224,
				"name": "仁化县",
				"parent_id": 440200,
				"type": 4,
				"zip": "512300"
			}, {
				"id": 440229,
				"name": "翁源县",
				"parent_id": 440200,
				"type": 4,
				"zip": "512600"
			}, {
				"id": 440222,
				"name": "始兴县",
				"parent_id": 440200,
				"type": 4,
				"zip": "512500"
			}, {
				"id": 440203,
				"name": "武江区",
				"parent_id": 440200,
				"type": 4,
				"zip": "512026"
			}, {
				"id": 440204,
				"name": "浈江区",
				"parent_id": 440200,
				"type": 4,
				"zip": "512023"
			}, {
				"id": 440205,
				"name": "曲江区",
				"parent_id": 440200,
				"type": 4,
				"zip": "512100"
			}]
		}, {
			"id": 442000,
			"name": "中山市",
			"parent_id": 440000,
			"type": 3,
			"zip": "528400",
			"district": [{
				"id": 44200010,
				"name": "石岐区街道",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200011,
				"name": "东区街道",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200012,
				"name": "火炬开发区街道",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200013,
				"name": "西区街道",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200014,
				"name": "南区街道",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200015,
				"name": "五桂山街道",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200016,
				"name": "小榄镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200017,
				"name": "黄圃镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200018,
				"name": "民众镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200019,
				"name": "东凤镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200020,
				"name": "东升镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200021,
				"name": "古镇镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200022,
				"name": "沙溪镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200023,
				"name": "坦洲镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200024,
				"name": "港口镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200025,
				"name": "三角镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200026,
				"name": "横栏镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200027,
				"name": "南头镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200028,
				"name": "阜沙镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200029,
				"name": "南朗镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200030,
				"name": "三乡镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200031,
				"name": "板芙镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200032,
				"name": "大涌镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}, {
				"id": 44200033,
				"name": "神湾镇",
				"parent_id": 442000,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 441900,
			"name": "东莞市",
			"parent_id": 440000,
			"type": 3,
			"zip": "523000",
			"district": [{
				"id": 44190010,
				"name": "东城街道",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190011,
				"name": "南城街道",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190012,
				"name": "万江街道",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190013,
				"name": "莞城街道",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190014,
				"name": "石碣镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190015,
				"name": "石龙镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190016,
				"name": "茶山镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190017,
				"name": "石排镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190018,
				"name": "企石镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190019,
				"name": "横沥镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190020,
				"name": "桥头镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190021,
				"name": "谢岗镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190022,
				"name": "东坑镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190023,
				"name": "常平镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190024,
				"name": "寮步镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190025,
				"name": "樟木头镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190026,
				"name": "大朗镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190027,
				"name": "黄江镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190028,
				"name": "清溪镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190029,
				"name": "塘厦镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190030,
				"name": "凤岗镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190031,
				"name": "大岭山镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190032,
				"name": "长安镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190033,
				"name": "虎门镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190034,
				"name": "厚街镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190035,
				"name": "沙田镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190036,
				"name": "道滘镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190037,
				"name": "洪梅镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190038,
				"name": "麻涌镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190039,
				"name": "望牛墩镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190040,
				"name": "中堂镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190041,
				"name": "高埗镇",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190042,
				"name": "松山湖管委会",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190043,
				"name": "虎门港管委会",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}, {
				"id": 44190044,
				"name": "东莞生态园",
				"parent_id": 441900,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 441500,
			"name": "汕尾市",
			"parent_id": 440000,
			"type": 3,
			"zip": "516600",
			"district": [{
				"id": 441582,
				"name": "其它区",
				"parent_id": 441500,
				"type": 4,
				"zip": ""
			}, {
				"id": 441581,
				"name": "陆丰市",
				"parent_id": 441500,
				"type": 4,
				"zip": "516500"
			}, {
				"id": 441502,
				"name": "城区",
				"parent_id": 441500,
				"type": 4,
				"zip": "516601"
			}, {
				"id": 441523,
				"name": "陆河县",
				"parent_id": 441500,
				"type": 4,
				"zip": "516700"
			}, {
				"id": 441521,
				"name": "海丰县",
				"parent_id": 441500,
				"type": 4,
				"zip": "516400"
			}]
		}, {
			"id": 441400,
			"name": "梅州市",
			"parent_id": 440000,
			"type": 3,
			"zip": "514000",
			"district": [{
				"id": 441481,
				"name": "兴宁市",
				"parent_id": 441400,
				"type": 4,
				"zip": "514500"
			}, {
				"id": 441482,
				"name": "其它区",
				"parent_id": 441400,
				"type": 4,
				"zip": ""
			}, {
				"id": 441424,
				"name": "五华县",
				"parent_id": 441400,
				"type": 4,
				"zip": "514400"
			}, {
				"id": 441426,
				"name": "平远县",
				"parent_id": 441400,
				"type": 4,
				"zip": "514600"
			}, {
				"id": 441427,
				"name": "蕉岭县",
				"parent_id": 441400,
				"type": 4,
				"zip": "514100"
			}, {
				"id": 441421,
				"name": "梅县",
				"parent_id": 441400,
				"type": 4,
				"zip": "514700"
			}, {
				"id": 441423,
				"name": "丰顺县",
				"parent_id": 441400,
				"type": 4,
				"zip": "514300"
			}, {
				"id": 441422,
				"name": "大埔县",
				"parent_id": 441400,
				"type": 4,
				"zip": "514200"
			}, {
				"id": 441402,
				"name": "梅江区",
				"parent_id": 441400,
				"type": 4,
				"zip": "514000"
			}]
		}, {
			"id": 441800,
			"name": "清远市",
			"parent_id": 440000,
			"type": 3,
			"zip": "511500",
			"district": [{
				"id": 441881,
				"name": "英德市",
				"parent_id": 441800,
				"type": 4,
				"zip": "513000"
			}, {
				"id": 441882,
				"name": "连州市",
				"parent_id": 441800,
				"type": 4,
				"zip": "513400"
			}, {
				"id": 441883,
				"name": "其它区",
				"parent_id": 441800,
				"type": 4,
				"zip": ""
			}, {
				"id": 441802,
				"name": "清城区",
				"parent_id": 441800,
				"type": 4,
				"zip": "511500"
			}, {
				"id": 441823,
				"name": "阳山县",
				"parent_id": 441800,
				"type": 4,
				"zip": "513100"
			}, {
				"id": 441821,
				"name": "佛冈县",
				"parent_id": 441800,
				"type": 4,
				"zip": "511600"
			}, {
				"id": 441825,
				"name": "连山壮族瑶族自治县",
				"parent_id": 441800,
				"type": 4,
				"zip": "513200"
			}, {
				"id": 441826,
				"name": "连南瑶族自治县",
				"parent_id": 441800,
				"type": 4,
				"zip": "513300"
			}, {
				"id": 441827,
				"name": "清新区",
				"parent_id": 441800,
				"type": 4,
				"zip": "511800"
			}]
		}, {
			"id": 441700,
			"name": "阳江市",
			"parent_id": 440000,
			"type": 3,
			"zip": "529500",
			"district": [{
				"id": 441781,
				"name": "阳春市",
				"parent_id": 441700,
				"type": 4,
				"zip": "529600"
			}, {
				"id": 441782,
				"name": "其它区",
				"parent_id": 441700,
				"type": 4,
				"zip": ""
			}, {
				"id": 441702,
				"name": "江城区",
				"parent_id": 441700,
				"type": 4,
				"zip": "529525"
			}, {
				"id": 441721,
				"name": "阳西县",
				"parent_id": 441700,
				"type": 4,
				"zip": "529800"
			}, {
				"id": 441723,
				"name": "阳东县",
				"parent_id": 441700,
				"type": 4,
				"zip": "529931"
			}]
		}, {
			"id": 441600,
			"name": "河源市",
			"parent_id": 440000,
			"type": 3,
			"zip": "517000",
			"district": [{
				"id": 441602,
				"name": "源城区",
				"parent_id": 441600,
				"type": 4,
				"zip": "517000"
			}, {
				"id": 441622,
				"name": "龙川县",
				"parent_id": 441600,
				"type": 4,
				"zip": "517300"
			}, {
				"id": 441623,
				"name": "连平县",
				"parent_id": 441600,
				"type": 4,
				"zip": "517100"
			}, {
				"id": 441621,
				"name": "紫金县",
				"parent_id": 441600,
				"type": 4,
				"zip": "517400"
			}, {
				"id": 441626,
				"name": "其它区",
				"parent_id": 441600,
				"type": 4,
				"zip": ""
			}, {
				"id": 441624,
				"name": "和平县",
				"parent_id": 441600,
				"type": 4,
				"zip": "517200"
			}, {
				"id": 441625,
				"name": "东源县",
				"parent_id": 441600,
				"type": 4,
				"zip": "517500"
			}]
		}, {
			"id": 440900,
			"name": "茂名市",
			"parent_id": 440000,
			"type": 3,
			"zip": "525000",
			"district": [{
				"id": 440981,
				"name": "高州市",
				"parent_id": 440900,
				"type": 4,
				"zip": "525200"
			}, {
				"id": 440983,
				"name": "信宜市",
				"parent_id": 440900,
				"type": 4,
				"zip": "525300"
			}, {
				"id": 440982,
				"name": "化州市",
				"parent_id": 440900,
				"type": 4,
				"zip": "525100"
			}, {
				"id": 440984,
				"name": "其它区",
				"parent_id": 440900,
				"type": 4,
				"zip": ""
			}, {
				"id": 440923,
				"name": "电白县",
				"parent_id": 440900,
				"type": 4,
				"zip": "525400"
			}, {
				"id": 440903,
				"name": "茂港区",
				"parent_id": 440900,
				"type": 4,
				"zip": "525027"
			}, {
				"id": 440902,
				"name": "茂南区",
				"parent_id": 440900,
				"type": 4,
				"zip": "525011"
			}]
		}, {
			"id": 441300,
			"name": "惠州市",
			"parent_id": 440000,
			"type": 3,
			"zip": "516000",
			"district": [{
				"id": 441324,
				"name": "龙门县",
				"parent_id": 441300,
				"type": 4,
				"zip": "516800"
			}, {
				"id": 441325,
				"name": "其它区",
				"parent_id": 441300,
				"type": 4,
				"zip": ""
			}, {
				"id": 441322,
				"name": "博罗县",
				"parent_id": 441300,
				"type": 4,
				"zip": "516100"
			}, {
				"id": 441323,
				"name": "惠东县",
				"parent_id": 441300,
				"type": 4,
				"zip": "516300"
			}, {
				"id": 441303,
				"name": "惠阳区",
				"parent_id": 441300,
				"type": 4,
				"zip": "516200"
			}, {
				"id": 441302,
				"name": "惠城区",
				"parent_id": 441300,
				"type": 4,
				"zip": "516001"
			}]
		}, {
			"id": 441200,
			"name": "肇庆市",
			"parent_id": 440000,
			"type": 3,
			"zip": "526000",
			"district": [{
				"id": 441223,
				"name": "广宁县",
				"parent_id": 441200,
				"type": 4,
				"zip": "526300"
			}, {
				"id": 441226,
				"name": "德庆县",
				"parent_id": 441200,
				"type": 4,
				"zip": "526600"
			}, {
				"id": 441224,
				"name": "怀集县",
				"parent_id": 441200,
				"type": 4,
				"zip": "526400"
			}, {
				"id": 441225,
				"name": "封开县",
				"parent_id": 441200,
				"type": 4,
				"zip": "526500"
			}, {
				"id": 441284,
				"name": "四会市",
				"parent_id": 441200,
				"type": 4,
				"zip": "526200"
			}, {
				"id": 441285,
				"name": "其它区",
				"parent_id": 441200,
				"type": 4,
				"zip": ""
			}, {
				"id": 441283,
				"name": "高要市",
				"parent_id": 441200,
				"type": 4,
				"zip": "526100"
			}, {
				"id": 441202,
				"name": "端州区",
				"parent_id": 441200,
				"type": 4,
				"zip": "526040"
			}, {
				"id": 441203,
				"name": "鼎湖区",
				"parent_id": 441200,
				"type": 4,
				"zip": "526070"
			}]
		}, {
			"id": 440500,
			"name": "汕头市",
			"parent_id": 440000,
			"type": 3,
			"zip": "515000",
			"district": [{
				"id": 440511,
				"name": "金平区",
				"parent_id": 440500,
				"type": 4,
				"zip": "515041"
			}, {
				"id": 440507,
				"name": "龙湖区",
				"parent_id": 440500,
				"type": 4,
				"zip": "515041"
			}, {
				"id": 440512,
				"name": "濠江区",
				"parent_id": 440500,
				"type": 4,
				"zip": "515071"
			}, {
				"id": 440513,
				"name": "潮阳区",
				"parent_id": 440500,
				"type": 4,
				"zip": "515100"
			}, {
				"id": 440514,
				"name": "潮南区",
				"parent_id": 440500,
				"type": 4,
				"zip": "515144"
			}, {
				"id": 440515,
				"name": "澄海区",
				"parent_id": 440500,
				"type": 4,
				"zip": "515800"
			}, {
				"id": 440523,
				"name": "南澳县",
				"parent_id": 440500,
				"type": 4,
				"zip": "515900"
			}, {
				"id": 440524,
				"name": "其它区",
				"parent_id": 440500,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 440400,
			"name": "珠海市",
			"parent_id": 440000,
			"type": 3,
			"zip": "519000",
			"district": [{
				"id": 440486,
				"name": "金唐区",
				"parent_id": 440400,
				"type": 4,
				"zip": ""
			}, {
				"id": 440487,
				"name": "南湾区",
				"parent_id": 440400,
				"type": 4,
				"zip": ""
			}, {
				"id": 440488,
				"name": "其它区",
				"parent_id": 440400,
				"type": 4,
				"zip": ""
			}, {
				"id": 440402,
				"name": "香洲区",
				"parent_id": 440400,
				"type": 4,
				"zip": "519000"
			}, {
				"id": 440403,
				"name": "斗门区",
				"parent_id": 440400,
				"type": 4,
				"zip": "519100"
			}, {
				"id": 440404,
				"name": "金湾区",
				"parent_id": 440400,
				"type": 4,
				"zip": "519090"
			}]
		}, {
			"id": 440800,
			"name": "湛江市",
			"parent_id": 440000,
			"type": 3,
			"zip": "524000",
			"district": [{
				"id": 440882,
				"name": "雷州市",
				"parent_id": 440800,
				"type": 4,
				"zip": "524200"
			}, {
				"id": 440883,
				"name": "吴川市",
				"parent_id": 440800,
				"type": 4,
				"zip": "524500"
			}, {
				"id": 440881,
				"name": "廉江市",
				"parent_id": 440800,
				"type": 4,
				"zip": "524400"
			}, {
				"id": 440884,
				"name": "其它区",
				"parent_id": 440800,
				"type": 4,
				"zip": ""
			}, {
				"id": 440802,
				"name": "赤坎区",
				"parent_id": 440800,
				"type": 4,
				"zip": "524033"
			}, {
				"id": 440803,
				"name": "霞山区",
				"parent_id": 440800,
				"type": 4,
				"zip": "524002"
			}, {
				"id": 440804,
				"name": "坡头区",
				"parent_id": 440800,
				"type": 4,
				"zip": "524057"
			}, {
				"id": 440811,
				"name": "麻章区",
				"parent_id": 440800,
				"type": 4,
				"zip": "524003"
			}, {
				"id": 440823,
				"name": "遂溪县",
				"parent_id": 440800,
				"type": 4,
				"zip": "524300"
			}, {
				"id": 440825,
				"name": "徐闻县",
				"parent_id": 440800,
				"type": 4,
				"zip": "524100"
			}]
		}, {
			"id": 440600,
			"name": "佛山市",
			"parent_id": 440000,
			"type": 3,
			"zip": "528000",
			"district": [{
				"id": 440606,
				"name": "顺德区",
				"parent_id": 440600,
				"type": 4,
				"zip": "528300"
			}, {
				"id": 440607,
				"name": "三水区",
				"parent_id": 440600,
				"type": 4,
				"zip": "528100"
			}, {
				"id": 440604,
				"name": "禅城区",
				"parent_id": 440600,
				"type": 4,
				"zip": "528000"
			}, {
				"id": 440605,
				"name": "南海区",
				"parent_id": 440600,
				"type": 4,
				"zip": "528200"
			}, {
				"id": 440609,
				"name": "其它区",
				"parent_id": 440600,
				"type": 4,
				"zip": ""
			}, {
				"id": 440608,
				"name": "高明区",
				"parent_id": 440600,
				"type": 4,
				"zip": "528500"
			}]
		}, {
			"id": 440700,
			"name": "江门市",
			"parent_id": 440000,
			"type": 3,
			"zip": "529000",
			"district": [{
				"id": 440704,
				"name": "江海区",
				"parent_id": 440700,
				"type": 4,
				"zip": "529000"
			}, {
				"id": 440705,
				"name": "新会区",
				"parent_id": 440700,
				"type": 4,
				"zip": "529100"
			}, {
				"id": 440783,
				"name": "开平市",
				"parent_id": 440700,
				"type": 4,
				"zip": "529300"
			}, {
				"id": 440781,
				"name": "台山市",
				"parent_id": 440700,
				"type": 4,
				"zip": "529200"
			}, {
				"id": 440786,
				"name": "其它区",
				"parent_id": 440700,
				"type": 4,
				"zip": ""
			}, {
				"id": 440785,
				"name": "恩平市",
				"parent_id": 440700,
				"type": 4,
				"zip": "529400"
			}, {
				"id": 440784,
				"name": "鹤山市",
				"parent_id": 440700,
				"type": 4,
				"zip": "529700"
			}, {
				"id": 440703,
				"name": "蓬江区",
				"parent_id": 440700,
				"type": 4,
				"zip": "529051"
			}]
		}]
	}, {
		"id": 500000,
		"name": "重庆",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 500100,
			"name": "重庆市",
			"parent_id": 500000,
			"type": 3,
			"zip": "400000",
			"district": [{
				"id": 500102,
				"name": "涪陵区",
				"parent_id": 500100,
				"type": 4,
				"zip": "408000"
			}, {
				"id": 500103,
				"name": "渝中区",
				"parent_id": 500100,
				"type": 4,
				"zip": "400012"
			}, {
				"id": 500101,
				"name": "万州区",
				"parent_id": 500100,
				"type": 4,
				"zip": "404000"
			}, {
				"id": 500110,
				"name": "万盛区",
				"parent_id": 500100,
				"type": 4,
				"zip": "400800"
			}, {
				"id": 500111,
				"name": "双桥区",
				"parent_id": 500100,
				"type": 4,
				"zip": "400900"
			}, {
				"id": 500108,
				"name": "南岸区",
				"parent_id": 500100,
				"type": 4,
				"zip": "400060"
			}, {
				"id": 500109,
				"name": "北碚区",
				"parent_id": 500100,
				"type": 4,
				"zip": "400700"
			}, {
				"id": 500106,
				"name": "沙坪坝区",
				"parent_id": 500100,
				"type": 4,
				"zip": "400020"
			}, {
				"id": 500107,
				"name": "九龙坡区",
				"parent_id": 500100,
				"type": 4,
				"zip": "400039"
			}, {
				"id": 500104,
				"name": "大渡口区",
				"parent_id": 500100,
				"type": 4,
				"zip": "400084"
			}, {
				"id": 500105,
				"name": "江北区",
				"parent_id": 500100,
				"type": 4,
				"zip": "400021"
			}, {
				"id": 500115,
				"name": "长寿区",
				"parent_id": 500100,
				"type": 4,
				"zip": "401220"
			}, {
				"id": 500114,
				"name": "黔江区",
				"parent_id": 500100,
				"type": 4,
				"zip": "409700"
			}, {
				"id": 500113,
				"name": "巴南区",
				"parent_id": 500100,
				"type": 4,
				"zip": "401320"
			}, {
				"id": 500112,
				"name": "渝北区",
				"parent_id": 500100,
				"type": 4,
				"zip": "401120"
			}, {
				"id": 500223,
				"name": "潼南县",
				"parent_id": 500100,
				"type": 4,
				"zip": "402660"
			}, {
				"id": 500222,
				"name": "綦江区",
				"parent_id": 500100,
				"type": 4,
				"zip": "401420"
			}, {
				"id": 500240,
				"name": "石柱土家族自治县",
				"parent_id": 500100,
				"type": 4,
				"zip": "409100"
			}, {
				"id": 500241,
				"name": "秀山土家族苗族自治县",
				"parent_id": 500100,
				"type": 4,
				"zip": "409900"
			}, {
				"id": 500242,
				"name": "酉阳土家族苗族自治县",
				"parent_id": 500100,
				"type": 4,
				"zip": "409800"
			}, {
				"id": 500243,
				"name": "彭水苗族土家族自治县",
				"parent_id": 500100,
				"type": 4,
				"zip": "409600"
			}, {
				"id": 500233,
				"name": "忠县",
				"parent_id": 500100,
				"type": 4,
				"zip": "404300"
			}, {
				"id": 500232,
				"name": "武隆县",
				"parent_id": 500100,
				"type": 4,
				"zip": "408500"
			}, {
				"id": 500235,
				"name": "云阳县",
				"parent_id": 500100,
				"type": 4,
				"zip": "404500"
			}, {
				"id": 500234,
				"name": "开县",
				"parent_id": 500100,
				"type": 4,
				"zip": "405400"
			}, {
				"id": 500237,
				"name": "巫山县",
				"parent_id": 500100,
				"type": 4,
				"zip": "404700"
			}, {
				"id": 500236,
				"name": "奉节县",
				"parent_id": 500100,
				"type": 4,
				"zip": "404600"
			}, {
				"id": 500238,
				"name": "巫溪县",
				"parent_id": 500100,
				"type": 4,
				"zip": "405800"
			}, {
				"id": 500225,
				"name": "大足区",
				"parent_id": 500100,
				"type": 4,
				"zip": "402360"
			}, {
				"id": 500224,
				"name": "铜梁县",
				"parent_id": 500100,
				"type": 4,
				"zip": "402560"
			}, {
				"id": 500227,
				"name": "璧山县",
				"parent_id": 500100,
				"type": 4,
				"zip": "402760"
			}, {
				"id": 500226,
				"name": "荣昌县",
				"parent_id": 500100,
				"type": 4,
				"zip": "402460"
			}, {
				"id": 500229,
				"name": "城口县",
				"parent_id": 500100,
				"type": 4,
				"zip": "405900"
			}, {
				"id": 500228,
				"name": "梁平县",
				"parent_id": 500100,
				"type": 4,
				"zip": "405200"
			}, {
				"id": 500231,
				"name": "垫江县",
				"parent_id": 500100,
				"type": 4,
				"zip": "408300"
			}, {
				"id": 500230,
				"name": "丰都县",
				"parent_id": 500100,
				"type": 4,
				"zip": "408200"
			}, {
				"id": 500381,
				"name": "江津区",
				"parent_id": 500100,
				"type": 4,
				"zip": "402260"
			}, {
				"id": 500383,
				"name": "永川区",
				"parent_id": 500100,
				"type": 4,
				"zip": "402160"
			}, {
				"id": 500382,
				"name": "合川区",
				"parent_id": 500100,
				"type": 4,
				"zip": "401520"
			}, {
				"id": 500384,
				"name": "南川区",
				"parent_id": 500100,
				"type": 4,
				"zip": "408400"
			}, {
				"id": 500385,
				"name": "其它区",
				"parent_id": 500100,
				"type": 4,
				"zip": ""
			}]
		}]
	}, {
		"id": 130000,
		"name": "河北省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 131100,
			"name": "衡水市",
			"parent_id": 130000,
			"type": 3,
			"zip": "053000",
			"district": [{
				"id": 131121,
				"name": "枣强县",
				"parent_id": 131100,
				"type": 4,
				"zip": "053100"
			}, {
				"id": 131123,
				"name": "武强县",
				"parent_id": 131100,
				"type": 4,
				"zip": "053300"
			}, {
				"id": 131122,
				"name": "武邑县",
				"parent_id": 131100,
				"type": 4,
				"zip": "053400"
			}, {
				"id": 131125,
				"name": "安平县",
				"parent_id": 131100,
				"type": 4,
				"zip": "053600"
			}, {
				"id": 131124,
				"name": "饶阳县",
				"parent_id": 131100,
				"type": 4,
				"zip": "053900"
			}, {
				"id": 131127,
				"name": "景县",
				"parent_id": 131100,
				"type": 4,
				"zip": "053500"
			}, {
				"id": 131126,
				"name": "故城县",
				"parent_id": 131100,
				"type": 4,
				"zip": "253800"
			}, {
				"id": 131128,
				"name": "阜城县",
				"parent_id": 131100,
				"type": 4,
				"zip": "053700"
			}, {
				"id": 131102,
				"name": "桃城区",
				"parent_id": 131100,
				"type": 4,
				"zip": "053000"
			}, {
				"id": 131181,
				"name": "冀州市",
				"parent_id": 131100,
				"type": 4,
				"zip": "053200"
			}, {
				"id": 131182,
				"name": "深州市",
				"parent_id": 131100,
				"type": 4,
				"zip": "053800"
			}, {
				"id": 131183,
				"name": "其它区",
				"parent_id": 131100,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 130100,
			"name": "石家庄市",
			"parent_id": 130000,
			"type": 3,
			"zip": "050000",
			"district": [{
				"id": 130103,
				"name": "桥东区",
				"parent_id": 130100,
				"type": 4,
				"zip": "050011"
			}, {
				"id": 130102,
				"name": "长安区",
				"parent_id": 130100,
				"type": 4,
				"zip": "050011"
			}, {
				"id": 130108,
				"name": "裕华区",
				"parent_id": 130100,
				"type": 4,
				"zip": "050081"
			}, {
				"id": 130105,
				"name": "新华区",
				"parent_id": 130100,
				"type": 4,
				"zip": "050051"
			}, {
				"id": 130104,
				"name": "桥西区",
				"parent_id": 130100,
				"type": 4,
				"zip": "050051"
			}, {
				"id": 130107,
				"name": "井陉矿区",
				"parent_id": 130100,
				"type": 4,
				"zip": "050100"
			}, {
				"id": 130123,
				"name": "正定县",
				"parent_id": 130100,
				"type": 4,
				"zip": "050800"
			}, {
				"id": 130121,
				"name": "井陉县",
				"parent_id": 130100,
				"type": 4,
				"zip": "050300"
			}, {
				"id": 130126,
				"name": "灵寿县",
				"parent_id": 130100,
				"type": 4,
				"zip": "050500"
			}, {
				"id": 130127,
				"name": "高邑县",
				"parent_id": 130100,
				"type": 4,
				"zip": "051330"
			}, {
				"id": 130124,
				"name": "栾城县",
				"parent_id": 130100,
				"type": 4,
				"zip": "051430"
			}, {
				"id": 130125,
				"name": "行唐县",
				"parent_id": 130100,
				"type": 4,
				"zip": "050600"
			}, {
				"id": 130131,
				"name": "平山县",
				"parent_id": 130100,
				"type": 4,
				"zip": "050400"
			}, {
				"id": 130130,
				"name": "无极县",
				"parent_id": 130100,
				"type": 4,
				"zip": "052460"
			}, {
				"id": 130129,
				"name": "赞皇县",
				"parent_id": 130100,
				"type": 4,
				"zip": "051230"
			}, {
				"id": 130128,
				"name": "深泽县",
				"parent_id": 130100,
				"type": 4,
				"zip": "052560"
			}, {
				"id": 130133,
				"name": "赵县",
				"parent_id": 130100,
				"type": 4,
				"zip": "051530"
			}, {
				"id": 130132,
				"name": "元氏县",
				"parent_id": 130100,
				"type": 4,
				"zip": "051130"
			}, {
				"id": 130186,
				"name": "其它区",
				"parent_id": 130100,
				"type": 4,
				"zip": ""
			}, {
				"id": 130185,
				"name": "鹿泉市",
				"parent_id": 130100,
				"type": 4,
				"zip": "050200"
			}, {
				"id": 130184,
				"name": "新乐市",
				"parent_id": 130100,
				"type": 4,
				"zip": "050700"
			}, {
				"id": 130183,
				"name": "晋州市",
				"parent_id": 130100,
				"type": 4,
				"zip": "052260"
			}, {
				"id": 130182,
				"name": "藁城市",
				"parent_id": 130100,
				"type": 4,
				"zip": "052160"
			}, {
				"id": 130181,
				"name": "辛集市",
				"parent_id": 130100,
				"type": 4,
				"zip": "052360"
			}]
		}, {
			"id": 130200,
			"name": "唐山市",
			"parent_id": 130000,
			"type": 3,
			"zip": "063000",
			"district": [{
				"id": 130223,
				"name": "滦县",
				"parent_id": 130200,
				"type": 4,
				"zip": "063700"
			}, {
				"id": 130208,
				"name": "丰润区",
				"parent_id": 130200,
				"type": 4,
				"zip": "064000"
			}, {
				"id": 130229,
				"name": "玉田县",
				"parent_id": 130200,
				"type": 4,
				"zip": "064100"
			}, {
				"id": 130230,
				"name": "曹妃甸区",
				"parent_id": 130200,
				"type": 4,
				"zip": "063200"
			}, {
				"id": 130224,
				"name": "滦南县",
				"parent_id": 130200,
				"type": 4,
				"zip": "063500"
			}, {
				"id": 130225,
				"name": "乐亭县",
				"parent_id": 130200,
				"type": 4,
				"zip": "063600"
			}, {
				"id": 130227,
				"name": "迁西县",
				"parent_id": 130200,
				"type": 4,
				"zip": "064300"
			}, {
				"id": 130207,
				"name": "丰南区",
				"parent_id": 130200,
				"type": 4,
				"zip": "063300"
			}, {
				"id": 130204,
				"name": "古冶区",
				"parent_id": 130200,
				"type": 4,
				"zip": "063104"
			}, {
				"id": 130205,
				"name": "开平区",
				"parent_id": 130200,
				"type": 4,
				"zip": "063021"
			}, {
				"id": 130202,
				"name": "路南区",
				"parent_id": 130200,
				"type": 4,
				"zip": "063017"
			}, {
				"id": 130203,
				"name": "路北区",
				"parent_id": 130200,
				"type": 4,
				"zip": "063015"
			}, {
				"id": 130281,
				"name": "遵化市",
				"parent_id": 130200,
				"type": 4,
				"zip": "064200"
			}, {
				"id": 130283,
				"name": "迁安市",
				"parent_id": 130200,
				"type": 4,
				"zip": "064400"
			}, {
				"id": 130284,
				"name": "其它区",
				"parent_id": 130200,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 130300,
			"name": "秦皇岛市",
			"parent_id": 130000,
			"type": 3,
			"zip": "066000",
			"district": [{
				"id": 130302,
				"name": "海港区",
				"parent_id": 130300,
				"type": 4,
				"zip": "066000"
			}, {
				"id": 130303,
				"name": "山海关区",
				"parent_id": 130300,
				"type": 4,
				"zip": "066200"
			}, {
				"id": 130324,
				"name": "卢龙县",
				"parent_id": 130300,
				"type": 4,
				"zip": "066400"
			}, {
				"id": 130321,
				"name": "青龙满族自治县",
				"parent_id": 130300,
				"type": 4,
				"zip": "066500"
			}, {
				"id": 130323,
				"name": "抚宁县",
				"parent_id": 130300,
				"type": 4,
				"zip": "066300"
			}, {
				"id": 130322,
				"name": "昌黎县",
				"parent_id": 130300,
				"type": 4,
				"zip": "066600"
			}, {
				"id": 130304,
				"name": "北戴河区",
				"parent_id": 130300,
				"type": 4,
				"zip": "066100"
			}, {
				"id": 130399,
				"name": "经济技术开发区",
				"parent_id": 130300,
				"type": 4,
				"zip": ""
			}, {
				"id": 130398,
				"name": "其它区",
				"parent_id": 130300,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 130400,
			"name": "邯郸市",
			"parent_id": 130000,
			"type": 3,
			"zip": "056000",
			"district": [{
				"id": 130423,
				"name": "临漳县",
				"parent_id": 130400,
				"type": 4,
				"zip": "056600"
			}, {
				"id": 130421,
				"name": "邯郸县",
				"parent_id": 130400,
				"type": 4,
				"zip": "056105"
			}, {
				"id": 130427,
				"name": "磁县",
				"parent_id": 130400,
				"type": 4,
				"zip": "056500"
			}, {
				"id": 130426,
				"name": "涉县",
				"parent_id": 130400,
				"type": 4,
				"zip": "056400"
			}, {
				"id": 130425,
				"name": "大名县",
				"parent_id": 130400,
				"type": 4,
				"zip": "056900"
			}, {
				"id": 130424,
				"name": "成安县",
				"parent_id": 130400,
				"type": 4,
				"zip": "056700"
			}, {
				"id": 130431,
				"name": "鸡泽县",
				"parent_id": 130400,
				"type": 4,
				"zip": "057350"
			}, {
				"id": 130430,
				"name": "邱县",
				"parent_id": 130400,
				"type": 4,
				"zip": "057450"
			}, {
				"id": 130429,
				"name": "永年县",
				"parent_id": 130400,
				"type": 4,
				"zip": "057150"
			}, {
				"id": 130428,
				"name": "肥乡县",
				"parent_id": 130400,
				"type": 4,
				"zip": "057550"
			}, {
				"id": 130402,
				"name": "邯山区",
				"parent_id": 130400,
				"type": 4,
				"zip": "056001"
			}, {
				"id": 130403,
				"name": "丛台区",
				"parent_id": 130400,
				"type": 4,
				"zip": "056004"
			}, {
				"id": 130406,
				"name": "峰峰矿区",
				"parent_id": 130400,
				"type": 4,
				"zip": "056200"
			}, {
				"id": 130404,
				"name": "复兴区",
				"parent_id": 130400,
				"type": 4,
				"zip": "056003"
			}, {
				"id": 130482,
				"name": "其它区",
				"parent_id": 130400,
				"type": 4,
				"zip": ""
			}, {
				"id": 130481,
				"name": "武安市",
				"parent_id": 130400,
				"type": 4,
				"zip": "056300"
			}, {
				"id": 130433,
				"name": "馆陶县",
				"parent_id": 130400,
				"type": 4,
				"zip": "057750"
			}, {
				"id": 130432,
				"name": "广平县",
				"parent_id": 130400,
				"type": 4,
				"zip": "057650"
			}, {
				"id": 130435,
				"name": "曲周县",
				"parent_id": 130400,
				"type": 4,
				"zip": "057250"
			}, {
				"id": 130434,
				"name": "魏县",
				"parent_id": 130400,
				"type": 4,
				"zip": "056800"
			}]
		}, {
			"id": 130500,
			"name": "邢台市",
			"parent_id": 130000,
			"type": 3,
			"zip": "054000",
			"district": [{
				"id": 130531,
				"name": "广宗县",
				"parent_id": 130500,
				"type": 4,
				"zip": "054600"
			}, {
				"id": 130530,
				"name": "新河县",
				"parent_id": 130500,
				"type": 4,
				"zip": "055650"
			}, {
				"id": 130529,
				"name": "巨鹿县",
				"parent_id": 130500,
				"type": 4,
				"zip": "055250"
			}, {
				"id": 130528,
				"name": "宁晋县",
				"parent_id": 130500,
				"type": 4,
				"zip": "055550"
			}, {
				"id": 130535,
				"name": "临西县",
				"parent_id": 130500,
				"type": 4,
				"zip": "054900"
			}, {
				"id": 130534,
				"name": "清河县",
				"parent_id": 130500,
				"type": 4,
				"zip": "054800"
			}, {
				"id": 130533,
				"name": "威县",
				"parent_id": 130500,
				"type": 4,
				"zip": "054700"
			}, {
				"id": 130532,
				"name": "平乡县",
				"parent_id": 130500,
				"type": 4,
				"zip": "054500"
			}, {
				"id": 130521,
				"name": "邢台县",
				"parent_id": 130500,
				"type": 4,
				"zip": "054001"
			}, {
				"id": 130522,
				"name": "临城县",
				"parent_id": 130500,
				"type": 4,
				"zip": "054300"
			}, {
				"id": 130523,
				"name": "内丘县",
				"parent_id": 130500,
				"type": 4,
				"zip": "054200"
			}, {
				"id": 130524,
				"name": "柏乡县",
				"parent_id": 130500,
				"type": 4,
				"zip": "055450"
			}, {
				"id": 130525,
				"name": "隆尧县",
				"parent_id": 130500,
				"type": 4,
				"zip": "055350"
			}, {
				"id": 130526,
				"name": "任县",
				"parent_id": 130500,
				"type": 4,
				"zip": "055150"
			}, {
				"id": 130527,
				"name": "南和县",
				"parent_id": 130500,
				"type": 4,
				"zip": "054400"
			}, {
				"id": 130503,
				"name": "桥西区",
				"parent_id": 130500,
				"type": 4,
				"zip": "054000"
			}, {
				"id": 130502,
				"name": "桥东区",
				"parent_id": 130500,
				"type": 4,
				"zip": "054001"
			}, {
				"id": 130583,
				"name": "其它区",
				"parent_id": 130500,
				"type": 4,
				"zip": ""
			}, {
				"id": 130582,
				"name": "沙河市",
				"parent_id": 130500,
				"type": 4,
				"zip": "054100"
			}, {
				"id": 130581,
				"name": "南宫市",
				"parent_id": 130500,
				"type": 4,
				"zip": "055750"
			}]
		}, {
			"id": 130600,
			"name": "保定市",
			"parent_id": 130000,
			"type": 3,
			"zip": "071000",
			"district": [{
				"id": 130602,
				"name": "新市区",
				"parent_id": 130600,
				"type": 4,
				"zip": "071052"
			}, {
				"id": 130603,
				"name": "北市区",
				"parent_id": 130600,
				"type": 4,
				"zip": "071000"
			}, {
				"id": 130604,
				"name": "南市区",
				"parent_id": 130600,
				"type": 4,
				"zip": "071000"
			}, {
				"id": 130621,
				"name": "满城县",
				"parent_id": 130600,
				"type": 4,
				"zip": "072150"
			}, {
				"id": 130623,
				"name": "涞水县",
				"parent_id": 130600,
				"type": 4,
				"zip": "074100"
			}, {
				"id": 130622,
				"name": "清苑县",
				"parent_id": 130600,
				"type": 4,
				"zip": "071100"
			}, {
				"id": 130630,
				"name": "涞源县",
				"parent_id": 130600,
				"type": 4,
				"zip": "074300"
			}, {
				"id": 130631,
				"name": "望都县",
				"parent_id": 130600,
				"type": 4,
				"zip": "072450"
			}, {
				"id": 130628,
				"name": "高阳县",
				"parent_id": 130600,
				"type": 4,
				"zip": "071500"
			}, {
				"id": 130629,
				"name": "容城县",
				"parent_id": 130600,
				"type": 4,
				"zip": "071700"
			}, {
				"id": 130626,
				"name": "定兴县",
				"parent_id": 130600,
				"type": 4,
				"zip": "072650"
			}, {
				"id": 130627,
				"name": "唐县",
				"parent_id": 130600,
				"type": 4,
				"zip": "072350"
			}, {
				"id": 130624,
				"name": "阜平县",
				"parent_id": 130600,
				"type": 4,
				"zip": "073200"
			}, {
				"id": 130625,
				"name": "徐水县",
				"parent_id": 130600,
				"type": 4,
				"zip": "072550"
			}, {
				"id": 130638,
				"name": "雄县",
				"parent_id": 130600,
				"type": 4,
				"zip": "071800"
			}, {
				"id": 130636,
				"name": "顺平县",
				"parent_id": 130600,
				"type": 4,
				"zip": "072250"
			}, {
				"id": 130637,
				"name": "博野县",
				"parent_id": 130600,
				"type": 4,
				"zip": "071300"
			}, {
				"id": 130634,
				"name": "曲阳县",
				"parent_id": 130600,
				"type": 4,
				"zip": "073100"
			}, {
				"id": 130635,
				"name": "蠡县",
				"parent_id": 130600,
				"type": 4,
				"zip": "071400"
			}, {
				"id": 130632,
				"name": "安新县",
				"parent_id": 130600,
				"type": 4,
				"zip": "071600"
			}, {
				"id": 130633,
				"name": "易县",
				"parent_id": 130600,
				"type": 4,
				"zip": "074200"
			}, {
				"id": 130684,
				"name": "高碑店市",
				"parent_id": 130600,
				"type": 4,
				"zip": "074000"
			}, {
				"id": 130681,
				"name": "涿州市",
				"parent_id": 130600,
				"type": 4,
				"zip": "072750"
			}, {
				"id": 130683,
				"name": "安国市",
				"parent_id": 130600,
				"type": 4,
				"zip": "071200"
			}, {
				"id": 130682,
				"name": "定州市",
				"parent_id": 130600,
				"type": 4,
				"zip": "073000"
			}, {
				"id": 130699,
				"name": "其它区",
				"parent_id": 130600,
				"type": 4,
				"zip": ""
			}, {
				"id": 130698,
				"name": "高开区",
				"parent_id": 130600,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 130700,
			"name": "张家口市",
			"parent_id": 130000,
			"type": 3,
			"zip": "075000",
			"district": [{
				"id": 130703,
				"name": "桥西区",
				"parent_id": 130700,
				"type": 4,
				"zip": "075061"
			}, {
				"id": 130702,
				"name": "桥东区",
				"parent_id": 130700,
				"type": 4,
				"zip": "075000"
			}, {
				"id": 130706,
				"name": "下花园区",
				"parent_id": 130700,
				"type": 4,
				"zip": "075300"
			}, {
				"id": 130705,
				"name": "宣化区",
				"parent_id": 130700,
				"type": 4,
				"zip": "075100"
			}, {
				"id": 130729,
				"name": "万全县",
				"parent_id": 130700,
				"type": 4,
				"zip": "076250"
			}, {
				"id": 130728,
				"name": "怀安县",
				"parent_id": 130700,
				"type": 4,
				"zip": "076150"
			}, {
				"id": 130731,
				"name": "涿鹿县",
				"parent_id": 130700,
				"type": 4,
				"zip": "075600"
			}, {
				"id": 130730,
				"name": "怀来县",
				"parent_id": 130700,
				"type": 4,
				"zip": "075400"
			}, {
				"id": 130733,
				"name": "崇礼县",
				"parent_id": 130700,
				"type": 4,
				"zip": "076350"
			}, {
				"id": 130732,
				"name": "赤城县",
				"parent_id": 130700,
				"type": 4,
				"zip": "075500"
			}, {
				"id": 130734,
				"name": "其它区",
				"parent_id": 130700,
				"type": 4,
				"zip": ""
			}, {
				"id": 130721,
				"name": "宣化县",
				"parent_id": 130700,
				"type": 4,
				"zip": "075100"
			}, {
				"id": 130723,
				"name": "康保县",
				"parent_id": 130700,
				"type": 4,
				"zip": "076650"
			}, {
				"id": 130722,
				"name": "张北县",
				"parent_id": 130700,
				"type": 4,
				"zip": "076450"
			}, {
				"id": 130725,
				"name": "尚义县",
				"parent_id": 130700,
				"type": 4,
				"zip": "076750"
			}, {
				"id": 130724,
				"name": "沽源县",
				"parent_id": 130700,
				"type": 4,
				"zip": "076550"
			}, {
				"id": 130727,
				"name": "阳原县",
				"parent_id": 130700,
				"type": 4,
				"zip": "075800"
			}, {
				"id": 130726,
				"name": "蔚县",
				"parent_id": 130700,
				"type": 4,
				"zip": "075700"
			}]
		}, {
			"id": 130800,
			"name": "承德市",
			"parent_id": 130000,
			"type": 3,
			"zip": "067000",
			"district": [{
				"id": 130804,
				"name": "鹰手营子矿区",
				"parent_id": 130800,
				"type": 4,
				"zip": "067000"
			}, {
				"id": 130802,
				"name": "双桥区",
				"parent_id": 130800,
				"type": 4,
				"zip": "067000"
			}, {
				"id": 130803,
				"name": "双滦区",
				"parent_id": 130800,
				"type": 4,
				"zip": "067000"
			}, {
				"id": 130821,
				"name": "承德县",
				"parent_id": 130800,
				"type": 4,
				"zip": "067400"
			}, {
				"id": 130822,
				"name": "兴隆县",
				"parent_id": 130800,
				"type": 4,
				"zip": "067300"
			}, {
				"id": 130823,
				"name": "平泉县",
				"parent_id": 130800,
				"type": 4,
				"zip": "067500"
			}, {
				"id": 130824,
				"name": "滦平县",
				"parent_id": 130800,
				"type": 4,
				"zip": "068250"
			}, {
				"id": 130825,
				"name": "隆化县",
				"parent_id": 130800,
				"type": 4,
				"zip": "068150"
			}, {
				"id": 130826,
				"name": "丰宁满族自治县",
				"parent_id": 130800,
				"type": 4,
				"zip": "068350"
			}, {
				"id": 130827,
				"name": "宽城满族自治县",
				"parent_id": 130800,
				"type": 4,
				"zip": "067600"
			}, {
				"id": 130828,
				"name": "围场满族蒙古族自治县",
				"parent_id": 130800,
				"type": 4,
				"zip": "068450"
			}, {
				"id": 130829,
				"name": "其它区",
				"parent_id": 130800,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 130900,
			"name": "沧州市",
			"parent_id": 130000,
			"type": 3,
			"zip": "061000",
			"district": [{
				"id": 130903,
				"name": "运河区",
				"parent_id": 130900,
				"type": 4,
				"zip": "061000"
			}, {
				"id": 130902,
				"name": "新华区",
				"parent_id": 130900,
				"type": 4,
				"zip": "061000"
			}, {
				"id": 130930,
				"name": "孟村回族自治县",
				"parent_id": 130900,
				"type": 4,
				"zip": "061400"
			}, {
				"id": 130929,
				"name": "献县",
				"parent_id": 130900,
				"type": 4,
				"zip": "062250"
			}, {
				"id": 130928,
				"name": "吴桥县",
				"parent_id": 130900,
				"type": 4,
				"zip": "061800"
			}, {
				"id": 130926,
				"name": "肃宁县",
				"parent_id": 130900,
				"type": 4,
				"zip": "062350"
			}, {
				"id": 130927,
				"name": "南皮县",
				"parent_id": 130900,
				"type": 4,
				"zip": "061500"
			}, {
				"id": 130924,
				"name": "海兴县",
				"parent_id": 130900,
				"type": 4,
				"zip": "061200"
			}, {
				"id": 130925,
				"name": "盐山县",
				"parent_id": 130900,
				"type": 4,
				"zip": "061300"
			}, {
				"id": 130922,
				"name": "青县",
				"parent_id": 130900,
				"type": 4,
				"zip": "062650"
			}, {
				"id": 130923,
				"name": "东光县",
				"parent_id": 130900,
				"type": 4,
				"zip": "061600"
			}, {
				"id": 130921,
				"name": "沧县",
				"parent_id": 130900,
				"type": 4,
				"zip": "061035"
			}, {
				"id": 130985,
				"name": "其它区",
				"parent_id": 130900,
				"type": 4,
				"zip": ""
			}, {
				"id": 130984,
				"name": "河间市",
				"parent_id": 130900,
				"type": 4,
				"zip": "062450"
			}, {
				"id": 130983,
				"name": "黄骅市",
				"parent_id": 130900,
				"type": 4,
				"zip": "061100"
			}, {
				"id": 130982,
				"name": "任丘市",
				"parent_id": 130900,
				"type": 4,
				"zip": "062550"
			}, {
				"id": 130981,
				"name": "泊头市",
				"parent_id": 130900,
				"type": 4,
				"zip": "062150"
			}]
		}, {
			"id": 131000,
			"name": "廊坊市",
			"parent_id": 130000,
			"type": 3,
			"zip": "065000",
			"district": [{
				"id": 131082,
				"name": "三河市",
				"parent_id": 131000,
				"type": 4,
				"zip": "065200"
			}, {
				"id": 131083,
				"name": "其它区",
				"parent_id": 131000,
				"type": 4,
				"zip": ""
			}, {
				"id": 131081,
				"name": "霸州市",
				"parent_id": 131000,
				"type": 4,
				"zip": "065700"
			}, {
				"id": 131002,
				"name": "安次区",
				"parent_id": 131000,
				"type": 4,
				"zip": "065000"
			}, {
				"id": 131003,
				"name": "广阳区",
				"parent_id": 131000,
				"type": 4,
				"zip": "065000"
			}, {
				"id": 131028,
				"name": "大厂回族自治县",
				"parent_id": 131000,
				"type": 4,
				"zip": "065300"
			}, {
				"id": 131024,
				"name": "香河县",
				"parent_id": 131000,
				"type": 4,
				"zip": "065400"
			}, {
				"id": 131025,
				"name": "大城县",
				"parent_id": 131000,
				"type": 4,
				"zip": "065900"
			}, {
				"id": 131026,
				"name": "文安县",
				"parent_id": 131000,
				"type": 4,
				"zip": "065800"
			}, {
				"id": 131023,
				"name": "永清县",
				"parent_id": 131000,
				"type": 4,
				"zip": "065600"
			}, {
				"id": 131022,
				"name": "固安县",
				"parent_id": 131000,
				"type": 4,
				"zip": "065500"
			}, {
				"id": 131052,
				"name": "燕郊经济技术开发区",
				"parent_id": 131000,
				"type": 4,
				"zip": ""
			}, {
				"id": 131051,
				"name": "开发区",
				"parent_id": 131000,
				"type": 4,
				"zip": ""
			}]
		}]
	}, {
		"id": 430000,
		"name": "湖南省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 431200,
			"name": "怀化市",
			"parent_id": 430000,
			"type": 3,
			"zip": "418000",
			"district": [{
				"id": 431202,
				"name": "鹤城区",
				"parent_id": 431200,
				"type": 4,
				"zip": "418000"
			}, {
				"id": 431221,
				"name": "中方县",
				"parent_id": 431200,
				"type": 4,
				"zip": "418005"
			}, {
				"id": 431222,
				"name": "沅陵县",
				"parent_id": 431200,
				"type": 4,
				"zip": "419600"
			}, {
				"id": 431223,
				"name": "辰溪县",
				"parent_id": 431200,
				"type": 4,
				"zip": "419500"
			}, {
				"id": 431224,
				"name": "溆浦县",
				"parent_id": 431200,
				"type": 4,
				"zip": "419300"
			}, {
				"id": 431225,
				"name": "会同县",
				"parent_id": 431200,
				"type": 4,
				"zip": "418300"
			}, {
				"id": 431226,
				"name": "麻阳苗族自治县",
				"parent_id": 431200,
				"type": 4,
				"zip": "419400"
			}, {
				"id": 431227,
				"name": "新晃侗族自治县",
				"parent_id": 431200,
				"type": 4,
				"zip": "419200"
			}, {
				"id": 431228,
				"name": "芷江侗族自治县",
				"parent_id": 431200,
				"type": 4,
				"zip": "419100"
			}, {
				"id": 431229,
				"name": "靖州苗族侗族自治县",
				"parent_id": 431200,
				"type": 4,
				"zip": "418400"
			}, {
				"id": 431230,
				"name": "通道侗族自治县",
				"parent_id": 431200,
				"type": 4,
				"zip": "418500"
			}, {
				"id": 431281,
				"name": "洪江市",
				"parent_id": 431200,
				"type": 4,
				"zip": "418200"
			}, {
				"id": 431282,
				"name": "其它区",
				"parent_id": 431200,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 431300,
			"name": "娄底市",
			"parent_id": 430000,
			"type": 3,
			"zip": "417000",
			"district": [{
				"id": 431302,
				"name": "娄星区",
				"parent_id": 431300,
				"type": 4,
				"zip": "417000"
			}, {
				"id": 431322,
				"name": "新化县",
				"parent_id": 431300,
				"type": 4,
				"zip": "417600"
			}, {
				"id": 431321,
				"name": "双峰县",
				"parent_id": 431300,
				"type": 4,
				"zip": "417700"
			}, {
				"id": 431381,
				"name": "冷水江市",
				"parent_id": 431300,
				"type": 4,
				"zip": "417500"
			}, {
				"id": 431382,
				"name": "涟源市",
				"parent_id": 431300,
				"type": 4,
				"zip": "417100"
			}, {
				"id": 431383,
				"name": "其它区",
				"parent_id": 431300,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 430200,
			"name": "株洲市",
			"parent_id": 430000,
			"type": 3,
			"zip": "412000",
			"district": [{
				"id": 430202,
				"name": "荷塘区",
				"parent_id": 430200,
				"type": 4,
				"zip": "412000"
			}, {
				"id": 430203,
				"name": "芦淞区",
				"parent_id": 430200,
				"type": 4,
				"zip": "412000"
			}, {
				"id": 430204,
				"name": "石峰区",
				"parent_id": 430200,
				"type": 4,
				"zip": "412005"
			}, {
				"id": 430282,
				"name": "其它区",
				"parent_id": 430200,
				"type": 4,
				"zip": ""
			}, {
				"id": 430281,
				"name": "醴陵市",
				"parent_id": 430200,
				"type": 4,
				"zip": "412200"
			}, {
				"id": 430211,
				"name": "天元区",
				"parent_id": 430200,
				"type": 4,
				"zip": "412000"
			}, {
				"id": 430223,
				"name": "攸县",
				"parent_id": 430200,
				"type": 4,
				"zip": "412300"
			}, {
				"id": 430221,
				"name": "株洲县",
				"parent_id": 430200,
				"type": 4,
				"zip": "412100"
			}, {
				"id": 430225,
				"name": "炎陵县",
				"parent_id": 430200,
				"type": 4,
				"zip": "412500"
			}, {
				"id": 430224,
				"name": "茶陵县",
				"parent_id": 430200,
				"type": 4,
				"zip": "412400"
			}]
		}, {
			"id": 430100,
			"name": "长沙市",
			"parent_id": 430000,
			"type": 3,
			"zip": "410000",
			"district": [{
				"id": 430181,
				"name": "浏阳市",
				"parent_id": 430100,
				"type": 4,
				"zip": "410300"
			}, {
				"id": 430182,
				"name": "其它区",
				"parent_id": 430100,
				"type": 4,
				"zip": ""
			}, {
				"id": 430111,
				"name": "雨花区",
				"parent_id": 430100,
				"type": 4,
				"zip": "410007"
			}, {
				"id": 430104,
				"name": "岳麓区",
				"parent_id": 430100,
				"type": 4,
				"zip": "410006"
			}, {
				"id": 430105,
				"name": "开福区",
				"parent_id": 430100,
				"type": 4,
				"zip": "410005"
			}, {
				"id": 430102,
				"name": "芙蓉区",
				"parent_id": 430100,
				"type": 4,
				"zip": "410006"
			}, {
				"id": 430103,
				"name": "天心区",
				"parent_id": 430100,
				"type": 4,
				"zip": "410002"
			}, {
				"id": 430124,
				"name": "宁乡县",
				"parent_id": 430100,
				"type": 4,
				"zip": "410600"
			}, {
				"id": 430121,
				"name": "长沙县",
				"parent_id": 430100,
				"type": 4,
				"zip": "410100"
			}, {
				"id": 430122,
				"name": "望城区",
				"parent_id": 430100,
				"type": 4,
				"zip": "410200"
			}]
		}, {
			"id": 430300,
			"name": "湘潭市",
			"parent_id": 430000,
			"type": 3,
			"zip": "411100",
			"district": [{
				"id": 430302,
				"name": "雨湖区",
				"parent_id": 430300,
				"type": 4,
				"zip": "411100"
			}, {
				"id": 430304,
				"name": "岳塘区",
				"parent_id": 430300,
				"type": 4,
				"zip": "411101"
			}, {
				"id": 430321,
				"name": "湘潭县",
				"parent_id": 430300,
				"type": 4,
				"zip": "411200"
			}, {
				"id": 430383,
				"name": "其它区",
				"parent_id": 430300,
				"type": 4,
				"zip": ""
			}, {
				"id": 430382,
				"name": "韶山市",
				"parent_id": 430300,
				"type": 4,
				"zip": "411300"
			}, {
				"id": 430381,
				"name": "湘乡市",
				"parent_id": 430300,
				"type": 4,
				"zip": "411400"
			}]
		}, {
			"id": 430400,
			"name": "衡阳市",
			"parent_id": 430000,
			"type": 3,
			"zip": "421000",
			"district": [{
				"id": 430424,
				"name": "衡东县",
				"parent_id": 430400,
				"type": 4,
				"zip": "421400"
			}, {
				"id": 430426,
				"name": "祁东县",
				"parent_id": 430400,
				"type": 4,
				"zip": "421600"
			}, {
				"id": 430421,
				"name": "衡阳县",
				"parent_id": 430400,
				"type": 4,
				"zip": "421200"
			}, {
				"id": 430422,
				"name": "衡南县",
				"parent_id": 430400,
				"type": 4,
				"zip": "421100"
			}, {
				"id": 430423,
				"name": "衡山县",
				"parent_id": 430400,
				"type": 4,
				"zip": "421300"
			}, {
				"id": 430408,
				"name": "蒸湘区",
				"parent_id": 430400,
				"type": 4,
				"zip": "421001"
			}, {
				"id": 430412,
				"name": "南岳区",
				"parent_id": 430400,
				"type": 4,
				"zip": "421900"
			}, {
				"id": 430405,
				"name": "珠晖区",
				"parent_id": 430400,
				"type": 4,
				"zip": "421002"
			}, {
				"id": 430407,
				"name": "石鼓区",
				"parent_id": 430400,
				"type": 4,
				"zip": "421001"
			}, {
				"id": 430406,
				"name": "雁峰区",
				"parent_id": 430400,
				"type": 4,
				"zip": "421001"
			}, {
				"id": 430481,
				"name": "耒阳市",
				"parent_id": 430400,
				"type": 4,
				"zip": "421800"
			}, {
				"id": 430483,
				"name": "其它区",
				"parent_id": 430400,
				"type": 4,
				"zip": ""
			}, {
				"id": 430482,
				"name": "常宁市",
				"parent_id": 430400,
				"type": 4,
				"zip": "421500"
			}]
		}, {
			"id": 430500,
			"name": "邵阳市",
			"parent_id": 430000,
			"type": 3,
			"zip": "422000",
			"district": [{
				"id": 430528,
				"name": "新宁县",
				"parent_id": 430500,
				"type": 4,
				"zip": "422700"
			}, {
				"id": 430529,
				"name": "城步苗族自治县",
				"parent_id": 430500,
				"type": 4,
				"zip": "422500"
			}, {
				"id": 430582,
				"name": "其它区",
				"parent_id": 430500,
				"type": 4,
				"zip": ""
			}, {
				"id": 430581,
				"name": "武冈市",
				"parent_id": 430500,
				"type": 4,
				"zip": "422400"
			}, {
				"id": 430527,
				"name": "绥宁县",
				"parent_id": 430500,
				"type": 4,
				"zip": "422600"
			}, {
				"id": 430525,
				"name": "洞口县",
				"parent_id": 430500,
				"type": 4,
				"zip": "422300"
			}, {
				"id": 430524,
				"name": "隆回县",
				"parent_id": 430500,
				"type": 4,
				"zip": "422200"
			}, {
				"id": 430523,
				"name": "邵阳县",
				"parent_id": 430500,
				"type": 4,
				"zip": "422100"
			}, {
				"id": 430522,
				"name": "新邵县",
				"parent_id": 430500,
				"type": 4,
				"zip": "422900"
			}, {
				"id": 430521,
				"name": "邵东县",
				"parent_id": 430500,
				"type": 4,
				"zip": "422800"
			}, {
				"id": 430502,
				"name": "双清区",
				"parent_id": 430500,
				"type": 4,
				"zip": "422001"
			}, {
				"id": 430503,
				"name": "大祥区",
				"parent_id": 430500,
				"type": 4,
				"zip": "422000"
			}, {
				"id": 430511,
				"name": "北塔区",
				"parent_id": 430500,
				"type": 4,
				"zip": "422001"
			}]
		}, {
			"id": 430700,
			"name": "常德市",
			"parent_id": 430000,
			"type": 3,
			"zip": "415000",
			"district": [{
				"id": 430703,
				"name": "鼎城区",
				"parent_id": 430700,
				"type": 4,
				"zip": "415100"
			}, {
				"id": 430702,
				"name": "武陵区",
				"parent_id": 430700,
				"type": 4,
				"zip": "415000"
			}, {
				"id": 430781,
				"name": "津市市",
				"parent_id": 430700,
				"type": 4,
				"zip": "415400"
			}, {
				"id": 430782,
				"name": "其它区",
				"parent_id": 430700,
				"type": 4,
				"zip": ""
			}, {
				"id": 430722,
				"name": "汉寿县",
				"parent_id": 430700,
				"type": 4,
				"zip": "415900"
			}, {
				"id": 430723,
				"name": "澧县",
				"parent_id": 430700,
				"type": 4,
				"zip": "415500"
			}, {
				"id": 430721,
				"name": "安乡县",
				"parent_id": 430700,
				"type": 4,
				"zip": "415600"
			}, {
				"id": 430726,
				"name": "石门县",
				"parent_id": 430700,
				"type": 4,
				"zip": "415300"
			}, {
				"id": 430724,
				"name": "临澧县",
				"parent_id": 430700,
				"type": 4,
				"zip": "415200"
			}, {
				"id": 430725,
				"name": "桃源县",
				"parent_id": 430700,
				"type": 4,
				"zip": "415700"
			}]
		}, {
			"id": 430600,
			"name": "岳阳市",
			"parent_id": 430000,
			"type": 3,
			"zip": "414000",
			"district": [{
				"id": 430682,
				"name": "临湘市",
				"parent_id": 430600,
				"type": 4,
				"zip": "414300"
			}, {
				"id": 430683,
				"name": "其它区",
				"parent_id": 430600,
				"type": 4,
				"zip": ""
			}, {
				"id": 430681,
				"name": "汨罗市",
				"parent_id": 430600,
				"type": 4,
				"zip": "414400"
			}, {
				"id": 430624,
				"name": "湘阴县",
				"parent_id": 430600,
				"type": 4,
				"zip": "414600"
			}, {
				"id": 430626,
				"name": "平江县",
				"parent_id": 430600,
				"type": 4,
				"zip": "410400"
			}, {
				"id": 430603,
				"name": "云溪区",
				"parent_id": 430600,
				"type": 4,
				"zip": "414003"
			}, {
				"id": 430602,
				"name": "岳阳楼区",
				"parent_id": 430600,
				"type": 4,
				"zip": "414000"
			}, {
				"id": 430623,
				"name": "华容县",
				"parent_id": 430600,
				"type": 4,
				"zip": "414200"
			}, {
				"id": 430621,
				"name": "岳阳县",
				"parent_id": 430600,
				"type": 4,
				"zip": "414100"
			}, {
				"id": 430611,
				"name": "君山区",
				"parent_id": 430600,
				"type": 4,
				"zip": "414005"
			}]
		}, {
			"id": 430800,
			"name": "张家界市",
			"parent_id": 430000,
			"type": 3,
			"zip": "427000",
			"district": [{
				"id": 430821,
				"name": "慈利县",
				"parent_id": 430800,
				"type": 4,
				"zip": "427200"
			}, {
				"id": 430822,
				"name": "桑植县",
				"parent_id": 430800,
				"type": 4,
				"zip": "427100"
			}, {
				"id": 430823,
				"name": "其它区",
				"parent_id": 430800,
				"type": 4,
				"zip": ""
			}, {
				"id": 430802,
				"name": "永定区",
				"parent_id": 430800,
				"type": 4,
				"zip": "427000"
			}, {
				"id": 430811,
				"name": "武陵源区",
				"parent_id": 430800,
				"type": 4,
				"zip": "427400"
			}]
		}, {
			"id": 430900,
			"name": "益阳市",
			"parent_id": 430000,
			"type": 3,
			"zip": "413000",
			"district": [{
				"id": 430921,
				"name": "南县",
				"parent_id": 430900,
				"type": 4,
				"zip": "413200"
			}, {
				"id": 430923,
				"name": "安化县",
				"parent_id": 430900,
				"type": 4,
				"zip": "413500"
			}, {
				"id": 430922,
				"name": "桃江县",
				"parent_id": 430900,
				"type": 4,
				"zip": "413400"
			}, {
				"id": 430902,
				"name": "资阳区",
				"parent_id": 430900,
				"type": 4,
				"zip": "413000"
			}, {
				"id": 430903,
				"name": "赫山区",
				"parent_id": 430900,
				"type": 4,
				"zip": "413002"
			}, {
				"id": 430981,
				"name": "沅江市",
				"parent_id": 430900,
				"type": 4,
				"zip": "413100"
			}, {
				"id": 430982,
				"name": "其它区",
				"parent_id": 430900,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 431100,
			"name": "永州市",
			"parent_id": 430000,
			"type": 3,
			"zip": "425000",
			"district": [{
				"id": 431126,
				"name": "宁远县",
				"parent_id": 431100,
				"type": 4,
				"zip": "425600"
			}, {
				"id": 431127,
				"name": "蓝山县",
				"parent_id": 431100,
				"type": 4,
				"zip": "425800"
			}, {
				"id": 431124,
				"name": "道县",
				"parent_id": 431100,
				"type": 4,
				"zip": "425300"
			}, {
				"id": 431125,
				"name": "江永县",
				"parent_id": 431100,
				"type": 4,
				"zip": "425400"
			}, {
				"id": 431122,
				"name": "东安县",
				"parent_id": 431100,
				"type": 4,
				"zip": "425900"
			}, {
				"id": 431123,
				"name": "双牌县",
				"parent_id": 431100,
				"type": 4,
				"zip": "425200"
			}, {
				"id": 431121,
				"name": "祁阳县",
				"parent_id": 431100,
				"type": 4,
				"zip": "426100"
			}, {
				"id": 431130,
				"name": "其它区",
				"parent_id": 431100,
				"type": 4,
				"zip": ""
			}, {
				"id": 431128,
				"name": "新田县",
				"parent_id": 431100,
				"type": 4,
				"zip": "425700"
			}, {
				"id": 431129,
				"name": "江华瑶族自治县",
				"parent_id": 431100,
				"type": 4,
				"zip": "425500"
			}, {
				"id": 431103,
				"name": "冷水滩区",
				"parent_id": 431100,
				"type": 4,
				"zip": "425000"
			}, {
				"id": 431102,
				"name": "零陵区",
				"parent_id": 431100,
				"type": 4,
				"zip": "425007"
			}]
		}, {
			"id": 431000,
			"name": "郴州市",
			"parent_id": 430000,
			"type": 3,
			"zip": "423000",
			"district": [{
				"id": 431082,
				"name": "其它区",
				"parent_id": 431000,
				"type": 4,
				"zip": ""
			}, {
				"id": 431081,
				"name": "资兴市",
				"parent_id": 431000,
				"type": 4,
				"zip": "423400"
			}, {
				"id": 431027,
				"name": "桂东县",
				"parent_id": 431000,
				"type": 4,
				"zip": "423500"
			}, {
				"id": 431026,
				"name": "汝城县",
				"parent_id": 431000,
				"type": 4,
				"zip": "424100"
			}, {
				"id": 431025,
				"name": "临武县",
				"parent_id": 431000,
				"type": 4,
				"zip": "424300"
			}, {
				"id": 431024,
				"name": "嘉禾县",
				"parent_id": 431000,
				"type": 4,
				"zip": "424500"
			}, {
				"id": 431028,
				"name": "安仁县",
				"parent_id": 431000,
				"type": 4,
				"zip": "423600"
			}, {
				"id": 431022,
				"name": "宜章县",
				"parent_id": 431000,
				"type": 4,
				"zip": "424200"
			}, {
				"id": 431023,
				"name": "永兴县",
				"parent_id": 431000,
				"type": 4,
				"zip": "423300"
			}, {
				"id": 431021,
				"name": "桂阳县",
				"parent_id": 431000,
				"type": 4,
				"zip": "424400"
			}, {
				"id": 431003,
				"name": "苏仙区",
				"parent_id": 431000,
				"type": 4,
				"zip": "423000"
			}, {
				"id": 431002,
				"name": "北湖区",
				"parent_id": 431000,
				"type": 4,
				"zip": "423000"
			}]
		}, {
			"id": 433100,
			"name": "湘西土家族苗族自治州",
			"parent_id": 430000,
			"type": 3,
			"zip": "416000",
			"district": [{
				"id": 433126,
				"name": "古丈县",
				"parent_id": 433100,
				"type": 4,
				"zip": "416300"
			}, {
				"id": 433127,
				"name": "永顺县",
				"parent_id": 433100,
				"type": 4,
				"zip": "416700"
			}, {
				"id": 433124,
				"name": "花垣县",
				"parent_id": 433100,
				"type": 4,
				"zip": "416400"
			}, {
				"id": 433125,
				"name": "保靖县",
				"parent_id": 433100,
				"type": 4,
				"zip": "416500"
			}, {
				"id": 433122,
				"name": "泸溪县",
				"parent_id": 433100,
				"type": 4,
				"zip": "416100"
			}, {
				"id": 433123,
				"name": "凤凰县",
				"parent_id": 433100,
				"type": 4,
				"zip": "416200"
			}, {
				"id": 433130,
				"name": "龙山县",
				"parent_id": 433100,
				"type": 4,
				"zip": "416800"
			}, {
				"id": 433131,
				"name": "其它区",
				"parent_id": 433100,
				"type": 4,
				"zip": ""
			}, {
				"id": 433101,
				"name": "吉首市",
				"parent_id": 433100,
				"type": 4,
				"zip": "416000"
			}]
		}]
	}, {
		"id": 620000,
		"name": "甘肃省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 623000,
			"name": "甘南藏族自治州",
			"parent_id": 620000,
			"type": 3,
			"zip": "747000",
			"district": [{
				"id": 623001,
				"name": "合作市",
				"parent_id": 623000,
				"type": 4,
				"zip": "747000"
			}, {
				"id": 623021,
				"name": "临潭县",
				"parent_id": 623000,
				"type": 4,
				"zip": "747500"
			}, {
				"id": 623023,
				"name": "舟曲县",
				"parent_id": 623000,
				"type": 4,
				"zip": "746300"
			}, {
				"id": 623022,
				"name": "卓尼县",
				"parent_id": 623000,
				"type": 4,
				"zip": "747600"
			}, {
				"id": 623024,
				"name": "迭部县",
				"parent_id": 623000,
				"type": 4,
				"zip": "747400"
			}, {
				"id": 623025,
				"name": "玛曲县",
				"parent_id": 623000,
				"type": 4,
				"zip": "747300"
			}, {
				"id": 623026,
				"name": "碌曲县",
				"parent_id": 623000,
				"type": 4,
				"zip": "747200"
			}, {
				"id": 623027,
				"name": "夏河县",
				"parent_id": 623000,
				"type": 4,
				"zip": "747100"
			}, {
				"id": 623028,
				"name": "其它区",
				"parent_id": 623000,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 622900,
			"name": "临夏回族自治州",
			"parent_id": 620000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 622901,
				"name": "临夏市",
				"parent_id": 622900,
				"type": 4,
				"zip": "731100"
			}, {
				"id": 622926,
				"name": "东乡族自治县",
				"parent_id": 622900,
				"type": 4,
				"zip": "731400"
			}, {
				"id": 622927,
				"name": "积石山保安族东乡族撒拉族自治县",
				"parent_id": 622900,
				"type": 4,
				"zip": "731700"
			}, {
				"id": 622924,
				"name": "广河县",
				"parent_id": 622900,
				"type": 4,
				"zip": "731300"
			}, {
				"id": 622925,
				"name": "和政县",
				"parent_id": 622900,
				"type": 4,
				"zip": "731200"
			}, {
				"id": 622922,
				"name": "康乐县",
				"parent_id": 622900,
				"type": 4,
				"zip": "731500"
			}, {
				"id": 622923,
				"name": "永靖县",
				"parent_id": 622900,
				"type": 4,
				"zip": "731600"
			}, {
				"id": 622921,
				"name": "临夏县",
				"parent_id": 622900,
				"type": 4,
				"zip": "731800"
			}, {
				"id": 622928,
				"name": "其它区",
				"parent_id": 622900,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 620300,
			"name": "金昌市",
			"parent_id": 620000,
			"type": 3,
			"zip": "737100",
			"district": [{
				"id": 620302,
				"name": "金川区",
				"parent_id": 620300,
				"type": 4,
				"zip": "737103"
			}, {
				"id": 620322,
				"name": "其它区",
				"parent_id": 620300,
				"type": 4,
				"zip": ""
			}, {
				"id": 620321,
				"name": "永昌县",
				"parent_id": 620300,
				"type": 4,
				"zip": "737200"
			}]
		}, {
			"id": 620400,
			"name": "白银市",
			"parent_id": 620000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 620402,
				"name": "白银区",
				"parent_id": 620400,
				"type": 4,
				"zip": "730900"
			}, {
				"id": 620403,
				"name": "平川区",
				"parent_id": 620400,
				"type": 4,
				"zip": "730910"
			}, {
				"id": 620424,
				"name": "其它区",
				"parent_id": 620400,
				"type": 4,
				"zip": ""
			}, {
				"id": 620421,
				"name": "靖远县",
				"parent_id": 620400,
				"type": 4,
				"zip": "730600"
			}, {
				"id": 620422,
				"name": "会宁县",
				"parent_id": 620400,
				"type": 4,
				"zip": "730700"
			}, {
				"id": 620423,
				"name": "景泰县",
				"parent_id": 620400,
				"type": 4,
				"zip": "730400"
			}]
		}, {
			"id": 620500,
			"name": "天水市",
			"parent_id": 620000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 620503,
				"name": "麦积区",
				"parent_id": 620500,
				"type": 4,
				"zip": "741020"
			}, {
				"id": 620502,
				"name": "秦州区",
				"parent_id": 620500,
				"type": 4,
				"zip": "741000"
			}, {
				"id": 620526,
				"name": "其它区",
				"parent_id": 620500,
				"type": 4,
				"zip": ""
			}, {
				"id": 620524,
				"name": "武山县",
				"parent_id": 620500,
				"type": 4,
				"zip": "741300"
			}, {
				"id": 620525,
				"name": "张家川回族自治县",
				"parent_id": 620500,
				"type": 4,
				"zip": "741500"
			}, {
				"id": 620522,
				"name": "秦安县",
				"parent_id": 620500,
				"type": 4,
				"zip": "741600"
			}, {
				"id": 620523,
				"name": "甘谷县",
				"parent_id": 620500,
				"type": 4,
				"zip": "741200"
			}, {
				"id": 620521,
				"name": "清水县",
				"parent_id": 620500,
				"type": 4,
				"zip": "741400"
			}]
		}, {
			"id": 620100,
			"name": "兰州市",
			"parent_id": 620000,
			"type": 3,
			"zip": "730000",
			"district": [{
				"id": 620124,
				"name": "其它区",
				"parent_id": 620100,
				"type": 4,
				"zip": ""
			}, {
				"id": 620122,
				"name": "皋兰县",
				"parent_id": 620100,
				"type": 4,
				"zip": "730200"
			}, {
				"id": 620123,
				"name": "榆中县",
				"parent_id": 620100,
				"type": 4,
				"zip": "730100"
			}, {
				"id": 620121,
				"name": "永登县",
				"parent_id": 620100,
				"type": 4,
				"zip": "730300"
			}, {
				"id": 620103,
				"name": "七里河区",
				"parent_id": 620100,
				"type": 4,
				"zip": "730050"
			}, {
				"id": 620102,
				"name": "城关区",
				"parent_id": 620100,
				"type": 4,
				"zip": "730030"
			}, {
				"id": 620111,
				"name": "红古区",
				"parent_id": 620100,
				"type": 4,
				"zip": "730080"
			}, {
				"id": 620105,
				"name": "安宁区",
				"parent_id": 620100,
				"type": 4,
				"zip": "730070"
			}, {
				"id": 620104,
				"name": "西固区",
				"parent_id": 620100,
				"type": 4,
				"zip": "730060"
			}]
		}, {
			"id": 620200,
			"name": "嘉峪关市",
			"parent_id": 620000,
			"type": 3,
			"zip": "735100",
			"district": [{
				"id": 62020010,
				"name": "新城镇",
				"parent_id": 620200,
				"type": 4,
				"zip": ""
			}, {
				"id": 62020011,
				"name": "峪泉镇",
				"parent_id": 620200,
				"type": 4,
				"zip": ""
			}, {
				"id": 62020012,
				"name": "文殊镇",
				"parent_id": 620200,
				"type": 4,
				"zip": ""
			}, {
				"id": 62020013,
				"name": "雄关区",
				"parent_id": 620200,
				"type": 4,
				"zip": ""
			}, {
				"id": 62020014,
				"name": "镜铁区",
				"parent_id": 620200,
				"type": 4,
				"zip": ""
			}, {
				"id": 62020015,
				"name": "长城区",
				"parent_id": 620200,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 621000,
			"name": "庆阳市",
			"parent_id": 620000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 621026,
				"name": "宁县",
				"parent_id": 621000,
				"type": 4,
				"zip": "745200"
			}, {
				"id": 621027,
				"name": "镇原县",
				"parent_id": 621000,
				"type": 4,
				"zip": "744500"
			}, {
				"id": 621024,
				"name": "合水县",
				"parent_id": 621000,
				"type": 4,
				"zip": "745400"
			}, {
				"id": 621025,
				"name": "正宁县",
				"parent_id": 621000,
				"type": 4,
				"zip": "745300"
			}, {
				"id": 621028,
				"name": "其它区",
				"parent_id": 621000,
				"type": 4,
				"zip": ""
			}, {
				"id": 621021,
				"name": "庆城县",
				"parent_id": 621000,
				"type": 4,
				"zip": "745100"
			}, {
				"id": 621023,
				"name": "华池县",
				"parent_id": 621000,
				"type": 4,
				"zip": "745600"
			}, {
				"id": 621022,
				"name": "环县",
				"parent_id": 621000,
				"type": 4,
				"zip": "745700"
			}, {
				"id": 621002,
				"name": "西峰区",
				"parent_id": 621000,
				"type": 4,
				"zip": "745000"
			}]
		}, {
			"id": 620900,
			"name": "酒泉市",
			"parent_id": 620000,
			"type": 3,
			"zip": "735000",
			"district": [{
				"id": 620983,
				"name": "其它区",
				"parent_id": 620900,
				"type": 4,
				"zip": ""
			}, {
				"id": 620982,
				"name": "敦煌市",
				"parent_id": 620900,
				"type": 4,
				"zip": "736200"
			}, {
				"id": 620981,
				"name": "玉门市",
				"parent_id": 620900,
				"type": 4,
				"zip": "735200"
			}, {
				"id": 620922,
				"name": "瓜州县",
				"parent_id": 620900,
				"type": 4,
				"zip": "743000"
			}, {
				"id": 620923,
				"name": "肃北蒙古族自治县",
				"parent_id": 620900,
				"type": 4,
				"zip": "736300"
			}, {
				"id": 620921,
				"name": "金塔县",
				"parent_id": 620900,
				"type": 4,
				"zip": "735300"
			}, {
				"id": 620924,
				"name": "阿克塞哈萨克族自治县",
				"parent_id": 620900,
				"type": 4,
				"zip": "736400"
			}, {
				"id": 620902,
				"name": "肃州区",
				"parent_id": 620900,
				"type": 4,
				"zip": "735000"
			}]
		}, {
			"id": 620800,
			"name": "平凉市",
			"parent_id": 620000,
			"type": 3,
			"zip": "744000",
			"district": [{
				"id": 620824,
				"name": "华亭县",
				"parent_id": 620800,
				"type": 4,
				"zip": "744100"
			}, {
				"id": 620825,
				"name": "庄浪县",
				"parent_id": 620800,
				"type": 4,
				"zip": "744600"
			}, {
				"id": 620826,
				"name": "静宁县",
				"parent_id": 620800,
				"type": 4,
				"zip": "743400"
			}, {
				"id": 620827,
				"name": "其它区",
				"parent_id": 620800,
				"type": 4,
				"zip": ""
			}, {
				"id": 620821,
				"name": "泾川县",
				"parent_id": 620800,
				"type": 4,
				"zip": "744300"
			}, {
				"id": 620822,
				"name": "灵台县",
				"parent_id": 620800,
				"type": 4,
				"zip": "744400"
			}, {
				"id": 620823,
				"name": "崇信县",
				"parent_id": 620800,
				"type": 4,
				"zip": "744200"
			}, {
				"id": 620802,
				"name": "崆峒区",
				"parent_id": 620800,
				"type": 4,
				"zip": "744000"
			}]
		}, {
			"id": 620700,
			"name": "张掖市",
			"parent_id": 620000,
			"type": 3,
			"zip": "734000",
			"district": [{
				"id": 620725,
				"name": "山丹县",
				"parent_id": 620700,
				"type": 4,
				"zip": "734100"
			}, {
				"id": 620724,
				"name": "高台县",
				"parent_id": 620700,
				"type": 4,
				"zip": "734300"
			}, {
				"id": 620726,
				"name": "其它区",
				"parent_id": 620700,
				"type": 4,
				"zip": ""
			}, {
				"id": 620721,
				"name": "肃南裕固族自治县",
				"parent_id": 620700,
				"type": 4,
				"zip": "734400"
			}, {
				"id": 620723,
				"name": "临泽县",
				"parent_id": 620700,
				"type": 4,
				"zip": "734200"
			}, {
				"id": 620722,
				"name": "民乐县",
				"parent_id": 620700,
				"type": 4,
				"zip": "734500"
			}, {
				"id": 620702,
				"name": "甘州区",
				"parent_id": 620700,
				"type": 4,
				"zip": "734000"
			}]
		}, {
			"id": 620600,
			"name": "武威市",
			"parent_id": 620000,
			"type": 3,
			"zip": "733000",
			"district": [{
				"id": 620623,
				"name": "天祝藏族自治县",
				"parent_id": 620600,
				"type": 4,
				"zip": "733200"
			}, {
				"id": 620622,
				"name": "古浪县",
				"parent_id": 620600,
				"type": 4,
				"zip": "733100"
			}, {
				"id": 620621,
				"name": "民勤县",
				"parent_id": 620600,
				"type": 4,
				"zip": "733300"
			}, {
				"id": 620624,
				"name": "其它区",
				"parent_id": 620600,
				"type": 4,
				"zip": ""
			}, {
				"id": 620602,
				"name": "凉州区",
				"parent_id": 620600,
				"type": 4,
				"zip": "733000"
			}]
		}, {
			"id": 621200,
			"name": "陇南市",
			"parent_id": 620000,
			"type": 3,
			"zip": "",
			"district": [{
				"id": 621202,
				"name": "武都区",
				"parent_id": 621200,
				"type": 4,
				"zip": "746000"
			}, {
				"id": 621221,
				"name": "成县",
				"parent_id": 621200,
				"type": 4,
				"zip": "742500"
			}, {
				"id": 621222,
				"name": "文县",
				"parent_id": 621200,
				"type": 4,
				"zip": "746400"
			}, {
				"id": 621223,
				"name": "宕昌县",
				"parent_id": 621200,
				"type": 4,
				"zip": "748500"
			}, {
				"id": 621224,
				"name": "康县",
				"parent_id": 621200,
				"type": 4,
				"zip": "746500"
			}, {
				"id": 621225,
				"name": "西和县",
				"parent_id": 621200,
				"type": 4,
				"zip": "742100"
			}, {
				"id": 621226,
				"name": "礼县",
				"parent_id": 621200,
				"type": 4,
				"zip": "742200"
			}, {
				"id": 621227,
				"name": "徽县",
				"parent_id": 621200,
				"type": 4,
				"zip": "742300"
			}, {
				"id": 621228,
				"name": "两当县",
				"parent_id": 621200,
				"type": 4,
				"zip": "742400"
			}, {
				"id": 621229,
				"name": "其它区",
				"parent_id": 621200,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 621100,
			"name": "定西市",
			"parent_id": 620000,
			"type": 3,
			"zip": "743000",
			"district": [{
				"id": 621127,
				"name": "其它区",
				"parent_id": 621100,
				"type": 4,
				"zip": ""
			}, {
				"id": 621126,
				"name": "岷县",
				"parent_id": 621100,
				"type": 4,
				"zip": "748400"
			}, {
				"id": 621125,
				"name": "漳县",
				"parent_id": 621100,
				"type": 4,
				"zip": "748300"
			}, {
				"id": 621124,
				"name": "临洮县",
				"parent_id": 621100,
				"type": 4,
				"zip": "730500"
			}, {
				"id": 621123,
				"name": "渭源县",
				"parent_id": 621100,
				"type": 4,
				"zip": "748200"
			}, {
				"id": 621122,
				"name": "陇西县",
				"parent_id": 621100,
				"type": 4,
				"zip": "748100"
			}, {
				"id": 621121,
				"name": "通渭县",
				"parent_id": 621100,
				"type": 4,
				"zip": "743300"
			}, {
				"id": 621102,
				"name": "安定区",
				"parent_id": 621100,
				"type": 4,
				"zip": "743000"
			}]
		}]
	}, {
		"id": 370000,
		"name": "山东省",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 370100,
			"name": "济南市",
			"parent_id": 370000,
			"type": 3,
			"zip": "250000",
			"district": [{
				"id": 370124,
				"name": "平阴县",
				"parent_id": 370100,
				"type": 4,
				"zip": "250400"
			}, {
				"id": 370125,
				"name": "济阳县",
				"parent_id": 370100,
				"type": 4,
				"zip": "251400"
			}, {
				"id": 370126,
				"name": "商河县",
				"parent_id": 370100,
				"type": 4,
				"zip": "251600"
			}, {
				"id": 370112,
				"name": "历城区",
				"parent_id": 370100,
				"type": 4,
				"zip": "250100"
			}, {
				"id": 370113,
				"name": "长清区",
				"parent_id": 370100,
				"type": 4,
				"zip": "250300"
			}, {
				"id": 370105,
				"name": "天桥区",
				"parent_id": 370100,
				"type": 4,
				"zip": "250031"
			}, {
				"id": 370104,
				"name": "槐荫区",
				"parent_id": 370100,
				"type": 4,
				"zip": "250021"
			}, {
				"id": 370103,
				"name": "市中区",
				"parent_id": 370100,
				"type": 4,
				"zip": "250002"
			}, {
				"id": 370102,
				"name": "历下区",
				"parent_id": 370100,
				"type": 4,
				"zip": "250013"
			}, {
				"id": 370182,
				"name": "其它区",
				"parent_id": 370100,
				"type": 4,
				"zip": ""
			}, {
				"id": 370181,
				"name": "章丘市",
				"parent_id": 370100,
				"type": 4,
				"zip": "250200"
			}]
		}, {
			"id": 370500,
			"name": "东营市",
			"parent_id": 370000,
			"type": 3,
			"zip": "257000",
			"district": [{
				"id": 370503,
				"name": "河口区",
				"parent_id": 370500,
				"type": 4,
				"zip": "257200"
			}, {
				"id": 370502,
				"name": "东营区",
				"parent_id": 370500,
				"type": 4,
				"zip": "257029"
			}, {
				"id": 370521,
				"name": "垦利县",
				"parent_id": 370500,
				"type": 4,
				"zip": "257500"
			}, {
				"id": 370522,
				"name": "利津县",
				"parent_id": 370500,
				"type": 4,
				"zip": "257400"
			}, {
				"id": 370523,
				"name": "广饶县",
				"parent_id": 370500,
				"type": 4,
				"zip": "257300"
			}, {
				"id": 370589,
				"name": "西城区",
				"parent_id": 370500,
				"type": 4,
				"zip": ""
			}, {
				"id": 370591,
				"name": "其它区",
				"parent_id": 370500,
				"type": 4,
				"zip": ""
			}, {
				"id": 370590,
				"name": "东城区",
				"parent_id": 370500,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 370600,
			"name": "烟台市",
			"parent_id": 370000,
			"type": 3,
			"zip": "264000",
			"district": [{
				"id": 370687,
				"name": "海阳市",
				"parent_id": 370600,
				"type": 4,
				"zip": "265100"
			}, {
				"id": 370686,
				"name": "栖霞市",
				"parent_id": 370600,
				"type": 4,
				"zip": "265300"
			}, {
				"id": 370685,
				"name": "招远市",
				"parent_id": 370600,
				"type": 4,
				"zip": "265400"
			}, {
				"id": 370684,
				"name": "蓬莱市",
				"parent_id": 370600,
				"type": 4,
				"zip": "265600"
			}, {
				"id": 370683,
				"name": "莱州市",
				"parent_id": 370600,
				"type": 4,
				"zip": "261400"
			}, {
				"id": 370682,
				"name": "莱阳市",
				"parent_id": 370600,
				"type": 4,
				"zip": "265200"
			}, {
				"id": 370681,
				"name": "龙口市",
				"parent_id": 370600,
				"type": 4,
				"zip": "265700"
			}, {
				"id": 370634,
				"name": "长岛县",
				"parent_id": 370600,
				"type": 4,
				"zip": "265800"
			}, {
				"id": 370602,
				"name": "芝罘区",
				"parent_id": 370600,
				"type": 4,
				"zip": "264001"
			}, {
				"id": 370611,
				"name": "福山区",
				"parent_id": 370600,
				"type": 4,
				"zip": "265500"
			}, {
				"id": 370613,
				"name": "莱山区",
				"parent_id": 370600,
				"type": 4,
				"zip": "264600"
			}, {
				"id": 370612,
				"name": "牟平区",
				"parent_id": 370600,
				"type": 4,
				"zip": "264100"
			}, {
				"id": 370688,
				"name": "其它区",
				"parent_id": 370600,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 370300,
			"name": "淄博市",
			"parent_id": 370000,
			"type": 3,
			"zip": "255000",
			"district": [{
				"id": 370302,
				"name": "淄川区",
				"parent_id": 370300,
				"type": 4,
				"zip": "255100"
			}, {
				"id": 370303,
				"name": "张店区",
				"parent_id": 370300,
				"type": 4,
				"zip": "255022"
			}, {
				"id": 370323,
				"name": "沂源县",
				"parent_id": 370300,
				"type": 4,
				"zip": "256100"
			}, {
				"id": 370322,
				"name": "高青县",
				"parent_id": 370300,
				"type": 4,
				"zip": "256300"
			}, {
				"id": 370321,
				"name": "桓台县",
				"parent_id": 370300,
				"type": 4,
				"zip": "256400"
			}, {
				"id": 370324,
				"name": "其它区",
				"parent_id": 370300,
				"type": 4,
				"zip": ""
			}, {
				"id": 370306,
				"name": "周村区",
				"parent_id": 370300,
				"type": 4,
				"zip": "255300"
			}, {
				"id": 370304,
				"name": "博山区",
				"parent_id": 370300,
				"type": 4,
				"zip": "255200"
			}, {
				"id": 370305,
				"name": "临淄区",
				"parent_id": 370300,
				"type": 4,
				"zip": "255400"
			}]
		}, {
			"id": 370200,
			"name": "青岛市",
			"parent_id": 370000,
			"type": 3,
			"zip": "266000",
			"district": [{
				"id": 370285,
				"name": "莱西市",
				"parent_id": 370200,
				"type": 4,
				"zip": "266600"
			}, {
				"id": 370284,
				"name": "胶南市",
				"parent_id": 370200,
				"type": 4,
				"zip": "266400"
			}, {
				"id": 370286,
				"name": "其它区",
				"parent_id": 370200,
				"type": 4,
				"zip": ""
			}, {
				"id": 370281,
				"name": "胶州市",
				"parent_id": 370200,
				"type": 4,
				"zip": "266300"
			}, {
				"id": 370283,
				"name": "平度市",
				"parent_id": 370200,
				"type": 4,
				"zip": "266700"
			}, {
				"id": 370282,
				"name": "即墨市",
				"parent_id": 370200,
				"type": 4,
				"zip": "266200"
			}, {
				"id": 370251,
				"name": "开发区",
				"parent_id": 370200,
				"type": 4,
				"zip": ""
			}, {
				"id": 370211,
				"name": "黄岛区",
				"parent_id": 370200,
				"type": 4,
				"zip": "266500"
			}, {
				"id": 370213,
				"name": "李沧区",
				"parent_id": 370200,
				"type": 4,
				"zip": "266100"
			}, {
				"id": 370212,
				"name": "崂山区",
				"parent_id": 370200,
				"type": 4,
				"zip": "266100"
			}, {
				"id": 370214,
				"name": "城阳区",
				"parent_id": 370200,
				"type": 4,
				"zip": "266041"
			}, {
				"id": 370202,
				"name": "市南区",
				"parent_id": 370200,
				"type": 4,
				"zip": "266001"
			}, {
				"id": 370203,
				"name": "市北区",
				"parent_id": 370200,
				"type": 4,
				"zip": "266011"
			}, {
				"id": 370205,
				"name": "四方区",
				"parent_id": 370200,
				"type": 4,
				"zip": "266031"
			}]
		}, {
			"id": 370400,
			"name": "枣庄市",
			"parent_id": 370000,
			"type": 3,
			"zip": "277100",
			"district": [{
				"id": 370482,
				"name": "其它区",
				"parent_id": 370400,
				"type": 4,
				"zip": ""
			}, {
				"id": 370481,
				"name": "滕州市",
				"parent_id": 370400,
				"type": 4,
				"zip": "277500"
			}, {
				"id": 370404,
				"name": "峄城区",
				"parent_id": 370400,
				"type": 4,
				"zip": "277300"
			}, {
				"id": 370405,
				"name": "台儿庄区",
				"parent_id": 370400,
				"type": 4,
				"zip": "277400"
			}, {
				"id": 370406,
				"name": "山亭区",
				"parent_id": 370400,
				"type": 4,
				"zip": "277200"
			}, {
				"id": 370402,
				"name": "市中区",
				"parent_id": 370400,
				"type": 4,
				"zip": "277101"
			}, {
				"id": 370403,
				"name": "薛城区",
				"parent_id": 370400,
				"type": 4,
				"zip": "277000"
			}]
		}, {
			"id": 371100,
			"name": "日照市",
			"parent_id": 370000,
			"type": 3,
			"zip": "276800",
			"district": [{
				"id": 371103,
				"name": "岚山区",
				"parent_id": 371100,
				"type": 4,
				"zip": "276808"
			}, {
				"id": 371102,
				"name": "东港区",
				"parent_id": 371100,
				"type": 4,
				"zip": "276800"
			}, {
				"id": 371123,
				"name": "其它区",
				"parent_id": 371100,
				"type": 4,
				"zip": ""
			}, {
				"id": 371122,
				"name": "莒县",
				"parent_id": 371100,
				"type": 4,
				"zip": "276500"
			}, {
				"id": 371121,
				"name": "五莲县",
				"parent_id": 371100,
				"type": 4,
				"zip": "262300"
			}]
		}, {
			"id": 371000,
			"name": "威海市",
			"parent_id": 370000,
			"type": 3,
			"zip": "264200",
			"district": [{
				"id": 371084,
				"name": "其它区",
				"parent_id": 371000,
				"type": 4,
				"zip": ""
			}, {
				"id": 371081,
				"name": "文登市",
				"parent_id": 371000,
				"type": 4,
				"zip": "264400"
			}, {
				"id": 371082,
				"name": "荣成市",
				"parent_id": 371000,
				"type": 4,
				"zip": "264300"
			}, {
				"id": 371083,
				"name": "乳山市",
				"parent_id": 371000,
				"type": 4,
				"zip": "264500"
			}, {
				"id": 371002,
				"name": "环翠区",
				"parent_id": 371000,
				"type": 4,
				"zip": "264200"
			}]
		}, {
			"id": 370900,
			"name": "泰安市",
			"parent_id": 370000,
			"type": 3,
			"zip": "271000",
			"district": [{
				"id": 370984,
				"name": "其它区",
				"parent_id": 370900,
				"type": 4,
				"zip": ""
			}, {
				"id": 370983,
				"name": "肥城市",
				"parent_id": 370900,
				"type": 4,
				"zip": "271600"
			}, {
				"id": 370982,
				"name": "新泰市",
				"parent_id": 370900,
				"type": 4,
				"zip": "271200"
			}, {
				"id": 370903,
				"name": "岱岳区",
				"parent_id": 370900,
				"type": 4,
				"zip": "271000"
			}, {
				"id": 370902,
				"name": "泰山区",
				"parent_id": 370900,
				"type": 4,
				"zip": "271000"
			}, {
				"id": 370921,
				"name": "宁阳县",
				"parent_id": 370900,
				"type": 4,
				"zip": "271400"
			}, {
				"id": 370923,
				"name": "东平县",
				"parent_id": 370900,
				"type": 4,
				"zip": "271500"
			}]
		}, {
			"id": 370700,
			"name": "潍坊市",
			"parent_id": 370000,
			"type": 3,
			"zip": "261000",
			"district": [{
				"id": 370703,
				"name": "寒亭区",
				"parent_id": 370700,
				"type": 4,
				"zip": "261100"
			}, {
				"id": 370702,
				"name": "潍城区",
				"parent_id": 370700,
				"type": 4,
				"zip": "261021"
			}, {
				"id": 370704,
				"name": "坊子区",
				"parent_id": 370700,
				"type": 4,
				"zip": "261200"
			}, {
				"id": 370705,
				"name": "奎文区",
				"parent_id": 370700,
				"type": 4,
				"zip": "261041"
			}, {
				"id": 370725,
				"name": "昌乐县",
				"parent_id": 370700,
				"type": 4,
				"zip": "262400"
			}, {
				"id": 370724,
				"name": "临朐县",
				"parent_id": 370700,
				"type": 4,
				"zip": "262600"
			}, {
				"id": 370751,
				"name": "开发区",
				"parent_id": 370700,
				"type": 4,
				"zip": ""
			}, {
				"id": 370782,
				"name": "诸城市",
				"parent_id": 370700,
				"type": 4,
				"zip": "262200"
			}, {
				"id": 370783,
				"name": "寿光市",
				"parent_id": 370700,
				"type": 4,
				"zip": "262700"
			}, {
				"id": 370781,
				"name": "青州市",
				"parent_id": 370700,
				"type": 4,
				"zip": "262500"
			}, {
				"id": 370785,
				"name": "高密市",
				"parent_id": 370700,
				"type": 4,
				"zip": "261500"
			}, {
				"id": 370784,
				"name": "安丘市",
				"parent_id": 370700,
				"type": 4,
				"zip": "262100"
			}, {
				"id": 370787,
				"name": "其它区",
				"parent_id": 370700,
				"type": 4,
				"zip": ""
			}, {
				"id": 370786,
				"name": "昌邑市",
				"parent_id": 370700,
				"type": 4,
				"zip": "261300"
			}]
		}, {
			"id": 370800,
			"name": "济宁市",
			"parent_id": 370000,
			"type": 3,
			"zip": "272100",
			"district": [{
				"id": 370830,
				"name": "汶上县",
				"parent_id": 370800,
				"type": 4,
				"zip": "272501"
			}, {
				"id": 370831,
				"name": "泗水县",
				"parent_id": 370800,
				"type": 4,
				"zip": "273200"
			}, {
				"id": 370828,
				"name": "金乡县",
				"parent_id": 370800,
				"type": 4,
				"zip": "272200"
			}, {
				"id": 370829,
				"name": "嘉祥县",
				"parent_id": 370800,
				"type": 4,
				"zip": "272400"
			}, {
				"id": 370826,
				"name": "微山县",
				"parent_id": 370800,
				"type": 4,
				"zip": "277600"
			}, {
				"id": 370827,
				"name": "鱼台县",
				"parent_id": 370800,
				"type": 4,
				"zip": "272300"
			}, {
				"id": 370832,
				"name": "梁山县",
				"parent_id": 370800,
				"type": 4,
				"zip": "272600"
			}, {
				"id": 370882,
				"name": "兖州市",
				"parent_id": 370800,
				"type": 4,
				"zip": "272000"
			}, {
				"id": 370883,
				"name": "邹城市",
				"parent_id": 370800,
				"type": 4,
				"zip": "273500"
			}, {
				"id": 370881,
				"name": "曲阜市",
				"parent_id": 370800,
				"type": 4,
				"zip": "273100"
			}, {
				"id": 370884,
				"name": "其它区",
				"parent_id": 370800,
				"type": 4,
				"zip": ""
			}, {
				"id": 370811,
				"name": "任城区",
				"parent_id": 370800,
				"type": 4,
				"zip": "272113"
			}, {
				"id": 370802,
				"name": "市中区",
				"parent_id": 370800,
				"type": 4,
				"zip": "272133"
			}]
		}, {
			"id": 371600,
			"name": "滨州市",
			"parent_id": 370000,
			"type": 3,
			"zip": "256600",
			"district": [{
				"id": 371622,
				"name": "阳信县",
				"parent_id": 371600,
				"type": 4,
				"zip": "251800"
			}, {
				"id": 371623,
				"name": "无棣县",
				"parent_id": 371600,
				"type": 4,
				"zip": "251900"
			}, {
				"id": 371621,
				"name": "惠民县",
				"parent_id": 371600,
				"type": 4,
				"zip": "257100"
			}, {
				"id": 371626,
				"name": "邹平县",
				"parent_id": 371600,
				"type": 4,
				"zip": "256200"
			}, {
				"id": 371627,
				"name": "其它区",
				"parent_id": 371600,
				"type": 4,
				"zip": ""
			}, {
				"id": 371624,
				"name": "沾化县",
				"parent_id": 371600,
				"type": 4,
				"zip": "256800"
			}, {
				"id": 371625,
				"name": "博兴县",
				"parent_id": 371600,
				"type": 4,
				"zip": "256500"
			}, {
				"id": 371602,
				"name": "滨城区",
				"parent_id": 371600,
				"type": 4,
				"zip": "256600"
			}]
		}, {
			"id": 371700,
			"name": "菏泽市",
			"parent_id": 370000,
			"type": 3,
			"zip": "274000",
			"district": [{
				"id": 371702,
				"name": "牡丹区",
				"parent_id": 371700,
				"type": 4,
				"zip": "274009"
			}, {
				"id": 371727,
				"name": "定陶县",
				"parent_id": 371700,
				"type": 4,
				"zip": "274100"
			}, {
				"id": 371726,
				"name": "鄄城县",
				"parent_id": 371700,
				"type": 4,
				"zip": "274600"
			}, {
				"id": 371725,
				"name": "郓城县",
				"parent_id": 371700,
				"type": 4,
				"zip": "274700"
			}, {
				"id": 371724,
				"name": "巨野县",
				"parent_id": 371700,
				"type": 4,
				"zip": "274900"
			}, {
				"id": 371723,
				"name": "成武县",
				"parent_id": 371700,
				"type": 4,
				"zip": "274200"
			}, {
				"id": 371722,
				"name": "单县",
				"parent_id": 371700,
				"type": 4,
				"zip": "274300"
			}, {
				"id": 371721,
				"name": "曹县",
				"parent_id": 371700,
				"type": 4,
				"zip": "274400"
			}, {
				"id": 371728,
				"name": "东明县",
				"parent_id": 371700,
				"type": 4,
				"zip": "274500"
			}, {
				"id": 371729,
				"name": "其它区",
				"parent_id": 371700,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 371500,
			"name": "聊城市",
			"parent_id": 370000,
			"type": 3,
			"zip": "252000",
			"district": [{
				"id": 371502,
				"name": "东昌府区",
				"parent_id": 371500,
				"type": 4,
				"zip": "252000"
			}, {
				"id": 371582,
				"name": "其它区",
				"parent_id": 371500,
				"type": 4,
				"zip": ""
			}, {
				"id": 371581,
				"name": "临清市",
				"parent_id": 371500,
				"type": 4,
				"zip": "252600"
			}, {
				"id": 371525,
				"name": "冠县",
				"parent_id": 371500,
				"type": 4,
				"zip": "252500"
			}, {
				"id": 371524,
				"name": "东阿县",
				"parent_id": 371500,
				"type": 4,
				"zip": "252200"
			}, {
				"id": 371526,
				"name": "高唐县",
				"parent_id": 371500,
				"type": 4,
				"zip": "252800"
			}, {
				"id": 371521,
				"name": "阳谷县",
				"parent_id": 371500,
				"type": 4,
				"zip": "252300"
			}, {
				"id": 371523,
				"name": "茌平县",
				"parent_id": 371500,
				"type": 4,
				"zip": "252100"
			}, {
				"id": 371522,
				"name": "莘县",
				"parent_id": 371500,
				"type": 4,
				"zip": "252400"
			}]
		}, {
			"id": 371400,
			"name": "德州市",
			"parent_id": 370000,
			"type": 3,
			"zip": "253000",
			"district": [{
				"id": 371481,
				"name": "乐陵市",
				"parent_id": 371400,
				"type": 4,
				"zip": "253600"
			}, {
				"id": 371482,
				"name": "禹城市",
				"parent_id": 371400,
				"type": 4,
				"zip": "251200"
			}, {
				"id": 371483,
				"name": "其它区",
				"parent_id": 371400,
				"type": 4,
				"zip": ""
			}, {
				"id": 371428,
				"name": "武城县",
				"parent_id": 371400,
				"type": 4,
				"zip": "253300"
			}, {
				"id": 371424,
				"name": "临邑县",
				"parent_id": 371400,
				"type": 4,
				"zip": "251500"
			}, {
				"id": 371425,
				"name": "齐河县",
				"parent_id": 371400,
				"type": 4,
				"zip": "251100"
			}, {
				"id": 371426,
				"name": "平原县",
				"parent_id": 371400,
				"type": 4,
				"zip": "253121"
			}, {
				"id": 371427,
				"name": "夏津县",
				"parent_id": 371400,
				"type": 4,
				"zip": "253200"
			}, {
				"id": 371451,
				"name": "开发区",
				"parent_id": 371400,
				"type": 4,
				"zip": ""
			}, {
				"id": 371402,
				"name": "德城区",
				"parent_id": 371400,
				"type": 4,
				"zip": "253011"
			}, {
				"id": 371423,
				"name": "庆云县",
				"parent_id": 371400,
				"type": 4,
				"zip": "253700"
			}, {
				"id": 371422,
				"name": "宁津县",
				"parent_id": 371400,
				"type": 4,
				"zip": "253400"
			}, {
				"id": 371421,
				"name": "陵县",
				"parent_id": 371400,
				"type": 4,
				"zip": "253500"
			}]
		}, {
			"id": 371200,
			"name": "莱芜市",
			"parent_id": 370000,
			"type": 3,
			"zip": "271100",
			"district": [{
				"id": 371203,
				"name": "钢城区",
				"parent_id": 371200,
				"type": 4,
				"zip": "271100"
			}, {
				"id": 371202,
				"name": "莱城区",
				"parent_id": 371200,
				"type": 4,
				"zip": "271100"
			}, {
				"id": 371204,
				"name": "其它区",
				"parent_id": 371200,
				"type": 4,
				"zip": ""
			}]
		}, {
			"id": 371300,
			"name": "临沂市",
			"parent_id": 370000,
			"type": 3,
			"zip": "276000",
			"district": [{
				"id": 371330,
				"name": "其它区",
				"parent_id": 371300,
				"type": 4,
				"zip": ""
			}, {
				"id": 371328,
				"name": "蒙阴县",
				"parent_id": 371300,
				"type": 4,
				"zip": "276200"
			}, {
				"id": 371329,
				"name": "临沭县",
				"parent_id": 371300,
				"type": 4,
				"zip": "276700"
			}, {
				"id": 371311,
				"name": "罗庄区",
				"parent_id": 371300,
				"type": 4,
				"zip": "276022"
			}, {
				"id": 371302,
				"name": "兰山区",
				"parent_id": 371300,
				"type": 4,
				"zip": "276002"
			}, {
				"id": 371324,
				"name": "苍山县",
				"parent_id": 371300,
				"type": 4,
				"zip": "277700"
			}, {
				"id": 371325,
				"name": "费县",
				"parent_id": 371300,
				"type": 4,
				"zip": "273400"
			}, {
				"id": 371326,
				"name": "平邑县",
				"parent_id": 371300,
				"type": 4,
				"zip": "273300"
			}, {
				"id": 371327,
				"name": "莒南县",
				"parent_id": 371300,
				"type": 4,
				"zip": "276600"
			}, {
				"id": 371321,
				"name": "沂南县",
				"parent_id": 371300,
				"type": 4,
				"zip": "276300"
			}, {
				"id": 371322,
				"name": "郯城县",
				"parent_id": 371300,
				"type": 4,
				"zip": "276100"
			}, {
				"id": 371323,
				"name": "沂水县",
				"parent_id": 371300,
				"type": 4,
				"zip": "276400"
			}, {
				"id": 371312,
				"name": "河东区",
				"parent_id": 371300,
				"type": 4,
				"zip": "276034"
			}]
		}]
	}, {
		"id": 990000,
		"name": "海外",
		"parent_id": 1,
		"type": 2,
		"zip": ""
	}, {
		"id": 310000,
		"name": "上海",
		"parent_id": 1,
		"type": 2,
		"zip": "",
		"city": [{
			"id": 310100,
			"name": "上海市",
			"parent_id": 310000,
			"type": 3,
			"zip": "200000",
			"district": [{
				"id": 310152,
				"name": "川沙区",
				"parent_id": 310100,
				"type": 4,
				"zip": ""
			}, {
				"id": 310231,
				"name": "其它区",
				"parent_id": 310100,
				"type": 4,
				"zip": ""
			}, {
				"id": 310230,
				"name": "崇明县",
				"parent_id": 310100,
				"type": 4,
				"zip": "202150"
			}, {
				"id": 310108,
				"name": "闸北区",
				"parent_id": 310100,
				"type": 4,
				"zip": "200070"
			}, {
				"id": 310109,
				"name": "虹口区",
				"parent_id": 310100,
				"type": 4,
				"zip": "200080"
			}, {
				"id": 310110,
				"name": "杨浦区",
				"parent_id": 310100,
				"type": 4,
				"zip": "200082"
			}, {
				"id": 310104,
				"name": "徐汇区",
				"parent_id": 310100,
				"type": 4,
				"zip": "200030"
			}, {
				"id": 310105,
				"name": "长宁区",
				"parent_id": 310100,
				"type": 4,
				"zip": "200050"
			}, {
				"id": 310106,
				"name": "静安区",
				"parent_id": 310100,
				"type": 4,
				"zip": "200040"
			}, {
				"id": 310107,
				"name": "普陀区",
				"parent_id": 310100,
				"type": 4,
				"zip": "200062"
			}, {
				"id": 310101,
				"name": "黄浦区",
				"parent_id": 310100,
				"type": 4,
				"zip": "200001"
			}, {
				"id": 310103,
				"name": "卢湾区",
				"parent_id": 310100,
				"type": 4,
				"zip": "200020"
			}, {
				"id": 310120,
				"name": "奉贤区",
				"parent_id": 310100,
				"type": 4,
				"zip": "201400"
			}, {
				"id": 310119,
				"name": "南汇区",
				"parent_id": 310100,
				"type": 4,
				"zip": "201300"
			}, {
				"id": 310118,
				"name": "青浦区",
				"parent_id": 310100,
				"type": 4,
				"zip": "201700"
			}, {
				"id": 310117,
				"name": "松江区",
				"parent_id": 310100,
				"type": 4,
				"zip": "201600"
			}, {
				"id": 310116,
				"name": "金山区",
				"parent_id": 310100,
				"type": 4,
				"zip": "201540"
			}, {
				"id": 310115,
				"name": "浦东新区",
				"parent_id": 310100,
				"type": 4,
				"zip": "200120"
			}, {
				"id": 310114,
				"name": "嘉定区",
				"parent_id": 310100,
				"type": 4,
				"zip": "201800"
			}, {
				"id": 310113,
				"name": "宝山区",
				"parent_id": 310100,
				"type": 4,
				"zip": "201900"
			}, {
				"id": 310112,
				"name": "闵行区",
				"parent_id": 310100,
				"type": 4,
				"zip": "201100"
			}]
		}]
	}]
		
	var iScroll;
	if(typeof(IScroll) == "undefined") { // 检测 iScroll 是否存在
		iScroll = $.AMUI.iScroll;
	} else {
		iScroll = IScroll;
	}

	// 构造函数
	function address(elm, options) {
		var self = this;
		self.$element = elm;
		self.options = options;

		// 初始化
		self._ready();

		// 带底部参数
		if(self.options.footer) {
			var $cancelBtn = self.$popup.find('.am-address-cancel');
			var $confirmBtn = self.$popup.find('.am-address-confirm');
			$confirmBtn.on('click', function() {
				self._selectEnd();
				return false;
			});
			$cancelBtn.on('click', function() {
				self.$popup.modal("close");
				return false;
			});
		}

		// 窗口被打开
		self.$popup.on('open.modal.amui', function() {
			self._readyProv();
		});

		// 窗口关闭
		self.$popup.on('close.modal.amui', function() {
			var selectProv = self.$prov.find("li.am-active").text();
			if(selectProv != self.options.prov) {
				self.$prov.find("li:contains(" + self.options.prov + ")").addClass("am-active").siblings().removeClass("am-active");
			}
		});

		// 是否自动打开
		if(self.options.autoOpen) {
			self.$popup.modal("open");
		}

		self.$element.on("click", function() {
			self.$popup.modal("open");
		});

		// 给 element 对象绑定选择窗口的id
		self.$element.data("address-popup", self.$popup.attr("id"));
	}

	// 渲染选项列表
	address._readyList = function(json, selectedAddress) {
		var index = 0;
		var html = [];
		$.each(json, function(i, v) {
			// 循环第一个值时，如果没有默认选择值就添加 active
			if(i == 0 && !selectedAddress) {
				html.push('<li class="am-active">' + v.name + '</li>');
				index = i;
				return;
			}
			if(selectedAddress && v.name === selectedAddress) {
				html.push('<li class="am-active">' + v.name + '</li>');
				index = i;
			} else {
				html.push('<li>' + v.name + '</li>');
			}
		});
		return {
			list: html.join(''),
			index: index
		};
	}

	// 渲染选择窗口
	address.prototype._ready = function() {
		var self = this;
		var html = [];
		html.push('<div class="am-popup am-address-popup" id="' + Math.ceil(Math.random() * (new Date).getTime()) + '">');
		html.push('<div class="am-popup-inner">');
		html.push('<div class="am-popup-hd">');
		html.push('<h4 class="am-popup-title">' + self.options.title + '</h4>');
		html.push('<span data-am-modal-close class="am-close">&times;</span>');
		html.push('</div>');
		html.push('<div class="am-popup-bd">');
		if(self.options.footer) {
			html.push('<div class="am-address-list am-address-list-footer">');
		} else {
			html.push('<div class="am-address-list">');
		}
		html.push('<div class="am-u-sm-4 am-address-prov"><ul class="am-list am-list-static"></div>');
		html.push('<div class="am-u-sm-4 am-address-city"><ul class="am-list am-list-static"></div>');
		html.push('<div class="am-u-sm-4 am-address-district"><ul class="am-list am-list-static"></div>');
		html.push('</div>');

		if(self.options.footer) {
			html.push('<div class="am-modal-footer am-address-footer">');
			html.push('<span class="am-modal-btn am-address-cancel">取消</span>');
			html.push('<span class="am-modal-btn am-address-confirm">确定</span>');
			html.push('</div>');
		}
		html.push('</div>');
		html.push('</div>');
		html.push('</div>');
		self.$popup = $(html.join('')).appendTo('body');

		self.$prov = self.$popup.find('div.am-address-prov');
		self.$city = self.$popup.find('div.am-address-city');
		self.$district = self.$popup.find('div.am-address-district');

		// 初始化数据
		self._readyProv("create");

		// 判断是否需要添加市级或县级栏
		if(self.options.selectNumber == 1) {
			self.$popup.find("div.am-address-list>div").removeClass("am-u-sm-4").addClass("am-u-sm-12");
		} else {
			self._readyCity("create");
		}
		if(self.options.selectNumber == 2) {
			self.$popup.find("div.am-address-list>div").removeClass("am-u-sm-4").addClass("am-u-sm-6");
		} else {
			self._readyDistrict("create");
		}
	}

	// 函数 _readyxxx 的参数 methods="create" 表示新建 否则负责刷新 IScroll 
	// {渲染,刷新} 省级数据
	address.prototype._readyProv = function(methods) {
		var self = this;
		if(methods == "create") {
			var prov = address._readyList(addressJson, self.options.prov);
			self.$prov.children("ul").html(prov.list).data("address-active", prov.index);
			if(!prov.index) {
				self.$prov.find("li:eq(0)").addClass("am-active").siblings("li").removeClass("am-active");
			}

			self.provIscroll = new iScroll(self.$prov[0], {
				tap: "addressTap",
				mouseWheel: true
			});

			// 点击事件
			self.$prov.on("addressTap", "li", function() {
				var $this = $(this);
				if($this.hasClass("am-active")) {
					return false;
				}
				$this.addClass("am-active").siblings("li").removeClass("am-active");
				if(self.options.selectNumber != 1) {
					self._readyCity(null, "tap");
				} else {
					self._selectEnd();
				}
				self.$element.trigger("provTap", [$this]);
			});
		} else {
			if(self.options.selectNumber != 1) {
				self._readyCity();
			}
			self.provIscroll.refresh();
			self.provIscroll.scrollToElement(self.$prov.find("li.am-active")[0], null, null, self.options.scrollToCenter);
		}
	}

	// {渲染,刷新} 市级数据
	address.prototype._readyCity = function(methods, onEvent) {
		var self = this;
		if(methods == "create") {
			self.cityIscroll = new iScroll(self.$city[0], {
				tap: "addressTap",
				mouseWheel: true
			});
			self.$city.on("addressTap", "li", function() {
				var $this = $(this);
				if($this.hasClass("am-active")) {
					return false;
				}
				$this.addClass("am-active").siblings("li").removeClass("am-active");
				if(self.options.selectNumber != 2) {
					self._readyDistrict(null, "tap");
				} else {
					self._selectEnd();
				}
				self.$element.trigger("cityTap", [$this]);
			});
		} else {
			var provIndex = self.$prov.find(".am-active").index();
			var city = address._readyList(addressJson[provIndex].city, self.options.city);
			self.$city.children("ul").html(city.list).data("address-active", city.index);
			if(!city.index) { // 没有默认选中项
				self.$city.find("li:eq(0)").addClass("am-active").siblings("li").removeClass("am-active");
			}
			// 触发省级 tap 事件时，如果市级只要一个并且是省市级联时，触发选择完毕函数
			if(onEvent === "tap" && addressJson[provIndex].city.length <= 1 && self.options.selectNumber == 2) {
				self._selectEnd();
			}

			self.cityIscroll.refresh();
			self.cityIscroll.scrollToElement(self.$city.find("li.am-active")[0], null, null, self.options.scrollToCenter);

			if(self.options.selectNumber != 2) {
				self._readyDistrict();
			}
		}
	}

	// {渲染,刷新} 县级 数据
	address.prototype._readyDistrict = function(methods, onEvent) {
		var self = this;
		if(methods == "create") {
			self.districtIscroll = new iScroll(self.$district[0], {
				tap: "addressTap",
				mouseWheel: true
			});

			// 点击事件
			self.$district.on("addressTap", "li", function() {
				var $this = $(this);
				$this.addClass("am-active").siblings("li").removeClass("am-active");
				self._selectEnd();
			});
		} else {
			var provIndex = self.$prov.find(".am-active").index();
			var cityIndex = self.$city.find(".am-active").index();
			var districtJson = addressJson[provIndex].city[cityIndex].district;
			if(districtJson.length <= 0) { // 如果县级数据不存在，设置为空
				self.$district.children("ul").html("");
				if(onEvent == "tap") {
					self._selectEnd();
				}
				return;
			}

			var district = address._readyList(districtJson, self.options.district);

			self.$district.children("ul").html(district.list).data("address-active", district.index);
			if(!district.index) {
				self.$district.find("li:eq(0)").addClass("am-active").siblings("li").removeClass("am-active");
			}
			self.districtIscroll.refresh();
			self.districtIscroll.scrollToElement(self.$district.find("li.am-active")[0], null, null, self.options.scrollToCenter);
		}
	}

	// 选择完毕
	address.prototype._selectEnd = function() {
		var self = this;
		// 获取已选省级数据
		var provIndex = self.$prov.find("li.am-active").index();
		var provJson = addressJson[provIndex];

		var sJson = {
			prov: provJson.name,
			city: "",
			district: ""
		}

		if(self.options.selectNumber != 1) { // selectNumber = 1 表示只选省级 
			var cityIndex = self.$city.find("li.am-active").index();
			var cityJson = addressJson[provIndex].city[cityIndex];
			sJson.city = cityJson.name;
			// 判断是否有 县区 级数据
			if(cityJson.district.length && self.options.selectNumber != 2) { // selectNumber = 2 表示只选省市级
				var districtIndex = self.$district.find("li.am-active").index();
				var districtJson = addressJson[provIndex].city[cityIndex].district[districtIndex];
				sJson.district = districtJson.name;
			}
		}

		self.options = $.extend(true, self.options, sJson); // 合并参数,下次打开选择窗口时，需读取 options 数据进行定位

		// 自动填充
		if(!self.options.customOutput) {
			self.$element.find("input").val(sJson.prov + sJson.city + sJson.district);
		}

		// 选取完毕回调
		if($.isFunction(self.options.selectEnd)) {
			self.options.selectEnd(sJson, self);
		}
		this.$popup.modal("close");
	}

	$.fn.address = function(options) {
		var opt = $.extend(true, {
			title: "请选择地址",
			prov: "北京",
			city: "北京市",
			district: "东城区",
			selectNumber: 0,
			scrollToCenter: false,
			autoOpen: false,
			customOutput: false,
			selectEnd: false,
		}, options);
		new address(this, opt);
		return this;
	}

	$.AMUI.ready(function(doc) {
		$('[data-am-address]', doc).each(function() {
			var $this = $(this);
			var options = $.AMUI.utils.parseOptions($this.attr('data-am-address') || $this.data("am-address"));
			$this.address(options);
		});
	});

	return $;
}));